#include <tree_sitter/parser.h>

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 13
#define STATE_COUNT 1108
#define LARGE_STATE_COUNT 101
#define SYMBOL_COUNT 230
#define ALIAS_COUNT 0
#define TOKEN_COUNT 103
#define EXTERNAL_TOKEN_COUNT 6
#define FIELD_COUNT 26
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define PRODUCTION_ID_COUNT 96

enum {
  sym_identifier = 1,
  anon_sym_SEMI = 2,
  anon_sym_import = 3,
  anon_sym_DOT = 4,
  anon_sym_from = 5,
  anon_sym___future__ = 6,
  anon_sym_LPAREN = 7,
  anon_sym_RPAREN = 8,
  anon_sym_COMMA = 9,
  anon_sym_as = 10,
  anon_sym_STAR = 11,
  anon_sym_print = 12,
  anon_sym_GT_GT = 13,
  anon_sym_assert = 14,
  anon_sym_COLON_EQ = 15,
  anon_sym_return = 16,
  anon_sym_del = 17,
  anon_sym_raise = 18,
  anon_sym_pass = 19,
  anon_sym_break = 20,
  anon_sym_continue = 21,
  anon_sym_if = 22,
  anon_sym_COLON = 23,
  anon_sym_elif = 24,
  anon_sym_else = 25,
  anon_sym_async = 26,
  anon_sym_for = 27,
  anon_sym_in = 28,
  anon_sym_while = 29,
  anon_sym_try = 30,
  anon_sym_except = 31,
  anon_sym_finally = 32,
  anon_sym_with = 33,
  anon_sym_def = 34,
  anon_sym_DASH_GT = 35,
  anon_sym_STAR_STAR = 36,
  anon_sym_global = 37,
  anon_sym_nonlocal = 38,
  anon_sym_exec = 39,
  anon_sym_class = 40,
  anon_sym_AT = 41,
  anon_sym_LBRACK = 42,
  anon_sym_RBRACK = 43,
  anon_sym_EQ = 44,
  anon_sym_not = 45,
  anon_sym_and = 46,
  anon_sym_or = 47,
  anon_sym_PLUS = 48,
  anon_sym_DASH = 49,
  anon_sym_SLASH = 50,
  anon_sym_PERCENT = 51,
  anon_sym_SLASH_SLASH = 52,
  anon_sym_PIPE = 53,
  anon_sym_AMP = 54,
  anon_sym_CARET = 55,
  anon_sym_LT_LT = 56,
  anon_sym_TILDE = 57,
  anon_sym_LT = 58,
  anon_sym_LT_EQ = 59,
  anon_sym_EQ_EQ = 60,
  anon_sym_BANG_EQ = 61,
  anon_sym_GT_EQ = 62,
  anon_sym_GT = 63,
  anon_sym_LT_GT = 64,
  anon_sym_is = 65,
  anon_sym_lambda = 66,
  anon_sym_PLUS_EQ = 67,
  anon_sym_DASH_EQ = 68,
  anon_sym_STAR_EQ = 69,
  anon_sym_SLASH_EQ = 70,
  anon_sym_AT_EQ = 71,
  anon_sym_SLASH_SLASH_EQ = 72,
  anon_sym_PERCENT_EQ = 73,
  anon_sym_STAR_STAR_EQ = 74,
  anon_sym_GT_GT_EQ = 75,
  anon_sym_LT_LT_EQ = 76,
  anon_sym_AMP_EQ = 77,
  anon_sym_CARET_EQ = 78,
  anon_sym_PIPE_EQ = 79,
  anon_sym_yield = 80,
  sym_ellipsis = 81,
  anon_sym_LBRACE = 82,
  anon_sym_RBRACE = 83,
  anon_sym_LBRACE_LBRACE = 84,
  anon_sym_RBRACE_RBRACE = 85,
  sym_escape_sequence = 86,
  sym__not_escape_sequence = 87,
  aux_sym_format_specifier_token1 = 88,
  sym_type_conversion = 89,
  sym_integer = 90,
  sym_float = 91,
  anon_sym_await = 92,
  sym_true = 93,
  sym_false = 94,
  sym_none = 95,
  sym_comment = 96,
  sym__newline = 97,
  sym__indent = 98,
  sym__dedent = 99,
  sym__string_start = 100,
  sym__string_content = 101,
  sym__string_end = 102,
  sym_module = 103,
  sym__statement = 104,
  sym__simple_statements = 105,
  sym_import_statement = 106,
  sym_import_prefix = 107,
  sym_relative_import = 108,
  sym_future_import_statement = 109,
  sym_import_from_statement = 110,
  sym__import_list = 111,
  sym_aliased_import = 112,
  sym_wildcard_import = 113,
  sym_print_statement = 114,
  sym_chevron = 115,
  sym_assert_statement = 116,
  sym_expression_statement = 117,
  sym_named_expression = 118,
  sym_return_statement = 119,
  sym_delete_statement = 120,
  sym_raise_statement = 121,
  sym_pass_statement = 122,
  sym_break_statement = 123,
  sym_continue_statement = 124,
  sym_if_statement = 125,
  sym_elif_clause = 126,
  sym_else_clause = 127,
  sym_for_statement = 128,
  sym_while_statement = 129,
  sym_try_statement = 130,
  sym_except_clause = 131,
  sym_finally_clause = 132,
  sym_with_statement = 133,
  sym_with_clause = 134,
  sym_with_item = 135,
  sym_function_definition = 136,
  sym_parameters = 137,
  sym_lambda_parameters = 138,
  sym_list_splat = 139,
  sym_dictionary_splat = 140,
  sym_global_statement = 141,
  sym_nonlocal_statement = 142,
  sym_exec_statement = 143,
  sym_class_definition = 144,
  sym_parenthesized_list_splat = 145,
  sym_argument_list = 146,
  sym_decorated_definition = 147,
  sym_decorator = 148,
  sym_block = 149,
  sym_expression_list = 150,
  sym_dotted_name = 151,
  sym__parameters = 152,
  sym__patterns = 153,
  sym_parameter = 154,
  sym_pattern = 155,
  sym_tuple_pattern = 156,
  sym_list_pattern = 157,
  sym_default_parameter = 158,
  sym_typed_default_parameter = 159,
  sym_list_splat_pattern = 160,
  sym_dictionary_splat_pattern = 161,
  sym__expression_within_for_in_clause = 162,
  sym_expression = 163,
  sym_primary_expression = 164,
  sym_not_operator = 165,
  sym_boolean_operator = 166,
  sym_binary_operator = 167,
  sym_unary_operator = 168,
  sym_comparison_operator = 169,
  sym_lambda = 170,
  sym_lambda_within_for_in_clause = 171,
  sym_assignment = 172,
  sym_augmented_assignment = 173,
  sym_pattern_list = 174,
  sym__right_hand_side = 175,
  sym_yield = 176,
  sym_attribute = 177,
  sym_subscript = 178,
  sym_slice = 179,
  sym_call = 180,
  sym_typed_parameter = 181,
  sym_type = 182,
  sym_keyword_argument = 183,
  sym_list = 184,
  sym_set = 185,
  sym_tuple = 186,
  sym_dictionary = 187,
  sym_pair = 188,
  sym_list_comprehension = 189,
  sym_dictionary_comprehension = 190,
  sym_set_comprehension = 191,
  sym_generator_expression = 192,
  sym__comprehension_clauses = 193,
  sym_parenthesized_expression = 194,
  sym__collection_elements = 195,
  sym_for_in_clause = 196,
  sym_if_clause = 197,
  sym_conditional_expression = 198,
  sym_concatenated_string = 199,
  sym_string = 200,
  sym_interpolation = 201,
  sym__escape_interpolation = 202,
  sym_format_specifier = 203,
  sym_format_expression = 204,
  sym_await = 205,
  aux_sym_module_repeat1 = 206,
  aux_sym__simple_statements_repeat1 = 207,
  aux_sym_import_prefix_repeat1 = 208,
  aux_sym__import_list_repeat1 = 209,
  aux_sym_print_statement_repeat1 = 210,
  aux_sym_assert_statement_repeat1 = 211,
  aux_sym_if_statement_repeat1 = 212,
  aux_sym_try_statement_repeat1 = 213,
  aux_sym_with_clause_repeat1 = 214,
  aux_sym_global_statement_repeat1 = 215,
  aux_sym_argument_list_repeat1 = 216,
  aux_sym_decorated_definition_repeat1 = 217,
  aux_sym_dotted_name_repeat1 = 218,
  aux_sym__parameters_repeat1 = 219,
  aux_sym__patterns_repeat1 = 220,
  aux_sym_comparison_operator_repeat1 = 221,
  aux_sym_subscript_repeat1 = 222,
  aux_sym_dictionary_repeat1 = 223,
  aux_sym__comprehension_clauses_repeat1 = 224,
  aux_sym__collection_elements_repeat1 = 225,
  aux_sym_for_in_clause_repeat1 = 226,
  aux_sym_concatenated_string_repeat1 = 227,
  aux_sym_string_repeat1 = 228,
  aux_sym_format_specifier_repeat1 = 229,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_SEMI] = ";",
  [anon_sym_import] = "import",
  [anon_sym_DOT] = ".",
  [anon_sym_from] = "from",
  [anon_sym___future__] = "__future__",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_COMMA] = ",",
  [anon_sym_as] = "as",
  [anon_sym_STAR] = "*",
  [anon_sym_print] = "print",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_assert] = "assert",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_return] = "return",
  [anon_sym_del] = "del",
  [anon_sym_raise] = "raise",
  [anon_sym_pass] = "pass",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [anon_sym_if] = "if",
  [anon_sym_COLON] = ":",
  [anon_sym_elif] = "elif",
  [anon_sym_else] = "else",
  [anon_sym_async] = "async",
  [anon_sym_for] = "for",
  [anon_sym_in] = "in",
  [anon_sym_while] = "while",
  [anon_sym_try] = "try",
  [anon_sym_except] = "except",
  [anon_sym_finally] = "finally",
  [anon_sym_with] = "with",
  [anon_sym_def] = "def",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_STAR_STAR] = "**",
  [anon_sym_global] = "global",
  [anon_sym_nonlocal] = "nonlocal",
  [anon_sym_exec] = "exec",
  [anon_sym_class] = "class",
  [anon_sym_AT] = "@",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_EQ] = "=",
  [anon_sym_not] = "not",
  [anon_sym_and] = "and",
  [anon_sym_or] = "or",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_SLASH_SLASH] = "//",
  [anon_sym_PIPE] = "|",
  [anon_sym_AMP] = "&",
  [anon_sym_CARET] = "^",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_TILDE] = "~",
  [anon_sym_LT] = "<",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_GT] = ">",
  [anon_sym_LT_GT] = "<>",
  [anon_sym_is] = "is",
  [anon_sym_lambda] = "lambda",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_AT_EQ] = "@=",
  [anon_sym_SLASH_SLASH_EQ] = "//=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_STAR_STAR_EQ] = "**=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_yield] = "yield",
  [sym_ellipsis] = "ellipsis",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_LBRACE_LBRACE] = "{{",
  [anon_sym_RBRACE_RBRACE] = "}}",
  [sym_escape_sequence] = "escape_sequence",
  [sym__not_escape_sequence] = "_not_escape_sequence",
  [aux_sym_format_specifier_token1] = "format_specifier_token1",
  [sym_type_conversion] = "type_conversion",
  [sym_integer] = "integer",
  [sym_float] = "float",
  [anon_sym_await] = "await",
  [sym_true] = "true",
  [sym_false] = "false",
  [sym_none] = "none",
  [sym_comment] = "comment",
  [sym__newline] = "_newline",
  [sym__indent] = "_indent",
  [sym__dedent] = "_dedent",
  [sym__string_start] = "\"",
  [sym__string_content] = "_string_content",
  [sym__string_end] = "\"",
  [sym_module] = "module",
  [sym__statement] = "_statement",
  [sym__simple_statements] = "_simple_statements",
  [sym_import_statement] = "import_statement",
  [sym_import_prefix] = "import_prefix",
  [sym_relative_import] = "relative_import",
  [sym_future_import_statement] = "future_import_statement",
  [sym_import_from_statement] = "import_from_statement",
  [sym__import_list] = "_import_list",
  [sym_aliased_import] = "aliased_import",
  [sym_wildcard_import] = "wildcard_import",
  [sym_print_statement] = "print_statement",
  [sym_chevron] = "chevron",
  [sym_assert_statement] = "assert_statement",
  [sym_expression_statement] = "expression_statement",
  [sym_named_expression] = "named_expression",
  [sym_return_statement] = "return_statement",
  [sym_delete_statement] = "delete_statement",
  [sym_raise_statement] = "raise_statement",
  [sym_pass_statement] = "pass_statement",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_if_statement] = "if_statement",
  [sym_elif_clause] = "elif_clause",
  [sym_else_clause] = "else_clause",
  [sym_for_statement] = "for_statement",
  [sym_while_statement] = "while_statement",
  [sym_try_statement] = "try_statement",
  [sym_except_clause] = "except_clause",
  [sym_finally_clause] = "finally_clause",
  [sym_with_statement] = "with_statement",
  [sym_with_clause] = "with_clause",
  [sym_with_item] = "with_item",
  [sym_function_definition] = "function_definition",
  [sym_parameters] = "parameters",
  [sym_lambda_parameters] = "lambda_parameters",
  [sym_list_splat] = "list_splat",
  [sym_dictionary_splat] = "dictionary_splat",
  [sym_global_statement] = "global_statement",
  [sym_nonlocal_statement] = "nonlocal_statement",
  [sym_exec_statement] = "exec_statement",
  [sym_class_definition] = "class_definition",
  [sym_parenthesized_list_splat] = "parenthesized_list_splat",
  [sym_argument_list] = "argument_list",
  [sym_decorated_definition] = "decorated_definition",
  [sym_decorator] = "decorator",
  [sym_block] = "block",
  [sym_expression_list] = "expression_list",
  [sym_dotted_name] = "dotted_name",
  [sym__parameters] = "_parameters",
  [sym__patterns] = "_patterns",
  [sym_parameter] = "parameter",
  [sym_pattern] = "pattern",
  [sym_tuple_pattern] = "tuple_pattern",
  [sym_list_pattern] = "list_pattern",
  [sym_default_parameter] = "default_parameter",
  [sym_typed_default_parameter] = "typed_default_parameter",
  [sym_list_splat_pattern] = "list_splat_pattern",
  [sym_dictionary_splat_pattern] = "dictionary_splat_pattern",
  [sym__expression_within_for_in_clause] = "_expression_within_for_in_clause",
  [sym_expression] = "expression",
  [sym_primary_expression] = "primary_expression",
  [sym_not_operator] = "not_operator",
  [sym_boolean_operator] = "boolean_operator",
  [sym_binary_operator] = "binary_operator",
  [sym_unary_operator] = "unary_operator",
  [sym_comparison_operator] = "comparison_operator",
  [sym_lambda] = "lambda",
  [sym_lambda_within_for_in_clause] = "lambda",
  [sym_assignment] = "assignment",
  [sym_augmented_assignment] = "augmented_assignment",
  [sym_pattern_list] = "pattern_list",
  [sym__right_hand_side] = "_right_hand_side",
  [sym_yield] = "yield",
  [sym_attribute] = "attribute",
  [sym_subscript] = "subscript",
  [sym_slice] = "slice",
  [sym_call] = "call",
  [sym_typed_parameter] = "typed_parameter",
  [sym_type] = "type",
  [sym_keyword_argument] = "keyword_argument",
  [sym_list] = "list",
  [sym_set] = "set",
  [sym_tuple] = "tuple",
  [sym_dictionary] = "dictionary",
  [sym_pair] = "pair",
  [sym_list_comprehension] = "list_comprehension",
  [sym_dictionary_comprehension] = "dictionary_comprehension",
  [sym_set_comprehension] = "set_comprehension",
  [sym_generator_expression] = "generator_expression",
  [sym__comprehension_clauses] = "_comprehension_clauses",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym__collection_elements] = "_collection_elements",
  [sym_for_in_clause] = "for_in_clause",
  [sym_if_clause] = "if_clause",
  [sym_conditional_expression] = "conditional_expression",
  [sym_concatenated_string] = "concatenated_string",
  [sym_string] = "string",
  [sym_interpolation] = "interpolation",
  [sym__escape_interpolation] = "_escape_interpolation",
  [sym_format_specifier] = "format_specifier",
  [sym_format_expression] = "format_expression",
  [sym_await] = "await",
  [aux_sym_module_repeat1] = "module_repeat1",
  [aux_sym__simple_statements_repeat1] = "_simple_statements_repeat1",
  [aux_sym_import_prefix_repeat1] = "import_prefix_repeat1",
  [aux_sym__import_list_repeat1] = "_import_list_repeat1",
  [aux_sym_print_statement_repeat1] = "print_statement_repeat1",
  [aux_sym_assert_statement_repeat1] = "assert_statement_repeat1",
  [aux_sym_if_statement_repeat1] = "if_statement_repeat1",
  [aux_sym_try_statement_repeat1] = "try_statement_repeat1",
  [aux_sym_with_clause_repeat1] = "with_clause_repeat1",
  [aux_sym_global_statement_repeat1] = "global_statement_repeat1",
  [aux_sym_argument_list_repeat1] = "argument_list_repeat1",
  [aux_sym_decorated_definition_repeat1] = "decorated_definition_repeat1",
  [aux_sym_dotted_name_repeat1] = "dotted_name_repeat1",
  [aux_sym__parameters_repeat1] = "_parameters_repeat1",
  [aux_sym__patterns_repeat1] = "_patterns_repeat1",
  [aux_sym_comparison_operator_repeat1] = "comparison_operator_repeat1",
  [aux_sym_subscript_repeat1] = "subscript_repeat1",
  [aux_sym_dictionary_repeat1] = "dictionary_repeat1",
  [aux_sym__comprehension_clauses_repeat1] = "_comprehension_clauses_repeat1",
  [aux_sym__collection_elements_repeat1] = "_collection_elements_repeat1",
  [aux_sym_for_in_clause_repeat1] = "for_in_clause_repeat1",
  [aux_sym_concatenated_string_repeat1] = "concatenated_string_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym_format_specifier_repeat1] = "format_specifier_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_from] = anon_sym_from,
  [anon_sym___future__] = anon_sym___future__,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_print] = anon_sym_print,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_assert] = anon_sym_assert,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_del] = anon_sym_del,
  [anon_sym_raise] = anon_sym_raise,
  [anon_sym_pass] = anon_sym_pass,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_elif] = anon_sym_elif,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_async] = anon_sym_async,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_except] = anon_sym_except,
  [anon_sym_finally] = anon_sym_finally,
  [anon_sym_with] = anon_sym_with,
  [anon_sym_def] = anon_sym_def,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_STAR_STAR] = anon_sym_STAR_STAR,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_nonlocal] = anon_sym_nonlocal,
  [anon_sym_exec] = anon_sym_exec,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_not] = anon_sym_not,
  [anon_sym_and] = anon_sym_and,
  [anon_sym_or] = anon_sym_or,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_SLASH_SLASH] = anon_sym_SLASH_SLASH,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_LT_GT] = anon_sym_LT_GT,
  [anon_sym_is] = anon_sym_is,
  [anon_sym_lambda] = anon_sym_lambda,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_AT_EQ] = anon_sym_AT_EQ,
  [anon_sym_SLASH_SLASH_EQ] = anon_sym_SLASH_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_STAR_STAR_EQ] = anon_sym_STAR_STAR_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_yield] = anon_sym_yield,
  [sym_ellipsis] = sym_ellipsis,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_LBRACE_LBRACE] = anon_sym_LBRACE_LBRACE,
  [anon_sym_RBRACE_RBRACE] = anon_sym_RBRACE_RBRACE,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym__not_escape_sequence] = sym__not_escape_sequence,
  [aux_sym_format_specifier_token1] = aux_sym_format_specifier_token1,
  [sym_type_conversion] = sym_type_conversion,
  [sym_integer] = sym_integer,
  [sym_float] = sym_float,
  [anon_sym_await] = anon_sym_await,
  [sym_true] = sym_true,
  [sym_false] = sym_false,
  [sym_none] = sym_none,
  [sym_comment] = sym_comment,
  [sym__newline] = sym__newline,
  [sym__indent] = sym__indent,
  [sym__dedent] = sym__dedent,
  [sym__string_start] = sym__string_start,
  [sym__string_content] = sym__string_content,
  [sym__string_end] = sym__string_start,
  [sym_module] = sym_module,
  [sym__statement] = sym__statement,
  [sym__simple_statements] = sym__simple_statements,
  [sym_import_statement] = sym_import_statement,
  [sym_import_prefix] = sym_import_prefix,
  [sym_relative_import] = sym_relative_import,
  [sym_future_import_statement] = sym_future_import_statement,
  [sym_import_from_statement] = sym_import_from_statement,
  [sym__import_list] = sym__import_list,
  [sym_aliased_import] = sym_aliased_import,
  [sym_wildcard_import] = sym_wildcard_import,
  [sym_print_statement] = sym_print_statement,
  [sym_chevron] = sym_chevron,
  [sym_assert_statement] = sym_assert_statement,
  [sym_expression_statement] = sym_expression_statement,
  [sym_named_expression] = sym_named_expression,
  [sym_return_statement] = sym_return_statement,
  [sym_delete_statement] = sym_delete_statement,
  [sym_raise_statement] = sym_raise_statement,
  [sym_pass_statement] = sym_pass_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_elif_clause] = sym_elif_clause,
  [sym_else_clause] = sym_else_clause,
  [sym_for_statement] = sym_for_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_try_statement] = sym_try_statement,
  [sym_except_clause] = sym_except_clause,
  [sym_finally_clause] = sym_finally_clause,
  [sym_with_statement] = sym_with_statement,
  [sym_with_clause] = sym_with_clause,
  [sym_with_item] = sym_with_item,
  [sym_function_definition] = sym_function_definition,
  [sym_parameters] = sym_parameters,
  [sym_lambda_parameters] = sym_lambda_parameters,
  [sym_list_splat] = sym_list_splat,
  [sym_dictionary_splat] = sym_dictionary_splat,
  [sym_global_statement] = sym_global_statement,
  [sym_nonlocal_statement] = sym_nonlocal_statement,
  [sym_exec_statement] = sym_exec_statement,
  [sym_class_definition] = sym_class_definition,
  [sym_parenthesized_list_splat] = sym_parenthesized_list_splat,
  [sym_argument_list] = sym_argument_list,
  [sym_decorated_definition] = sym_decorated_definition,
  [sym_decorator] = sym_decorator,
  [sym_block] = sym_block,
  [sym_expression_list] = sym_expression_list,
  [sym_dotted_name] = sym_dotted_name,
  [sym__parameters] = sym__parameters,
  [sym__patterns] = sym__patterns,
  [sym_parameter] = sym_parameter,
  [sym_pattern] = sym_pattern,
  [sym_tuple_pattern] = sym_tuple_pattern,
  [sym_list_pattern] = sym_list_pattern,
  [sym_default_parameter] = sym_default_parameter,
  [sym_typed_default_parameter] = sym_typed_default_parameter,
  [sym_list_splat_pattern] = sym_list_splat_pattern,
  [sym_dictionary_splat_pattern] = sym_dictionary_splat_pattern,
  [sym__expression_within_for_in_clause] = sym__expression_within_for_in_clause,
  [sym_expression] = sym_expression,
  [sym_primary_expression] = sym_primary_expression,
  [sym_not_operator] = sym_not_operator,
  [sym_boolean_operator] = sym_boolean_operator,
  [sym_binary_operator] = sym_binary_operator,
  [sym_unary_operator] = sym_unary_operator,
  [sym_comparison_operator] = sym_comparison_operator,
  [sym_lambda] = sym_lambda,
  [sym_lambda_within_for_in_clause] = sym_lambda,
  [sym_assignment] = sym_assignment,
  [sym_augmented_assignment] = sym_augmented_assignment,
  [sym_pattern_list] = sym_pattern_list,
  [sym__right_hand_side] = sym__right_hand_side,
  [sym_yield] = sym_yield,
  [sym_attribute] = sym_attribute,
  [sym_subscript] = sym_subscript,
  [sym_slice] = sym_slice,
  [sym_call] = sym_call,
  [sym_typed_parameter] = sym_typed_parameter,
  [sym_type] = sym_type,
  [sym_keyword_argument] = sym_keyword_argument,
  [sym_list] = sym_list,
  [sym_set] = sym_set,
  [sym_tuple] = sym_tuple,
  [sym_dictionary] = sym_dictionary,
  [sym_pair] = sym_pair,
  [sym_list_comprehension] = sym_list_comprehension,
  [sym_dictionary_comprehension] = sym_dictionary_comprehension,
  [sym_set_comprehension] = sym_set_comprehension,
  [sym_generator_expression] = sym_generator_expression,
  [sym__comprehension_clauses] = sym__comprehension_clauses,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym__collection_elements] = sym__collection_elements,
  [sym_for_in_clause] = sym_for_in_clause,
  [sym_if_clause] = sym_if_clause,
  [sym_conditional_expression] = sym_conditional_expression,
  [sym_concatenated_string] = sym_concatenated_string,
  [sym_string] = sym_string,
  [sym_interpolation] = sym_interpolation,
  [sym__escape_interpolation] = sym__escape_interpolation,
  [sym_format_specifier] = sym_format_specifier,
  [sym_format_expression] = sym_format_expression,
  [sym_await] = sym_await,
  [aux_sym_module_repeat1] = aux_sym_module_repeat1,
  [aux_sym__simple_statements_repeat1] = aux_sym__simple_statements_repeat1,
  [aux_sym_import_prefix_repeat1] = aux_sym_import_prefix_repeat1,
  [aux_sym__import_list_repeat1] = aux_sym__import_list_repeat1,
  [aux_sym_print_statement_repeat1] = aux_sym_print_statement_repeat1,
  [aux_sym_assert_statement_repeat1] = aux_sym_assert_statement_repeat1,
  [aux_sym_if_statement_repeat1] = aux_sym_if_statement_repeat1,
  [aux_sym_try_statement_repeat1] = aux_sym_try_statement_repeat1,
  [aux_sym_with_clause_repeat1] = aux_sym_with_clause_repeat1,
  [aux_sym_global_statement_repeat1] = aux_sym_global_statement_repeat1,
  [aux_sym_argument_list_repeat1] = aux_sym_argument_list_repeat1,
  [aux_sym_decorated_definition_repeat1] = aux_sym_decorated_definition_repeat1,
  [aux_sym_dotted_name_repeat1] = aux_sym_dotted_name_repeat1,
  [aux_sym__parameters_repeat1] = aux_sym__parameters_repeat1,
  [aux_sym__patterns_repeat1] = aux_sym__patterns_repeat1,
  [aux_sym_comparison_operator_repeat1] = aux_sym_comparison_operator_repeat1,
  [aux_sym_subscript_repeat1] = aux_sym_subscript_repeat1,
  [aux_sym_dictionary_repeat1] = aux_sym_dictionary_repeat1,
  [aux_sym__comprehension_clauses_repeat1] = aux_sym__comprehension_clauses_repeat1,
  [aux_sym__collection_elements_repeat1] = aux_sym__collection_elements_repeat1,
  [aux_sym_for_in_clause_repeat1] = aux_sym_for_in_clause_repeat1,
  [aux_sym_concatenated_string_repeat1] = aux_sym_concatenated_string_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym_format_specifier_repeat1] = aux_sym_format_specifier_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_from] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___future__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_print] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_del] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_raise] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pass] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_elif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_async] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_except] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_finally] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_def] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nonlocal] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_exec] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_is] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lambda] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_yield] = {
    .visible = true,
    .named = false,
  },
  [sym_ellipsis] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym__not_escape_sequence] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_format_specifier_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_type_conversion] = {
    .visible = true,
    .named = true,
  },
  [sym_integer] = {
    .visible = true,
    .named = true,
  },
  [sym_float] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_await] = {
    .visible = true,
    .named = false,
  },
  [sym_true] = {
    .visible = true,
    .named = true,
  },
  [sym_false] = {
    .visible = true,
    .named = true,
  },
  [sym_none] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym__newline] = {
    .visible = false,
    .named = true,
  },
  [sym__indent] = {
    .visible = false,
    .named = true,
  },
  [sym__dedent] = {
    .visible = false,
    .named = true,
  },
  [sym__string_start] = {
    .visible = true,
    .named = false,
  },
  [sym__string_content] = {
    .visible = false,
    .named = true,
  },
  [sym__string_end] = {
    .visible = true,
    .named = false,
  },
  [sym_module] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_statements] = {
    .visible = false,
    .named = true,
  },
  [sym_import_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_import_prefix] = {
    .visible = true,
    .named = true,
  },
  [sym_relative_import] = {
    .visible = true,
    .named = true,
  },
  [sym_future_import_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_import_from_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__import_list] = {
    .visible = false,
    .named = true,
  },
  [sym_aliased_import] = {
    .visible = true,
    .named = true,
  },
  [sym_wildcard_import] = {
    .visible = true,
    .named = true,
  },
  [sym_print_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_chevron] = {
    .visible = true,
    .named = true,
  },
  [sym_assert_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_named_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_delete_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_raise_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_pass_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_elif_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_except_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_finally_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_with_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_with_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_with_item] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_list_splat] = {
    .visible = true,
    .named = true,
  },
  [sym_dictionary_splat] = {
    .visible = true,
    .named = true,
  },
  [sym_global_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_nonlocal_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_exec_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_class_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_list_splat] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_decorated_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_decorator] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_list] = {
    .visible = true,
    .named = true,
  },
  [sym_dotted_name] = {
    .visible = true,
    .named = true,
  },
  [sym__parameters] = {
    .visible = false,
    .named = true,
  },
  [sym__patterns] = {
    .visible = false,
    .named = true,
  },
  [sym_parameter] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_tuple_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_list_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_default_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_default_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_list_splat_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_dictionary_splat_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__expression_within_for_in_clause] = {
    .visible = false,
    .named = true,
  },
  [sym_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_primary_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_not_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_comparison_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda_within_for_in_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_augmented_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern_list] = {
    .visible = true,
    .named = true,
  },
  [sym__right_hand_side] = {
    .visible = false,
    .named = true,
  },
  [sym_yield] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript] = {
    .visible = true,
    .named = true,
  },
  [sym_slice] = {
    .visible = true,
    .named = true,
  },
  [sym_call] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_type] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_list] = {
    .visible = true,
    .named = true,
  },
  [sym_set] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple] = {
    .visible = true,
    .named = true,
  },
  [sym_dictionary] = {
    .visible = true,
    .named = true,
  },
  [sym_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_list_comprehension] = {
    .visible = true,
    .named = true,
  },
  [sym_dictionary_comprehension] = {
    .visible = true,
    .named = true,
  },
  [sym_set_comprehension] = {
    .visible = true,
    .named = true,
  },
  [sym_generator_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__comprehension_clauses] = {
    .visible = false,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__collection_elements] = {
    .visible = false,
    .named = true,
  },
  [sym_for_in_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_if_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_concatenated_string] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolation] = {
    .visible = true,
    .named = true,
  },
  [sym__escape_interpolation] = {
    .visible = false,
    .named = true,
  },
  [sym_format_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_format_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_await] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_module_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__simple_statements_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_import_prefix_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__import_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_print_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_assert_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_try_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_with_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_global_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_decorated_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dotted_name_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__patterns_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_comparison_operator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subscript_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dictionary_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__comprehension_clauses_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__collection_elements_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_for_in_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_concatenated_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_format_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum {
  field_alias = 1,
  field_alternative = 2,
  field_argument = 3,
  field_arguments = 4,
  field_attribute = 5,
  field_body = 6,
  field_cause = 7,
  field_code = 8,
  field_condition = 9,
  field_consequence = 10,
  field_definition = 11,
  field_function = 12,
  field_key = 13,
  field_left = 14,
  field_module_name = 15,
  field_name = 16,
  field_object = 17,
  field_operator = 18,
  field_operators = 19,
  field_parameters = 20,
  field_return_type = 21,
  field_right = 22,
  field_subscript = 23,
  field_superclasses = 24,
  field_type = 25,
  field_value = 26,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alias] = "alias",
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_attribute] = "attribute",
  [field_body] = "body",
  [field_cause] = "cause",
  [field_code] = "code",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_definition] = "definition",
  [field_function] = "function",
  [field_key] = "key",
  [field_left] = "left",
  [field_module_name] = "module_name",
  [field_name] = "name",
  [field_object] = "object",
  [field_operator] = "operator",
  [field_operators] = "operators",
  [field_parameters] = "parameters",
  [field_return_type] = "return_type",
  [field_right] = "right",
  [field_subscript] = "subscript",
  [field_superclasses] = "superclasses",
  [field_type] = "type",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 1},
  [3] = {.index = 1, .length = 1},
  [5] = {.index = 2, .length = 1},
  [6] = {.index = 3, .length = 1},
  [7] = {.index = 4, .length = 1},
  [8] = {.index = 5, .length = 2},
  [10] = {.index = 7, .length = 2},
  [11] = {.index = 9, .length = 1},
  [12] = {.index = 10, .length = 1},
  [13] = {.index = 11, .length = 2},
  [14] = {.index = 13, .length = 1},
  [15] = {.index = 14, .length = 2},
  [16] = {.index = 16, .length = 1},
  [17] = {.index = 17, .length = 1},
  [18] = {.index = 18, .length = 2},
  [19] = {.index = 20, .length = 2},
  [20] = {.index = 22, .length = 2},
  [21] = {.index = 24, .length = 3},
  [22] = {.index = 27, .length = 2},
  [23] = {.index = 29, .length = 1},
  [24] = {.index = 30, .length = 2},
  [25] = {.index = 32, .length = 1},
  [26] = {.index = 33, .length = 2},
  [27] = {.index = 35, .length = 2},
  [28] = {.index = 37, .length = 1},
  [29] = {.index = 38, .length = 2},
  [30] = {.index = 40, .length = 1},
  [32] = {.index = 41, .length = 1},
  [33] = {.index = 42, .length = 2},
  [34] = {.index = 44, .length = 1},
  [35] = {.index = 45, .length = 2},
  [36] = {.index = 47, .length = 2},
  [37] = {.index = 17, .length = 1},
  [38] = {.index = 49, .length = 1},
  [39] = {.index = 50, .length = 2},
  [40] = {.index = 52, .length = 2},
  [41] = {.index = 54, .length = 1},
  [42] = {.index = 55, .length = 2},
  [43] = {.index = 57, .length = 2},
  [44] = {.index = 59, .length = 2},
  [45] = {.index = 61, .length = 2},
  [46] = {.index = 63, .length = 1},
  [47] = {.index = 64, .length = 3},
  [48] = {.index = 67, .length = 3},
  [49] = {.index = 70, .length = 3},
  [50] = {.index = 73, .length = 1},
  [51] = {.index = 74, .length = 3},
  [52] = {.index = 77, .length = 3},
  [53] = {.index = 80, .length = 2},
  [54] = {.index = 82, .length = 2},
  [55] = {.index = 84, .length = 3},
  [56] = {.index = 87, .length = 3},
  [57] = {.index = 90, .length = 3},
  [58] = {.index = 93, .length = 3},
  [59] = {.index = 18, .length = 2},
  [60] = {.index = 96, .length = 1},
  [61] = {.index = 97, .length = 3},
  [62] = {.index = 100, .length = 2},
  [63] = {.index = 102, .length = 1},
  [64] = {.index = 103, .length = 2},
  [65] = {.index = 105, .length = 2},
  [66] = {.index = 107, .length = 4},
  [67] = {.index = 111, .length = 2},
  [68] = {.index = 113, .length = 4},
  [69] = {.index = 117, .length = 4},
  [70] = {.index = 121, .length = 2},
  [71] = {.index = 123, .length = 3},
  [72] = {.index = 126, .length = 3},
  [73] = {.index = 129, .length = 4},
  [75] = {.index = 133, .length = 4},
  [76] = {.index = 137, .length = 4},
  [77] = {.index = 141, .length = 3},
  [78] = {.index = 144, .length = 2},
  [79] = {.index = 146, .length = 3},
  [80] = {.index = 149, .length = 5},
  [81] = {.index = 154, .length = 3},
  [82] = {.index = 157, .length = 4},
  [83] = {.index = 161, .length = 4},
  [84] = {.index = 165, .length = 4},
  [86] = {.index = 169, .length = 4},
  [87] = {.index = 173, .length = 3},
  [88] = {.index = 176, .length = 4},
  [89] = {.index = 180, .length = 4},
  [90] = {.index = 184, .length = 4},
  [91] = {.index = 188, .length = 5},
  [92] = {.index = 193, .length = 5},
  [93] = {.index = 198, .length = 5},
  [94] = {.index = 203, .length = 5},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_name, 1, .inherited = true},
  [1] =
    {field_name, 0},
  [2] =
    {field_argument, 1},
  [3] =
    {field_value, 0},
  [4] =
    {field_code, 1},
  [5] =
    {field_argument, 1},
    {field_operator, 0},
  [7] =
    {field_arguments, 1},
    {field_function, 0},
  [9] =
    {field_operators, 1, .inherited = true},
  [10] =
    {field_definition, 1},
  [11] =
    {field_name, 0},
    {field_name, 1, .inherited = true},
  [13] =
    {field_argument, 2, .inherited = true},
  [14] =
    {field_argument, 1},
    {field_argument, 2, .inherited = true},
  [16] =
    {field_cause, 2},
  [17] =
    {field_body, 2},
  [18] =
    {field_name, 0},
    {field_value, 2},
  [20] =
    {field_left, 0},
    {field_type, 2},
  [22] =
    {field_left, 0},
    {field_right, 2},
  [24] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [27] =
    {field_attribute, 2},
    {field_object, 0},
  [29] =
    {field_operators, 0},
  [30] =
    {field_operators, 0, .inherited = true},
    {field_operators, 1, .inherited = true},
  [32] =
    {field_name, 1},
  [33] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
  [35] =
    {field_alias, 2},
    {field_name, 0},
  [37] =
    {field_name, 3, .inherited = true},
  [38] =
    {field_module_name, 1},
    {field_name, 3, .inherited = true},
  [40] =
    {field_module_name, 1},
  [41] =
    {field_body, 1},
  [42] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [44] =
    {field_cause, 3},
  [45] =
    {field_condition, 1},
    {field_consequence, 3},
  [47] =
    {field_body, 3},
    {field_condition, 1},
  [49] =
    {field_body, 3},
  [50] =
    {field_alias, 2},
    {field_value, 0},
  [52] =
    {field_body, 3},
    {field_name, 1},
  [54] =
    {field_type, 2},
  [55] =
    {field_body, 3},
    {field_parameters, 1},
  [57] =
    {field_key, 0},
    {field_value, 2},
  [59] =
    {field_subscript, 2},
    {field_value, 0},
  [61] =
    {field_operators, 0},
    {field_operators, 1},
  [63] =
    {field_alternative, 0},
  [64] =
    {field_alternative, 4},
    {field_condition, 1},
    {field_consequence, 3},
  [67] =
    {field_alternative, 4, .inherited = true},
    {field_condition, 1},
    {field_consequence, 3},
  [70] =
    {field_condition, 1},
    {field_consequence, 3},
    {field_consequence, 4},
  [73] =
    {field_body, 4},
  [74] =
    {field_alternative, 4},
    {field_body, 3},
    {field_condition, 1},
  [77] =
    {field_body, 3},
    {field_body, 4},
    {field_condition, 1},
  [80] =
    {field_body, 2},
    {field_body, 3},
  [82] =
    {field_body, 3},
    {field_body, 4},
  [84] =
    {field_body, 4},
    {field_name, 1},
    {field_parameters, 2},
  [87] =
    {field_body, 3},
    {field_body, 4},
    {field_name, 1},
  [90] =
    {field_body, 4},
    {field_name, 1},
    {field_superclasses, 2},
  [93] =
    {field_left, 0},
    {field_right, 4},
    {field_type, 2},
  [96] =
    {field_subscript, 1},
  [97] =
    {field_subscript, 2},
    {field_subscript, 3, .inherited = true},
    {field_value, 0},
  [100] =
    {field_subscript, 0, .inherited = true},
    {field_subscript, 1, .inherited = true},
  [102] =
    {field_name, 4, .inherited = true},
  [103] =
    {field_module_name, 1},
    {field_name, 4, .inherited = true},
  [105] =
    {field_left, 1},
    {field_right, 3},
  [107] =
    {field_alternative, 4, .inherited = true},
    {field_alternative, 5},
    {field_condition, 1},
    {field_consequence, 3},
  [111] =
    {field_alternative, 0, .inherited = true},
    {field_alternative, 1, .inherited = true},
  [113] =
    {field_alternative, 5},
    {field_condition, 1},
    {field_consequence, 3},
    {field_consequence, 4},
  [117] =
    {field_alternative, 5, .inherited = true},
    {field_condition, 1},
    {field_consequence, 3},
    {field_consequence, 4},
  [121] =
    {field_body, 4},
    {field_body, 5},
  [123] =
    {field_body, 5},
    {field_name, 2},
    {field_parameters, 3},
  [126] =
    {field_body, 5},
    {field_left, 1},
    {field_right, 3},
  [129] =
    {field_alternative, 5},
    {field_body, 3},
    {field_body, 4},
    {field_condition, 1},
  [133] =
    {field_body, 4},
    {field_body, 5},
    {field_name, 1},
    {field_parameters, 2},
  [137] =
    {field_body, 4},
    {field_body, 5},
    {field_name, 1},
    {field_superclasses, 2},
  [141] =
    {field_name, 0},
    {field_type, 2},
    {field_value, 4},
  [144] =
    {field_left, 2},
    {field_right, 4},
  [146] =
    {field_left, 1},
    {field_right, 3},
    {field_right, 4},
  [149] =
    {field_alternative, 5, .inherited = true},
    {field_alternative, 6},
    {field_condition, 1},
    {field_consequence, 3},
    {field_consequence, 4},
  [154] =
    {field_body, 6},
    {field_left, 2},
    {field_right, 4},
  [157] =
    {field_body, 5},
    {field_body, 6},
    {field_name, 2},
    {field_parameters, 3},
  [161] =
    {field_alternative, 6},
    {field_body, 5},
    {field_left, 1},
    {field_right, 3},
  [165] =
    {field_body, 5},
    {field_body, 6},
    {field_left, 1},
    {field_right, 3},
  [169] =
    {field_body, 6},
    {field_name, 1},
    {field_parameters, 2},
    {field_return_type, 4},
  [173] =
    {field_left, 2},
    {field_right, 4},
    {field_right, 5},
  [176] =
    {field_alternative, 7},
    {field_body, 6},
    {field_left, 2},
    {field_right, 4},
  [180] =
    {field_body, 6},
    {field_body, 7},
    {field_left, 2},
    {field_right, 4},
  [184] =
    {field_body, 7},
    {field_name, 2},
    {field_parameters, 3},
    {field_return_type, 5},
  [188] =
    {field_alternative, 7},
    {field_body, 5},
    {field_body, 6},
    {field_left, 1},
    {field_right, 3},
  [193] =
    {field_body, 6},
    {field_body, 7},
    {field_name, 1},
    {field_parameters, 2},
    {field_return_type, 4},
  [198] =
    {field_alternative, 8},
    {field_body, 6},
    {field_body, 7},
    {field_left, 2},
    {field_right, 4},
  [203] =
    {field_body, 7},
    {field_body, 8},
    {field_name, 2},
    {field_parameters, 3},
    {field_return_type, 5},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = sym_identifier,
  },
  [4] = {
    [1] = sym_identifier,
  },
  [9] = {
    [0] = sym_list_splat_pattern,
  },
  [31] = {
    [1] = sym_parenthesized_expression,
  },
  [35] = {
    [3] = sym_block,
  },
  [36] = {
    [3] = sym_block,
  },
  [37] = {
    [2] = sym_block,
  },
  [38] = {
    [3] = sym_block,
  },
  [40] = {
    [3] = sym_block,
  },
  [47] = {
    [3] = sym_block,
  },
  [48] = {
    [3] = sym_block,
  },
  [50] = {
    [4] = sym_block,
  },
  [51] = {
    [3] = sym_block,
  },
  [55] = {
    [4] = sym_block,
  },
  [57] = {
    [4] = sym_block,
  },
  [59] = {
    [0] = sym_identifier,
  },
  [66] = {
    [3] = sym_block,
  },
  [71] = {
    [5] = sym_block,
  },
  [72] = {
    [5] = sym_block,
  },
  [74] = {
    [2] = sym_block,
  },
  [81] = {
    [6] = sym_block,
  },
  [83] = {
    [5] = sym_block,
  },
  [85] = {
    [3] = sym_block,
  },
  [86] = {
    [6] = sym_block,
  },
  [88] = {
    [6] = sym_block,
  },
  [90] = {
    [7] = sym_block,
  },
  [95] = {
    [5] = sym_block,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym__simple_statements, 2,
    sym__simple_statements,
    sym_block,
  sym_parenthesized_list_splat, 2,
    sym_parenthesized_list_splat,
    sym_parenthesized_expression,
  0,
};

static inline bool sym_identifier_character_set_1(int32_t c) {
  return (c < 43020
    ? (c < 4096
      ? (c < 2693
        ? (c < 1969
          ? (c < 910
            ? (c < 736
              ? (c < 186
                ? (c < 170
                  ? (c < 'a'
                    ? (c >= 'A' && c <= '_')
                    : c <= 'z')
                  : (c <= 170 || c == 181))
                : (c <= 186 || (c < 248
                  ? (c < 216
                    ? (c >= 192 && c <= 214)
                    : c <= 246)
                  : (c <= 705 || (c >= 710 && c <= 721)))))
              : (c <= 740 || (c < 891
                ? (c < 880
                  ? (c < 750
                    ? c == 748
                    : c <= 750)
                  : (c <= 884 || (c >= 886 && c <= 887)))
                : (c <= 893 || (c < 904
                  ? (c < 902
                    ? c == 895
                    : c <= 902)
                  : (c <= 906 || c == 908))))))
            : (c <= 929 || (c < 1646
              ? (c < 1369
                ? (c < 1162
                  ? (c < 1015
                    ? (c >= 931 && c <= 1013)
                    : c <= 1153)
                  : (c <= 1327 || (c >= 1329 && c <= 1366)))
                : (c <= 1369 || (c < 1519
                  ? (c < 1488
                    ? (c >= 1376 && c <= 1416)
                    : c <= 1514)
                  : (c <= 1522 || (c >= 1568 && c <= 1610)))))
              : (c <= 1647 || (c < 1786
                ? (c < 1765
                  ? (c < 1749
                    ? (c >= 1649 && c <= 1747)
                    : c <= 1749)
                  : (c <= 1766 || (c >= 1774 && c <= 1775)))
                : (c <= 1788 || (c < 1810
                  ? (c < 1808
                    ? c == 1791
                    : c <= 1808)
                  : (c <= 1839 || (c >= 1869 && c <= 1957)))))))))
          : (c <= 1969 || (c < 2474
            ? (c < 2208
              ? (c < 2074
                ? (c < 2042
                  ? (c < 2036
                    ? (c >= 1994 && c <= 2026)
                    : c <= 2037)
                  : (c <= 2042 || (c >= 2048 && c <= 2069)))
                : (c <= 2074 || (c < 2112
                  ? (c < 2088
                    ? c == 2084
                    : c <= 2088)
                  : (c <= 2136 || (c >= 2144 && c <= 2154)))))
              : (c <= 2228 || (c < 2392
                ? (c < 2365
                  ? (c < 2308
                    ? (c >= 2230 && c <= 2247)
                    : c <= 2361)
                  : (c <= 2365 || c == 2384))
                : (c <= 2401 || (c < 2447
                  ? (c < 2437
                    ? (c >= 2417 && c <= 2432)
                    : c <= 2444)
                  : (c <= 2448 || (c >= 2451 && c <= 2472)))))))
            : (c <= 2480 || (c < 2575
              ? (c < 2524
                ? (c < 2493
                  ? (c < 2486
                    ? c == 2482
                    : c <= 2489)
                  : (c <= 2493 || c == 2510))
                : (c <= 2525 || (c < 2556
                  ? (c < 2544
                    ? (c >= 2527 && c <= 2529)
                    : c <= 2545)
                  : (c <= 2556 || (c >= 2565 && c <= 2570)))))
              : (c <= 2576 || (c < 2616
                ? (c < 2610
                  ? (c < 2602
                    ? (c >= 2579 && c <= 2600)
                    : c <= 2608)
                  : (c <= 2611 || (c >= 2613 && c <= 2614)))
                : (c <= 2617 || (c < 2654
                  ? (c >= 2649 && c <= 2652)
                  : (c <= 2654 || (c >= 2674 && c <= 2676)))))))))))
        : (c <= 2701 || (c < 3214
          ? (c < 2947
            ? (c < 2821
              ? (c < 2741
                ? (c < 2730
                  ? (c < 2707
                    ? (c >= 2703 && c <= 2705)
                    : c <= 2728)
                  : (c <= 2736 || (c >= 2738 && c <= 2739)))
                : (c <= 2745 || (c < 2784
                  ? (c < 2768
                    ? c == 2749
                    : c <= 2768)
                  : (c <= 2785 || c == 2809))))
              : (c <= 2828 || (c < 2869
                ? (c < 2858
                  ? (c < 2835
                    ? (c >= 2831 && c <= 2832)
                    : c <= 2856)
                  : (c <= 2864 || (c >= 2866 && c <= 2867)))
                : (c <= 2873 || (c < 2911
                  ? (c < 2908
                    ? c == 2877
                    : c <= 2909)
                  : (c <= 2913 || c == 2929))))))
            : (c <= 2947 || (c < 3024
              ? (c < 2972
                ? (c < 2962
                  ? (c < 2958
                    ? (c >= 2949 && c <= 2954)
                    : c <= 2960)
                  : (c <= 2965 || (c >= 2969 && c <= 2970)))
                : (c <= 2972 || (c < 2984
                  ? (c < 2979
                    ? (c >= 2974 && c <= 2975)
                    : c <= 2980)
                  : (c <= 2986 || (c >= 2990 && c <= 3001)))))
              : (c <= 3024 || (c < 3133
                ? (c < 3090
                  ? (c < 3086
                    ? (c >= 3077 && c <= 3084)
                    : c <= 3088)
                  : (c <= 3112 || (c >= 3114 && c <= 3129)))
                : (c <= 3133 || (c < 3200
                  ? (c < 3168
                    ? (c >= 3160 && c <= 3162)
                    : c <= 3169)
                  : (c <= 3200 || (c >= 3205 && c <= 3212)))))))))
          : (c <= 3216 || (c < 3520
            ? (c < 3346
              ? (c < 3294
                ? (c < 3253
                  ? (c < 3242
                    ? (c >= 3218 && c <= 3240)
                    : c <= 3251)
                  : (c <= 3257 || c == 3261))
                : (c <= 3294 || (c < 3332
                  ? (c < 3313
                    ? (c >= 3296 && c <= 3297)
                    : c <= 3314)
                  : (c <= 3340 || (c >= 3342 && c <= 3344)))))
              : (c <= 3386 || (c < 3450
                ? (c < 3412
                  ? (c < 3406
                    ? c == 3389
                    : c <= 3406)
                  : (c <= 3414 || (c >= 3423 && c <= 3425)))
                : (c <= 3455 || (c < 3507
                  ? (c < 3482
                    ? (c >= 3461 && c <= 3478)
                    : c <= 3505)
                  : (c <= 3515 || c == 3517))))))
            : (c <= 3526 || (c < 3762
              ? (c < 3716
                ? (c < 3648
                  ? (c < 3634
                    ? (c >= 3585 && c <= 3632)
                    : c <= 3634)
                  : (c <= 3654 || (c >= 3713 && c <= 3714)))
                : (c <= 3716 || (c < 3749
                  ? (c < 3724
                    ? (c >= 3718 && c <= 3722)
                    : c <= 3747)
                  : (c <= 3749 || (c >= 3751 && c <= 3760)))))
              : (c <= 3762 || (c < 3840
                ? (c < 3782
                  ? (c < 3776
                    ? c == 3773
                    : c <= 3780)
                  : (c <= 3782 || (c >= 3804 && c <= 3807)))
                : (c <= 3840 || (c < 3913
                  ? (c >= 3904 && c <= 3911)
                  : (c <= 3948 || (c >= 3976 && c <= 3980)))))))))))))
      : (c <= 4138 || (c < 8025
        ? (c < 5952
          ? (c < 4752
            ? (c < 4295
              ? (c < 4197
                ? (c < 4186
                  ? (c < 4176
                    ? c == 4159
                    : c <= 4181)
                  : (c <= 4189 || c == 4193))
                : (c <= 4198 || (c < 4238
                  ? (c < 4213
                    ? (c >= 4206 && c <= 4208)
                    : c <= 4225)
                  : (c <= 4238 || (c >= 4256 && c <= 4293)))))
              : (c <= 4295 || (c < 4688
                ? (c < 4348
                  ? (c < 4304
                    ? c == 4301
                    : c <= 4346)
                  : (c <= 4680 || (c >= 4682 && c <= 4685)))
                : (c <= 4694 || (c < 4704
                  ? (c < 4698
                    ? c == 4696
                    : c <= 4701)
                  : (c <= 4744 || (c >= 4746 && c <= 4749)))))))
            : (c <= 4784 || (c < 5024
              ? (c < 4808
                ? (c < 4800
                  ? (c < 4792
                    ? (c >= 4786 && c <= 4789)
                    : c <= 4798)
                  : (c <= 4800 || (c >= 4802 && c <= 4805)))
                : (c <= 4822 || (c < 4888
                  ? (c < 4882
                    ? (c >= 4824 && c <= 4880)
                    : c <= 4885)
                  : (c <= 4954 || (c >= 4992 && c <= 5007)))))
              : (c <= 5109 || (c < 5792
                ? (c < 5743
                  ? (c < 5121
                    ? (c >= 5112 && c <= 5117)
                    : c <= 5740)
                  : (c <= 5759 || (c >= 5761 && c <= 5786)))
                : (c <= 5866 || (c < 5902
                  ? (c < 5888
                    ? (c >= 5870 && c <= 5880)
                    : c <= 5900)
                  : (c <= 5905 || (c >= 5920 && c <= 5937)))))))))
          : (c <= 5969 || (c < 7043
            ? (c < 6400
              ? (c < 6108
                ? (c < 6016
                  ? (c < 5998
                    ? (c >= 5984 && c <= 5996)
                    : c <= 6000)
                  : (c <= 6067 || c == 6103))
                : (c <= 6108 || (c < 6314
                  ? (c < 6272
                    ? (c >= 6176 && c <= 6264)
                    : c <= 6312)
                  : (c <= 6314 || (c >= 6320 && c <= 6389)))))
              : (c <= 6430 || (c < 6656
                ? (c < 6528
                  ? (c < 6512
                    ? (c >= 6480 && c <= 6509)
                    : c <= 6516)
                  : (c <= 6571 || (c >= 6576 && c <= 6601)))
                : (c <= 6678 || (c < 6917
                  ? (c < 6823
                    ? (c >= 6688 && c <= 6740)
                    : c <= 6823)
                  : (c <= 6963 || (c >= 6981 && c <= 6987)))))))
            : (c <= 7072 || (c < 7406
              ? (c < 7258
                ? (c < 7168
                  ? (c < 7098
                    ? (c >= 7086 && c <= 7087)
                    : c <= 7141)
                  : (c <= 7203 || (c >= 7245 && c <= 7247)))
                : (c <= 7293 || (c < 7357
                  ? (c < 7312
                    ? (c >= 7296 && c <= 7304)
                    : c <= 7354)
                  : (c <= 7359 || (c >= 7401 && c <= 7404)))))
              : (c <= 7411 || (c < 7960
                ? (c < 7424
                  ? (c < 7418
                    ? (c >= 7413 && c <= 7414)
                    : c <= 7418)
                  : (c <= 7615 || (c >= 7680 && c <= 7957)))
                : (c <= 7965 || (c < 8008
                  ? (c >= 7968 && c <= 8005)
                  : (c <= 8013 || (c >= 8016 && c <= 8023)))))))))))
        : (c <= 8025 || (c < 11631
          ? (c < 8469
            ? (c < 8150
              ? (c < 8118
                ? (c < 8031
                  ? (c < 8029
                    ? c == 8027
                    : c <= 8029)
                  : (c <= 8061 || (c >= 8064 && c <= 8116)))
                : (c <= 8124 || (c < 8134
                  ? (c < 8130
                    ? c == 8126
                    : c <= 8132)
                  : (c <= 8140 || (c >= 8144 && c <= 8147)))))
              : (c <= 8155 || (c < 8319
                ? (c < 8182
                  ? (c < 8178
                    ? (c >= 8160 && c <= 8172)
                    : c <= 8180)
                  : (c <= 8188 || c == 8305))
                : (c <= 8319 || (c < 8455
                  ? (c < 8450
                    ? (c >= 8336 && c <= 8348)
                    : c <= 8450)
                  : (c <= 8455 || (c >= 8458 && c <= 8467)))))))
            : (c <= 8469 || (c < 11264
              ? (c < 8490
                ? (c < 8486
                  ? (c < 8484
                    ? (c >= 8472 && c <= 8477)
                    : c <= 8484)
                  : (c <= 8486 || c == 8488))
                : (c <= 8505 || (c < 8526
                  ? (c < 8517
                    ? (c >= 8508 && c <= 8511)
                    : c <= 8521)
                  : (c <= 8526 || (c >= 8544 && c <= 8584)))))
              : (c <= 11310 || (c < 11520
                ? (c < 11499
                  ? (c < 11360
                    ? (c >= 11312 && c <= 11358)
                    : c <= 11492)
                  : (c <= 11502 || (c >= 11506 && c <= 11507)))
                : (c <= 11557 || (c < 11565
                  ? c == 11559
                  : (c <= 11565 || (c >= 11568 && c <= 11623)))))))))
          : (c <= 11631 || (c < 12704
            ? (c < 12293
              ? (c < 11704
                ? (c < 11688
                  ? (c < 11680
                    ? (c >= 11648 && c <= 11670)
                    : c <= 11686)
                  : (c <= 11694 || (c >= 11696 && c <= 11702)))
                : (c <= 11710 || (c < 11728
                  ? (c < 11720
                    ? (c >= 11712 && c <= 11718)
                    : c <= 11726)
                  : (c <= 11734 || (c >= 11736 && c <= 11742)))))
              : (c <= 12295 || (c < 12445
                ? (c < 12344
                  ? (c < 12337
                    ? (c >= 12321 && c <= 12329)
                    : c <= 12341)
                  : (c <= 12348 || (c >= 12353 && c <= 12438)))
                : (c <= 12447 || (c < 12549
                  ? (c < 12540
                    ? (c >= 12449 && c <= 12538)
                    : c <= 12543)
                  : (c <= 12591 || (c >= 12593 && c <= 12686)))))))
            : (c <= 12735 || (c < 42623
              ? (c < 42192
                ? (c < 19968
                  ? (c < 13312
                    ? (c >= 12784 && c <= 12799)
                    : c <= 19903)
                  : (c <= 40956 || (c >= 40960 && c <= 42124)))
                : (c <= 42237 || (c < 42538
                  ? (c < 42512
                    ? (c >= 42240 && c <= 42508)
                    : c <= 42527)
                  : (c <= 42539 || (c >= 42560 && c <= 42606)))))
              : (c <= 42653 || (c < 42946
                ? (c < 42786
                  ? (c < 42775
                    ? (c >= 42656 && c <= 42735)
                    : c <= 42783)
                  : (c <= 42888 || (c >= 42891 && c <= 42943)))
                : (c <= 42954 || (c < 43011
                  ? (c >= 42997 && c <= 43009)
                  : (c <= 43013 || (c >= 43015 && c <= 43018)))))))))))))))
    : (c <= 43042 || (c < 70453
      ? (c < 66176
        ? (c < 64112
          ? (c < 43697
            ? (c < 43471
              ? (c < 43261
                ? (c < 43250
                  ? (c < 43138
                    ? (c >= 43072 && c <= 43123)
                    : c <= 43187)
                  : (c <= 43255 || c == 43259))
                : (c <= 43262 || (c < 43360
                  ? (c < 43312
                    ? (c >= 43274 && c <= 43301)
                    : c <= 43334)
                  : (c <= 43388 || (c >= 43396 && c <= 43442)))))
              : (c <= 43471 || (c < 43584
                ? (c < 43514
                  ? (c < 43494
                    ? (c >= 43488 && c <= 43492)
                    : c <= 43503)
                  : (c <= 43518 || (c >= 43520 && c <= 43560)))
                : (c <= 43586 || (c < 43642
                  ? (c < 43616
                    ? (c >= 43588 && c <= 43595)
                    : c <= 43638)
                  : (c <= 43642 || (c >= 43646 && c <= 43695)))))))
            : (c <= 43697 || (c < 43793
              ? (c < 43739
                ? (c < 43712
                  ? (c < 43705
                    ? (c >= 43701 && c <= 43702)
                    : c <= 43709)
                  : (c <= 43712 || c == 43714))
                : (c <= 43741 || (c < 43777
                  ? (c < 43762
                    ? (c >= 43744 && c <= 43754)
                    : c <= 43764)
                  : (c <= 43782 || (c >= 43785 && c <= 43790)))))
              : (c <= 43798 || (c < 43888
                ? (c < 43824
                  ? (c < 43816
                    ? (c >= 43808 && c <= 43814)
                    : c <= 43822)
                  : (c <= 43866 || (c >= 43868 && c <= 43881)))
                : (c <= 44002 || (c < 55243
                  ? (c < 55216
                    ? (c >= 44032 && c <= 55203)
                    : c <= 55238)
                  : (c <= 55291 || (c >= 63744 && c <= 64109)))))))))
          : (c <= 64217 || (c < 65147
            ? (c < 64326
              ? (c < 64298
                ? (c < 64285
                  ? (c < 64275
                    ? (c >= 64256 && c <= 64262)
                    : c <= 64279)
                  : (c <= 64285 || (c >= 64287 && c <= 64296)))
                : (c <= 64310 || (c < 64320
                  ? (c < 64318
                    ? (c >= 64312 && c <= 64316)
                    : c <= 64318)
                  : (c <= 64321 || (c >= 64323 && c <= 64324)))))
              : (c <= 64433 || (c < 65008
                ? (c < 64848
                  ? (c < 64612
                    ? (c >= 64467 && c <= 64605)
                    : c <= 64829)
                  : (c <= 64911 || (c >= 64914 && c <= 64967)))
                : (c <= 65017 || (c < 65143
                  ? (c < 65139
                    ? c == 65137
                    : c <= 65139)
                  : (c <= 65143 || c == 65145))))))
            : (c <= 65147 || (c < 65498
              ? (c < 65382
                ? (c < 65313
                  ? (c < 65151
                    ? c == 65149
                    : c <= 65276)
                  : (c <= 65338 || (c >= 65345 && c <= 65370)))
                : (c <= 65437 || (c < 65482
                  ? (c < 65474
                    ? (c >= 65440 && c <= 65470)
                    : c <= 65479)
                  : (c <= 65487 || (c >= 65490 && c <= 65495)))))
              : (c <= 65500 || (c < 65599
                ? (c < 65576
                  ? (c < 65549
                    ? (c >= 65536 && c <= 65547)
                    : c <= 65574)
                  : (c <= 65594 || (c >= 65596 && c <= 65597)))
                : (c <= 65613 || (c < 65664
                  ? (c >= 65616 && c <= 65629)
                  : (c <= 65786 || (c >= 65856 && c <= 65908)))))))))))
        : (c <= 66204 || (c < 68416
          ? (c < 67639
            ? (c < 66736
              ? (c < 66432
                ? (c < 66349
                  ? (c < 66304
                    ? (c >= 66208 && c <= 66256)
                    : c <= 66335)
                  : (c <= 66378 || (c >= 66384 && c <= 66421)))
                : (c <= 66461 || (c < 66513
                  ? (c < 66504
                    ? (c >= 66464 && c <= 66499)
                    : c <= 66511)
                  : (c <= 66517 || (c >= 66560 && c <= 66717)))))
              : (c <= 66771 || (c < 67392
                ? (c < 66864
                  ? (c < 66816
                    ? (c >= 66776 && c <= 66811)
                    : c <= 66855)
                  : (c <= 66915 || (c >= 67072 && c <= 67382)))
                : (c <= 67413 || (c < 67592
                  ? (c < 67584
                    ? (c >= 67424 && c <= 67431)
                    : c <= 67589)
                  : (c <= 67592 || (c >= 67594 && c <= 67637)))))))
            : (c <= 67640 || (c < 68030
              ? (c < 67808
                ? (c < 67680
                  ? (c < 67647
                    ? c == 67644
                    : c <= 67669)
                  : (c <= 67702 || (c >= 67712 && c <= 67742)))
                : (c <= 67826 || (c < 67872
                  ? (c < 67840
                    ? (c >= 67828 && c <= 67829)
                    : c <= 67861)
                  : (c <= 67897 || (c >= 67968 && c <= 68023)))))
              : (c <= 68031 || (c < 68192
                ? (c < 68117
                  ? (c < 68112
                    ? c == 68096
                    : c <= 68115)
                  : (c <= 68119 || (c >= 68121 && c <= 68149)))
                : (c <= 68220 || (c < 68297
                  ? (c < 68288
                    ? (c >= 68224 && c <= 68252)
                    : c <= 68295)
                  : (c <= 68324 || (c >= 68352 && c <= 68405)))))))))
          : (c <= 68437 || (c < 69968
            ? (c < 69415
              ? (c < 68800
                ? (c < 68608
                  ? (c < 68480
                    ? (c >= 68448 && c <= 68466)
                    : c <= 68497)
                  : (c <= 68680 || (c >= 68736 && c <= 68786)))
                : (c <= 68850 || (c < 69296
                  ? (c < 69248
                    ? (c >= 68864 && c <= 68899)
                    : c <= 69289)
                  : (c <= 69297 || (c >= 69376 && c <= 69404)))))
              : (c <= 69415 || (c < 69763
                ? (c < 69600
                  ? (c < 69552
                    ? (c >= 69424 && c <= 69445)
                    : c <= 69572)
                  : (c <= 69622 || (c >= 69635 && c <= 69687)))
                : (c <= 69807 || (c < 69956
                  ? (c < 69891
                    ? (c >= 69840 && c <= 69864)
                    : c <= 69926)
                  : (c <= 69956 || c == 69959))))))
            : (c <= 70002 || (c < 70282
              ? (c < 70108
                ? (c < 70081
                  ? (c < 70019
                    ? c == 70006
                    : c <= 70066)
                  : (c <= 70084 || c == 70106))
                : (c <= 70108 || (c < 70272
                  ? (c < 70163
                    ? (c >= 70144 && c <= 70161)
                    : c <= 70187)
                  : (c <= 70278 || c == 70280))))
              : (c <= 70285 || (c < 70415
                ? (c < 70320
                  ? (c < 70303
                    ? (c >= 70287 && c <= 70301)
                    : c <= 70312)
                  : (c <= 70366 || (c >= 70405 && c <= 70412)))
                : (c <= 70416 || (c < 70442
                  ? (c >= 70419 && c <= 70440)
                  : (c <= 70448 || (c >= 70450 && c <= 70451)))))))))))))
      : (c <= 70457 || (c < 113808
        ? (c < 72818
          ? (c < 71945
            ? (c < 71040
              ? (c < 70727
                ? (c < 70493
                  ? (c < 70480
                    ? c == 70461
                    : c <= 70480)
                  : (c <= 70497 || (c >= 70656 && c <= 70708)))
                : (c <= 70730 || (c < 70852
                  ? (c < 70784
                    ? (c >= 70751 && c <= 70753)
                    : c <= 70831)
                  : (c <= 70853 || c == 70855))))
              : (c <= 71086 || (c < 71352
                ? (c < 71236
                  ? (c < 71168
                    ? (c >= 71128 && c <= 71131)
                    : c <= 71215)
                  : (c <= 71236 || (c >= 71296 && c <= 71338)))
                : (c <= 71352 || (c < 71840
                  ? (c < 71680
                    ? (c >= 71424 && c <= 71450)
                    : c <= 71723)
                  : (c <= 71903 || (c >= 71935 && c <= 71942)))))))
            : (c <= 71945 || (c < 72192
              ? (c < 72001
                ? (c < 71960
                  ? (c < 71957
                    ? (c >= 71948 && c <= 71955)
                    : c <= 71958)
                  : (c <= 71983 || c == 71999))
                : (c <= 72001 || (c < 72161
                  ? (c < 72106
                    ? (c >= 72096 && c <= 72103)
                    : c <= 72144)
                  : (c <= 72161 || c == 72163))))
              : (c <= 72192 || (c < 72349
                ? (c < 72272
                  ? (c < 72250
                    ? (c >= 72203 && c <= 72242)
                    : c <= 72250)
                  : (c <= 72272 || (c >= 72284 && c <= 72329)))
                : (c <= 72349 || (c < 72714
                  ? (c < 72704
                    ? (c >= 72384 && c <= 72440)
                    : c <= 72712)
                  : (c <= 72750 || c == 72768))))))))
          : (c <= 72847 || (c < 92992
            ? (c < 73648
              ? (c < 73056
                ? (c < 72971
                  ? (c < 72968
                    ? (c >= 72960 && c <= 72966)
                    : c <= 72969)
                  : (c <= 73008 || c == 73030))
                : (c <= 73061 || (c < 73112
                  ? (c < 73066
                    ? (c >= 73063 && c <= 73064)
                    : c <= 73097)
                  : (c <= 73112 || (c >= 73440 && c <= 73458)))))
              : (c <= 73648 || (c < 82944
                ? (c < 74880
                  ? (c < 74752
                    ? (c >= 73728 && c <= 74649)
                    : c <= 74862)
                  : (c <= 75075 || (c >= 77824 && c <= 78894)))
                : (c <= 83526 || (c < 92880
                  ? (c < 92736
                    ? (c >= 92160 && c <= 92728)
                    : c <= 92766)
                  : (c <= 92909 || (c >= 92928 && c <= 92975)))))))
            : (c <= 92995 || (c < 100352
              ? (c < 94032
                ? (c < 93760
                  ? (c < 93053
                    ? (c >= 93027 && c <= 93047)
                    : c <= 93071)
                  : (c <= 93823 || (c >= 93952 && c <= 94026)))
                : (c <= 94032 || (c < 94179
                  ? (c < 94176
                    ? (c >= 94099 && c <= 94111)
                    : c <= 94177)
                  : (c <= 94179 || (c >= 94208 && c <= 100343)))))
              : (c <= 101589 || (c < 110960
                ? (c < 110928
                  ? (c < 110592
                    ? (c >= 101632 && c <= 101640)
                    : c <= 110878)
                  : (c <= 110930 || (c >= 110948 && c <= 110951)))
                : (c <= 111355 || (c < 113776
                  ? (c >= 113664 && c <= 113770)
                  : (c <= 113788 || (c >= 113792 && c <= 113800)))))))))))
        : (c <= 113817 || (c < 126469
          ? (c < 120488
            ? (c < 120005
              ? (c < 119973
                ? (c < 119966
                  ? (c < 119894
                    ? (c >= 119808 && c <= 119892)
                    : c <= 119964)
                  : (c <= 119967 || c == 119970))
                : (c <= 119974 || (c < 119995
                  ? (c < 119982
                    ? (c >= 119977 && c <= 119980)
                    : c <= 119993)
                  : (c <= 119995 || (c >= 119997 && c <= 120003)))))
              : (c <= 120069 || (c < 120123
                ? (c < 120086
                  ? (c < 120077
                    ? (c >= 120071 && c <= 120074)
                    : c <= 120084)
                  : (c <= 120092 || (c >= 120094 && c <= 120121)))
                : (c <= 120126 || (c < 120138
                  ? (c < 120134
                    ? (c >= 120128 && c <= 120132)
                    : c <= 120134)
                  : (c <= 120144 || (c >= 120146 && c <= 120485)))))))
            : (c <= 120512 || (c < 120772
              ? (c < 120630
                ? (c < 120572
                  ? (c < 120540
                    ? (c >= 120514 && c <= 120538)
                    : c <= 120570)
                  : (c <= 120596 || (c >= 120598 && c <= 120628)))
                : (c <= 120654 || (c < 120714
                  ? (c < 120688
                    ? (c >= 120656 && c <= 120686)
                    : c <= 120712)
                  : (c <= 120744 || (c >= 120746 && c <= 120770)))))
              : (c <= 120779 || (c < 124928
                ? (c < 123214
                  ? (c < 123191
                    ? (c >= 123136 && c <= 123180)
                    : c <= 123197)
                  : (c <= 123214 || (c >= 123584 && c <= 123627)))
                : (c <= 125124 || (c < 125259
                  ? (c >= 125184 && c <= 125251)
                  : (c <= 125259 || (c >= 126464 && c <= 126467)))))))))
          : (c <= 126495 || (c < 126561
            ? (c < 126537
              ? (c < 126516
                ? (c < 126503
                  ? (c < 126500
                    ? (c >= 126497 && c <= 126498)
                    : c <= 126500)
                  : (c <= 126503 || (c >= 126505 && c <= 126514)))
                : (c <= 126519 || (c < 126530
                  ? (c < 126523
                    ? c == 126521
                    : c <= 126523)
                  : (c <= 126530 || c == 126535))))
              : (c <= 126537 || (c < 126551
                ? (c < 126545
                  ? (c < 126541
                    ? c == 126539
                    : c <= 126543)
                  : (c <= 126546 || c == 126548))
                : (c <= 126551 || (c < 126557
                  ? (c < 126555
                    ? c == 126553
                    : c <= 126555)
                  : (c <= 126557 || c == 126559))))))
            : (c <= 126562 || (c < 126629
              ? (c < 126585
                ? (c < 126572
                  ? (c < 126567
                    ? c == 126564
                    : c <= 126570)
                  : (c <= 126578 || (c >= 126580 && c <= 126583)))
                : (c <= 126588 || (c < 126603
                  ? (c < 126592
                    ? c == 126590
                    : c <= 126601)
                  : (c <= 126619 || (c >= 126625 && c <= 126627)))))
              : (c <= 126633 || (c < 178208
                ? (c < 173824
                  ? (c < 131072
                    ? (c >= 126635 && c <= 126651)
                    : c <= 173789)
                  : (c <= 177972 || (c >= 177984 && c <= 178205)))
                : (c <= 183969 || (c < 194560
                  ? (c >= 183984 && c <= 191456)
                  : (c <= 195101 || (c >= 196608 && c <= 201546)))))))))))))))));
}

static inline bool sym_identifier_character_set_2(int32_t c) {
  return (c < 43052
    ? (c < 3718
      ? (c < 2730
        ? (c < 2042
          ? (c < 1015
            ? (c < 710
              ? (c < 181
                ? (c < '_'
                  ? (c < 'A'
                    ? (c >= '0' && c <= '9')
                    : c <= 'Z')
                  : (c <= '_' || (c < 170
                    ? (c >= 'a' && c <= 'z')
                    : c <= 170)))
                : (c <= 181 || (c < 192
                  ? (c < 186
                    ? c == 183
                    : c <= 186)
                  : (c <= 214 || (c < 248
                    ? (c >= 216 && c <= 246)
                    : c <= 705)))))
              : (c <= 721 || (c < 891
                ? (c < 750
                  ? (c < 748
                    ? (c >= 736 && c <= 740)
                    : c <= 748)
                  : (c <= 750 || (c < 886
                    ? (c >= 768 && c <= 884)
                    : c <= 887)))
                : (c <= 893 || (c < 908
                  ? (c < 902
                    ? c == 895
                    : c <= 906)
                  : (c <= 908 || (c < 931
                    ? (c >= 910 && c <= 929)
                    : c <= 1013)))))))
            : (c <= 1153 || (c < 1519
              ? (c < 1425
                ? (c < 1329
                  ? (c < 1162
                    ? (c >= 1155 && c <= 1159)
                    : c <= 1327)
                  : (c <= 1366 || (c < 1376
                    ? c == 1369
                    : c <= 1416)))
                : (c <= 1469 || (c < 1476
                  ? (c < 1473
                    ? c == 1471
                    : c <= 1474)
                  : (c <= 1477 || (c < 1488
                    ? c == 1479
                    : c <= 1514)))))
              : (c <= 1522 || (c < 1770
                ? (c < 1646
                  ? (c < 1568
                    ? (c >= 1552 && c <= 1562)
                    : c <= 1641)
                  : (c <= 1747 || (c < 1759
                    ? (c >= 1749 && c <= 1756)
                    : c <= 1768)))
                : (c <= 1788 || (c < 1869
                  ? (c < 1808
                    ? c == 1791
                    : c <= 1866)
                  : (c <= 1969 || (c >= 1984 && c <= 2037)))))))))
          : (c <= 2042 || (c < 2534
            ? (c < 2447
              ? (c < 2230
                ? (c < 2112
                  ? (c < 2048
                    ? c == 2045
                    : c <= 2093)
                  : (c <= 2139 || (c < 2208
                    ? (c >= 2144 && c <= 2154)
                    : c <= 2228)))
                : (c <= 2247 || (c < 2406
                  ? (c < 2275
                    ? (c >= 2259 && c <= 2273)
                    : c <= 2403)
                  : (c <= 2415 || (c < 2437
                    ? (c >= 2417 && c <= 2435)
                    : c <= 2444)))))
              : (c <= 2448 || (c < 2503
                ? (c < 2482
                  ? (c < 2474
                    ? (c >= 2451 && c <= 2472)
                    : c <= 2480)
                  : (c <= 2482 || (c < 2492
                    ? (c >= 2486 && c <= 2489)
                    : c <= 2500)))
                : (c <= 2504 || (c < 2524
                  ? (c < 2519
                    ? (c >= 2507 && c <= 2510)
                    : c <= 2519)
                  : (c <= 2525 || (c >= 2527 && c <= 2531)))))))
            : (c <= 2545 || (c < 2622
              ? (c < 2579
                ? (c < 2561
                  ? (c < 2558
                    ? c == 2556
                    : c <= 2558)
                  : (c <= 2563 || (c < 2575
                    ? (c >= 2565 && c <= 2570)
                    : c <= 2576)))
                : (c <= 2600 || (c < 2613
                  ? (c < 2610
                    ? (c >= 2602 && c <= 2608)
                    : c <= 2611)
                  : (c <= 2614 || (c < 2620
                    ? (c >= 2616 && c <= 2617)
                    : c <= 2620)))))
              : (c <= 2626 || (c < 2662
                ? (c < 2641
                  ? (c < 2635
                    ? (c >= 2631 && c <= 2632)
                    : c <= 2637)
                  : (c <= 2641 || (c < 2654
                    ? (c >= 2649 && c <= 2652)
                    : c <= 2654)))
                : (c <= 2677 || (c < 2703
                  ? (c < 2693
                    ? (c >= 2689 && c <= 2691)
                    : c <= 2701)
                  : (c <= 2705 || (c >= 2707 && c <= 2728)))))))))))
        : (c <= 2736 || (c < 3142
          ? (c < 2918
            ? (c < 2831
              ? (c < 2768
                ? (c < 2748
                  ? (c < 2741
                    ? (c >= 2738 && c <= 2739)
                    : c <= 2745)
                  : (c <= 2757 || (c < 2763
                    ? (c >= 2759 && c <= 2761)
                    : c <= 2765)))
                : (c <= 2768 || (c < 2809
                  ? (c < 2790
                    ? (c >= 2784 && c <= 2787)
                    : c <= 2799)
                  : (c <= 2815 || (c < 2821
                    ? (c >= 2817 && c <= 2819)
                    : c <= 2828)))))
              : (c <= 2832 || (c < 2887
                ? (c < 2866
                  ? (c < 2858
                    ? (c >= 2835 && c <= 2856)
                    : c <= 2864)
                  : (c <= 2867 || (c < 2876
                    ? (c >= 2869 && c <= 2873)
                    : c <= 2884)))
                : (c <= 2888 || (c < 2908
                  ? (c < 2901
                    ? (c >= 2891 && c <= 2893)
                    : c <= 2903)
                  : (c <= 2909 || (c >= 2911 && c <= 2915)))))))
            : (c <= 2927 || (c < 3006
              ? (c < 2969
                ? (c < 2949
                  ? (c < 2946
                    ? c == 2929
                    : c <= 2947)
                  : (c <= 2954 || (c < 2962
                    ? (c >= 2958 && c <= 2960)
                    : c <= 2965)))
                : (c <= 2970 || (c < 2979
                  ? (c < 2974
                    ? c == 2972
                    : c <= 2975)
                  : (c <= 2980 || (c < 2990
                    ? (c >= 2984 && c <= 2986)
                    : c <= 3001)))))
              : (c <= 3010 || (c < 3072
                ? (c < 3024
                  ? (c < 3018
                    ? (c >= 3014 && c <= 3016)
                    : c <= 3021)
                  : (c <= 3024 || (c < 3046
                    ? c == 3031
                    : c <= 3055)))
                : (c <= 3084 || (c < 3114
                  ? (c < 3090
                    ? (c >= 3086 && c <= 3088)
                    : c <= 3112)
                  : (c <= 3129 || (c >= 3133 && c <= 3140)))))))))
          : (c <= 3144 || (c < 3398
            ? (c < 3260
              ? (c < 3200
                ? (c < 3160
                  ? (c < 3157
                    ? (c >= 3146 && c <= 3149)
                    : c <= 3158)
                  : (c <= 3162 || (c < 3174
                    ? (c >= 3168 && c <= 3171)
                    : c <= 3183)))
                : (c <= 3203 || (c < 3218
                  ? (c < 3214
                    ? (c >= 3205 && c <= 3212)
                    : c <= 3216)
                  : (c <= 3240 || (c < 3253
                    ? (c >= 3242 && c <= 3251)
                    : c <= 3257)))))
              : (c <= 3268 || (c < 3302
                ? (c < 3285
                  ? (c < 3274
                    ? (c >= 3270 && c <= 3272)
                    : c <= 3277)
                  : (c <= 3286 || (c < 3296
                    ? c == 3294
                    : c <= 3299)))
                : (c <= 3311 || (c < 3342
                  ? (c < 3328
                    ? (c >= 3313 && c <= 3314)
                    : c <= 3340)
                  : (c <= 3344 || (c >= 3346 && c <= 3396)))))))
            : (c <= 3400 || (c < 3530
              ? (c < 3457
                ? (c < 3423
                  ? (c < 3412
                    ? (c >= 3402 && c <= 3406)
                    : c <= 3415)
                  : (c <= 3427 || (c < 3450
                    ? (c >= 3430 && c <= 3439)
                    : c <= 3455)))
                : (c <= 3459 || (c < 3507
                  ? (c < 3482
                    ? (c >= 3461 && c <= 3478)
                    : c <= 3505)
                  : (c <= 3515 || (c < 3520
                    ? c == 3517
                    : c <= 3526)))))
              : (c <= 3530 || (c < 3585
                ? (c < 3544
                  ? (c < 3542
                    ? (c >= 3535 && c <= 3540)
                    : c <= 3542)
                  : (c <= 3551 || (c < 3570
                    ? (c >= 3558 && c <= 3567)
                    : c <= 3571)))
                : (c <= 3642 || (c < 3713
                  ? (c < 3664
                    ? (c >= 3648 && c <= 3662)
                    : c <= 3673)
                  : (c <= 3714 || c == 3716))))))))))))
      : (c <= 3722 || (c < 7296
        ? (c < 5024
          ? (c < 4256
            ? (c < 3893
              ? (c < 3784
                ? (c < 3751
                  ? (c < 3749
                    ? (c >= 3724 && c <= 3747)
                    : c <= 3749)
                  : (c <= 3773 || (c < 3782
                    ? (c >= 3776 && c <= 3780)
                    : c <= 3782)))
                : (c <= 3789 || (c < 3840
                  ? (c < 3804
                    ? (c >= 3792 && c <= 3801)
                    : c <= 3807)
                  : (c <= 3840 || (c < 3872
                    ? (c >= 3864 && c <= 3865)
                    : c <= 3881)))))
              : (c <= 3893 || (c < 3974
                ? (c < 3902
                  ? (c < 3897
                    ? c == 3895
                    : c <= 3897)
                  : (c <= 3911 || (c < 3953
                    ? (c >= 3913 && c <= 3948)
                    : c <= 3972)))
                : (c <= 3991 || (c < 4096
                  ? (c < 4038
                    ? (c >= 3993 && c <= 4028)
                    : c <= 4038)
                  : (c <= 4169 || (c >= 4176 && c <= 4253)))))))
            : (c <= 4293 || (c < 4786
              ? (c < 4688
                ? (c < 4304
                  ? (c < 4301
                    ? c == 4295
                    : c <= 4301)
                  : (c <= 4346 || (c < 4682
                    ? (c >= 4348 && c <= 4680)
                    : c <= 4685)))
                : (c <= 4694 || (c < 4704
                  ? (c < 4698
                    ? c == 4696
                    : c <= 4701)
                  : (c <= 4744 || (c < 4752
                    ? (c >= 4746 && c <= 4749)
                    : c <= 4784)))))
              : (c <= 4789 || (c < 4882
                ? (c < 4802
                  ? (c < 4800
                    ? (c >= 4792 && c <= 4798)
                    : c <= 4800)
                  : (c <= 4805 || (c < 4824
                    ? (c >= 4808 && c <= 4822)
                    : c <= 4880)))
                : (c <= 4885 || (c < 4969
                  ? (c < 4957
                    ? (c >= 4888 && c <= 4954)
                    : c <= 4959)
                  : (c <= 4977 || (c >= 4992 && c <= 5007)))))))))
          : (c <= 5109 || (c < 6400
            ? (c < 5998
              ? (c < 5870
                ? (c < 5743
                  ? (c < 5121
                    ? (c >= 5112 && c <= 5117)
                    : c <= 5740)
                  : (c <= 5759 || (c < 5792
                    ? (c >= 5761 && c <= 5786)
                    : c <= 5866)))
                : (c <= 5880 || (c < 5920
                  ? (c < 5902
                    ? (c >= 5888 && c <= 5900)
                    : c <= 5908)
                  : (c <= 5940 || (c < 5984
                    ? (c >= 5952 && c <= 5971)
                    : c <= 5996)))))
              : (c <= 6000 || (c < 6155
                ? (c < 6103
                  ? (c < 6016
                    ? (c >= 6002 && c <= 6003)
                    : c <= 6099)
                  : (c <= 6103 || (c < 6112
                    ? (c >= 6108 && c <= 6109)
                    : c <= 6121)))
                : (c <= 6157 || (c < 6272
                  ? (c < 6176
                    ? (c >= 6160 && c <= 6169)
                    : c <= 6264)
                  : (c <= 6314 || (c >= 6320 && c <= 6389)))))))
            : (c <= 6430 || (c < 6800
              ? (c < 6576
                ? (c < 6470
                  ? (c < 6448
                    ? (c >= 6432 && c <= 6443)
                    : c <= 6459)
                  : (c <= 6509 || (c < 6528
                    ? (c >= 6512 && c <= 6516)
                    : c <= 6571)))
                : (c <= 6601 || (c < 6688
                  ? (c < 6656
                    ? (c >= 6608 && c <= 6618)
                    : c <= 6683)
                  : (c <= 6750 || (c < 6783
                    ? (c >= 6752 && c <= 6780)
                    : c <= 6793)))))
              : (c <= 6809 || (c < 7019
                ? (c < 6847
                  ? (c < 6832
                    ? c == 6823
                    : c <= 6845)
                  : (c <= 6848 || (c < 6992
                    ? (c >= 6912 && c <= 6987)
                    : c <= 7001)))
                : (c <= 7027 || (c < 7232
                  ? (c < 7168
                    ? (c >= 7040 && c <= 7155)
                    : c <= 7223)
                  : (c <= 7241 || (c >= 7245 && c <= 7293)))))))))))
        : (c <= 7304 || (c < 11264
          ? (c < 8178
            ? (c < 8027
              ? (c < 7675
                ? (c < 7376
                  ? (c < 7357
                    ? (c >= 7312 && c <= 7354)
                    : c <= 7359)
                  : (c <= 7378 || (c < 7424
                    ? (c >= 7380 && c <= 7418)
                    : c <= 7673)))
                : (c <= 7957 || (c < 8008
                  ? (c < 7968
                    ? (c >= 7960 && c <= 7965)
                    : c <= 8005)
                  : (c <= 8013 || (c < 8025
                    ? (c >= 8016 && c <= 8023)
                    : c <= 8025)))))
              : (c <= 8027 || (c < 8130
                ? (c < 8064
                  ? (c < 8031
                    ? c == 8029
                    : c <= 8061)
                  : (c <= 8116 || (c < 8126
                    ? (c >= 8118 && c <= 8124)
                    : c <= 8126)))
                : (c <= 8132 || (c < 8150
                  ? (c < 8144
                    ? (c >= 8134 && c <= 8140)
                    : c <= 8147)
                  : (c <= 8155 || (c >= 8160 && c <= 8172)))))))
            : (c <= 8180 || (c < 8458
              ? (c < 8336
                ? (c < 8276
                  ? (c < 8255
                    ? (c >= 8182 && c <= 8188)
                    : c <= 8256)
                  : (c <= 8276 || (c < 8319
                    ? c == 8305
                    : c <= 8319)))
                : (c <= 8348 || (c < 8421
                  ? (c < 8417
                    ? (c >= 8400 && c <= 8412)
                    : c <= 8417)
                  : (c <= 8432 || (c < 8455
                    ? c == 8450
                    : c <= 8455)))))
              : (c <= 8467 || (c < 8490
                ? (c < 8484
                  ? (c < 8472
                    ? c == 8469
                    : c <= 8477)
                  : (c <= 8484 || (c < 8488
                    ? c == 8486
                    : c <= 8488)))
                : (c <= 8505 || (c < 8526
                  ? (c < 8517
                    ? (c >= 8508 && c <= 8511)
                    : c <= 8521)
                  : (c <= 8526 || (c >= 8544 && c <= 8584)))))))))
          : (c <= 11310 || (c < 12353
            ? (c < 11696
              ? (c < 11565
                ? (c < 11499
                  ? (c < 11360
                    ? (c >= 11312 && c <= 11358)
                    : c <= 11492)
                  : (c <= 11507 || (c < 11559
                    ? (c >= 11520 && c <= 11557)
                    : c <= 11559)))
                : (c <= 11565 || (c < 11647
                  ? (c < 11631
                    ? (c >= 11568 && c <= 11623)
                    : c <= 11631)
                  : (c <= 11670 || (c < 11688
                    ? (c >= 11680 && c <= 11686)
                    : c <= 11694)))))
              : (c <= 11702 || (c < 11744
                ? (c < 11720
                  ? (c < 11712
                    ? (c >= 11704 && c <= 11710)
                    : c <= 11718)
                  : (c <= 11726 || (c < 11736
                    ? (c >= 11728 && c <= 11734)
                    : c <= 11742)))
                : (c <= 11775 || (c < 12337
                  ? (c < 12321
                    ? (c >= 12293 && c <= 12295)
                    : c <= 12335)
                  : (c <= 12341 || (c >= 12344 && c <= 12348)))))))
            : (c <= 12438 || (c < 42192
              ? (c < 12593
                ? (c < 12449
                  ? (c < 12445
                    ? (c >= 12441 && c <= 12442)
                    : c <= 12447)
                  : (c <= 12538 || (c < 12549
                    ? (c >= 12540 && c <= 12543)
                    : c <= 12591)))
                : (c <= 12686 || (c < 13312
                  ? (c < 12784
                    ? (c >= 12704 && c <= 12735)
                    : c <= 12799)
                  : (c <= 19903 || (c < 40960
                    ? (c >= 19968 && c <= 40956)
                    : c <= 42124)))))
              : (c <= 42237 || (c < 42775
                ? (c < 42560
                  ? (c < 42512
                    ? (c >= 42240 && c <= 42508)
                    : c <= 42539)
                  : (c <= 42607 || (c < 42623
                    ? (c >= 42612 && c <= 42621)
                    : c <= 42737)))
                : (c <= 42783 || (c < 42946
                  ? (c < 42891
                    ? (c >= 42786 && c <= 42888)
                    : c <= 42943)
                  : (c <= 42954 || (c >= 42997 && c <= 43047)))))))))))))))
    : (c <= 43052 || (c < 71096
      ? (c < 66864
        ? (c < 64914
          ? (c < 43816
            ? (c < 43520
              ? (c < 43261
                ? (c < 43216
                  ? (c < 43136
                    ? (c >= 43072 && c <= 43123)
                    : c <= 43205)
                  : (c <= 43225 || (c < 43259
                    ? (c >= 43232 && c <= 43255)
                    : c <= 43259)))
                : (c <= 43309 || (c < 43392
                  ? (c < 43360
                    ? (c >= 43312 && c <= 43347)
                    : c <= 43388)
                  : (c <= 43456 || (c < 43488
                    ? (c >= 43471 && c <= 43481)
                    : c <= 43518)))))
              : (c <= 43574 || (c < 43744
                ? (c < 43616
                  ? (c < 43600
                    ? (c >= 43584 && c <= 43597)
                    : c <= 43609)
                  : (c <= 43638 || (c < 43739
                    ? (c >= 43642 && c <= 43714)
                    : c <= 43741)))
                : (c <= 43759 || (c < 43785
                  ? (c < 43777
                    ? (c >= 43762 && c <= 43766)
                    : c <= 43782)
                  : (c <= 43790 || (c < 43808
                    ? (c >= 43793 && c <= 43798)
                    : c <= 43814)))))))
            : (c <= 43822 || (c < 64275
              ? (c < 44032
                ? (c < 43888
                  ? (c < 43868
                    ? (c >= 43824 && c <= 43866)
                    : c <= 43881)
                  : (c <= 44010 || (c < 44016
                    ? (c >= 44012 && c <= 44013)
                    : c <= 44025)))
                : (c <= 55203 || (c < 63744
                  ? (c < 55243
                    ? (c >= 55216 && c <= 55238)
                    : c <= 55291)
                  : (c <= 64109 || (c < 64256
                    ? (c >= 64112 && c <= 64217)
                    : c <= 64262)))))
              : (c <= 64279 || (c < 64323
                ? (c < 64312
                  ? (c < 64298
                    ? (c >= 64285 && c <= 64296)
                    : c <= 64310)
                  : (c <= 64316 || (c < 64320
                    ? c == 64318
                    : c <= 64321)))
                : (c <= 64324 || (c < 64612
                  ? (c < 64467
                    ? (c >= 64326 && c <= 64433)
                    : c <= 64605)
                  : (c <= 64829 || (c >= 64848 && c <= 64911)))))))))
          : (c <= 64967 || (c < 65549
            ? (c < 65151
              ? (c < 65137
                ? (c < 65056
                  ? (c < 65024
                    ? (c >= 65008 && c <= 65017)
                    : c <= 65039)
                  : (c <= 65071 || (c < 65101
                    ? (c >= 65075 && c <= 65076)
                    : c <= 65103)))
                : (c <= 65137 || (c < 65145
                  ? (c < 65143
                    ? c == 65139
                    : c <= 65143)
                  : (c <= 65145 || (c < 65149
                    ? c == 65147
                    : c <= 65149)))))
              : (c <= 65276 || (c < 65474
                ? (c < 65343
                  ? (c < 65313
                    ? (c >= 65296 && c <= 65305)
                    : c <= 65338)
                  : (c <= 65343 || (c < 65382
                    ? (c >= 65345 && c <= 65370)
                    : c <= 65470)))
                : (c <= 65479 || (c < 65498
                  ? (c < 65490
                    ? (c >= 65482 && c <= 65487)
                    : c <= 65495)
                  : (c <= 65500 || (c >= 65536 && c <= 65547)))))))
            : (c <= 65574 || (c < 66349
              ? (c < 65856
                ? (c < 65599
                  ? (c < 65596
                    ? (c >= 65576 && c <= 65594)
                    : c <= 65597)
                  : (c <= 65613 || (c < 65664
                    ? (c >= 65616 && c <= 65629)
                    : c <= 65786)))
                : (c <= 65908 || (c < 66208
                  ? (c < 66176
                    ? c == 66045
                    : c <= 66204)
                  : (c <= 66256 || (c < 66304
                    ? c == 66272
                    : c <= 66335)))))
              : (c <= 66378 || (c < 66560
                ? (c < 66464
                  ? (c < 66432
                    ? (c >= 66384 && c <= 66426)
                    : c <= 66461)
                  : (c <= 66499 || (c < 66513
                    ? (c >= 66504 && c <= 66511)
                    : c <= 66517)))
                : (c <= 66717 || (c < 66776
                  ? (c < 66736
                    ? (c >= 66720 && c <= 66729)
                    : c <= 66771)
                  : (c <= 66811 || (c >= 66816 && c <= 66855)))))))))))
        : (c <= 66915 || (c < 69632
          ? (c < 68152
            ? (c < 67808
              ? (c < 67594
                ? (c < 67424
                  ? (c < 67392
                    ? (c >= 67072 && c <= 67382)
                    : c <= 67413)
                  : (c <= 67431 || (c < 67592
                    ? (c >= 67584 && c <= 67589)
                    : c <= 67592)))
                : (c <= 67637 || (c < 67647
                  ? (c < 67644
                    ? (c >= 67639 && c <= 67640)
                    : c <= 67644)
                  : (c <= 67669 || (c < 67712
                    ? (c >= 67680 && c <= 67702)
                    : c <= 67742)))))
              : (c <= 67826 || (c < 68096
                ? (c < 67872
                  ? (c < 67840
                    ? (c >= 67828 && c <= 67829)
                    : c <= 67861)
                  : (c <= 67897 || (c < 68030
                    ? (c >= 67968 && c <= 68023)
                    : c <= 68031)))
                : (c <= 68099 || (c < 68117
                  ? (c < 68108
                    ? (c >= 68101 && c <= 68102)
                    : c <= 68115)
                  : (c <= 68119 || (c >= 68121 && c <= 68149)))))))
            : (c <= 68154 || (c < 68800
              ? (c < 68352
                ? (c < 68224
                  ? (c < 68192
                    ? c == 68159
                    : c <= 68220)
                  : (c <= 68252 || (c < 68297
                    ? (c >= 68288 && c <= 68295)
                    : c <= 68326)))
                : (c <= 68405 || (c < 68480
                  ? (c < 68448
                    ? (c >= 68416 && c <= 68437)
                    : c <= 68466)
                  : (c <= 68497 || (c < 68736
                    ? (c >= 68608 && c <= 68680)
                    : c <= 68786)))))
              : (c <= 68850 || (c < 69376
                ? (c < 69248
                  ? (c < 68912
                    ? (c >= 68864 && c <= 68903)
                    : c <= 68921)
                  : (c <= 69289 || (c < 69296
                    ? (c >= 69291 && c <= 69292)
                    : c <= 69297)))
                : (c <= 69404 || (c < 69552
                  ? (c < 69424
                    ? c == 69415
                    : c <= 69456)
                  : (c <= 69572 || (c >= 69600 && c <= 69622)))))))))
          : (c <= 69702 || (c < 70384
            ? (c < 70094
              ? (c < 69942
                ? (c < 69840
                  ? (c < 69759
                    ? (c >= 69734 && c <= 69743)
                    : c <= 69818)
                  : (c <= 69864 || (c < 69888
                    ? (c >= 69872 && c <= 69881)
                    : c <= 69940)))
                : (c <= 69951 || (c < 70006
                  ? (c < 69968
                    ? (c >= 69956 && c <= 69959)
                    : c <= 70003)
                  : (c <= 70006 || (c < 70089
                    ? (c >= 70016 && c <= 70084)
                    : c <= 70092)))))
              : (c <= 70106 || (c < 70280
                ? (c < 70163
                  ? (c < 70144
                    ? c == 70108
                    : c <= 70161)
                  : (c <= 70199 || (c < 70272
                    ? c == 70206
                    : c <= 70278)))
                : (c <= 70280 || (c < 70303
                  ? (c < 70287
                    ? (c >= 70282 && c <= 70285)
                    : c <= 70301)
                  : (c <= 70312 || (c >= 70320 && c <= 70378)))))))
            : (c <= 70393 || (c < 70487
              ? (c < 70450
                ? (c < 70415
                  ? (c < 70405
                    ? (c >= 70400 && c <= 70403)
                    : c <= 70412)
                  : (c <= 70416 || (c < 70442
                    ? (c >= 70419 && c <= 70440)
                    : c <= 70448)))
                : (c <= 70451 || (c < 70471
                  ? (c < 70459
                    ? (c >= 70453 && c <= 70457)
                    : c <= 70468)
                  : (c <= 70472 || (c < 70480
                    ? (c >= 70475 && c <= 70477)
                    : c <= 70480)))))
              : (c <= 70487 || (c < 70750
                ? (c < 70512
                  ? (c < 70502
                    ? (c >= 70493 && c <= 70499)
                    : c <= 70508)
                  : (c <= 70516 || (c < 70736
                    ? (c >= 70656 && c <= 70730)
                    : c <= 70745)))
                : (c <= 70753 || (c < 70864
                  ? (c < 70855
                    ? (c >= 70784 && c <= 70853)
                    : c <= 70855)
                  : (c <= 70873 || (c >= 71040 && c <= 71093)))))))))))))
      : (c <= 71104 || (c < 119894
        ? (c < 73104
          ? (c < 72163
            ? (c < 71935
              ? (c < 71360
                ? (c < 71236
                  ? (c < 71168
                    ? (c >= 71128 && c <= 71133)
                    : c <= 71232)
                  : (c <= 71236 || (c < 71296
                    ? (c >= 71248 && c <= 71257)
                    : c <= 71352)))
                : (c <= 71369 || (c < 71472
                  ? (c < 71453
                    ? (c >= 71424 && c <= 71450)
                    : c <= 71467)
                  : (c <= 71481 || (c < 71840
                    ? (c >= 71680 && c <= 71738)
                    : c <= 71913)))))
              : (c <= 71942 || (c < 71995
                ? (c < 71957
                  ? (c < 71948
                    ? c == 71945
                    : c <= 71955)
                  : (c <= 71958 || (c < 71991
                    ? (c >= 71960 && c <= 71989)
                    : c <= 71992)))
                : (c <= 72003 || (c < 72106
                  ? (c < 72096
                    ? (c >= 72016 && c <= 72025)
                    : c <= 72103)
                  : (c <= 72151 || (c >= 72154 && c <= 72161)))))))
            : (c <= 72164 || (c < 72873
              ? (c < 72704
                ? (c < 72272
                  ? (c < 72263
                    ? (c >= 72192 && c <= 72254)
                    : c <= 72263)
                  : (c <= 72345 || (c < 72384
                    ? c == 72349
                    : c <= 72440)))
                : (c <= 72712 || (c < 72784
                  ? (c < 72760
                    ? (c >= 72714 && c <= 72758)
                    : c <= 72768)
                  : (c <= 72793 || (c < 72850
                    ? (c >= 72818 && c <= 72847)
                    : c <= 72871)))))
              : (c <= 72886 || (c < 73023
                ? (c < 72971
                  ? (c < 72968
                    ? (c >= 72960 && c <= 72966)
                    : c <= 72969)
                  : (c <= 73014 || (c < 73020
                    ? c == 73018
                    : c <= 73021)))
                : (c <= 73031 || (c < 73063
                  ? (c < 73056
                    ? (c >= 73040 && c <= 73049)
                    : c <= 73061)
                  : (c <= 73064 || (c >= 73066 && c <= 73102)))))))))
          : (c <= 73105 || (c < 94095
            ? (c < 92768
              ? (c < 74752
                ? (c < 73440
                  ? (c < 73120
                    ? (c >= 73107 && c <= 73112)
                    : c <= 73129)
                  : (c <= 73462 || (c < 73728
                    ? c == 73648
                    : c <= 74649)))
                : (c <= 74862 || (c < 82944
                  ? (c < 77824
                    ? (c >= 74880 && c <= 75075)
                    : c <= 78894)
                  : (c <= 83526 || (c < 92736
                    ? (c >= 92160 && c <= 92728)
                    : c <= 92766)))))
              : (c <= 92777 || (c < 93027
                ? (c < 92928
                  ? (c < 92912
                    ? (c >= 92880 && c <= 92909)
                    : c <= 92916)
                  : (c <= 92982 || (c < 93008
                    ? (c >= 92992 && c <= 92995)
                    : c <= 93017)))
                : (c <= 93047 || (c < 93952
                  ? (c < 93760
                    ? (c >= 93053 && c <= 93071)
                    : c <= 93823)
                  : (c <= 94026 || (c >= 94031 && c <= 94087)))))))
            : (c <= 94111 || (c < 113776
              ? (c < 101632
                ? (c < 94192
                  ? (c < 94179
                    ? (c >= 94176 && c <= 94177)
                    : c <= 94180)
                  : (c <= 94193 || (c < 100352
                    ? (c >= 94208 && c <= 100343)
                    : c <= 101589)))
                : (c <= 101640 || (c < 110948
                  ? (c < 110928
                    ? (c >= 110592 && c <= 110878)
                    : c <= 110930)
                  : (c <= 110951 || (c < 113664
                    ? (c >= 110960 && c <= 111355)
                    : c <= 113770)))))
              : (c <= 113788 || (c < 119163
                ? (c < 113821
                  ? (c < 113808
                    ? (c >= 113792 && c <= 113800)
                    : c <= 113817)
                  : (c <= 113822 || (c < 119149
                    ? (c >= 119141 && c <= 119145)
                    : c <= 119154)))
                : (c <= 119170 || (c < 119362
                  ? (c < 119210
                    ? (c >= 119173 && c <= 119179)
                    : c <= 119213)
                  : (c <= 119364 || (c >= 119808 && c <= 119892)))))))))))
        : (c <= 119964 || (c < 124928
          ? (c < 120630
            ? (c < 120094
              ? (c < 119995
                ? (c < 119973
                  ? (c < 119970
                    ? (c >= 119966 && c <= 119967)
                    : c <= 119970)
                  : (c <= 119974 || (c < 119982
                    ? (c >= 119977 && c <= 119980)
                    : c <= 119993)))
                : (c <= 119995 || (c < 120071
                  ? (c < 120005
                    ? (c >= 119997 && c <= 120003)
                    : c <= 120069)
                  : (c <= 120074 || (c < 120086
                    ? (c >= 120077 && c <= 120084)
                    : c <= 120092)))))
              : (c <= 120121 || (c < 120488
                ? (c < 120134
                  ? (c < 120128
                    ? (c >= 120123 && c <= 120126)
                    : c <= 120132)
                  : (c <= 120134 || (c < 120146
                    ? (c >= 120138 && c <= 120144)
                    : c <= 120485)))
                : (c <= 120512 || (c < 120572
                  ? (c < 120540
                    ? (c >= 120514 && c <= 120538)
                    : c <= 120570)
                  : (c <= 120596 || (c >= 120598 && c <= 120628)))))))
            : (c <= 120654 || (c < 121505
              ? (c < 120782
                ? (c < 120714
                  ? (c < 120688
                    ? (c >= 120656 && c <= 120686)
                    : c <= 120712)
                  : (c <= 120744 || (c < 120772
                    ? (c >= 120746 && c <= 120770)
                    : c <= 120779)))
                : (c <= 120831 || (c < 121461
                  ? (c < 121403
                    ? (c >= 121344 && c <= 121398)
                    : c <= 121452)
                  : (c <= 121461 || (c < 121499
                    ? c == 121476
                    : c <= 121503)))))
              : (c <= 121519 || (c < 123136
                ? (c < 122907
                  ? (c < 122888
                    ? (c >= 122880 && c <= 122886)
                    : c <= 122904)
                  : (c <= 122913 || (c < 122918
                    ? (c >= 122915 && c <= 122916)
                    : c <= 122922)))
                : (c <= 123180 || (c < 123214
                  ? (c < 123200
                    ? (c >= 123184 && c <= 123197)
                    : c <= 123209)
                  : (c <= 123214 || (c >= 123584 && c <= 123641)))))))))
          : (c <= 125124 || (c < 126557
            ? (c < 126523
              ? (c < 126497
                ? (c < 125264
                  ? (c < 125184
                    ? (c >= 125136 && c <= 125142)
                    : c <= 125259)
                  : (c <= 125273 || (c < 126469
                    ? (c >= 126464 && c <= 126467)
                    : c <= 126495)))
                : (c <= 126498 || (c < 126505
                  ? (c < 126503
                    ? c == 126500
                    : c <= 126503)
                  : (c <= 126514 || (c < 126521
                    ? (c >= 126516 && c <= 126519)
                    : c <= 126521)))))
              : (c <= 126523 || (c < 126545
                ? (c < 126537
                  ? (c < 126535
                    ? c == 126530
                    : c <= 126535)
                  : (c <= 126537 || (c < 126541
                    ? c == 126539
                    : c <= 126543)))
                : (c <= 126546 || (c < 126553
                  ? (c < 126551
                    ? c == 126548
                    : c <= 126551)
                  : (c <= 126553 || c == 126555))))))
            : (c <= 126557 || (c < 126629
              ? (c < 126580
                ? (c < 126564
                  ? (c < 126561
                    ? c == 126559
                    : c <= 126562)
                  : (c <= 126564 || (c < 126572
                    ? (c >= 126567 && c <= 126570)
                    : c <= 126578)))
                : (c <= 126583 || (c < 126592
                  ? (c < 126590
                    ? (c >= 126585 && c <= 126588)
                    : c <= 126590)
                  : (c <= 126601 || (c < 126625
                    ? (c >= 126603 && c <= 126619)
                    : c <= 126627)))))
              : (c <= 126633 || (c < 178208
                ? (c < 131072
                  ? (c < 130032
                    ? (c >= 126635 && c <= 126651)
                    : c <= 130041)
                  : (c <= 173789 || (c < 177984
                    ? (c >= 173824 && c <= 177972)
                    : c <= 178205)))
                : (c <= 183969 || (c < 196608
                  ? (c < 194560
                    ? (c >= 183984 && c <= 191456)
                    : c <= 195101)
                  : (c <= 201546 || (c >= 917760 && c <= 917999)))))))))))))))));
}

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(40);
      if (lookahead == '!') ADVANCE(14);
      if (lookahead == '#') ADVANCE(115);
      if (lookahead == '%') ADVANCE(62);
      if (lookahead == '&') ADVANCE(65);
      if (lookahead == '(') ADVANCE(44);
      if (lookahead == ')') ADVANCE(45);
      if (lookahead == '*') ADVANCE(47);
      if (lookahead == '+') ADVANCE(58);
      if (lookahead == ',') ADVANCE(46);
      if (lookahead == '-') ADVANCE(60);
      if (lookahead == '.') ADVANCE(43);
      if (lookahead == '/') ADVANCE(61);
      if (lookahead == '0') ADVANCE(104);
      if (lookahead == ':') ADVANCE(51);
      if (lookahead == ';') ADVANCE(41);
      if (lookahead == '<') ADVANCE(69);
      if (lookahead == '=') ADVANCE(57);
      if (lookahead == '>') ADVANCE(74);
      if (lookahead == '@') ADVANCE(54);
      if (lookahead == '[') ADVANCE(55);
      if (lookahead == '\\') SKIP(36)
      if (lookahead == ']') ADVANCE(56);
      if (lookahead == '^') ADVANCE(66);
      if (lookahead == '{') ADVANCE(91);
      if (lookahead == '|') ADVANCE(64);
      if (lookahead == '}') ADVANCE(92);
      if (lookahead == '~') ADVANCE(68);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\f' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(0)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(103);
      if (sym_identifier_character_set_1(lookahead)) ADVANCE(114);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(10)
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(10)
      if (lookahead == '\r') SKIP(1)
      END_STATE();
    case 3:
      if (lookahead == '\n') ADVANCE(96);
      END_STATE();
    case 4:
      if (lookahead == '\n') SKIP(4)
      if (lookahead == '#') ADVANCE(100);
      if (lookahead == '\\') ADVANCE(98);
      if (lookahead == '{') ADVANCE(90);
      if (lookahead == '}') ADVANCE(92);
      if (lookahead == '\t' ||
          lookahead == '\f' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) ADVANCE(99);
      if (lookahead != 0) ADVANCE(100);
      END_STATE();
    case 5:
      if (lookahead == '\n') SKIP(11)
      END_STATE();
    case 6:
      if (lookahead == '\n') SKIP(11)
      if (lookahead == '\r') SKIP(5)
      END_STATE();
    case 7:
      if (lookahead == '\n') SKIP(9)
      END_STATE();
    case 8:
      if (lookahead == '\n') SKIP(9)
      if (lookahead == '\r') SKIP(7)
      END_STATE();
    case 9:
      if (lookahead == '!') ADVANCE(14);
      if (lookahead == '#') ADVANCE(115);
      if (lookahead == '%') ADVANCE(62);
      if (lookahead == '&') ADVANCE(65);
      if (lookahead == '(') ADVANCE(44);
      if (lookahead == ')') ADVANCE(45);
      if (lookahead == '*') ADVANCE(47);
      if (lookahead == '+') ADVANCE(58);
      if (lookahead == ',') ADVANCE(46);
      if (lookahead == '-') ADVANCE(59);
      if (lookahead == '.') ADVANCE(42);
      if (lookahead == '/') ADVANCE(61);
      if (lookahead == ':') ADVANCE(51);
      if (lookahead == ';') ADVANCE(41);
      if (lookahead == '<') ADVANCE(69);
      if (lookahead == '=') ADVANCE(57);
      if (lookahead == '>') ADVANCE(74);
      if (lookahead == '@') ADVANCE(54);
      if (lookahead == '[') ADVANCE(55);
      if (lookahead == '\\') SKIP(8)
      if (lookahead == ']') ADVANCE(56);
      if (lookahead == '^') ADVANCE(66);
      if (lookahead == '|') ADVANCE(64);
      if (lookahead == '}') ADVANCE(92);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\f' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(9)
      if (sym_identifier_character_set_1(lookahead)) ADVANCE(114);
      END_STATE();
    case 10:
      if (lookahead == '!') ADVANCE(14);
      if (lookahead == '#') ADVANCE(115);
      if (lookahead == '%') ADVANCE(62);
      if (lookahead == '&') ADVANCE(65);
      if (lookahead == '(') ADVANCE(44);
      if (lookahead == ')') ADVANCE(45);
      if (lookahead == '*') ADVANCE(47);
      if (lookahead == '+') ADVANCE(58);
      if (lookahead == ',') ADVANCE(46);
      if (lookahead == '-') ADVANCE(59);
      if (lookahead == '.') ADVANCE(42);
      if (lookahead == '/') ADVANCE(61);
      if (lookahead == ':') ADVANCE(50);
      if (lookahead == ';') ADVANCE(41);
      if (lookahead == '<') ADVANCE(69);
      if (lookahead == '=') ADVANCE(57);
      if (lookahead == '>') ADVANCE(74);
      if (lookahead == '@') ADVANCE(54);
      if (lookahead == '[') ADVANCE(55);
      if (lookahead == '\\') SKIP(2)
      if (lookahead == ']') ADVANCE(56);
      if (lookahead == '^') ADVANCE(66);
      if (lookahead == '|') ADVANCE(64);
      if (lookahead == '}') ADVANCE(92);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\f' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(10)
      if (sym_identifier_character_set_1(lookahead)) ADVANCE(114);
      END_STATE();
    case 11:
      if (lookahead == '#') ADVANCE(115);
      if (lookahead == '-') ADVANCE(15);
      if (lookahead == ':') ADVANCE(50);
      if (lookahead == '\\') SKIP(6)
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\f' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(11)
      END_STATE();
    case 12:
      if (lookahead == '#') ADVANCE(115);
      if (lookahead == '\\') ADVANCE(97);
      if (lookahead == '{') ADVANCE(91);
      if (lookahead == '}') ADVANCE(19);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\f' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(12)
      END_STATE();
    case 13:
      if (lookahead == '.') ADVANCE(89);
      END_STATE();
    case 14:
      if (lookahead == '=') ADVANCE(72);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(101);
      END_STATE();
    case 15:
      if (lookahead == '>') ADVANCE(52);
      END_STATE();
    case 16:
      if (lookahead == '_') ADVANCE(21);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(106);
      END_STATE();
    case 17:
      if (lookahead == '_') ADVANCE(22);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(107);
      END_STATE();
    case 18:
      if (lookahead == '_') ADVANCE(26);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(108);
      END_STATE();
    case 19:
      if (lookahead == '}') ADVANCE(94);
      END_STATE();
    case 20:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(23);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(111);
      END_STATE();
    case 21:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(106);
      END_STATE();
    case 22:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(107);
      END_STATE();
    case 23:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(111);
      END_STATE();
    case 24:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(95);
      END_STATE();
    case 25:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(24);
      END_STATE();
    case 26:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(108);
      END_STATE();
    case 27:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(95);
      END_STATE();
    case 28:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(27);
      END_STATE();
    case 29:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(28);
      END_STATE();
    case 30:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(29);
      END_STATE();
    case 31:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(30);
      END_STATE();
    case 32:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(31);
      END_STATE();
    case 33:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(32);
      END_STATE();
    case 34:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(33);
      END_STATE();
    case 35:
      if (eof) ADVANCE(40);
      if (lookahead == '\n') SKIP(0)
      END_STATE();
    case 36:
      if (eof) ADVANCE(40);
      if (lookahead == '\n') SKIP(0)
      if (lookahead == '\r') SKIP(35)
      END_STATE();
    case 37:
      if (eof) ADVANCE(40);
      if (lookahead == '\n') SKIP(39)
      END_STATE();
    case 38:
      if (eof) ADVANCE(40);
      if (lookahead == '\n') SKIP(39)
      if (lookahead == '\r') SKIP(37)
      END_STATE();
    case 39:
      if (eof) ADVANCE(40);
      if (lookahead == '!') ADVANCE(14);
      if (lookahead == '#') ADVANCE(115);
      if (lookahead == '%') ADVANCE(62);
      if (lookahead == '&') ADVANCE(65);
      if (lookahead == '(') ADVANCE(44);
      if (lookahead == ')') ADVANCE(45);
      if (lookahead == '*') ADVANCE(47);
      if (lookahead == '+') ADVANCE(58);
      if (lookahead == ',') ADVANCE(46);
      if (lookahead == '-') ADVANCE(59);
      if (lookahead == '.') ADVANCE(43);
      if (lookahead == '/') ADVANCE(61);
      if (lookahead == '0') ADVANCE(104);
      if (lookahead == ':') ADVANCE(50);
      if (lookahead == ';') ADVANCE(41);
      if (lookahead == '<') ADVANCE(69);
      if (lookahead == '=') ADVANCE(57);
      if (lookahead == '>') ADVANCE(74);
      if (lookahead == '@') ADVANCE(54);
      if (lookahead == '[') ADVANCE(55);
      if (lookahead == '\\') SKIP(38)
      if (lookahead == ']') ADVANCE(56);
      if (lookahead == '^') ADVANCE(66);
      if (lookahead == '{') ADVANCE(90);
      if (lookahead == '|') ADVANCE(64);
      if (lookahead == '}') ADVANCE(92);
      if (lookahead == '~') ADVANCE(68);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\f' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(39)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(103);
      if (sym_identifier_character_set_1(lookahead)) ADVANCE(114);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 41:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(13);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(110);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(53);
      if (lookahead == '=') ADVANCE(78);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(84);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '=') ADVANCE(49);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      if (lookahead == '=') ADVANCE(83);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == '=') ADVANCE(80);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(71);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '=') ADVANCE(76);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(77);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(77);
      if (lookahead == '>') ADVANCE(52);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '/') ADVANCE(63);
      if (lookahead == '=') ADVANCE(79);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(82);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      if (lookahead == '=') ADVANCE(81);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(88);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '=') ADVANCE(86);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(87);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(85);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(67);
      if (lookahead == '=') ADVANCE(70);
      if (lookahead == '>') ADVANCE(75);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(73);
      if (lookahead == '>') ADVANCE(48);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_LT_GT);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_AT_EQ);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH_EQ);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_STAR_STAR_EQ);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(sym_ellipsis);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '{') ADVANCE(93);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_LBRACE_LBRACE);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_RBRACE_RBRACE);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (lookahead == '\\') ADVANCE(97);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(sym__not_escape_sequence);
      if (lookahead == '\n') ADVANCE(96);
      if (lookahead == '\r') ADVANCE(3);
      if (lookahead == 'U') ADVANCE(34);
      if (lookahead == 'u') ADVANCE(30);
      if (lookahead == 'x') ADVANCE(28);
      if (lookahead == '"' ||
          lookahead == '\'' ||
          lookahead == '\\' ||
          lookahead == 'a' ||
          lookahead == 'b' ||
          lookahead == 'f' ||
          lookahead == 'n' ||
          lookahead == 'r' ||
          ('t' <= lookahead && lookahead <= 'v')) ADVANCE(95);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(25);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(aux_sym_format_specifier_token1);
      if (lookahead == '\r') ADVANCE(100);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '{' &&
          lookahead != '}') ADVANCE(100);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(aux_sym_format_specifier_token1);
      if (lookahead == '#') ADVANCE(100);
      if (lookahead == '\\') ADVANCE(98);
      if (lookahead == '\t' ||
          lookahead == '\f' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) ADVANCE(99);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '{' &&
          lookahead != '}') ADVANCE(100);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(aux_sym_format_specifier_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '{' &&
          lookahead != '}') ADVANCE(100);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(sym_type_conversion);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(sym_integer);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(112);
      if (lookahead == '_') ADVANCE(105);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(20);
      if (lookahead == 'J' ||
          lookahead == 'L' ||
          lookahead == 'j' ||
          lookahead == 'l') ADVANCE(102);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(103);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(112);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(16);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(17);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(18);
      if (lookahead == '_') ADVANCE(105);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(20);
      if (lookahead == 'J' ||
          lookahead == 'L' ||
          lookahead == 'j' ||
          lookahead == 'l') ADVANCE(102);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(103);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(112);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(20);
      if (lookahead == 'J' ||
          lookahead == 'L' ||
          lookahead == 'j' ||
          lookahead == 'l') ADVANCE(102);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(103);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '_') ADVANCE(21);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(102);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(106);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '_') ADVANCE(22);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(102);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(107);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '_') ADVANCE(26);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(102);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(108);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(sym_float);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == '_') ADVANCE(112);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(20);
      if (lookahead == 'J' ||
          lookahead == 'L' ||
          lookahead == 'j' ||
          lookahead == 'l') ADVANCE(109);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(110);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == '_') ADVANCE(113);
      if (lookahead == 'J' ||
          lookahead == 'L' ||
          lookahead == 'j' ||
          lookahead == 'l') ADVANCE(109);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(111);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(20);
      if (lookahead == 'J' ||
          lookahead == 'L' ||
          lookahead == 'j' ||
          lookahead == 'l') ADVANCE(109);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(110);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == 'J' ||
          lookahead == 'L' ||
          lookahead == 'j' ||
          lookahead == 'l') ADVANCE(109);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(111);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(sym_identifier);
      if (sym_identifier_character_set_2(lookahead)) ADVANCE(114);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(115);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (lookahead == 'F') ADVANCE(1);
      if (lookahead == 'N') ADVANCE(2);
      if (lookahead == 'T') ADVANCE(3);
      if (lookahead == '\\') SKIP(4)
      if (lookahead == '_') ADVANCE(5);
      if (lookahead == 'a') ADVANCE(6);
      if (lookahead == 'b') ADVANCE(7);
      if (lookahead == 'c') ADVANCE(8);
      if (lookahead == 'd') ADVANCE(9);
      if (lookahead == 'e') ADVANCE(10);
      if (lookahead == 'f') ADVANCE(11);
      if (lookahead == 'g') ADVANCE(12);
      if (lookahead == 'i') ADVANCE(13);
      if (lookahead == 'l') ADVANCE(14);
      if (lookahead == 'n') ADVANCE(15);
      if (lookahead == 'o') ADVANCE(16);
      if (lookahead == 'p') ADVANCE(17);
      if (lookahead == 'r') ADVANCE(18);
      if (lookahead == 't') ADVANCE(19);
      if (lookahead == 'w') ADVANCE(20);
      if (lookahead == 'y') ADVANCE(21);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\f' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(0)
      END_STATE();
    case 1:
      if (lookahead == 'a') ADVANCE(22);
      END_STATE();
    case 2:
      if (lookahead == 'o') ADVANCE(23);
      END_STATE();
    case 3:
      if (lookahead == 'r') ADVANCE(24);
      END_STATE();
    case 4:
      if (lookahead == '\n') SKIP(0)
      if (lookahead == '\r') SKIP(25)
      END_STATE();
    case 5:
      if (lookahead == '_') ADVANCE(26);
      END_STATE();
    case 6:
      if (lookahead == 'n') ADVANCE(27);
      if (lookahead == 's') ADVANCE(28);
      if (lookahead == 'w') ADVANCE(29);
      END_STATE();
    case 7:
      if (lookahead == 'r') ADVANCE(30);
      END_STATE();
    case 8:
      if (lookahead == 'l') ADVANCE(31);
      if (lookahead == 'o') ADVANCE(32);
      END_STATE();
    case 9:
      if (lookahead == 'e') ADVANCE(33);
      END_STATE();
    case 10:
      if (lookahead == 'l') ADVANCE(34);
      if (lookahead == 'x') ADVANCE(35);
      END_STATE();
    case 11:
      if (lookahead == 'i') ADVANCE(36);
      if (lookahead == 'o') ADVANCE(37);
      if (lookahead == 'r') ADVANCE(38);
      END_STATE();
    case 12:
      if (lookahead == 'l') ADVANCE(39);
      END_STATE();
    case 13:
      if (lookahead == 'f') ADVANCE(40);
      if (lookahead == 'm') ADVANCE(41);
      if (lookahead == 'n') ADVANCE(42);
      if (lookahead == 's') ADVANCE(43);
      END_STATE();
    case 14:
      if (lookahead == 'a') ADVANCE(44);
      END_STATE();
    case 15:
      if (lookahead == 'o') ADVANCE(45);
      END_STATE();
    case 16:
      if (lookahead == 'r') ADVANCE(46);
      END_STATE();
    case 17:
      if (lookahead == 'a') ADVANCE(47);
      if (lookahead == 'r') ADVANCE(48);
      END_STATE();
    case 18:
      if (lookahead == 'a') ADVANCE(49);
      if (lookahead == 'e') ADVANCE(50);
      END_STATE();
    case 19:
      if (lookahead == 'r') ADVANCE(51);
      END_STATE();
    case 20:
      if (lookahead == 'h') ADVANCE(52);
      if (lookahead == 'i') ADVANCE(53);
      END_STATE();
    case 21:
      if (lookahead == 'i') ADVANCE(54);
      END_STATE();
    case 22:
      if (lookahead == 'l') ADVANCE(55);
      END_STATE();
    case 23:
      if (lookahead == 'n') ADVANCE(56);
      END_STATE();
    case 24:
      if (lookahead == 'u') ADVANCE(57);
      END_STATE();
    case 25:
      if (lookahead == '\n') SKIP(0)
      END_STATE();
    case 26:
      if (lookahead == 'f') ADVANCE(58);
      END_STATE();
    case 27:
      if (lookahead == 'd') ADVANCE(59);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == 's') ADVANCE(60);
      if (lookahead == 'y') ADVANCE(61);
      END_STATE();
    case 29:
      if (lookahead == 'a') ADVANCE(62);
      END_STATE();
    case 30:
      if (lookahead == 'e') ADVANCE(63);
      END_STATE();
    case 31:
      if (lookahead == 'a') ADVANCE(64);
      END_STATE();
    case 32:
      if (lookahead == 'n') ADVANCE(65);
      END_STATE();
    case 33:
      if (lookahead == 'f') ADVANCE(66);
      if (lookahead == 'l') ADVANCE(67);
      END_STATE();
    case 34:
      if (lookahead == 'i') ADVANCE(68);
      if (lookahead == 's') ADVANCE(69);
      END_STATE();
    case 35:
      if (lookahead == 'c') ADVANCE(70);
      if (lookahead == 'e') ADVANCE(71);
      END_STATE();
    case 36:
      if (lookahead == 'n') ADVANCE(72);
      END_STATE();
    case 37:
      if (lookahead == 'r') ADVANCE(73);
      END_STATE();
    case 38:
      if (lookahead == 'o') ADVANCE(74);
      END_STATE();
    case 39:
      if (lookahead == 'o') ADVANCE(75);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 41:
      if (lookahead == 'p') ADVANCE(76);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_in);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_is);
      END_STATE();
    case 44:
      if (lookahead == 'm') ADVANCE(77);
      END_STATE();
    case 45:
      if (lookahead == 'n') ADVANCE(78);
      if (lookahead == 't') ADVANCE(79);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(anon_sym_or);
      END_STATE();
    case 47:
      if (lookahead == 's') ADVANCE(80);
      END_STATE();
    case 48:
      if (lookahead == 'i') ADVANCE(81);
      END_STATE();
    case 49:
      if (lookahead == 'i') ADVANCE(82);
      END_STATE();
    case 50:
      if (lookahead == 't') ADVANCE(83);
      END_STATE();
    case 51:
      if (lookahead == 'y') ADVANCE(84);
      END_STATE();
    case 52:
      if (lookahead == 'i') ADVANCE(85);
      END_STATE();
    case 53:
      if (lookahead == 't') ADVANCE(86);
      END_STATE();
    case 54:
      if (lookahead == 'e') ADVANCE(87);
      END_STATE();
    case 55:
      if (lookahead == 's') ADVANCE(88);
      END_STATE();
    case 56:
      if (lookahead == 'e') ADVANCE(89);
      END_STATE();
    case 57:
      if (lookahead == 'e') ADVANCE(90);
      END_STATE();
    case 58:
      if (lookahead == 'u') ADVANCE(91);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_and);
      END_STATE();
    case 60:
      if (lookahead == 'e') ADVANCE(92);
      END_STATE();
    case 61:
      if (lookahead == 'n') ADVANCE(93);
      END_STATE();
    case 62:
      if (lookahead == 'i') ADVANCE(94);
      END_STATE();
    case 63:
      if (lookahead == 'a') ADVANCE(95);
      END_STATE();
    case 64:
      if (lookahead == 's') ADVANCE(96);
      END_STATE();
    case 65:
      if (lookahead == 't') ADVANCE(97);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(anon_sym_def);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(anon_sym_del);
      END_STATE();
    case 68:
      if (lookahead == 'f') ADVANCE(98);
      END_STATE();
    case 69:
      if (lookahead == 'e') ADVANCE(99);
      END_STATE();
    case 70:
      if (lookahead == 'e') ADVANCE(100);
      END_STATE();
    case 71:
      if (lookahead == 'c') ADVANCE(101);
      END_STATE();
    case 72:
      if (lookahead == 'a') ADVANCE(102);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 74:
      if (lookahead == 'm') ADVANCE(103);
      END_STATE();
    case 75:
      if (lookahead == 'b') ADVANCE(104);
      END_STATE();
    case 76:
      if (lookahead == 'o') ADVANCE(105);
      END_STATE();
    case 77:
      if (lookahead == 'b') ADVANCE(106);
      END_STATE();
    case 78:
      if (lookahead == 'l') ADVANCE(107);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_not);
      END_STATE();
    case 80:
      if (lookahead == 's') ADVANCE(108);
      END_STATE();
    case 81:
      if (lookahead == 'n') ADVANCE(109);
      END_STATE();
    case 82:
      if (lookahead == 's') ADVANCE(110);
      END_STATE();
    case 83:
      if (lookahead == 'u') ADVANCE(111);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 85:
      if (lookahead == 'l') ADVANCE(112);
      END_STATE();
    case 86:
      if (lookahead == 'h') ADVANCE(113);
      END_STATE();
    case 87:
      if (lookahead == 'l') ADVANCE(114);
      END_STATE();
    case 88:
      if (lookahead == 'e') ADVANCE(115);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(sym_none);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(sym_true);
      END_STATE();
    case 91:
      if (lookahead == 't') ADVANCE(116);
      END_STATE();
    case 92:
      if (lookahead == 'r') ADVANCE(117);
      END_STATE();
    case 93:
      if (lookahead == 'c') ADVANCE(118);
      END_STATE();
    case 94:
      if (lookahead == 't') ADVANCE(119);
      END_STATE();
    case 95:
      if (lookahead == 'k') ADVANCE(120);
      END_STATE();
    case 96:
      if (lookahead == 's') ADVANCE(121);
      END_STATE();
    case 97:
      if (lookahead == 'i') ADVANCE(122);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(anon_sym_elif);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 100:
      if (lookahead == 'p') ADVANCE(123);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_exec);
      END_STATE();
    case 102:
      if (lookahead == 'l') ADVANCE(124);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_from);
      END_STATE();
    case 104:
      if (lookahead == 'a') ADVANCE(125);
      END_STATE();
    case 105:
      if (lookahead == 'r') ADVANCE(126);
      END_STATE();
    case 106:
      if (lookahead == 'd') ADVANCE(127);
      END_STATE();
    case 107:
      if (lookahead == 'o') ADVANCE(128);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(anon_sym_pass);
      END_STATE();
    case 109:
      if (lookahead == 't') ADVANCE(129);
      END_STATE();
    case 110:
      if (lookahead == 'e') ADVANCE(130);
      END_STATE();
    case 111:
      if (lookahead == 'r') ADVANCE(131);
      END_STATE();
    case 112:
      if (lookahead == 'e') ADVANCE(132);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_with);
      END_STATE();
    case 114:
      if (lookahead == 'd') ADVANCE(133);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(sym_false);
      END_STATE();
    case 116:
      if (lookahead == 'u') ADVANCE(134);
      END_STATE();
    case 117:
      if (lookahead == 't') ADVANCE(135);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym_async);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_await);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 122:
      if (lookahead == 'n') ADVANCE(136);
      END_STATE();
    case 123:
      if (lookahead == 't') ADVANCE(137);
      END_STATE();
    case 124:
      if (lookahead == 'l') ADVANCE(138);
      END_STATE();
    case 125:
      if (lookahead == 'l') ADVANCE(139);
      END_STATE();
    case 126:
      if (lookahead == 't') ADVANCE(140);
      END_STATE();
    case 127:
      if (lookahead == 'a') ADVANCE(141);
      END_STATE();
    case 128:
      if (lookahead == 'c') ADVANCE(142);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(anon_sym_print);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_raise);
      END_STATE();
    case 131:
      if (lookahead == 'n') ADVANCE(143);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_yield);
      END_STATE();
    case 134:
      if (lookahead == 'r') ADVANCE(144);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(anon_sym_assert);
      END_STATE();
    case 136:
      if (lookahead == 'u') ADVANCE(145);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_except);
      END_STATE();
    case 138:
      if (lookahead == 'y') ADVANCE(146);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_lambda);
      END_STATE();
    case 142:
      if (lookahead == 'a') ADVANCE(147);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 144:
      if (lookahead == 'e') ADVANCE(148);
      END_STATE();
    case 145:
      if (lookahead == 'e') ADVANCE(149);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_finally);
      END_STATE();
    case 147:
      if (lookahead == 'l') ADVANCE(150);
      END_STATE();
    case 148:
      if (lookahead == '_') ADVANCE(151);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_nonlocal);
      END_STATE();
    case 151:
      if (lookahead == '_') ADVANCE(152);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym___future__);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 39, .external_lex_state = 2},
  [2] = {.lex_state = 39, .external_lex_state = 3},
  [3] = {.lex_state = 39, .external_lex_state = 3},
  [4] = {.lex_state = 39, .external_lex_state = 3},
  [5] = {.lex_state = 39, .external_lex_state = 3},
  [6] = {.lex_state = 39, .external_lex_state = 3},
  [7] = {.lex_state = 39, .external_lex_state = 3},
  [8] = {.lex_state = 39, .external_lex_state = 3},
  [9] = {.lex_state = 39, .external_lex_state = 3},
  [10] = {.lex_state = 39, .external_lex_state = 3},
  [11] = {.lex_state = 39, .external_lex_state = 3},
  [12] = {.lex_state = 39, .external_lex_state = 3},
  [13] = {.lex_state = 39, .external_lex_state = 3},
  [14] = {.lex_state = 39, .external_lex_state = 3},
  [15] = {.lex_state = 39, .external_lex_state = 3},
  [16] = {.lex_state = 39, .external_lex_state = 3},
  [17] = {.lex_state = 39, .external_lex_state = 3},
  [18] = {.lex_state = 39, .external_lex_state = 3},
  [19] = {.lex_state = 39, .external_lex_state = 3},
  [20] = {.lex_state = 39, .external_lex_state = 3},
  [21] = {.lex_state = 39, .external_lex_state = 3},
  [22] = {.lex_state = 39, .external_lex_state = 3},
  [23] = {.lex_state = 39, .external_lex_state = 3},
  [24] = {.lex_state = 39, .external_lex_state = 3},
  [25] = {.lex_state = 39, .external_lex_state = 3},
  [26] = {.lex_state = 39, .external_lex_state = 3},
  [27] = {.lex_state = 39, .external_lex_state = 3},
  [28] = {.lex_state = 39, .external_lex_state = 3},
  [29] = {.lex_state = 39, .external_lex_state = 3},
  [30] = {.lex_state = 39, .external_lex_state = 3},
  [31] = {.lex_state = 39, .external_lex_state = 3},
  [32] = {.lex_state = 39, .external_lex_state = 3},
  [33] = {.lex_state = 39, .external_lex_state = 3},
  [34] = {.lex_state = 39, .external_lex_state = 3},
  [35] = {.lex_state = 39, .external_lex_state = 3},
  [36] = {.lex_state = 39, .external_lex_state = 3},
  [37] = {.lex_state = 39, .external_lex_state = 3},
  [38] = {.lex_state = 39, .external_lex_state = 3},
  [39] = {.lex_state = 39, .external_lex_state = 3},
  [40] = {.lex_state = 39, .external_lex_state = 3},
  [41] = {.lex_state = 39, .external_lex_state = 3},
  [42] = {.lex_state = 39, .external_lex_state = 2},
  [43] = {.lex_state = 39, .external_lex_state = 3},
  [44] = {.lex_state = 39, .external_lex_state = 3},
  [45] = {.lex_state = 39, .external_lex_state = 2},
  [46] = {.lex_state = 39, .external_lex_state = 4},
  [47] = {.lex_state = 39, .external_lex_state = 4},
  [48] = {.lex_state = 39, .external_lex_state = 5},
  [49] = {.lex_state = 39, .external_lex_state = 5},
  [50] = {.lex_state = 39, .external_lex_state = 5},
  [51] = {.lex_state = 39, .external_lex_state = 5},
  [52] = {.lex_state = 39, .external_lex_state = 5},
  [53] = {.lex_state = 39, .external_lex_state = 5},
  [54] = {.lex_state = 39, .external_lex_state = 5},
  [55] = {.lex_state = 39, .external_lex_state = 5},
  [56] = {.lex_state = 39, .external_lex_state = 5},
  [57] = {.lex_state = 39, .external_lex_state = 5},
  [58] = {.lex_state = 39, .external_lex_state = 5},
  [59] = {.lex_state = 39, .external_lex_state = 5},
  [60] = {.lex_state = 39, .external_lex_state = 5},
  [61] = {.lex_state = 39, .external_lex_state = 5},
  [62] = {.lex_state = 39, .external_lex_state = 5},
  [63] = {.lex_state = 39, .external_lex_state = 5},
  [64] = {.lex_state = 39, .external_lex_state = 5},
  [65] = {.lex_state = 39, .external_lex_state = 5},
  [66] = {.lex_state = 39, .external_lex_state = 5},
  [67] = {.lex_state = 39, .external_lex_state = 5},
  [68] = {.lex_state = 39, .external_lex_state = 5},
  [69] = {.lex_state = 39, .external_lex_state = 5},
  [70] = {.lex_state = 39, .external_lex_state = 5},
  [71] = {.lex_state = 39, .external_lex_state = 5},
  [72] = {.lex_state = 39, .external_lex_state = 5},
  [73] = {.lex_state = 39, .external_lex_state = 5},
  [74] = {.lex_state = 39, .external_lex_state = 5},
  [75] = {.lex_state = 39, .external_lex_state = 5},
  [76] = {.lex_state = 39, .external_lex_state = 5},
  [77] = {.lex_state = 39, .external_lex_state = 5},
  [78] = {.lex_state = 39, .external_lex_state = 5},
  [79] = {.lex_state = 39, .external_lex_state = 5},
  [80] = {.lex_state = 39, .external_lex_state = 5},
  [81] = {.lex_state = 39, .external_lex_state = 5},
  [82] = {.lex_state = 39, .external_lex_state = 5},
  [83] = {.lex_state = 39, .external_lex_state = 5},
  [84] = {.lex_state = 39, .external_lex_state = 5},
  [85] = {.lex_state = 39, .external_lex_state = 5},
  [86] = {.lex_state = 39, .external_lex_state = 4},
  [87] = {.lex_state = 39, .external_lex_state = 4},
  [88] = {.lex_state = 39, .external_lex_state = 4},
  [89] = {.lex_state = 39, .external_lex_state = 4},
  [90] = {.lex_state = 39, .external_lex_state = 4},
  [91] = {.lex_state = 39, .external_lex_state = 4},
  [92] = {.lex_state = 39, .external_lex_state = 2},
  [93] = {.lex_state = 39, .external_lex_state = 2},
  [94] = {.lex_state = 39, .external_lex_state = 2},
  [95] = {.lex_state = 39, .external_lex_state = 4},
  [96] = {.lex_state = 39, .external_lex_state = 2},
  [97] = {.lex_state = 39, .external_lex_state = 2},
  [98] = {.lex_state = 39, .external_lex_state = 2},
  [99] = {.lex_state = 39, .external_lex_state = 2},
  [100] = {.lex_state = 39, .external_lex_state = 2},
  [101] = {.lex_state = 39, .external_lex_state = 2},
  [102] = {.lex_state = 39, .external_lex_state = 2},
  [103] = {.lex_state = 39, .external_lex_state = 2},
  [104] = {.lex_state = 39, .external_lex_state = 2},
  [105] = {.lex_state = 39, .external_lex_state = 2},
  [106] = {.lex_state = 39, .external_lex_state = 2},
  [107] = {.lex_state = 39, .external_lex_state = 2},
  [108] = {.lex_state = 39, .external_lex_state = 2},
  [109] = {.lex_state = 39, .external_lex_state = 2},
  [110] = {.lex_state = 39, .external_lex_state = 2},
  [111] = {.lex_state = 39, .external_lex_state = 2},
  [112] = {.lex_state = 39, .external_lex_state = 2},
  [113] = {.lex_state = 39, .external_lex_state = 2},
  [114] = {.lex_state = 39, .external_lex_state = 2},
  [115] = {.lex_state = 10},
  [116] = {.lex_state = 39, .external_lex_state = 2},
  [117] = {.lex_state = 39, .external_lex_state = 2},
  [118] = {.lex_state = 10},
  [119] = {.lex_state = 10},
  [120] = {.lex_state = 10},
  [121] = {.lex_state = 39, .external_lex_state = 2},
  [122] = {.lex_state = 39, .external_lex_state = 2},
  [123] = {.lex_state = 39, .external_lex_state = 2},
  [124] = {.lex_state = 39, .external_lex_state = 2},
  [125] = {.lex_state = 10},
  [126] = {.lex_state = 10},
  [127] = {.lex_state = 39, .external_lex_state = 2},
  [128] = {.lex_state = 10},
  [129] = {.lex_state = 39, .external_lex_state = 2},
  [130] = {.lex_state = 39, .external_lex_state = 2},
  [131] = {.lex_state = 39, .external_lex_state = 2},
  [132] = {.lex_state = 39, .external_lex_state = 2},
  [133] = {.lex_state = 39, .external_lex_state = 2},
  [134] = {.lex_state = 39, .external_lex_state = 2},
  [135] = {.lex_state = 39, .external_lex_state = 2},
  [136] = {.lex_state = 39, .external_lex_state = 2},
  [137] = {.lex_state = 39, .external_lex_state = 2},
  [138] = {.lex_state = 39, .external_lex_state = 2},
  [139] = {.lex_state = 39, .external_lex_state = 2},
  [140] = {.lex_state = 39, .external_lex_state = 2},
  [141] = {.lex_state = 39, .external_lex_state = 2},
  [142] = {.lex_state = 39, .external_lex_state = 2},
  [143] = {.lex_state = 39, .external_lex_state = 2},
  [144] = {.lex_state = 39, .external_lex_state = 2},
  [145] = {.lex_state = 39, .external_lex_state = 2},
  [146] = {.lex_state = 39, .external_lex_state = 2},
  [147] = {.lex_state = 39, .external_lex_state = 2},
  [148] = {.lex_state = 39, .external_lex_state = 2},
  [149] = {.lex_state = 39, .external_lex_state = 2},
  [150] = {.lex_state = 39, .external_lex_state = 2},
  [151] = {.lex_state = 39, .external_lex_state = 2},
  [152] = {.lex_state = 39, .external_lex_state = 2},
  [153] = {.lex_state = 39, .external_lex_state = 2},
  [154] = {.lex_state = 39, .external_lex_state = 2},
  [155] = {.lex_state = 39, .external_lex_state = 2},
  [156] = {.lex_state = 39, .external_lex_state = 2},
  [157] = {.lex_state = 39, .external_lex_state = 2},
  [158] = {.lex_state = 39, .external_lex_state = 2},
  [159] = {.lex_state = 10, .external_lex_state = 6},
  [160] = {.lex_state = 39, .external_lex_state = 2},
  [161] = {.lex_state = 10, .external_lex_state = 6},
  [162] = {.lex_state = 39, .external_lex_state = 3},
  [163] = {.lex_state = 39, .external_lex_state = 4},
  [164] = {.lex_state = 39, .external_lex_state = 2},
  [165] = {.lex_state = 39, .external_lex_state = 2},
  [166] = {.lex_state = 39, .external_lex_state = 2},
  [167] = {.lex_state = 39, .external_lex_state = 2},
  [168] = {.lex_state = 10, .external_lex_state = 4},
  [169] = {.lex_state = 39, .external_lex_state = 4},
  [170] = {.lex_state = 39, .external_lex_state = 2},
  [171] = {.lex_state = 39, .external_lex_state = 3},
  [172] = {.lex_state = 39, .external_lex_state = 2},
  [173] = {.lex_state = 39, .external_lex_state = 2},
  [174] = {.lex_state = 39, .external_lex_state = 2},
  [175] = {.lex_state = 10, .external_lex_state = 6},
  [176] = {.lex_state = 39, .external_lex_state = 2},
  [177] = {.lex_state = 10, .external_lex_state = 6},
  [178] = {.lex_state = 10, .external_lex_state = 6},
  [179] = {.lex_state = 39, .external_lex_state = 2},
  [180] = {.lex_state = 39, .external_lex_state = 2},
  [181] = {.lex_state = 10, .external_lex_state = 6},
  [182] = {.lex_state = 39, .external_lex_state = 2},
  [183] = {.lex_state = 39, .external_lex_state = 2},
  [184] = {.lex_state = 39, .external_lex_state = 2},
  [185] = {.lex_state = 39, .external_lex_state = 2},
  [186] = {.lex_state = 10, .external_lex_state = 6},
  [187] = {.lex_state = 39, .external_lex_state = 2},
  [188] = {.lex_state = 10, .external_lex_state = 6},
  [189] = {.lex_state = 39, .external_lex_state = 2},
  [190] = {.lex_state = 39, .external_lex_state = 2},
  [191] = {.lex_state = 39, .external_lex_state = 2},
  [192] = {.lex_state = 39, .external_lex_state = 4},
  [193] = {.lex_state = 39, .external_lex_state = 4},
  [194] = {.lex_state = 39, .external_lex_state = 4},
  [195] = {.lex_state = 10, .external_lex_state = 6},
  [196] = {.lex_state = 9, .external_lex_state = 6},
  [197] = {.lex_state = 39, .external_lex_state = 2},
  [198] = {.lex_state = 39, .external_lex_state = 2},
  [199] = {.lex_state = 39, .external_lex_state = 2},
  [200] = {.lex_state = 39, .external_lex_state = 2},
  [201] = {.lex_state = 39, .external_lex_state = 3},
  [202] = {.lex_state = 39, .external_lex_state = 4},
  [203] = {.lex_state = 39, .external_lex_state = 4},
  [204] = {.lex_state = 39, .external_lex_state = 4},
  [205] = {.lex_state = 39, .external_lex_state = 2},
  [206] = {.lex_state = 39, .external_lex_state = 2},
  [207] = {.lex_state = 39, .external_lex_state = 3},
  [208] = {.lex_state = 39, .external_lex_state = 3},
  [209] = {.lex_state = 39, .external_lex_state = 2},
  [210] = {.lex_state = 10, .external_lex_state = 6},
  [211] = {.lex_state = 39, .external_lex_state = 4},
  [212] = {.lex_state = 39, .external_lex_state = 2},
  [213] = {.lex_state = 39, .external_lex_state = 4},
  [214] = {.lex_state = 10, .external_lex_state = 6},
  [215] = {.lex_state = 10, .external_lex_state = 6},
  [216] = {.lex_state = 39, .external_lex_state = 4},
  [217] = {.lex_state = 39, .external_lex_state = 2},
  [218] = {.lex_state = 39, .external_lex_state = 2},
  [219] = {.lex_state = 39, .external_lex_state = 2},
  [220] = {.lex_state = 39, .external_lex_state = 2},
  [221] = {.lex_state = 39, .external_lex_state = 2},
  [222] = {.lex_state = 10, .external_lex_state = 6},
  [223] = {.lex_state = 39, .external_lex_state = 2},
  [224] = {.lex_state = 39, .external_lex_state = 2},
  [225] = {.lex_state = 39, .external_lex_state = 2},
  [226] = {.lex_state = 39, .external_lex_state = 2},
  [227] = {.lex_state = 39, .external_lex_state = 2},
  [228] = {.lex_state = 39, .external_lex_state = 2},
  [229] = {.lex_state = 39, .external_lex_state = 3},
  [230] = {.lex_state = 39, .external_lex_state = 2},
  [231] = {.lex_state = 39, .external_lex_state = 2},
  [232] = {.lex_state = 39, .external_lex_state = 3},
  [233] = {.lex_state = 39, .external_lex_state = 2},
  [234] = {.lex_state = 39, .external_lex_state = 2},
  [235] = {.lex_state = 39, .external_lex_state = 2},
  [236] = {.lex_state = 39, .external_lex_state = 2},
  [237] = {.lex_state = 39, .external_lex_state = 3},
  [238] = {.lex_state = 39, .external_lex_state = 2},
  [239] = {.lex_state = 39, .external_lex_state = 2},
  [240] = {.lex_state = 39, .external_lex_state = 3},
  [241] = {.lex_state = 39, .external_lex_state = 3},
  [242] = {.lex_state = 39, .external_lex_state = 2},
  [243] = {.lex_state = 39, .external_lex_state = 2},
  [244] = {.lex_state = 39, .external_lex_state = 2},
  [245] = {.lex_state = 39, .external_lex_state = 2},
  [246] = {.lex_state = 39, .external_lex_state = 2},
  [247] = {.lex_state = 39, .external_lex_state = 3},
  [248] = {.lex_state = 39, .external_lex_state = 2},
  [249] = {.lex_state = 39, .external_lex_state = 2},
  [250] = {.lex_state = 39, .external_lex_state = 3},
  [251] = {.lex_state = 39, .external_lex_state = 3},
  [252] = {.lex_state = 39, .external_lex_state = 2},
  [253] = {.lex_state = 39, .external_lex_state = 2},
  [254] = {.lex_state = 39, .external_lex_state = 2},
  [255] = {.lex_state = 39, .external_lex_state = 2},
  [256] = {.lex_state = 39, .external_lex_state = 2},
  [257] = {.lex_state = 39, .external_lex_state = 2},
  [258] = {.lex_state = 39, .external_lex_state = 2},
  [259] = {.lex_state = 39, .external_lex_state = 2},
  [260] = {.lex_state = 39, .external_lex_state = 2},
  [261] = {.lex_state = 39, .external_lex_state = 2},
  [262] = {.lex_state = 39, .external_lex_state = 2},
  [263] = {.lex_state = 39, .external_lex_state = 2},
  [264] = {.lex_state = 39, .external_lex_state = 2},
  [265] = {.lex_state = 39, .external_lex_state = 2},
  [266] = {.lex_state = 39, .external_lex_state = 2},
  [267] = {.lex_state = 39, .external_lex_state = 2},
  [268] = {.lex_state = 39, .external_lex_state = 2},
  [269] = {.lex_state = 39, .external_lex_state = 2},
  [270] = {.lex_state = 39, .external_lex_state = 2},
  [271] = {.lex_state = 39, .external_lex_state = 2},
  [272] = {.lex_state = 39, .external_lex_state = 2},
  [273] = {.lex_state = 39, .external_lex_state = 3},
  [274] = {.lex_state = 39, .external_lex_state = 2},
  [275] = {.lex_state = 39, .external_lex_state = 2},
  [276] = {.lex_state = 39, .external_lex_state = 2},
  [277] = {.lex_state = 39, .external_lex_state = 2},
  [278] = {.lex_state = 39, .external_lex_state = 2},
  [279] = {.lex_state = 39, .external_lex_state = 2},
  [280] = {.lex_state = 39, .external_lex_state = 2},
  [281] = {.lex_state = 39, .external_lex_state = 2},
  [282] = {.lex_state = 39, .external_lex_state = 2},
  [283] = {.lex_state = 39, .external_lex_state = 2},
  [284] = {.lex_state = 39, .external_lex_state = 2},
  [285] = {.lex_state = 39, .external_lex_state = 2},
  [286] = {.lex_state = 39, .external_lex_state = 2},
  [287] = {.lex_state = 39, .external_lex_state = 2},
  [288] = {.lex_state = 39, .external_lex_state = 2},
  [289] = {.lex_state = 39, .external_lex_state = 2},
  [290] = {.lex_state = 39, .external_lex_state = 2},
  [291] = {.lex_state = 39, .external_lex_state = 2},
  [292] = {.lex_state = 39, .external_lex_state = 2},
  [293] = {.lex_state = 39, .external_lex_state = 2},
  [294] = {.lex_state = 39, .external_lex_state = 2},
  [295] = {.lex_state = 39, .external_lex_state = 2},
  [296] = {.lex_state = 39, .external_lex_state = 2},
  [297] = {.lex_state = 39, .external_lex_state = 2},
  [298] = {.lex_state = 39, .external_lex_state = 2},
  [299] = {.lex_state = 39, .external_lex_state = 2},
  [300] = {.lex_state = 39, .external_lex_state = 2},
  [301] = {.lex_state = 39, .external_lex_state = 2},
  [302] = {.lex_state = 39, .external_lex_state = 2},
  [303] = {.lex_state = 39, .external_lex_state = 2},
  [304] = {.lex_state = 39, .external_lex_state = 2},
  [305] = {.lex_state = 39, .external_lex_state = 2},
  [306] = {.lex_state = 39, .external_lex_state = 2},
  [307] = {.lex_state = 39, .external_lex_state = 2},
  [308] = {.lex_state = 39, .external_lex_state = 3},
  [309] = {.lex_state = 39, .external_lex_state = 2},
  [310] = {.lex_state = 39, .external_lex_state = 2},
  [311] = {.lex_state = 39, .external_lex_state = 2},
  [312] = {.lex_state = 39, .external_lex_state = 2},
  [313] = {.lex_state = 39, .external_lex_state = 3},
  [314] = {.lex_state = 39, .external_lex_state = 2},
  [315] = {.lex_state = 39, .external_lex_state = 2},
  [316] = {.lex_state = 39, .external_lex_state = 3},
  [317] = {.lex_state = 39, .external_lex_state = 3},
  [318] = {.lex_state = 39, .external_lex_state = 2},
  [319] = {.lex_state = 39, .external_lex_state = 2},
  [320] = {.lex_state = 39, .external_lex_state = 2},
  [321] = {.lex_state = 39, .external_lex_state = 2},
  [322] = {.lex_state = 39, .external_lex_state = 3},
  [323] = {.lex_state = 39, .external_lex_state = 2},
  [324] = {.lex_state = 39, .external_lex_state = 2},
  [325] = {.lex_state = 39, .external_lex_state = 2},
  [326] = {.lex_state = 39, .external_lex_state = 2},
  [327] = {.lex_state = 39, .external_lex_state = 2},
  [328] = {.lex_state = 39, .external_lex_state = 2},
  [329] = {.lex_state = 39, .external_lex_state = 2},
  [330] = {.lex_state = 39, .external_lex_state = 2},
  [331] = {.lex_state = 39, .external_lex_state = 2},
  [332] = {.lex_state = 39, .external_lex_state = 2},
  [333] = {.lex_state = 39, .external_lex_state = 2},
  [334] = {.lex_state = 39, .external_lex_state = 2},
  [335] = {.lex_state = 39, .external_lex_state = 2},
  [336] = {.lex_state = 39, .external_lex_state = 3},
  [337] = {.lex_state = 39, .external_lex_state = 3},
  [338] = {.lex_state = 39, .external_lex_state = 3},
  [339] = {.lex_state = 39, .external_lex_state = 2},
  [340] = {.lex_state = 39, .external_lex_state = 2},
  [341] = {.lex_state = 39, .external_lex_state = 3},
  [342] = {.lex_state = 39, .external_lex_state = 3},
  [343] = {.lex_state = 39, .external_lex_state = 2},
  [344] = {.lex_state = 39, .external_lex_state = 3},
  [345] = {.lex_state = 39, .external_lex_state = 2},
  [346] = {.lex_state = 39, .external_lex_state = 3},
  [347] = {.lex_state = 39, .external_lex_state = 2},
  [348] = {.lex_state = 39, .external_lex_state = 2},
  [349] = {.lex_state = 39, .external_lex_state = 2},
  [350] = {.lex_state = 39, .external_lex_state = 2},
  [351] = {.lex_state = 39, .external_lex_state = 3},
  [352] = {.lex_state = 39, .external_lex_state = 2},
  [353] = {.lex_state = 39, .external_lex_state = 3},
  [354] = {.lex_state = 39, .external_lex_state = 2},
  [355] = {.lex_state = 39, .external_lex_state = 3},
  [356] = {.lex_state = 39, .external_lex_state = 3},
  [357] = {.lex_state = 39, .external_lex_state = 3},
  [358] = {.lex_state = 39, .external_lex_state = 2},
  [359] = {.lex_state = 39, .external_lex_state = 3},
  [360] = {.lex_state = 10, .external_lex_state = 2},
  [361] = {.lex_state = 10, .external_lex_state = 2},
  [362] = {.lex_state = 39, .external_lex_state = 2},
  [363] = {.lex_state = 10, .external_lex_state = 2},
  [364] = {.lex_state = 39, .external_lex_state = 3},
  [365] = {.lex_state = 39, .external_lex_state = 3},
  [366] = {.lex_state = 39, .external_lex_state = 2},
  [367] = {.lex_state = 39, .external_lex_state = 3},
  [368] = {.lex_state = 39, .external_lex_state = 3},
  [369] = {.lex_state = 39, .external_lex_state = 3},
  [370] = {.lex_state = 39, .external_lex_state = 3},
  [371] = {.lex_state = 39, .external_lex_state = 2},
  [372] = {.lex_state = 39, .external_lex_state = 2},
  [373] = {.lex_state = 39, .external_lex_state = 2},
  [374] = {.lex_state = 39, .external_lex_state = 3},
  [375] = {.lex_state = 39, .external_lex_state = 2},
  [376] = {.lex_state = 39, .external_lex_state = 2},
  [377] = {.lex_state = 39, .external_lex_state = 3},
  [378] = {.lex_state = 39, .external_lex_state = 3},
  [379] = {.lex_state = 39, .external_lex_state = 3},
  [380] = {.lex_state = 39, .external_lex_state = 2},
  [381] = {.lex_state = 39, .external_lex_state = 3},
  [382] = {.lex_state = 39, .external_lex_state = 3},
  [383] = {.lex_state = 39, .external_lex_state = 2},
  [384] = {.lex_state = 39, .external_lex_state = 3},
  [385] = {.lex_state = 39, .external_lex_state = 2},
  [386] = {.lex_state = 39, .external_lex_state = 2},
  [387] = {.lex_state = 39, .external_lex_state = 2},
  [388] = {.lex_state = 39, .external_lex_state = 2},
  [389] = {.lex_state = 39, .external_lex_state = 3},
  [390] = {.lex_state = 39, .external_lex_state = 2},
  [391] = {.lex_state = 39, .external_lex_state = 3},
  [392] = {.lex_state = 39, .external_lex_state = 3},
  [393] = {.lex_state = 39, .external_lex_state = 2},
  [394] = {.lex_state = 39, .external_lex_state = 2},
  [395] = {.lex_state = 39, .external_lex_state = 3},
  [396] = {.lex_state = 39, .external_lex_state = 3},
  [397] = {.lex_state = 39, .external_lex_state = 3},
  [398] = {.lex_state = 39, .external_lex_state = 2},
  [399] = {.lex_state = 39, .external_lex_state = 2},
  [400] = {.lex_state = 39, .external_lex_state = 3},
  [401] = {.lex_state = 39, .external_lex_state = 2},
  [402] = {.lex_state = 39, .external_lex_state = 3},
  [403] = {.lex_state = 39, .external_lex_state = 2},
  [404] = {.lex_state = 39, .external_lex_state = 2},
  [405] = {.lex_state = 39, .external_lex_state = 2},
  [406] = {.lex_state = 39, .external_lex_state = 3},
  [407] = {.lex_state = 39, .external_lex_state = 2},
  [408] = {.lex_state = 39, .external_lex_state = 2},
  [409] = {.lex_state = 39, .external_lex_state = 3},
  [410] = {.lex_state = 39, .external_lex_state = 2},
  [411] = {.lex_state = 39, .external_lex_state = 2},
  [412] = {.lex_state = 39, .external_lex_state = 3},
  [413] = {.lex_state = 39, .external_lex_state = 3},
  [414] = {.lex_state = 39, .external_lex_state = 3},
  [415] = {.lex_state = 39, .external_lex_state = 3},
  [416] = {.lex_state = 39, .external_lex_state = 3},
  [417] = {.lex_state = 39, .external_lex_state = 2},
  [418] = {.lex_state = 39, .external_lex_state = 2},
  [419] = {.lex_state = 39, .external_lex_state = 2},
  [420] = {.lex_state = 39, .external_lex_state = 3},
  [421] = {.lex_state = 39, .external_lex_state = 2},
  [422] = {.lex_state = 39, .external_lex_state = 3},
  [423] = {.lex_state = 39, .external_lex_state = 3},
  [424] = {.lex_state = 39, .external_lex_state = 3},
  [425] = {.lex_state = 39, .external_lex_state = 3},
  [426] = {.lex_state = 39, .external_lex_state = 2},
  [427] = {.lex_state = 39, .external_lex_state = 2},
  [428] = {.lex_state = 39, .external_lex_state = 2},
  [429] = {.lex_state = 39, .external_lex_state = 3},
  [430] = {.lex_state = 39, .external_lex_state = 2},
  [431] = {.lex_state = 39, .external_lex_state = 2},
  [432] = {.lex_state = 39, .external_lex_state = 2},
  [433] = {.lex_state = 39, .external_lex_state = 2},
  [434] = {.lex_state = 39, .external_lex_state = 3},
  [435] = {.lex_state = 39, .external_lex_state = 2},
  [436] = {.lex_state = 39, .external_lex_state = 2},
  [437] = {.lex_state = 39, .external_lex_state = 2},
  [438] = {.lex_state = 10, .external_lex_state = 2},
  [439] = {.lex_state = 39, .external_lex_state = 2},
  [440] = {.lex_state = 39, .external_lex_state = 2},
  [441] = {.lex_state = 39, .external_lex_state = 2},
  [442] = {.lex_state = 10, .external_lex_state = 2},
  [443] = {.lex_state = 39, .external_lex_state = 2},
  [444] = {.lex_state = 39, .external_lex_state = 2},
  [445] = {.lex_state = 10},
  [446] = {.lex_state = 10},
  [447] = {.lex_state = 10},
  [448] = {.lex_state = 10},
  [449] = {.lex_state = 10},
  [450] = {.lex_state = 10},
  [451] = {.lex_state = 10},
  [452] = {.lex_state = 10},
  [453] = {.lex_state = 10},
  [454] = {.lex_state = 10},
  [455] = {.lex_state = 10},
  [456] = {.lex_state = 10},
  [457] = {.lex_state = 10},
  [458] = {.lex_state = 10},
  [459] = {.lex_state = 10},
  [460] = {.lex_state = 10},
  [461] = {.lex_state = 10},
  [462] = {.lex_state = 10},
  [463] = {.lex_state = 39, .external_lex_state = 2},
  [464] = {.lex_state = 39, .external_lex_state = 2},
  [465] = {.lex_state = 10},
  [466] = {.lex_state = 10},
  [467] = {.lex_state = 10},
  [468] = {.lex_state = 10},
  [469] = {.lex_state = 10},
  [470] = {.lex_state = 10},
  [471] = {.lex_state = 10},
  [472] = {.lex_state = 10},
  [473] = {.lex_state = 10},
  [474] = {.lex_state = 10},
  [475] = {.lex_state = 10},
  [476] = {.lex_state = 10},
  [477] = {.lex_state = 10},
  [478] = {.lex_state = 10},
  [479] = {.lex_state = 10},
  [480] = {.lex_state = 10},
  [481] = {.lex_state = 10},
  [482] = {.lex_state = 10},
  [483] = {.lex_state = 10},
  [484] = {.lex_state = 10},
  [485] = {.lex_state = 10},
  [486] = {.lex_state = 10},
  [487] = {.lex_state = 10},
  [488] = {.lex_state = 10},
  [489] = {.lex_state = 10},
  [490] = {.lex_state = 9},
  [491] = {.lex_state = 10},
  [492] = {.lex_state = 10},
  [493] = {.lex_state = 39, .external_lex_state = 2},
  [494] = {.lex_state = 10},
  [495] = {.lex_state = 9},
  [496] = {.lex_state = 10},
  [497] = {.lex_state = 10},
  [498] = {.lex_state = 10, .external_lex_state = 4},
  [499] = {.lex_state = 10},
  [500] = {.lex_state = 10, .external_lex_state = 6},
  [501] = {.lex_state = 10, .external_lex_state = 4},
  [502] = {.lex_state = 10, .external_lex_state = 4},
  [503] = {.lex_state = 10, .external_lex_state = 6},
  [504] = {.lex_state = 10},
  [505] = {.lex_state = 10, .external_lex_state = 6},
  [506] = {.lex_state = 10, .external_lex_state = 2},
  [507] = {.lex_state = 39, .external_lex_state = 2},
  [508] = {.lex_state = 10, .external_lex_state = 6},
  [509] = {.lex_state = 10, .external_lex_state = 6},
  [510] = {.lex_state = 10, .external_lex_state = 6},
  [511] = {.lex_state = 10, .external_lex_state = 6},
  [512] = {.lex_state = 39, .external_lex_state = 2},
  [513] = {.lex_state = 10, .external_lex_state = 6},
  [514] = {.lex_state = 10, .external_lex_state = 6},
  [515] = {.lex_state = 10, .external_lex_state = 6},
  [516] = {.lex_state = 10, .external_lex_state = 6},
  [517] = {.lex_state = 10, .external_lex_state = 2},
  [518] = {.lex_state = 10, .external_lex_state = 2},
  [519] = {.lex_state = 39, .external_lex_state = 2},
  [520] = {.lex_state = 39, .external_lex_state = 2},
  [521] = {.lex_state = 39, .external_lex_state = 2},
  [522] = {.lex_state = 9, .external_lex_state = 6},
  [523] = {.lex_state = 10},
  [524] = {.lex_state = 10},
  [525] = {.lex_state = 10},
  [526] = {.lex_state = 39, .external_lex_state = 2},
  [527] = {.lex_state = 39, .external_lex_state = 2},
  [528] = {.lex_state = 39, .external_lex_state = 2},
  [529] = {.lex_state = 39, .external_lex_state = 2},
  [530] = {.lex_state = 39, .external_lex_state = 2},
  [531] = {.lex_state = 39, .external_lex_state = 2},
  [532] = {.lex_state = 39, .external_lex_state = 2},
  [533] = {.lex_state = 39, .external_lex_state = 2},
  [534] = {.lex_state = 9},
  [535] = {.lex_state = 39, .external_lex_state = 2},
  [536] = {.lex_state = 39, .external_lex_state = 2},
  [537] = {.lex_state = 39, .external_lex_state = 2},
  [538] = {.lex_state = 39, .external_lex_state = 2},
  [539] = {.lex_state = 39, .external_lex_state = 2},
  [540] = {.lex_state = 39, .external_lex_state = 2},
  [541] = {.lex_state = 39, .external_lex_state = 2},
  [542] = {.lex_state = 39, .external_lex_state = 2},
  [543] = {.lex_state = 39, .external_lex_state = 2},
  [544] = {.lex_state = 39, .external_lex_state = 2},
  [545] = {.lex_state = 39, .external_lex_state = 2},
  [546] = {.lex_state = 39, .external_lex_state = 2},
  [547] = {.lex_state = 39, .external_lex_state = 2},
  [548] = {.lex_state = 39, .external_lex_state = 2},
  [549] = {.lex_state = 39, .external_lex_state = 2},
  [550] = {.lex_state = 39, .external_lex_state = 2},
  [551] = {.lex_state = 39, .external_lex_state = 2},
  [552] = {.lex_state = 39, .external_lex_state = 2},
  [553] = {.lex_state = 39, .external_lex_state = 2},
  [554] = {.lex_state = 10},
  [555] = {.lex_state = 10},
  [556] = {.lex_state = 10},
  [557] = {.lex_state = 10},
  [558] = {.lex_state = 39, .external_lex_state = 2},
  [559] = {.lex_state = 10},
  [560] = {.lex_state = 39, .external_lex_state = 2},
  [561] = {.lex_state = 10},
  [562] = {.lex_state = 10},
  [563] = {.lex_state = 10},
  [564] = {.lex_state = 10, .external_lex_state = 4},
  [565] = {.lex_state = 10},
  [566] = {.lex_state = 39, .external_lex_state = 2},
  [567] = {.lex_state = 10},
  [568] = {.lex_state = 10},
  [569] = {.lex_state = 39, .external_lex_state = 2},
  [570] = {.lex_state = 10, .external_lex_state = 4},
  [571] = {.lex_state = 39, .external_lex_state = 2},
  [572] = {.lex_state = 10},
  [573] = {.lex_state = 10},
  [574] = {.lex_state = 39, .external_lex_state = 2},
  [575] = {.lex_state = 39, .external_lex_state = 2},
  [576] = {.lex_state = 39, .external_lex_state = 2},
  [577] = {.lex_state = 39, .external_lex_state = 2},
  [578] = {.lex_state = 39, .external_lex_state = 2},
  [579] = {.lex_state = 39, .external_lex_state = 2},
  [580] = {.lex_state = 39, .external_lex_state = 2},
  [581] = {.lex_state = 39, .external_lex_state = 2},
  [582] = {.lex_state = 39, .external_lex_state = 2},
  [583] = {.lex_state = 39, .external_lex_state = 2},
  [584] = {.lex_state = 9},
  [585] = {.lex_state = 10, .external_lex_state = 6},
  [586] = {.lex_state = 10, .external_lex_state = 2},
  [587] = {.lex_state = 10, .external_lex_state = 6},
  [588] = {.lex_state = 10},
  [589] = {.lex_state = 9},
  [590] = {.lex_state = 10, .external_lex_state = 6},
  [591] = {.lex_state = 10},
  [592] = {.lex_state = 10, .external_lex_state = 6},
  [593] = {.lex_state = 10, .external_lex_state = 6},
  [594] = {.lex_state = 10},
  [595] = {.lex_state = 10, .external_lex_state = 6},
  [596] = {.lex_state = 10, .external_lex_state = 6},
  [597] = {.lex_state = 10, .external_lex_state = 6},
  [598] = {.lex_state = 10, .external_lex_state = 6},
  [599] = {.lex_state = 10, .external_lex_state = 6},
  [600] = {.lex_state = 10, .external_lex_state = 6},
  [601] = {.lex_state = 10},
  [602] = {.lex_state = 10, .external_lex_state = 6},
  [603] = {.lex_state = 10, .external_lex_state = 6},
  [604] = {.lex_state = 10, .external_lex_state = 6},
  [605] = {.lex_state = 10, .external_lex_state = 6},
  [606] = {.lex_state = 10, .external_lex_state = 6},
  [607] = {.lex_state = 10, .external_lex_state = 6},
  [608] = {.lex_state = 10, .external_lex_state = 6},
  [609] = {.lex_state = 10, .external_lex_state = 6},
  [610] = {.lex_state = 10, .external_lex_state = 6},
  [611] = {.lex_state = 10, .external_lex_state = 2},
  [612] = {.lex_state = 10, .external_lex_state = 6},
  [613] = {.lex_state = 10},
  [614] = {.lex_state = 10, .external_lex_state = 6},
  [615] = {.lex_state = 10, .external_lex_state = 6},
  [616] = {.lex_state = 10, .external_lex_state = 6},
  [617] = {.lex_state = 10},
  [618] = {.lex_state = 10},
  [619] = {.lex_state = 10},
  [620] = {.lex_state = 10},
  [621] = {.lex_state = 10},
  [622] = {.lex_state = 10},
  [623] = {.lex_state = 10},
  [624] = {.lex_state = 9},
  [625] = {.lex_state = 10},
  [626] = {.lex_state = 9},
  [627] = {.lex_state = 10},
  [628] = {.lex_state = 10},
  [629] = {.lex_state = 10},
  [630] = {.lex_state = 10},
  [631] = {.lex_state = 10},
  [632] = {.lex_state = 10},
  [633] = {.lex_state = 10},
  [634] = {.lex_state = 10},
  [635] = {.lex_state = 10},
  [636] = {.lex_state = 10},
  [637] = {.lex_state = 10},
  [638] = {.lex_state = 10},
  [639] = {.lex_state = 10},
  [640] = {.lex_state = 10},
  [641] = {.lex_state = 10},
  [642] = {.lex_state = 10},
  [643] = {.lex_state = 10},
  [644] = {.lex_state = 10},
  [645] = {.lex_state = 10},
  [646] = {.lex_state = 10},
  [647] = {.lex_state = 10},
  [648] = {.lex_state = 10},
  [649] = {.lex_state = 39},
  [650] = {.lex_state = 39},
  [651] = {.lex_state = 39},
  [652] = {.lex_state = 39},
  [653] = {.lex_state = 39},
  [654] = {.lex_state = 0, .external_lex_state = 6},
  [655] = {.lex_state = 10},
  [656] = {.lex_state = 39},
  [657] = {.lex_state = 39},
  [658] = {.lex_state = 10},
  [659] = {.lex_state = 0, .external_lex_state = 6},
  [660] = {.lex_state = 39},
  [661] = {.lex_state = 10, .external_lex_state = 6},
  [662] = {.lex_state = 39},
  [663] = {.lex_state = 39},
  [664] = {.lex_state = 39},
  [665] = {.lex_state = 39},
  [666] = {.lex_state = 10},
  [667] = {.lex_state = 39},
  [668] = {.lex_state = 39},
  [669] = {.lex_state = 39},
  [670] = {.lex_state = 39},
  [671] = {.lex_state = 39},
  [672] = {.lex_state = 39},
  [673] = {.lex_state = 39},
  [674] = {.lex_state = 39},
  [675] = {.lex_state = 39},
  [676] = {.lex_state = 39},
  [677] = {.lex_state = 0},
  [678] = {.lex_state = 39},
  [679] = {.lex_state = 39},
  [680] = {.lex_state = 0},
  [681] = {.lex_state = 0},
  [682] = {.lex_state = 39},
  [683] = {.lex_state = 39},
  [684] = {.lex_state = 39},
  [685] = {.lex_state = 39},
  [686] = {.lex_state = 0},
  [687] = {.lex_state = 39},
  [688] = {.lex_state = 39},
  [689] = {.lex_state = 39},
  [690] = {.lex_state = 39},
  [691] = {.lex_state = 39},
  [692] = {.lex_state = 39},
  [693] = {.lex_state = 39},
  [694] = {.lex_state = 39},
  [695] = {.lex_state = 39},
  [696] = {.lex_state = 0},
  [697] = {.lex_state = 39},
  [698] = {.lex_state = 39},
  [699] = {.lex_state = 0},
  [700] = {.lex_state = 0},
  [701] = {.lex_state = 12, .external_lex_state = 7},
  [702] = {.lex_state = 12, .external_lex_state = 7},
  [703] = {.lex_state = 12, .external_lex_state = 7},
  [704] = {.lex_state = 12, .external_lex_state = 7},
  [705] = {.lex_state = 12, .external_lex_state = 7},
  [706] = {.lex_state = 0},
  [707] = {.lex_state = 12, .external_lex_state = 7},
  [708] = {.lex_state = 12, .external_lex_state = 7},
  [709] = {.lex_state = 0},
  [710] = {.lex_state = 12, .external_lex_state = 7},
  [711] = {.lex_state = 0},
  [712] = {.lex_state = 0},
  [713] = {.lex_state = 0},
  [714] = {.lex_state = 0},
  [715] = {.lex_state = 0},
  [716] = {.lex_state = 0},
  [717] = {.lex_state = 12, .external_lex_state = 7},
  [718] = {.lex_state = 0},
  [719] = {.lex_state = 0},
  [720] = {.lex_state = 0},
  [721] = {.lex_state = 0},
  [722] = {.lex_state = 0},
  [723] = {.lex_state = 0},
  [724] = {.lex_state = 0},
  [725] = {.lex_state = 0, .external_lex_state = 6},
  [726] = {.lex_state = 0, .external_lex_state = 6},
  [727] = {.lex_state = 0, .external_lex_state = 6},
  [728] = {.lex_state = 0, .external_lex_state = 6},
  [729] = {.lex_state = 0, .external_lex_state = 6},
  [730] = {.lex_state = 0},
  [731] = {.lex_state = 0},
  [732] = {.lex_state = 0, .external_lex_state = 6},
  [733] = {.lex_state = 0},
  [734] = {.lex_state = 0, .external_lex_state = 6},
  [735] = {.lex_state = 0},
  [736] = {.lex_state = 0},
  [737] = {.lex_state = 0, .external_lex_state = 6},
  [738] = {.lex_state = 0, .external_lex_state = 6},
  [739] = {.lex_state = 0},
  [740] = {.lex_state = 0},
  [741] = {.lex_state = 0},
  [742] = {.lex_state = 0, .external_lex_state = 6},
  [743] = {.lex_state = 39},
  [744] = {.lex_state = 0},
  [745] = {.lex_state = 39},
  [746] = {.lex_state = 39},
  [747] = {.lex_state = 39},
  [748] = {.lex_state = 0, .external_lex_state = 6},
  [749] = {.lex_state = 39},
  [750] = {.lex_state = 39},
  [751] = {.lex_state = 0, .external_lex_state = 6},
  [752] = {.lex_state = 0, .external_lex_state = 6},
  [753] = {.lex_state = 0},
  [754] = {.lex_state = 0},
  [755] = {.lex_state = 0, .external_lex_state = 6},
  [756] = {.lex_state = 39},
  [757] = {.lex_state = 0, .external_lex_state = 6},
  [758] = {.lex_state = 0, .external_lex_state = 6},
  [759] = {.lex_state = 0},
  [760] = {.lex_state = 0},
  [761] = {.lex_state = 0, .external_lex_state = 6},
  [762] = {.lex_state = 0},
  [763] = {.lex_state = 39},
  [764] = {.lex_state = 0},
  [765] = {.lex_state = 0},
  [766] = {.lex_state = 0, .external_lex_state = 6},
  [767] = {.lex_state = 0},
  [768] = {.lex_state = 39},
  [769] = {.lex_state = 12, .external_lex_state = 7},
  [770] = {.lex_state = 39},
  [771] = {.lex_state = 12, .external_lex_state = 7},
  [772] = {.lex_state = 39},
  [773] = {.lex_state = 0},
  [774] = {.lex_state = 39},
  [775] = {.lex_state = 0},
  [776] = {.lex_state = 39},
  [777] = {.lex_state = 39},
  [778] = {.lex_state = 39},
  [779] = {.lex_state = 39},
  [780] = {.lex_state = 0, .external_lex_state = 6},
  [781] = {.lex_state = 10},
  [782] = {.lex_state = 12, .external_lex_state = 7},
  [783] = {.lex_state = 39},
  [784] = {.lex_state = 10},
  [785] = {.lex_state = 0, .external_lex_state = 6},
  [786] = {.lex_state = 10, .external_lex_state = 6},
  [787] = {.lex_state = 39},
  [788] = {.lex_state = 39},
  [789] = {.lex_state = 39},
  [790] = {.lex_state = 0},
  [791] = {.lex_state = 39},
  [792] = {.lex_state = 0},
  [793] = {.lex_state = 39},
  [794] = {.lex_state = 39},
  [795] = {.lex_state = 10, .external_lex_state = 6},
  [796] = {.lex_state = 10},
  [797] = {.lex_state = 39},
  [798] = {.lex_state = 10},
  [799] = {.lex_state = 10, .external_lex_state = 6},
  [800] = {.lex_state = 39},
  [801] = {.lex_state = 0, .external_lex_state = 6},
  [802] = {.lex_state = 39},
  [803] = {.lex_state = 0},
  [804] = {.lex_state = 39},
  [805] = {.lex_state = 0, .external_lex_state = 6},
  [806] = {.lex_state = 39},
  [807] = {.lex_state = 39},
  [808] = {.lex_state = 0},
  [809] = {.lex_state = 4},
  [810] = {.lex_state = 10},
  [811] = {.lex_state = 0},
  [812] = {.lex_state = 0},
  [813] = {.lex_state = 0, .external_lex_state = 6},
  [814] = {.lex_state = 0},
  [815] = {.lex_state = 0},
  [816] = {.lex_state = 0},
  [817] = {.lex_state = 0},
  [818] = {.lex_state = 0},
  [819] = {.lex_state = 10, .external_lex_state = 6},
  [820] = {.lex_state = 0},
  [821] = {.lex_state = 0, .external_lex_state = 6},
  [822] = {.lex_state = 4},
  [823] = {.lex_state = 0},
  [824] = {.lex_state = 0, .external_lex_state = 6},
  [825] = {.lex_state = 0, .external_lex_state = 6},
  [826] = {.lex_state = 0},
  [827] = {.lex_state = 0},
  [828] = {.lex_state = 0, .external_lex_state = 6},
  [829] = {.lex_state = 0},
  [830] = {.lex_state = 0},
  [831] = {.lex_state = 0, .external_lex_state = 6},
  [832] = {.lex_state = 0, .external_lex_state = 6},
  [833] = {.lex_state = 0, .external_lex_state = 6},
  [834] = {.lex_state = 4},
  [835] = {.lex_state = 0, .external_lex_state = 6},
  [836] = {.lex_state = 0},
  [837] = {.lex_state = 0},
  [838] = {.lex_state = 0},
  [839] = {.lex_state = 0, .external_lex_state = 6},
  [840] = {.lex_state = 0, .external_lex_state = 6},
  [841] = {.lex_state = 0, .external_lex_state = 6},
  [842] = {.lex_state = 39},
  [843] = {.lex_state = 39},
  [844] = {.lex_state = 0, .external_lex_state = 6},
  [845] = {.lex_state = 10},
  [846] = {.lex_state = 0},
  [847] = {.lex_state = 0, .external_lex_state = 6},
  [848] = {.lex_state = 0},
  [849] = {.lex_state = 0},
  [850] = {.lex_state = 0},
  [851] = {.lex_state = 0},
  [852] = {.lex_state = 0, .external_lex_state = 6},
  [853] = {.lex_state = 39},
  [854] = {.lex_state = 0},
  [855] = {.lex_state = 10},
  [856] = {.lex_state = 39},
  [857] = {.lex_state = 0},
  [858] = {.lex_state = 0, .external_lex_state = 6},
  [859] = {.lex_state = 0, .external_lex_state = 6},
  [860] = {.lex_state = 0, .external_lex_state = 6},
  [861] = {.lex_state = 39},
  [862] = {.lex_state = 39},
  [863] = {.lex_state = 39},
  [864] = {.lex_state = 39},
  [865] = {.lex_state = 39},
  [866] = {.lex_state = 39},
  [867] = {.lex_state = 39},
  [868] = {.lex_state = 0},
  [869] = {.lex_state = 0, .external_lex_state = 6},
  [870] = {.lex_state = 0, .external_lex_state = 6},
  [871] = {.lex_state = 0},
  [872] = {.lex_state = 0},
  [873] = {.lex_state = 0},
  [874] = {.lex_state = 0},
  [875] = {.lex_state = 0},
  [876] = {.lex_state = 0},
  [877] = {.lex_state = 0, .external_lex_state = 6},
  [878] = {.lex_state = 0, .external_lex_state = 6},
  [879] = {.lex_state = 0, .external_lex_state = 6},
  [880] = {.lex_state = 0, .external_lex_state = 6},
  [881] = {.lex_state = 0, .external_lex_state = 6},
  [882] = {.lex_state = 0},
  [883] = {.lex_state = 0, .external_lex_state = 6},
  [884] = {.lex_state = 0},
  [885] = {.lex_state = 0},
  [886] = {.lex_state = 39},
  [887] = {.lex_state = 39},
  [888] = {.lex_state = 39},
  [889] = {.lex_state = 39},
  [890] = {.lex_state = 0},
  [891] = {.lex_state = 0},
  [892] = {.lex_state = 0},
  [893] = {.lex_state = 0},
  [894] = {.lex_state = 0, .external_lex_state = 6},
  [895] = {.lex_state = 0},
  [896] = {.lex_state = 0, .external_lex_state = 6},
  [897] = {.lex_state = 0},
  [898] = {.lex_state = 0},
  [899] = {.lex_state = 0, .external_lex_state = 6},
  [900] = {.lex_state = 39},
  [901] = {.lex_state = 0},
  [902] = {.lex_state = 4},
  [903] = {.lex_state = 0},
  [904] = {.lex_state = 0},
  [905] = {.lex_state = 0},
  [906] = {.lex_state = 0},
  [907] = {.lex_state = 0},
  [908] = {.lex_state = 0},
  [909] = {.lex_state = 0},
  [910] = {.lex_state = 0},
  [911] = {.lex_state = 0, .external_lex_state = 6},
  [912] = {.lex_state = 0},
  [913] = {.lex_state = 39},
  [914] = {.lex_state = 0},
  [915] = {.lex_state = 0},
  [916] = {.lex_state = 0},
  [917] = {.lex_state = 0},
  [918] = {.lex_state = 0},
  [919] = {.lex_state = 0},
  [920] = {.lex_state = 39},
  [921] = {.lex_state = 0},
  [922] = {.lex_state = 0, .external_lex_state = 6},
  [923] = {.lex_state = 0},
  [924] = {.lex_state = 0},
  [925] = {.lex_state = 0},
  [926] = {.lex_state = 0},
  [927] = {.lex_state = 39},
  [928] = {.lex_state = 0},
  [929] = {.lex_state = 0},
  [930] = {.lex_state = 0},
  [931] = {.lex_state = 0},
  [932] = {.lex_state = 0},
  [933] = {.lex_state = 0},
  [934] = {.lex_state = 0},
  [935] = {.lex_state = 0},
  [936] = {.lex_state = 0},
  [937] = {.lex_state = 0, .external_lex_state = 6},
  [938] = {.lex_state = 0, .external_lex_state = 6},
  [939] = {.lex_state = 0},
  [940] = {.lex_state = 0},
  [941] = {.lex_state = 0, .external_lex_state = 6},
  [942] = {.lex_state = 0},
  [943] = {.lex_state = 0},
  [944] = {.lex_state = 0},
  [945] = {.lex_state = 0},
  [946] = {.lex_state = 0},
  [947] = {.lex_state = 0},
  [948] = {.lex_state = 39},
  [949] = {.lex_state = 0},
  [950] = {.lex_state = 0},
  [951] = {.lex_state = 39},
  [952] = {.lex_state = 39},
  [953] = {.lex_state = 0},
  [954] = {.lex_state = 0, .external_lex_state = 6},
  [955] = {.lex_state = 0},
  [956] = {.lex_state = 0, .external_lex_state = 6},
  [957] = {.lex_state = 0},
  [958] = {.lex_state = 0},
  [959] = {.lex_state = 0, .external_lex_state = 6},
  [960] = {.lex_state = 0, .external_lex_state = 6},
  [961] = {.lex_state = 0},
  [962] = {.lex_state = 39},
  [963] = {.lex_state = 39},
  [964] = {.lex_state = 39},
  [965] = {.lex_state = 0, .external_lex_state = 6},
  [966] = {.lex_state = 0, .external_lex_state = 6},
  [967] = {.lex_state = 39},
  [968] = {.lex_state = 39},
  [969] = {.lex_state = 0},
  [970] = {.lex_state = 0, .external_lex_state = 6},
  [971] = {.lex_state = 39},
  [972] = {.lex_state = 0},
  [973] = {.lex_state = 0, .external_lex_state = 6},
  [974] = {.lex_state = 0, .external_lex_state = 6},
  [975] = {.lex_state = 0, .external_lex_state = 6},
  [976] = {.lex_state = 0},
  [977] = {.lex_state = 0, .external_lex_state = 6},
  [978] = {.lex_state = 0, .external_lex_state = 6},
  [979] = {.lex_state = 39},
  [980] = {.lex_state = 0, .external_lex_state = 6},
  [981] = {.lex_state = 0, .external_lex_state = 6},
  [982] = {.lex_state = 0, .external_lex_state = 6},
  [983] = {.lex_state = 0, .external_lex_state = 6},
  [984] = {.lex_state = 0},
  [985] = {.lex_state = 0},
  [986] = {.lex_state = 11},
  [987] = {.lex_state = 11},
  [988] = {.lex_state = 0},
  [989] = {.lex_state = 0},
  [990] = {.lex_state = 0},
  [991] = {.lex_state = 0},
  [992] = {.lex_state = 0},
  [993] = {.lex_state = 0},
  [994] = {.lex_state = 0, .external_lex_state = 6},
  [995] = {.lex_state = 11},
  [996] = {.lex_state = 11},
  [997] = {.lex_state = 0, .external_lex_state = 6},
  [998] = {.lex_state = 11},
  [999] = {.lex_state = 0, .external_lex_state = 6},
  [1000] = {.lex_state = 0, .external_lex_state = 6},
  [1001] = {.lex_state = 0},
  [1002] = {.lex_state = 0},
  [1003] = {.lex_state = 0, .external_lex_state = 6},
  [1004] = {.lex_state = 0},
  [1005] = {.lex_state = 0},
  [1006] = {.lex_state = 0},
  [1007] = {.lex_state = 0, .external_lex_state = 6},
  [1008] = {.lex_state = 0, .external_lex_state = 6},
  [1009] = {.lex_state = 11},
  [1010] = {.lex_state = 0},
  [1011] = {.lex_state = 0, .external_lex_state = 6},
  [1012] = {.lex_state = 0, .external_lex_state = 6},
  [1013] = {.lex_state = 0},
  [1014] = {.lex_state = 0},
  [1015] = {.lex_state = 0},
  [1016] = {.lex_state = 0},
  [1017] = {.lex_state = 0},
  [1018] = {.lex_state = 0},
  [1019] = {.lex_state = 0},
  [1020] = {.lex_state = 0},
  [1021] = {.lex_state = 0},
  [1022] = {.lex_state = 0},
  [1023] = {.lex_state = 0},
  [1024] = {.lex_state = 0},
  [1025] = {.lex_state = 0},
  [1026] = {.lex_state = 0},
  [1027] = {.lex_state = 0},
  [1028] = {.lex_state = 0},
  [1029] = {.lex_state = 0},
  [1030] = {.lex_state = 0},
  [1031] = {.lex_state = 0},
  [1032] = {.lex_state = 0},
  [1033] = {.lex_state = 0},
  [1034] = {.lex_state = 0},
  [1035] = {.lex_state = 0},
  [1036] = {.lex_state = 0},
  [1037] = {.lex_state = 0},
  [1038] = {.lex_state = 0},
  [1039] = {.lex_state = 39},
  [1040] = {.lex_state = 0},
  [1041] = {.lex_state = 0},
  [1042] = {.lex_state = 0},
  [1043] = {.lex_state = 39},
  [1044] = {.lex_state = 0},
  [1045] = {.lex_state = 39},
  [1046] = {.lex_state = 0},
  [1047] = {.lex_state = 39},
  [1048] = {.lex_state = 39},
  [1049] = {.lex_state = 0},
  [1050] = {.lex_state = 0},
  [1051] = {.lex_state = 0},
  [1052] = {.lex_state = 0},
  [1053] = {.lex_state = 0},
  [1054] = {.lex_state = 39},
  [1055] = {.lex_state = 0},
  [1056] = {.lex_state = 39},
  [1057] = {.lex_state = 0},
  [1058] = {.lex_state = 39},
  [1059] = {.lex_state = 0},
  [1060] = {.lex_state = 0},
  [1061] = {.lex_state = 0},
  [1062] = {.lex_state = 39},
  [1063] = {.lex_state = 0},
  [1064] = {.lex_state = 0},
  [1065] = {.lex_state = 39},
  [1066] = {.lex_state = 0},
  [1067] = {.lex_state = 39},
  [1068] = {.lex_state = 0},
  [1069] = {.lex_state = 0},
  [1070] = {.lex_state = 39},
  [1071] = {.lex_state = 39},
  [1072] = {.lex_state = 39},
  [1073] = {.lex_state = 0},
  [1074] = {.lex_state = 0},
  [1075] = {.lex_state = 39},
  [1076] = {.lex_state = 0},
  [1077] = {.lex_state = 39},
  [1078] = {.lex_state = 39},
  [1079] = {.lex_state = 0},
  [1080] = {.lex_state = 39},
  [1081] = {.lex_state = 39},
  [1082] = {.lex_state = 39},
  [1083] = {.lex_state = 0},
  [1084] = {.lex_state = 39},
  [1085] = {.lex_state = 0},
  [1086] = {.lex_state = 39},
  [1087] = {.lex_state = 0},
  [1088] = {.lex_state = 0},
  [1089] = {.lex_state = 0},
  [1090] = {.lex_state = 39},
  [1091] = {.lex_state = 0},
  [1092] = {.lex_state = 0},
  [1093] = {.lex_state = 0},
  [1094] = {.lex_state = 0},
  [1095] = {.lex_state = 39},
  [1096] = {.lex_state = 0},
  [1097] = {.lex_state = 0},
  [1098] = {.lex_state = 39},
  [1099] = {.lex_state = 0},
  [1100] = {.lex_state = 0},
  [1101] = {.lex_state = 39},
  [1102] = {.lex_state = 0},
  [1103] = {.lex_state = 0},
  [1104] = {.lex_state = 39},
  [1105] = {.lex_state = 0},
  [1106] = {.lex_state = 0},
  [1107] = {.lex_state = 39},
};

enum {
  ts_external_token__newline = 0,
  ts_external_token__indent = 1,
  ts_external_token__dedent = 2,
  ts_external_token__string_start = 3,
  ts_external_token__string_content = 4,
  ts_external_token__string_end = 5,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token__newline] = sym__newline,
  [ts_external_token__indent] = sym__indent,
  [ts_external_token__dedent] = sym__dedent,
  [ts_external_token__string_start] = sym__string_start,
  [ts_external_token__string_content] = sym__string_content,
  [ts_external_token__string_end] = sym__string_end,
};

static const bool ts_external_scanner_states[8][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token__newline] = true,
    [ts_external_token__indent] = true,
    [ts_external_token__dedent] = true,
    [ts_external_token__string_start] = true,
    [ts_external_token__string_content] = true,
    [ts_external_token__string_end] = true,
  },
  [2] = {
    [ts_external_token__string_start] = true,
  },
  [3] = {
    [ts_external_token__dedent] = true,
    [ts_external_token__string_start] = true,
  },
  [4] = {
    [ts_external_token__newline] = true,
    [ts_external_token__string_start] = true,
  },
  [5] = {
    [ts_external_token__newline] = true,
    [ts_external_token__indent] = true,
    [ts_external_token__string_start] = true,
  },
  [6] = {
    [ts_external_token__newline] = true,
  },
  [7] = {
    [ts_external_token__string_content] = true,
    [ts_external_token__string_end] = true,
  },
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_from] = ACTIONS(1),
    [anon_sym___future__] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_print] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_assert] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_del] = ACTIONS(1),
    [anon_sym_raise] = ACTIONS(1),
    [anon_sym_pass] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_elif] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_async] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_except] = ACTIONS(1),
    [anon_sym_finally] = ACTIONS(1),
    [anon_sym_with] = ACTIONS(1),
    [anon_sym_def] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_STAR_STAR] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_nonlocal] = ACTIONS(1),
    [anon_sym_exec] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_not] = ACTIONS(1),
    [anon_sym_and] = ACTIONS(1),
    [anon_sym_or] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_SLASH_SLASH] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_LT_GT] = ACTIONS(1),
    [anon_sym_is] = ACTIONS(1),
    [anon_sym_lambda] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_AT_EQ] = ACTIONS(1),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_yield] = ACTIONS(1),
    [sym_ellipsis] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_LBRACE_LBRACE] = ACTIONS(1),
    [sym_type_conversion] = ACTIONS(1),
    [sym_integer] = ACTIONS(1),
    [sym_float] = ACTIONS(1),
    [anon_sym_await] = ACTIONS(1),
    [sym_true] = ACTIONS(1),
    [sym_false] = ACTIONS(1),
    [sym_none] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(1),
    [sym__indent] = ACTIONS(1),
    [sym__dedent] = ACTIONS(1),
    [sym__string_start] = ACTIONS(1),
    [sym__string_content] = ACTIONS(1),
    [sym__string_end] = ACTIONS(1),
  },
  [1] = {
    [sym_module] = STATE(1085),
    [sym__statement] = STATE(42),
    [sym__simple_statements] = STATE(42),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_if_statement] = STATE(42),
    [sym_for_statement] = STATE(42),
    [sym_while_statement] = STATE(42),
    [sym_try_statement] = STATE(42),
    [sym_with_statement] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_class_definition] = STATE(42),
    [sym_decorated_definition] = STATE(42),
    [sym_decorator] = STATE(733),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(42),
    [aux_sym_decorated_definition_repeat1] = STATE(733),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(33),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_for] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_try] = ACTIONS(41),
    [anon_sym_with] = ACTIONS(43),
    [anon_sym_def] = ACTIONS(45),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(53),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__string_start] = ACTIONS(75),
  },
  [2] = {
    [sym__statement] = STATE(40),
    [sym__simple_statements] = STATE(40),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(40),
    [sym_for_statement] = STATE(40),
    [sym_while_statement] = STATE(40),
    [sym_try_statement] = STATE(40),
    [sym_with_statement] = STATE(40),
    [sym_function_definition] = STATE(40),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(40),
    [sym_decorated_definition] = STATE(40),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(808),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(40),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(93),
    [sym__string_start] = ACTIONS(75),
  },
  [3] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(322),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [4] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(316),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [5] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(290),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [6] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(362),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [7] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(357),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [8] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(354),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [9] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(369),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [10] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(401),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [11] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(365),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [12] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(381),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [13] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(368),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [14] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(337),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [15] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(395),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [16] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(346),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [17] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(433),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [18] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(269),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [19] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(373),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [20] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(338),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [21] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(298),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [22] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(410),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [23] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(380),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [24] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(386),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [25] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(415),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [26] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(403),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [27] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(413),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [28] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(375),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [29] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(389),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [30] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(423),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [31] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(219),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [32] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(351),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [33] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(308),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [34] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(335),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [35] = {
    [sym__statement] = STATE(40),
    [sym__simple_statements] = STATE(40),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(40),
    [sym_for_statement] = STATE(40),
    [sym_while_statement] = STATE(40),
    [sym_try_statement] = STATE(40),
    [sym_with_statement] = STATE(40),
    [sym_function_definition] = STATE(40),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(40),
    [sym_decorated_definition] = STATE(40),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(826),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(40),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(93),
    [sym__string_start] = ACTIONS(75),
  },
  [36] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(347),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [37] = {
    [sym__statement] = STATE(41),
    [sym__simple_statements] = STATE(41),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(41),
    [sym_for_statement] = STATE(41),
    [sym_while_statement] = STATE(41),
    [sym_try_statement] = STATE(41),
    [sym_with_statement] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(41),
    [sym_decorated_definition] = STATE(41),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(208),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(41),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(95),
    [sym__string_start] = ACTIONS(75),
  },
  [38] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(339),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [39] = {
    [sym__statement] = STATE(44),
    [sym__simple_statements] = STATE(44),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(44),
    [sym_for_statement] = STATE(44),
    [sym_while_statement] = STATE(44),
    [sym_try_statement] = STATE(44),
    [sym_with_statement] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(44),
    [sym_decorated_definition] = STATE(44),
    [sym_decorator] = STATE(731),
    [sym_block] = STATE(408),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(44),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(97),
    [sym__string_start] = ACTIONS(75),
  },
  [40] = {
    [sym__statement] = STATE(43),
    [sym__simple_statements] = STATE(43),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(43),
    [sym_for_statement] = STATE(43),
    [sym_while_statement] = STATE(43),
    [sym_try_statement] = STATE(43),
    [sym_with_statement] = STATE(43),
    [sym_function_definition] = STATE(43),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(43),
    [sym_decorated_definition] = STATE(43),
    [sym_decorator] = STATE(731),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(43),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(99),
    [sym__string_start] = ACTIONS(75),
  },
  [41] = {
    [sym__statement] = STATE(43),
    [sym__simple_statements] = STATE(43),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(43),
    [sym_for_statement] = STATE(43),
    [sym_while_statement] = STATE(43),
    [sym_try_statement] = STATE(43),
    [sym_with_statement] = STATE(43),
    [sym_function_definition] = STATE(43),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(43),
    [sym_decorated_definition] = STATE(43),
    [sym_decorator] = STATE(731),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(43),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym__string_start] = ACTIONS(75),
  },
  [42] = {
    [sym__statement] = STATE(45),
    [sym__simple_statements] = STATE(45),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_if_statement] = STATE(45),
    [sym_for_statement] = STATE(45),
    [sym_while_statement] = STATE(45),
    [sym_try_statement] = STATE(45),
    [sym_with_statement] = STATE(45),
    [sym_function_definition] = STATE(45),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_class_definition] = STATE(45),
    [sym_decorated_definition] = STATE(45),
    [sym_decorator] = STATE(733),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(45),
    [aux_sym_decorated_definition_repeat1] = STATE(733),
    [ts_builtin_sym_end] = ACTIONS(103),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(33),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_for] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_try] = ACTIONS(41),
    [anon_sym_with] = ACTIONS(43),
    [anon_sym_def] = ACTIONS(45),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(53),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__string_start] = ACTIONS(75),
  },
  [43] = {
    [sym__statement] = STATE(43),
    [sym__simple_statements] = STATE(43),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(43),
    [sym_for_statement] = STATE(43),
    [sym_while_statement] = STATE(43),
    [sym_try_statement] = STATE(43),
    [sym_with_statement] = STATE(43),
    [sym_function_definition] = STATE(43),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(43),
    [sym_decorated_definition] = STATE(43),
    [sym_decorator] = STATE(731),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(43),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(105),
    [anon_sym_import] = ACTIONS(108),
    [anon_sym_from] = ACTIONS(111),
    [anon_sym_LPAREN] = ACTIONS(114),
    [anon_sym_STAR] = ACTIONS(117),
    [anon_sym_print] = ACTIONS(120),
    [anon_sym_assert] = ACTIONS(123),
    [anon_sym_return] = ACTIONS(126),
    [anon_sym_del] = ACTIONS(129),
    [anon_sym_raise] = ACTIONS(132),
    [anon_sym_pass] = ACTIONS(135),
    [anon_sym_break] = ACTIONS(138),
    [anon_sym_continue] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(144),
    [anon_sym_async] = ACTIONS(147),
    [anon_sym_for] = ACTIONS(150),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_try] = ACTIONS(156),
    [anon_sym_with] = ACTIONS(159),
    [anon_sym_def] = ACTIONS(162),
    [anon_sym_global] = ACTIONS(165),
    [anon_sym_nonlocal] = ACTIONS(168),
    [anon_sym_exec] = ACTIONS(171),
    [anon_sym_class] = ACTIONS(174),
    [anon_sym_AT] = ACTIONS(177),
    [anon_sym_LBRACK] = ACTIONS(180),
    [anon_sym_not] = ACTIONS(183),
    [anon_sym_PLUS] = ACTIONS(186),
    [anon_sym_DASH] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_lambda] = ACTIONS(189),
    [anon_sym_yield] = ACTIONS(192),
    [sym_ellipsis] = ACTIONS(195),
    [anon_sym_LBRACE] = ACTIONS(198),
    [sym_integer] = ACTIONS(201),
    [sym_float] = ACTIONS(195),
    [anon_sym_await] = ACTIONS(204),
    [sym_true] = ACTIONS(201),
    [sym_false] = ACTIONS(201),
    [sym_none] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(207),
    [sym__string_start] = ACTIONS(209),
  },
  [44] = {
    [sym__statement] = STATE(43),
    [sym__simple_statements] = STATE(43),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_if_statement] = STATE(43),
    [sym_for_statement] = STATE(43),
    [sym_while_statement] = STATE(43),
    [sym_try_statement] = STATE(43),
    [sym_with_statement] = STATE(43),
    [sym_function_definition] = STATE(43),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_class_definition] = STATE(43),
    [sym_decorated_definition] = STATE(43),
    [sym_decorator] = STATE(731),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(43),
    [aux_sym_decorated_definition_repeat1] = STATE(731),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_while] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_with] = ACTIONS(87),
    [anon_sym_def] = ACTIONS(89),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_class] = ACTIONS(91),
    [anon_sym_AT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__dedent] = ACTIONS(212),
    [sym__string_start] = ACTIONS(75),
  },
  [45] = {
    [sym__statement] = STATE(45),
    [sym__simple_statements] = STATE(45),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_if_statement] = STATE(45),
    [sym_for_statement] = STATE(45),
    [sym_while_statement] = STATE(45),
    [sym_try_statement] = STATE(45),
    [sym_with_statement] = STATE(45),
    [sym_function_definition] = STATE(45),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_class_definition] = STATE(45),
    [sym_decorated_definition] = STATE(45),
    [sym_decorator] = STATE(733),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [aux_sym_module_repeat1] = STATE(45),
    [aux_sym_decorated_definition_repeat1] = STATE(733),
    [ts_builtin_sym_end] = ACTIONS(207),
    [sym_identifier] = ACTIONS(105),
    [anon_sym_import] = ACTIONS(108),
    [anon_sym_from] = ACTIONS(111),
    [anon_sym_LPAREN] = ACTIONS(114),
    [anon_sym_STAR] = ACTIONS(117),
    [anon_sym_print] = ACTIONS(120),
    [anon_sym_assert] = ACTIONS(123),
    [anon_sym_return] = ACTIONS(126),
    [anon_sym_del] = ACTIONS(129),
    [anon_sym_raise] = ACTIONS(132),
    [anon_sym_pass] = ACTIONS(135),
    [anon_sym_break] = ACTIONS(138),
    [anon_sym_continue] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(214),
    [anon_sym_async] = ACTIONS(217),
    [anon_sym_for] = ACTIONS(220),
    [anon_sym_while] = ACTIONS(223),
    [anon_sym_try] = ACTIONS(226),
    [anon_sym_with] = ACTIONS(229),
    [anon_sym_def] = ACTIONS(232),
    [anon_sym_global] = ACTIONS(165),
    [anon_sym_nonlocal] = ACTIONS(168),
    [anon_sym_exec] = ACTIONS(171),
    [anon_sym_class] = ACTIONS(235),
    [anon_sym_AT] = ACTIONS(177),
    [anon_sym_LBRACK] = ACTIONS(180),
    [anon_sym_not] = ACTIONS(183),
    [anon_sym_PLUS] = ACTIONS(186),
    [anon_sym_DASH] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_lambda] = ACTIONS(189),
    [anon_sym_yield] = ACTIONS(192),
    [sym_ellipsis] = ACTIONS(195),
    [anon_sym_LBRACE] = ACTIONS(198),
    [sym_integer] = ACTIONS(201),
    [sym_float] = ACTIONS(195),
    [anon_sym_await] = ACTIONS(204),
    [sym_true] = ACTIONS(201),
    [sym_false] = ACTIONS(201),
    [sym_none] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [sym__string_start] = ACTIONS(209),
  },
  [46] = {
    [sym_chevron] = STATE(852),
    [sym_named_expression] = STATE(725),
    [sym_expression] = STATE(766),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_attribute] = STATE(605),
    [sym_subscript] = STATE(605),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(238),
    [anon_sym_SEMI] = ACTIONS(240),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_LPAREN] = ACTIONS(240),
    [anon_sym_COMMA] = ACTIONS(244),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_print] = ACTIONS(247),
    [anon_sym_GT_GT] = ACTIONS(249),
    [anon_sym_if] = ACTIONS(242),
    [anon_sym_COLON] = ACTIONS(251),
    [anon_sym_async] = ACTIONS(247),
    [anon_sym_in] = ACTIONS(242),
    [anon_sym_STAR_STAR] = ACTIONS(242),
    [anon_sym_exec] = ACTIONS(247),
    [anon_sym_AT] = ACTIONS(242),
    [anon_sym_LBRACK] = ACTIONS(240),
    [anon_sym_EQ] = ACTIONS(253),
    [anon_sym_not] = ACTIONS(242),
    [anon_sym_and] = ACTIONS(242),
    [anon_sym_or] = ACTIONS(242),
    [anon_sym_PLUS] = ACTIONS(242),
    [anon_sym_DASH] = ACTIONS(242),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(242),
    [anon_sym_SLASH_SLASH] = ACTIONS(242),
    [anon_sym_PIPE] = ACTIONS(242),
    [anon_sym_AMP] = ACTIONS(242),
    [anon_sym_CARET] = ACTIONS(242),
    [anon_sym_LT_LT] = ACTIONS(242),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_GT] = ACTIONS(240),
    [anon_sym_is] = ACTIONS(242),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_PLUS_EQ] = ACTIONS(251),
    [anon_sym_DASH_EQ] = ACTIONS(251),
    [anon_sym_STAR_EQ] = ACTIONS(251),
    [anon_sym_SLASH_EQ] = ACTIONS(251),
    [anon_sym_AT_EQ] = ACTIONS(251),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(251),
    [anon_sym_PERCENT_EQ] = ACTIONS(251),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(251),
    [anon_sym_GT_GT_EQ] = ACTIONS(251),
    [anon_sym_LT_LT_EQ] = ACTIONS(251),
    [anon_sym_AMP_EQ] = ACTIONS(251),
    [anon_sym_CARET_EQ] = ACTIONS(251),
    [anon_sym_PIPE_EQ] = ACTIONS(251),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(255),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(240),
    [sym__string_start] = ACTIONS(75),
  },
  [47] = {
    [sym_named_expression] = STATE(725),
    [sym_expression] = STATE(732),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_attribute] = STATE(605),
    [sym_subscript] = STATE(605),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(238),
    [anon_sym_SEMI] = ACTIONS(240),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_COMMA] = ACTIONS(244),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_print] = ACTIONS(247),
    [anon_sym_GT_GT] = ACTIONS(242),
    [anon_sym_if] = ACTIONS(242),
    [anon_sym_COLON] = ACTIONS(251),
    [anon_sym_async] = ACTIONS(247),
    [anon_sym_in] = ACTIONS(242),
    [anon_sym_STAR_STAR] = ACTIONS(242),
    [anon_sym_exec] = ACTIONS(247),
    [anon_sym_AT] = ACTIONS(242),
    [anon_sym_LBRACK] = ACTIONS(259),
    [anon_sym_EQ] = ACTIONS(253),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_and] = ACTIONS(242),
    [anon_sym_or] = ACTIONS(242),
    [anon_sym_PLUS] = ACTIONS(261),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(242),
    [anon_sym_SLASH_SLASH] = ACTIONS(242),
    [anon_sym_PIPE] = ACTIONS(242),
    [anon_sym_AMP] = ACTIONS(242),
    [anon_sym_CARET] = ACTIONS(242),
    [anon_sym_LT_LT] = ACTIONS(242),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_GT] = ACTIONS(240),
    [anon_sym_is] = ACTIONS(242),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_PLUS_EQ] = ACTIONS(251),
    [anon_sym_DASH_EQ] = ACTIONS(251),
    [anon_sym_STAR_EQ] = ACTIONS(251),
    [anon_sym_SLASH_EQ] = ACTIONS(251),
    [anon_sym_AT_EQ] = ACTIONS(251),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(251),
    [anon_sym_PERCENT_EQ] = ACTIONS(251),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(251),
    [anon_sym_GT_GT_EQ] = ACTIONS(251),
    [anon_sym_LT_LT_EQ] = ACTIONS(251),
    [anon_sym_AMP_EQ] = ACTIONS(251),
    [anon_sym_CARET_EQ] = ACTIONS(251),
    [anon_sym_PIPE_EQ] = ACTIONS(251),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(255),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(240),
    [sym__string_start] = ACTIONS(75),
  },
  [48] = {
    [sym__simple_statements] = STATE(412),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(265),
    [sym__indent] = ACTIONS(267),
    [sym__string_start] = ACTIONS(75),
  },
  [49] = {
    [sym__simple_statements] = STATE(400),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(269),
    [sym__indent] = ACTIONS(271),
    [sym__string_start] = ACTIONS(75),
  },
  [50] = {
    [sym__simple_statements] = STATE(419),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(273),
    [sym__indent] = ACTIONS(275),
    [sym__string_start] = ACTIONS(75),
  },
  [51] = {
    [sym__simple_statements] = STATE(356),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(277),
    [sym__indent] = ACTIONS(279),
    [sym__string_start] = ACTIONS(75),
  },
  [52] = {
    [sym__simple_statements] = STATE(313),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(281),
    [sym__indent] = ACTIONS(283),
    [sym__string_start] = ACTIONS(75),
  },
  [53] = {
    [sym__simple_statements] = STATE(311),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(285),
    [sym__indent] = ACTIONS(287),
    [sym__string_start] = ACTIONS(75),
  },
  [54] = {
    [sym__simple_statements] = STATE(343),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(289),
    [sym__indent] = ACTIONS(291),
    [sym__string_start] = ACTIONS(75),
  },
  [55] = {
    [sym__simple_statements] = STATE(815),
    [sym_import_statement] = STATE(894),
    [sym_future_import_statement] = STATE(894),
    [sym_import_from_statement] = STATE(894),
    [sym_print_statement] = STATE(894),
    [sym_assert_statement] = STATE(894),
    [sym_expression_statement] = STATE(894),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(894),
    [sym_delete_statement] = STATE(894),
    [sym_raise_statement] = STATE(894),
    [sym_pass_statement] = STATE(894),
    [sym_break_statement] = STATE(894),
    [sym_continue_statement] = STATE(894),
    [sym_global_statement] = STATE(894),
    [sym_nonlocal_statement] = STATE(894),
    [sym_exec_statement] = STATE(894),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(293),
    [sym__indent] = ACTIONS(295),
    [sym__string_start] = ACTIONS(75),
  },
  [56] = {
    [sym__simple_statements] = STATE(409),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(297),
    [sym__indent] = ACTIONS(299),
    [sym__string_start] = ACTIONS(75),
  },
  [57] = {
    [sym__simple_statements] = STATE(273),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(301),
    [sym__indent] = ACTIONS(303),
    [sym__string_start] = ACTIONS(75),
  },
  [58] = {
    [sym__simple_statements] = STATE(201),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(305),
    [sym__indent] = ACTIONS(307),
    [sym__string_start] = ACTIONS(75),
  },
  [59] = {
    [sym__simple_statements] = STATE(342),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(309),
    [sym__indent] = ACTIONS(311),
    [sym__string_start] = ACTIONS(75),
  },
  [60] = {
    [sym__simple_statements] = STATE(431),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(313),
    [sym__indent] = ACTIONS(315),
    [sym__string_start] = ACTIONS(75),
  },
  [61] = {
    [sym__simple_statements] = STATE(382),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(317),
    [sym__indent] = ACTIONS(319),
    [sym__string_start] = ACTIONS(75),
  },
  [62] = {
    [sym__simple_statements] = STATE(391),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(321),
    [sym__indent] = ACTIONS(323),
    [sym__string_start] = ACTIONS(75),
  },
  [63] = {
    [sym__simple_statements] = STATE(818),
    [sym_import_statement] = STATE(894),
    [sym_future_import_statement] = STATE(894),
    [sym_import_from_statement] = STATE(894),
    [sym_print_statement] = STATE(894),
    [sym_assert_statement] = STATE(894),
    [sym_expression_statement] = STATE(894),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(894),
    [sym_delete_statement] = STATE(894),
    [sym_raise_statement] = STATE(894),
    [sym_pass_statement] = STATE(894),
    [sym_break_statement] = STATE(894),
    [sym_continue_statement] = STATE(894),
    [sym_global_statement] = STATE(894),
    [sym_nonlocal_statement] = STATE(894),
    [sym_exec_statement] = STATE(894),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(325),
    [sym__indent] = ACTIONS(327),
    [sym__string_start] = ACTIONS(75),
  },
  [64] = {
    [sym__simple_statements] = STATE(407),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(329),
    [sym__indent] = ACTIONS(331),
    [sym__string_start] = ACTIONS(75),
  },
  [65] = {
    [sym__simple_statements] = STATE(336),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(333),
    [sym__indent] = ACTIONS(335),
    [sym__string_start] = ACTIONS(75),
  },
  [66] = {
    [sym__simple_statements] = STATE(206),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(337),
    [sym__indent] = ACTIONS(339),
    [sym__string_start] = ACTIONS(75),
  },
  [67] = {
    [sym__simple_statements] = STATE(355),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(341),
    [sym__indent] = ACTIONS(343),
    [sym__string_start] = ACTIONS(75),
  },
  [68] = {
    [sym__simple_statements] = STATE(285),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(345),
    [sym__indent] = ACTIONS(347),
    [sym__string_start] = ACTIONS(75),
  },
  [69] = {
    [sym__simple_statements] = STATE(345),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(349),
    [sym__indent] = ACTIONS(351),
    [sym__string_start] = ACTIONS(75),
  },
  [70] = {
    [sym__simple_statements] = STATE(416),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(353),
    [sym__indent] = ACTIONS(355),
    [sym__string_start] = ACTIONS(75),
  },
  [71] = {
    [sym__simple_statements] = STATE(404),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(357),
    [sym__indent] = ACTIONS(359),
    [sym__string_start] = ACTIONS(75),
  },
  [72] = {
    [sym__simple_statements] = STATE(388),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(361),
    [sym__indent] = ACTIONS(363),
    [sym__string_start] = ACTIONS(75),
  },
  [73] = {
    [sym__simple_statements] = STATE(305),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(365),
    [sym__indent] = ACTIONS(367),
    [sym__string_start] = ACTIONS(75),
  },
  [74] = {
    [sym__simple_statements] = STATE(430),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(369),
    [sym__indent] = ACTIONS(371),
    [sym__string_start] = ACTIONS(75),
  },
  [75] = {
    [sym__simple_statements] = STATE(359),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(373),
    [sym__indent] = ACTIONS(375),
    [sym__string_start] = ACTIONS(75),
  },
  [76] = {
    [sym__simple_statements] = STATE(371),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(377),
    [sym__indent] = ACTIONS(379),
    [sym__string_start] = ACTIONS(75),
  },
  [77] = {
    [sym__simple_statements] = STATE(390),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(381),
    [sym__indent] = ACTIONS(383),
    [sym__string_start] = ACTIONS(75),
  },
  [78] = {
    [sym__simple_statements] = STATE(399),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(385),
    [sym__indent] = ACTIONS(387),
    [sym__string_start] = ACTIONS(75),
  },
  [79] = {
    [sym__simple_statements] = STATE(350),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(389),
    [sym__indent] = ACTIONS(391),
    [sym__string_start] = ACTIONS(75),
  },
  [80] = {
    [sym__simple_statements] = STATE(414),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(393),
    [sym__indent] = ACTIONS(395),
    [sym__string_start] = ACTIONS(75),
  },
  [81] = {
    [sym__simple_statements] = STATE(340),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(397),
    [sym__indent] = ACTIONS(399),
    [sym__string_start] = ACTIONS(75),
  },
  [82] = {
    [sym__simple_statements] = STATE(358),
    [sym_import_statement] = STATE(899),
    [sym_future_import_statement] = STATE(899),
    [sym_import_from_statement] = STATE(899),
    [sym_print_statement] = STATE(899),
    [sym_assert_statement] = STATE(899),
    [sym_expression_statement] = STATE(899),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(899),
    [sym_delete_statement] = STATE(899),
    [sym_raise_statement] = STATE(899),
    [sym_pass_statement] = STATE(899),
    [sym_break_statement] = STATE(899),
    [sym_continue_statement] = STATE(899),
    [sym_global_statement] = STATE(899),
    [sym_nonlocal_statement] = STATE(899),
    [sym_exec_statement] = STATE(899),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(401),
    [sym__indent] = ACTIONS(403),
    [sym__string_start] = ACTIONS(75),
  },
  [83] = {
    [sym__simple_statements] = STATE(364),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(405),
    [sym__indent] = ACTIONS(407),
    [sym__string_start] = ACTIONS(75),
  },
  [84] = {
    [sym__simple_statements] = STATE(317),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(409),
    [sym__indent] = ACTIONS(411),
    [sym__string_start] = ACTIONS(75),
  },
  [85] = {
    [sym__simple_statements] = STATE(379),
    [sym_import_statement] = STATE(959),
    [sym_future_import_statement] = STATE(959),
    [sym_import_from_statement] = STATE(959),
    [sym_print_statement] = STATE(959),
    [sym_assert_statement] = STATE(959),
    [sym_expression_statement] = STATE(959),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(959),
    [sym_delete_statement] = STATE(959),
    [sym_raise_statement] = STATE(959),
    [sym_pass_statement] = STATE(959),
    [sym_break_statement] = STATE(959),
    [sym_continue_statement] = STATE(959),
    [sym_global_statement] = STATE(959),
    [sym_nonlocal_statement] = STATE(959),
    [sym_exec_statement] = STATE(959),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(413),
    [sym__indent] = ACTIONS(415),
    [sym__string_start] = ACTIONS(75),
  },
  [86] = {
    [sym_import_statement] = STATE(974),
    [sym_future_import_statement] = STATE(974),
    [sym_import_from_statement] = STATE(974),
    [sym_print_statement] = STATE(974),
    [sym_assert_statement] = STATE(974),
    [sym_expression_statement] = STATE(974),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(974),
    [sym_delete_statement] = STATE(974),
    [sym_raise_statement] = STATE(974),
    [sym_pass_statement] = STATE(974),
    [sym_break_statement] = STATE(974),
    [sym_continue_statement] = STATE(974),
    [sym_global_statement] = STATE(974),
    [sym_nonlocal_statement] = STATE(974),
    [sym_exec_statement] = STATE(974),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(417),
    [sym__string_start] = ACTIONS(75),
  },
  [87] = {
    [sym_import_statement] = STATE(974),
    [sym_future_import_statement] = STATE(974),
    [sym_import_from_statement] = STATE(974),
    [sym_print_statement] = STATE(974),
    [sym_assert_statement] = STATE(974),
    [sym_expression_statement] = STATE(974),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(974),
    [sym_delete_statement] = STATE(974),
    [sym_raise_statement] = STATE(974),
    [sym_pass_statement] = STATE(974),
    [sym_break_statement] = STATE(974),
    [sym_continue_statement] = STATE(974),
    [sym_global_statement] = STATE(974),
    [sym_nonlocal_statement] = STATE(974),
    [sym_exec_statement] = STATE(974),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(419),
    [sym__string_start] = ACTIONS(75),
  },
  [88] = {
    [sym_import_statement] = STATE(974),
    [sym_future_import_statement] = STATE(974),
    [sym_import_from_statement] = STATE(974),
    [sym_print_statement] = STATE(974),
    [sym_assert_statement] = STATE(974),
    [sym_expression_statement] = STATE(974),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(974),
    [sym_delete_statement] = STATE(974),
    [sym_raise_statement] = STATE(974),
    [sym_pass_statement] = STATE(974),
    [sym_break_statement] = STATE(974),
    [sym_continue_statement] = STATE(974),
    [sym_global_statement] = STATE(974),
    [sym_nonlocal_statement] = STATE(974),
    [sym_exec_statement] = STATE(974),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(421),
    [sym__string_start] = ACTIONS(75),
  },
  [89] = {
    [sym_import_statement] = STATE(974),
    [sym_future_import_statement] = STATE(974),
    [sym_import_from_statement] = STATE(974),
    [sym_print_statement] = STATE(974),
    [sym_assert_statement] = STATE(974),
    [sym_expression_statement] = STATE(974),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(974),
    [sym_delete_statement] = STATE(974),
    [sym_raise_statement] = STATE(974),
    [sym_pass_statement] = STATE(974),
    [sym_break_statement] = STATE(974),
    [sym_continue_statement] = STATE(974),
    [sym_global_statement] = STATE(974),
    [sym_nonlocal_statement] = STATE(974),
    [sym_exec_statement] = STATE(974),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(423),
    [sym__string_start] = ACTIONS(75),
  },
  [90] = {
    [sym_import_statement] = STATE(974),
    [sym_future_import_statement] = STATE(974),
    [sym_import_from_statement] = STATE(974),
    [sym_print_statement] = STATE(974),
    [sym_assert_statement] = STATE(974),
    [sym_expression_statement] = STATE(974),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(974),
    [sym_delete_statement] = STATE(974),
    [sym_raise_statement] = STATE(974),
    [sym_pass_statement] = STATE(974),
    [sym_break_statement] = STATE(974),
    [sym_continue_statement] = STATE(974),
    [sym_global_statement] = STATE(974),
    [sym_nonlocal_statement] = STATE(974),
    [sym_exec_statement] = STATE(974),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(425),
    [sym__string_start] = ACTIONS(75),
  },
  [91] = {
    [sym_import_statement] = STATE(974),
    [sym_future_import_statement] = STATE(974),
    [sym_import_from_statement] = STATE(974),
    [sym_print_statement] = STATE(974),
    [sym_assert_statement] = STATE(974),
    [sym_expression_statement] = STATE(974),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(974),
    [sym_delete_statement] = STATE(974),
    [sym_raise_statement] = STATE(974),
    [sym_pass_statement] = STATE(974),
    [sym_break_statement] = STATE(974),
    [sym_continue_statement] = STATE(974),
    [sym_global_statement] = STATE(974),
    [sym_nonlocal_statement] = STATE(974),
    [sym_exec_statement] = STATE(974),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(427),
    [sym__string_start] = ACTIONS(75),
  },
  [92] = {
    [sym_import_statement] = STATE(974),
    [sym_future_import_statement] = STATE(974),
    [sym_import_from_statement] = STATE(974),
    [sym_print_statement] = STATE(974),
    [sym_assert_statement] = STATE(974),
    [sym_expression_statement] = STATE(974),
    [sym_named_expression] = STATE(725),
    [sym_return_statement] = STATE(974),
    [sym_delete_statement] = STATE(974),
    [sym_raise_statement] = STATE(974),
    [sym_pass_statement] = STATE(974),
    [sym_break_statement] = STATE(974),
    [sym_continue_statement] = STATE(974),
    [sym_global_statement] = STATE(974),
    [sym_nonlocal_statement] = STATE(974),
    [sym_exec_statement] = STATE(974),
    [sym_pattern] = STATE(667),
    [sym_tuple_pattern] = STATE(662),
    [sym_list_pattern] = STATE(662),
    [sym_list_splat_pattern] = STATE(662),
    [sym_expression] = STATE(780),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_assignment] = STATE(999),
    [sym_augmented_assignment] = STATE(999),
    [sym_pattern_list] = STATE(668),
    [sym_yield] = STATE(999),
    [sym_attribute] = STATE(210),
    [sym_subscript] = STATE(210),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_from] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [anon_sym_print] = ACTIONS(17),
    [anon_sym_assert] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_del] = ACTIONS(23),
    [anon_sym_raise] = ACTIONS(25),
    [anon_sym_pass] = ACTIONS(27),
    [anon_sym_break] = ACTIONS(29),
    [anon_sym_continue] = ACTIONS(31),
    [anon_sym_async] = ACTIONS(263),
    [anon_sym_global] = ACTIONS(47),
    [anon_sym_nonlocal] = ACTIONS(49),
    [anon_sym_exec] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_lambda] = ACTIONS(63),
    [anon_sym_yield] = ACTIONS(65),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(73),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__string_start] = ACTIONS(75),
  },
  [93] = {
    [sym_named_expression] = STATE(675),
    [sym_expression] = STATE(673),
    [sym_primary_expression] = STATE(448),
    [sym_not_operator] = STATE(675),
    [sym_boolean_operator] = STATE(675),
    [sym_binary_operator] = STATE(454),
    [sym_unary_operator] = STATE(454),
    [sym_comparison_operator] = STATE(675),
    [sym_lambda] = STATE(675),
    [sym_attribute] = STATE(454),
    [sym_subscript] = STATE(454),
    [sym_call] = STATE(454),
    [sym_list] = STATE(454),
    [sym_set] = STATE(454),
    [sym_tuple] = STATE(454),
    [sym_dictionary] = STATE(454),
    [sym_list_comprehension] = STATE(454),
    [sym_dictionary_comprehension] = STATE(454),
    [sym_set_comprehension] = STATE(454),
    [sym_generator_expression] = STATE(454),
    [sym_parenthesized_expression] = STATE(454),
    [sym_conditional_expression] = STATE(675),
    [sym_concatenated_string] = STATE(454),
    [sym_string] = STATE(361),
    [sym_await] = STATE(675),
    [sym_identifier] = ACTIONS(429),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_RPAREN] = ACTIONS(240),
    [anon_sym_COMMA] = ACTIONS(240),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_print] = ACTIONS(433),
    [anon_sym_GT_GT] = ACTIONS(240),
    [anon_sym_if] = ACTIONS(242),
    [anon_sym_COLON] = ACTIONS(240),
    [anon_sym_else] = ACTIONS(242),
    [anon_sym_async] = ACTIONS(433),
    [anon_sym_in] = ACTIONS(242),
    [anon_sym_STAR_STAR] = ACTIONS(240),
    [anon_sym_exec] = ACTIONS(433),
    [anon_sym_AT] = ACTIONS(240),
    [anon_sym_LBRACK] = ACTIONS(435),
    [anon_sym_RBRACK] = ACTIONS(240),
    [anon_sym_EQ] = ACTIONS(242),
    [anon_sym_not] = ACTIONS(437),
    [anon_sym_and] = ACTIONS(242),
    [anon_sym_or] = ACTIONS(242),
    [anon_sym_PLUS] = ACTIONS(439),
    [anon_sym_DASH] = ACTIONS(439),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_SLASH_SLASH] = ACTIONS(240),
    [anon_sym_PIPE] = ACTIONS(240),
    [anon_sym_AMP] = ACTIONS(240),
    [anon_sym_CARET] = ACTIONS(240),
    [anon_sym_LT_LT] = ACTIONS(240),
    [anon_sym_TILDE] = ACTIONS(439),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_GT] = ACTIONS(240),
    [anon_sym_is] = ACTIONS(242),
    [anon_sym_lambda] = ACTIONS(441),
    [sym_ellipsis] = ACTIONS(443),
    [anon_sym_LBRACE] = ACTIONS(445),
    [anon_sym_RBRACE] = ACTIONS(240),
    [sym_type_conversion] = ACTIONS(240),
    [sym_integer] = ACTIONS(447),
    [sym_float] = ACTIONS(443),
    [anon_sym_await] = ACTIONS(449),
    [sym_true] = ACTIONS(447),
    [sym_false] = ACTIONS(447),
    [sym_none] = ACTIONS(447),
    [sym_comment] = ACTIONS(3),
    [sym__string_start] = ACTIONS(451),
  },
  [94] = {
    [sym_named_expression] = STATE(675),
    [sym_expression] = STATE(673),
    [sym_primary_expression] = STATE(447),
    [sym_not_operator] = STATE(675),
    [sym_boolean_operator] = STATE(675),
    [sym_binary_operator] = STATE(454),
    [sym_unary_operator] = STATE(454),
    [sym_comparison_operator] = STATE(675),
    [sym_lambda] = STATE(675),
    [sym_attribute] = STATE(454),
    [sym_subscript] = STATE(454),
    [sym_call] = STATE(454),
    [sym_list] = STATE(454),
    [sym_set] = STATE(454),
    [sym_tuple] = STATE(454),
    [sym_dictionary] = STATE(454),
    [sym_list_comprehension] = STATE(454),
    [sym_dictionary_comprehension] = STATE(454),
    [sym_set_comprehension] = STATE(454),
    [sym_generator_expression] = STATE(454),
    [sym_parenthesized_expression] = STATE(454),
    [sym_conditional_expression] = STATE(675),
    [sym_concatenated_string] = STATE(454),
    [sym_string] = STATE(361),
    [sym_await] = STATE(675),
    [sym_identifier] = ACTIONS(453),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_LPAREN] = ACTIONS(455),
    [anon_sym_RPAREN] = ACTIONS(240),
    [anon_sym_COMMA] = ACTIONS(240),
    [anon_sym_as] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_print] = ACTIONS(457),
    [anon_sym_GT_GT] = ACTIONS(240),
    [anon_sym_if] = ACTIONS(242),
    [anon_sym_COLON] = ACTIONS(240),
    [anon_sym_async] = ACTIONS(457),
    [anon_sym_for] = ACTIONS(242),
    [anon_sym_in] = ACTIONS(242),
    [anon_sym_STAR_STAR] = ACTIONS(240),
    [anon_sym_exec] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(240),
    [anon_sym_LBRACK] = ACTIONS(459),
    [anon_sym_RBRACK] = ACTIONS(240),
    [anon_sym_not] = ACTIONS(461),
    [anon_sym_and] = ACTIONS(242),
    [anon_sym_or] = ACTIONS(242),
    [anon_sym_PLUS] = ACTIONS(463),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_SLASH_SLASH] = ACTIONS(240),
    [anon_sym_PIPE] = ACTIONS(240),
    [anon_sym_AMP] = ACTIONS(240),
    [anon_sym_CARET] = ACTIONS(240),
    [anon_sym_LT_LT] = ACTIONS(240),
    [anon_sym_TILDE] = ACTIONS(463),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_GT] = ACTIONS(240),
    [anon_sym_is] = ACTIONS(242),
    [anon_sym_lambda] = ACTIONS(465),
    [sym_ellipsis] = ACTIONS(443),
    [anon_sym_LBRACE] = ACTIONS(445),
    [anon_sym_RBRACE] = ACTIONS(240),
    [sym_integer] = ACTIONS(447),
    [sym_float] = ACTIONS(443),
    [anon_sym_await] = ACTIONS(467),
    [sym_true] = ACTIONS(447),
    [sym_false] = ACTIONS(447),
    [sym_none] = ACTIONS(447),
    [sym_comment] = ACTIONS(3),
    [sym__string_start] = ACTIONS(451),
  },
  [95] = {
    [sym_named_expression] = STATE(725),
    [sym_expression] = STATE(732),
    [sym_primary_expression] = STATE(500),
    [sym_not_operator] = STATE(725),
    [sym_boolean_operator] = STATE(725),
    [sym_binary_operator] = STATE(605),
    [sym_unary_operator] = STATE(605),
    [sym_comparison_operator] = STATE(725),
    [sym_lambda] = STATE(725),
    [sym_attribute] = STATE(605),
    [sym_subscript] = STATE(605),
    [sym_call] = STATE(605),
    [sym_list] = STATE(605),
    [sym_set] = STATE(605),
    [sym_tuple] = STATE(605),
    [sym_dictionary] = STATE(605),
    [sym_list_comprehension] = STATE(605),
    [sym_dictionary_comprehension] = STATE(605),
    [sym_set_comprehension] = STATE(605),
    [sym_generator_expression] = STATE(605),
    [sym_parenthesized_expression] = STATE(605),
    [sym_conditional_expression] = STATE(725),
    [sym_concatenated_string] = STATE(605),
    [sym_string] = STATE(498),
    [sym_await] = STATE(725),
    [sym_identifier] = ACTIONS(238),
    [anon_sym_SEMI] = ACTIONS(240),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_from] = ACTIONS(242),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_COMMA] = ACTIONS(240),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_print] = ACTIONS(247),
    [anon_sym_GT_GT] = ACTIONS(240),
    [anon_sym_if] = ACTIONS(242),
    [anon_sym_async] = ACTIONS(247),
    [anon_sym_in] = ACTIONS(242),
    [anon_sym_STAR_STAR] = ACTIONS(240),
    [anon_sym_exec] = ACTIONS(247),
    [anon_sym_AT] = ACTIONS(240),
    [anon_sym_LBRACK] = ACTIONS(259),
    [anon_sym_EQ] = ACTIONS(242),
    [anon_sym_not] = ACTIONS(59),
    [anon_sym_and] = ACTIONS(242),
    [anon_sym_or] = ACTIONS(242),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_SLASH_SLASH] = ACTIONS(240),
    [anon_sym_PIPE] = ACTIONS(240),
    [anon_sym_AMP] = ACTIONS(240),
    [anon_sym_CARET] = ACTIONS(240),
    [anon_sym_LT_LT] = ACTIONS(240),
    [anon_sym_TILDE] = ACTIONS(61),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_GT] = ACTIONS(240),
    [anon_sym_is] = ACTIONS(242),
    [anon_sym_lambda] = ACTIONS(63),
    [sym_ellipsis] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(69),
    [sym_integer] = ACTIONS(71),
    [sym_float] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(255),
    [sym_true] = ACTIONS(71),
    [sym_false] = ACTIONS(71),
    [sym_none] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(240),
    [sym__string_start] = ACTIONS(75),
  },
  [96] = {
    [sym_named_expression] = STATE(675),
    [sym_expression] = STATE(673),
    [sym_primary_expression] = STATE(447),
    [sym_not_operator] = STATE(675),
    [sym_boolean_operator] = STATE(675),
    [sym_binary_operator] = STATE(454),
    [sym_unary_operator] = STATE(454),
    [sym_comparison_operator] = STATE(675),
    [sym_lambda] = STATE(675),
    [sym_attribute] = STATE(454),
    [sym_subscript] = STATE(454),
    [sym_call] = STATE(454),
    [sym_list] = STATE(454),
    [sym_set] = STATE(454),
    [sym_tuple] = STATE(454),
    [sym_dictionary] = STATE(454),
    [sym_list_comprehension] = STATE(454),
    [sym_dictionary_comprehension] = STATE(454),
    [sym_set_comprehension] = STATE(454),
    [sym_generator_expression] = STATE(454),
    [sym_parenthesized_expression] = STATE(454),
    [sym_conditional_expression] = STATE(675),
    [sym_concatenated_string] = STATE(454),
    [sym_string] = STATE(361),
    [sym_await] = STATE(675),
    [sym_identifier] = ACTIONS(453),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_LPAREN] = ACTIONS(455),
    [anon_sym_RPAREN] = ACTIONS(240),
    [anon_sym_COMMA] = ACTIONS(240),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_print] = ACTIONS(457),
    [anon_sym_GT_GT] = ACTIONS(240),
    [anon_sym_if] = ACTIONS(242),
    [anon_sym_async] = ACTIONS(457),
    [anon_sym_for] = ACTIONS(242),
    [anon_sym_in] = ACTIONS(242),
    [anon_sym_STAR_STAR] = ACTIONS(240),
    [anon_sym_exec] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(240),
    [anon_sym_LBRACK] = ACTIONS(459),
    [anon_sym_EQ] = ACTIONS(469),
    [anon_sym_not] = ACTIONS(461),
    [anon_sym_and] = ACTIONS(242),
    [anon_sym_or] = ACTIONS(242),
    [anon_sym_PLUS] = ACTIONS(463),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_SLASH_SLASH] = ACTIONS(240),
    [anon_sym_PIPE] = ACTIONS(240),
    [anon_sym_AMP] = ACTIONS(240),
    [anon_sym_CARET] = ACTIONS(240),
    [anon_sym_LT_LT] = ACTIONS(240),
    [anon_sym_TILDE] = ACTIONS(463),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_GT] = ACTIONS(240),
    [anon_sym_is] = ACTIONS(242),
    [anon_sym_lambda] = ACTIONS(465),
    [sym_ellipsis] = ACTIONS(443),
    [anon_sym_LBRACE] = ACTIONS(445),
    [sym_integer] = ACTIONS(447),
    [sym_float] = ACTIONS(443),
    [anon_sym_await] = ACTIONS(467),
    [sym_true] = ACTIONS(447),
    [sym_false] = ACTIONS(447),
    [sym_none] = ACTIONS(447),
    [sym_comment] = ACTIONS(3),
    [sym__string_start] = ACTIONS(451),
  },
  [97] = {
    [sym_named_expression] = STATE(763),
    [sym_expression] = STATE(770),
    [sym_primary_expression] = STATE(504),
    [sym_not_operator] = STATE(763),
    [sym_boolean_operator] = STATE(763),
    [sym_binary_operator] = STATE(639),
    [sym_unary_operator] = STATE(639),
    [sym_comparison_operator] = STATE(763),
    [sym_lambda] = STATE(763),
    [sym_attribute] = STATE(639),
    [sym_subscript] = STATE(639),
    [sym_call] = STATE(639),
    [sym_list] = STATE(639),
    [sym_set] = STATE(639),
    [sym_tuple] = STATE(639),
    [sym_dictionary] = STATE(639),
    [sym_list_comprehension] = STATE(639),
    [sym_dictionary_comprehension] = STATE(639),
    [sym_set_comprehension] = STATE(639),
    [sym_generator_expression] = STATE(639),
    [sym_parenthesized_expression] = STATE(639),
    [sym_conditional_expression] = STATE(763),
    [sym_concatenated_string] = STATE(639),
    [sym_string] = STATE(506),
    [sym_await] = STATE(763),
    [sym_identifier] = ACTIONS(471),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_LPAREN] = ACTIONS(473),
    [anon_sym_RPAREN] = ACTIONS(240),
    [anon_sym_COMMA] = ACTIONS(240),
    [anon_sym_as] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_print] = ACTIONS(433),
    [anon_sym_GT_GT] = ACTIONS(240),
    [anon_sym_if] = ACTIONS(242),
    [anon_sym_COLON] = ACTIONS(240),
    [anon_sym_async] = ACTIONS(433),
    [anon_sym_in] = ACTIONS(242),
    [anon_sym_STAR_STAR] = ACTIONS(240),
    [anon_sym_exec] = ACTIONS(433),
    [anon_sym_AT] = ACTIONS(240),
    [anon_sym_LBRACK] = ACTIONS(475),
    [anon_sym_not] = ACTIONS(477),
    [anon_sym_and] = ACTIONS(242),
    [anon_sym_or] = ACTIONS(242),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(479),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_SLASH_SLASH] = ACTIONS(240),
    [anon_sym_PIPE] = ACTIONS(240),
    [anon_sym_AMP] = ACTIONS(240),
    [anon_sym_CARET] = ACTIONS(240),
    [anon_sym_LT_LT] = ACTIONS(240),
    [anon_sym_TILDE] = ACTIONS(479),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_GT] = ACTIONS(240),
    [anon_sym_is] = ACTIONS(242),
    [anon_sym_lambda] = ACTIONS(481),
    [sym_ellipsis] = ACTIONS(483),
    [anon_sym_LBRACE] = ACTIONS(485),
    [sym_integer] = ACTIONS(487),
    [sym_float] = ACTIONS(483),
    [anon_sym_await] = ACTIONS(489),
    [sym_true] = ACTIONS(487),
    [sym_false] = ACTIONS(487),
    [sym_none] = ACTIONS(487),
    [sym_comment] = ACTIONS(3),
    [sym__string_start] = ACTIONS(491),
  },
  [98] = {
    [sym_named_expression] = STATE(675),
    [sym_expression] = STATE(673),
    [sym_primary_expression] = STATE(447),
    [sym_not_operator] = STATE(675),
    [sym_boolean_operator] = STATE(675),
    [sym_binary_operator] = STATE(454),
    [sym_unary_operator] = STATE(454),
    [sym_comparison_operator] = STATE(675),
    [sym_lambda] = STATE(675),
    [sym_attribute] = STATE(454),
    [sym_subscript] = STATE(454),
    [sym_call] = STATE(454),
    [sym_list] = STATE(454),
    [sym_set] = STATE(454),
    [sym_tuple] = STATE(454),
    [sym_dictionary] = STATE(454),
    [sym_list_comprehension] = STATE(454),
    [sym_dictionary_comprehension] = STATE(454),
    [sym_set_comprehension] = STATE(454),
    [sym_generator_expression] = STATE(454),
    [sym_parenthesized_expression] = STATE(454),
    [sym_conditional_expression] = STATE(675),
    [sym_concatenated_string] = STATE(454),
    [sym_string] = STATE(361),
    [sym_await] = STATE(675),
    [sym_identifier] = ACTIONS(453),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_LPAREN] = ACTIONS(455),
    [anon_sym_RPAREN] = ACTIONS(244),
    [anon_sym_COMMA] = ACTIONS(244),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_print] = ACTIONS(457),
    [anon_sym_GT_GT] = ACTIONS(240),
    [anon_sym_if] = ACTIONS(242),
    [anon_sym_async] = ACTIONS(457),
    [anon_sym_for] = ACTIONS(242),
    [anon_sym_in] = ACTIONS(242),
    [anon_sym_STAR_STAR] = ACTIONS(240),
    [anon_sym_exec] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(240),
    [anon_sym_LBRACK] = ACTIONS(459),
    [anon_sym_RBRACK] = ACTIONS(244),
    [anon_sym_not] = ACTIONS(461),
    [anon_sym_and] = ACTIONS(242),
    [anon_sym_or] = ACTIONS(242),
    [anon_sym_PLUS] = ACTIONS(463),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_SLASH_SLASH] = ACTIONS(240),
    [anon_sym_PIPE] = ACTIONS(240),
    [anon_sym_AMP] = ACTIONS(240),
    [anon_sym_CARET] = ACTIONS(240),
    [anon_sym_LT_LT] = ACTIONS(240),
    [anon_sym_TILDE] = ACTIONS(463),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_GT] = ACTIONS(240),
    [anon_sym_is] = ACTIONS(242),
    [anon_sym_lambda] = ACTIONS(465),
    [sym_ellipsis] = ACTIONS(443),
    [anon_sym_LBRACE] = ACTIONS(445),
    [sym_integer] = ACTIONS(447),
    [sym_float] = ACTIONS(443),
    [anon_sym_await] = ACTIONS(467),
    [sym_true] = ACTIONS(447),
    [sym_false] = ACTIONS(447),
    [sym_none] = ACTIONS(447),
    [sym_comment] = ACTIONS(3),
    [sym__string_start] = ACTIONS(451),
  },
  [99] = {
    [sym_named_expression] = STATE(675),
    [sym_expression] = STATE(673),
    [sym_primary_expression] = STATE(448),
    [sym_not_operator] = STATE(675),
    [sym_boolean_operator] = STATE(675),
    [sym_binary_operator] = STATE(454),
    [sym_unary_operator] = STATE(454),
    [sym_comparison_operator] = STATE(675),
    [sym_lambda] = STATE(675),
    [sym_attribute] = STATE(454),
    [sym_subscript] = STATE(454),
    [sym_call] = STATE(454),
    [sym_list] = STATE(454),
    [sym_set] = STATE(454),
    [sym_tuple] = STATE(454),
    [sym_dictionary] = STATE(454),
    [sym_list_comprehension] = STATE(454),
    [sym_dictionary_comprehension] = STATE(454),
    [sym_set_comprehension] = STATE(454),
    [sym_generator_expression] = STATE(454),
    [sym_parenthesized_expression] = STATE(454),
    [sym_conditional_expression] = STATE(675),
    [sym_concatenated_string] = STATE(454),
    [sym_string] = STATE(361),
    [sym_await] = STATE(675),
    [sym_identifier] = ACTIONS(429),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_RPAREN] = ACTIONS(240),
    [anon_sym_COMMA] = ACTIONS(240),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_print] = ACTIONS(433),
    [anon_sym_GT_GT] = ACTIONS(240),
    [anon_sym_if] = ACTIONS(242),
    [anon_sym_async] = ACTIONS(433),
    [anon_sym_in] = ACTIONS(242),
    [anon_sym_STAR_STAR] = ACTIONS(240),
    [anon_sym_exec] = ACTIONS(433),
    [anon_sym_AT] = ACTIONS(240),
    [anon_sym_LBRACK] = ACTIONS(435),
    [anon_sym_EQ] = ACTIONS(469),
    [anon_sym_not] = ACTIONS(437),
    [anon_sym_and] = ACTIONS(242),
    [anon_sym_or] = ACTIONS(242),
    [anon_sym_PLUS] = ACTIONS(439),
    [anon_sym_DASH] = ACTIONS(439),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_SLASH_SLASH] = ACTIONS(240),
    [anon_sym_PIPE] = ACTIONS(240),
    [anon_sym_AMP] = ACTIONS(240),
    [anon_sym_CARET] = ACTIONS(240),
    [anon_sym_LT_LT] = ACTIONS(240),
    [anon_sym_TILDE] = ACTIONS(439),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_GT] = ACTIONS(240),
    [anon_sym_is] = ACTIONS(242),
    [anon_sym_lambda] = ACTIONS(441),
    [sym_ellipsis] = ACTIONS(443),
    [anon_sym_LBRACE] = ACTIONS(445),
    [sym_integer] = ACTIONS(447),
    [sym_float] = ACTIONS(443),
    [anon_sym_await] = ACTIONS(449),
    [sym_true] = ACTIONS(447),
    [sym_false] = ACTIONS(447),
    [sym_none] = ACTIONS(447),
    [sym_comment] = ACTIONS(3),
    [sym__string_start] = ACTIONS(451),
  },
  [100] = {
    [sym_named_expression] = STATE(675),
    [sym_expression] = STATE(673),
    [sym_primary_expression] = STATE(448),
    [sym_not_operator] = STATE(675),
    [sym_boolean_operator] = STATE(675),
    [sym_binary_operator] = STATE(454),
    [sym_unary_operator] = STATE(454),
    [sym_comparison_operator] = STATE(675),
    [sym_lambda] = STATE(675),
    [sym_attribute] = STATE(454),
    [sym_subscript] = STATE(454),
    [sym_call] = STATE(454),
    [sym_list] = STATE(454),
    [sym_set] = STATE(454),
    [sym_tuple] = STATE(454),
    [sym_dictionary] = STATE(454),
    [sym_list_comprehension] = STATE(454),
    [sym_dictionary_comprehension] = STATE(454),
    [sym_set_comprehension] = STATE(454),
    [sym_generator_expression] = STATE(454),
    [sym_parenthesized_expression] = STATE(454),
    [sym_conditional_expression] = STATE(675),
    [sym_concatenated_string] = STATE(454),
    [sym_string] = STATE(361),
    [sym_await] = STATE(675),
    [sym_identifier] = ACTIONS(429),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_RPAREN] = ACTIONS(493),
    [anon_sym_COMMA] = ACTIONS(493),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_print] = ACTIONS(433),
    [anon_sym_GT_GT] = ACTIONS(240),
    [anon_sym_if] = ACTIONS(242),
    [anon_sym_async] = ACTIONS(433),
    [anon_sym_in] = ACTIONS(242),
    [anon_sym_STAR_STAR] = ACTIONS(240),
    [anon_sym_exec] = ACTIONS(433),
    [anon_sym_AT] = ACTIONS(240),
    [anon_sym_LBRACK] = ACTIONS(435),
    [anon_sym_RBRACK] = ACTIONS(493),
    [anon_sym_not] = ACTIONS(437),
    [anon_sym_and] = ACTIONS(242),
    [anon_sym_or] = ACTIONS(242),
    [anon_sym_PLUS] = ACTIONS(439),
    [anon_sym_DASH] = ACTIONS(439),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_SLASH_SLASH] = ACTIONS(240),
    [anon_sym_PIPE] = ACTIONS(240),
    [anon_sym_AMP] = ACTIONS(240),
    [anon_sym_CARET] = ACTIONS(240),
    [anon_sym_LT_LT] = ACTIONS(240),
    [anon_sym_TILDE] = ACTIONS(439),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_GT] = ACTIONS(240),
    [anon_sym_is] = ACTIONS(242),
    [anon_sym_lambda] = ACTIONS(441),
    [sym_ellipsis] = ACTIONS(443),
    [anon_sym_LBRACE] = ACTIONS(445),
    [sym_integer] = ACTIONS(447),
    [sym_float] = ACTIONS(443),
    [anon_sym_await] = ACTIONS(449),
    [sym_true] = ACTIONS(447),
    [sym_false] = ACTIONS(447),
    [sym_none] = ACTIONS(447),
    [sym_comment] = ACTIONS(3),
    [sym__string_start] = ACTIONS(451),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(496), 1,
      sym_identifier,
    ACTIONS(498), 1,
      anon_sym_LPAREN,
    ACTIONS(500), 1,
      anon_sym_STAR,
    ACTIONS(504), 1,
      anon_sym_LBRACK,
    ACTIONS(506), 1,
      anon_sym_RBRACK,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(510), 1,
      anon_sym_await,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(706), 1,
      sym_expression,
    STATE(846), 1,
      sym_pattern,
    STATE(1083), 1,
      sym__collection_elements,
    STATE(1096), 1,
      sym__patterns,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(588), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(502), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    STATE(829), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [113] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(496), 1,
      sym_identifier,
    ACTIONS(498), 1,
      anon_sym_LPAREN,
    ACTIONS(500), 1,
      anon_sym_STAR,
    ACTIONS(504), 1,
      anon_sym_LBRACK,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(510), 1,
      anon_sym_await,
    ACTIONS(512), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(715), 1,
      sym_expression,
    STATE(846), 1,
      sym_pattern,
    STATE(1096), 1,
      sym__patterns,
    STATE(1097), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(588), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(502), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    STATE(829), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [226] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(496), 1,
      sym_identifier,
    ACTIONS(498), 1,
      anon_sym_LPAREN,
    ACTIONS(500), 1,
      anon_sym_STAR,
    ACTIONS(504), 1,
      anon_sym_LBRACK,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(510), 1,
      anon_sym_await,
    ACTIONS(514), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(712), 1,
      sym_expression,
    STATE(846), 1,
      sym_pattern,
    STATE(925), 1,
      sym_yield,
    STATE(1022), 1,
      sym__collection_elements,
    STATE(1034), 1,
      sym__patterns,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(588), 2,
      sym_attribute,
      sym_subscript,
    STATE(829), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(502), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [341] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(57), 1,
      anon_sym_LBRACK,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(65), 1,
      anon_sym_yield,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(73), 1,
      anon_sym_await,
    ACTIONS(75), 1,
      sym__string_start,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(667), 1,
      sym_pattern,
    STATE(668), 1,
      sym_pattern_list,
    STATE(757), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    STATE(210), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(263), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1012), 5,
      sym_expression_list,
      sym_assignment,
      sym_augmented_assignment,
      sym__right_hand_side,
      sym_yield,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [450] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(57), 1,
      anon_sym_LBRACK,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(65), 1,
      anon_sym_yield,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(73), 1,
      anon_sym_await,
    ACTIONS(75), 1,
      sym__string_start,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(667), 1,
      sym_pattern,
    STATE(668), 1,
      sym_pattern_list,
    STATE(757), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    STATE(210), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(263), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(973), 5,
      sym_expression_list,
      sym_assignment,
      sym_augmented_assignment,
      sym__right_hand_side,
      sym_yield,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [559] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(496), 1,
      sym_identifier,
    ACTIONS(498), 1,
      anon_sym_LPAREN,
    ACTIONS(500), 1,
      anon_sym_STAR,
    ACTIONS(504), 1,
      anon_sym_LBRACK,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(510), 1,
      anon_sym_await,
    ACTIONS(516), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(706), 1,
      sym_expression,
    STATE(846), 1,
      sym_pattern,
    STATE(1083), 1,
      sym__collection_elements,
    STATE(1096), 1,
      sym__patterns,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(588), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(502), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    STATE(829), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [672] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(57), 1,
      anon_sym_LBRACK,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(65), 1,
      anon_sym_yield,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(73), 1,
      anon_sym_await,
    ACTIONS(75), 1,
      sym__string_start,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(667), 1,
      sym_pattern,
    STATE(668), 1,
      sym_pattern_list,
    STATE(757), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    STATE(210), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(263), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1007), 5,
      sym_expression_list,
      sym_assignment,
      sym_augmented_assignment,
      sym__right_hand_side,
      sym_yield,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [781] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(496), 1,
      sym_identifier,
    ACTIONS(498), 1,
      anon_sym_LPAREN,
    ACTIONS(500), 1,
      anon_sym_STAR,
    ACTIONS(504), 1,
      anon_sym_LBRACK,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(510), 1,
      anon_sym_await,
    ACTIONS(518), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(709), 1,
      sym_expression,
    STATE(846), 1,
      sym_pattern,
    STATE(898), 1,
      sym_yield,
    STATE(1034), 1,
      sym__patterns,
    STATE(1087), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(588), 2,
      sym_attribute,
      sym_subscript,
    STATE(829), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(502), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [896] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(496), 1,
      sym_identifier,
    ACTIONS(498), 1,
      anon_sym_LPAREN,
    ACTIONS(500), 1,
      anon_sym_STAR,
    ACTIONS(504), 1,
      anon_sym_LBRACK,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(510), 1,
      anon_sym_await,
    ACTIONS(520), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(709), 1,
      sym_expression,
    STATE(846), 1,
      sym_pattern,
    STATE(898), 1,
      sym_yield,
    STATE(905), 1,
      sym_parenthesized_list_splat,
    STATE(910), 1,
      sym_list_splat,
    STATE(1034), 1,
      sym__patterns,
    STATE(1087), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(588), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(502), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [1013] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_TILDE,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(522), 1,
      sym_identifier,
    ACTIONS(524), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      anon_sym_STAR,
    ACTIONS(532), 1,
      anon_sym_in,
    ACTIONS(534), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(657), 1,
      sym_pattern,
    STATE(666), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(536), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(565), 2,
      sym_attribute,
      sym_subscript,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(528), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
    ACTIONS(530), 15,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [1111] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(540), 1,
      anon_sym_COMMA,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(546), 1,
      anon_sym_RBRACE,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(692), 1,
      sym_expression,
    STATE(765), 1,
      sym_pair,
    STATE(921), 1,
      sym_dictionary_splat,
    STATE(1064), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(829), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [1223] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(548), 1,
      anon_sym_COMMA,
    ACTIONS(550), 1,
      anon_sym_RBRACE,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(683), 1,
      sym_expression,
    STATE(773), 1,
      sym_pair,
    STATE(907), 1,
      sym_dictionary_splat,
    STATE(1073), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(829), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [1335] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(552), 1,
      anon_sym_COMMA,
    ACTIONS(554), 1,
      anon_sym_RBRACE,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(695), 1,
      sym_expression,
    STATE(764), 1,
      sym_pair,
    STATE(945), 1,
      sym_dictionary_splat,
    STATE(1046), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(829), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [1447] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_TILDE,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(522), 1,
      sym_identifier,
    ACTIONS(524), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      anon_sym_STAR,
    ACTIONS(534), 1,
      anon_sym_LBRACK,
    ACTIONS(558), 1,
      anon_sym_in,
    STATE(361), 1,
      sym_string,
    STATE(657), 1,
      sym_pattern,
    STATE(666), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(536), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(565), 2,
      sym_attribute,
      sym_subscript,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(528), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
    ACTIONS(556), 15,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [1545] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(562), 17,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(560), 36,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [1606] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(568), 1,
      anon_sym_STAR,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(760), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(566), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(875), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [1705] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(568), 1,
      anon_sym_STAR,
    ACTIONS(570), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(696), 1,
      sym_expression,
    STATE(897), 1,
      sym_with_item,
    STATE(947), 1,
      sym_yield,
    STATE(1059), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(829), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [1810] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(574), 17,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(572), 36,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [1871] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(578), 17,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(576), 36,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [1932] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(578), 17,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(576), 36,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [1993] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(582), 1,
      anon_sym_RPAREN,
    ACTIONS(584), 1,
      anon_sym_COMMA,
    ACTIONS(588), 1,
      anon_sym_await,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(716), 1,
      sym_expression,
    STATE(936), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(935), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [2096] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(588), 1,
      anon_sym_await,
    ACTIONS(590), 1,
      anon_sym_RPAREN,
    ACTIONS(592), 1,
      anon_sym_COMMA,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(714), 1,
      sym_expression,
    STATE(931), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(932), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [2199] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_RPAREN,
    ACTIONS(584), 1,
      anon_sym_COMMA,
    ACTIONS(594), 1,
      sym_identifier,
    ACTIONS(596), 1,
      anon_sym_await,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(803), 1,
      sym_expression,
    STATE(936), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(935), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [2302] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(588), 1,
      anon_sym_await,
    ACTIONS(598), 1,
      anon_sym_RPAREN,
    ACTIONS(600), 1,
      anon_sym_COMMA,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(713), 1,
      sym_expression,
    STATE(946), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(944), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [2405] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(604), 17,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(602), 36,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [2466] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(608), 17,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(606), 36,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [2527] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(568), 1,
      anon_sym_STAR,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(760), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(610), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(875), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [2626] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(574), 17,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(572), 36,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [2687] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      sym_identifier,
    ACTIONS(596), 1,
      anon_sym_await,
    ACTIONS(612), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(830), 1,
      sym_expression,
    STATE(1002), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(1006), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [2787] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(568), 1,
      anon_sym_STAR,
    ACTIONS(570), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(709), 1,
      sym_expression,
    STATE(898), 1,
      sym_yield,
    STATE(1087), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(829), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [2889] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(568), 1,
      anon_sym_STAR,
    ACTIONS(614), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(709), 1,
      sym_expression,
    STATE(898), 1,
      sym_yield,
    STATE(905), 1,
      sym_parenthesized_list_splat,
    STATE(910), 1,
      sym_list_splat,
    STATE(1087), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [2993] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      sym_identifier,
    ACTIONS(596), 1,
      anon_sym_await,
    ACTIONS(616), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(830), 1,
      sym_expression,
    STATE(1002), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(1006), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [3093] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(568), 1,
      anon_sym_STAR,
    ACTIONS(614), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(709), 1,
      sym_expression,
    STATE(898), 1,
      sym_yield,
    STATE(1087), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(829), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [3195] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(622), 1,
      anon_sym_lambda,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(720), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 2,
      anon_sym_print,
      anon_sym_exec,
    STATE(762), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(618), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(620), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [3291] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      sym_identifier,
    ACTIONS(596), 1,
      anon_sym_await,
    ACTIONS(624), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(830), 1,
      sym_expression,
    STATE(1002), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(1006), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [3391] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      sym_identifier,
    ACTIONS(596), 1,
      anon_sym_await,
    ACTIONS(626), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(830), 1,
      sym_expression,
    STATE(1002), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(1006), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [3491] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(568), 1,
      anon_sym_STAR,
    ACTIONS(628), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(706), 1,
      sym_expression,
    STATE(1083), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(829), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [3591] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      sym_identifier,
    ACTIONS(596), 1,
      anon_sym_await,
    ACTIONS(630), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(830), 1,
      sym_expression,
    STATE(1002), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(1006), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [3691] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      sym_identifier,
    ACTIONS(596), 1,
      anon_sym_await,
    ACTIONS(632), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(830), 1,
      sym_expression,
    STATE(1002), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(1006), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [3791] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      sym_identifier,
    ACTIONS(596), 1,
      anon_sym_await,
    ACTIONS(634), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(830), 1,
      sym_expression,
    STATE(1002), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(1006), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [3891] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(568), 1,
      anon_sym_STAR,
    ACTIONS(636), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(706), 1,
      sym_expression,
    STATE(1083), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(829), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [3991] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      sym_identifier,
    ACTIONS(596), 1,
      anon_sym_await,
    ACTIONS(638), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(830), 1,
      sym_expression,
    STATE(1002), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(1006), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [4091] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(568), 1,
      anon_sym_STAR,
    ACTIONS(636), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(700), 1,
      sym_expression,
    STATE(1055), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(829), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [4191] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(568), 1,
      anon_sym_STAR,
    ACTIONS(570), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(711), 1,
      sym_expression,
    STATE(947), 1,
      sym_yield,
    STATE(1059), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(829), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [4293] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(568), 1,
      anon_sym_STAR,
    ACTIONS(640), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(712), 1,
      sym_expression,
    STATE(925), 1,
      sym_yield,
    STATE(1022), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(829), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [4395] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(568), 1,
      anon_sym_STAR,
    ACTIONS(642), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(715), 1,
      sym_expression,
    STATE(1097), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(829), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [4495] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(538), 1,
      anon_sym_LPAREN,
    ACTIONS(568), 1,
      anon_sym_STAR,
    ACTIONS(570), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(709), 1,
      sym_expression,
    STATE(898), 1,
      sym_yield,
    STATE(905), 1,
      sym_parenthesized_list_splat,
    STATE(910), 1,
      sym_list_splat,
    STATE(1087), 1,
      sym__collection_elements,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [4599] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      sym_identifier,
    ACTIONS(596), 1,
      anon_sym_await,
    ACTIONS(644), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(830), 1,
      sym_expression,
    STATE(1002), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(1006), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [4699] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      sym_identifier,
    ACTIONS(596), 1,
      anon_sym_await,
    ACTIONS(646), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(830), 1,
      sym_expression,
    STATE(1002), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(1006), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [4799] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      sym_identifier,
    ACTIONS(596), 1,
      anon_sym_await,
    ACTIONS(648), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(830), 1,
      sym_expression,
    STATE(1002), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(1006), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [4899] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      sym_identifier,
    ACTIONS(596), 1,
      anon_sym_await,
    ACTIONS(650), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(830), 1,
      sym_expression,
    STATE(1002), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(1006), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [4999] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(622), 1,
      anon_sym_lambda,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(720), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 2,
      anon_sym_print,
      anon_sym_exec,
    STATE(762), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(652), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(654), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [5095] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(622), 1,
      anon_sym_lambda,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(720), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 2,
      anon_sym_print,
      anon_sym_exec,
    STATE(762), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(656), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(658), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [5191] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(622), 1,
      anon_sym_lambda,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(720), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 2,
      anon_sym_print,
      anon_sym_exec,
    STATE(762), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(660), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(662), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [5287] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(664), 1,
      anon_sym_from,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(740), 1,
      sym_expression,
    STATE(885), 1,
      sym_expression_list,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(666), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [5382] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(542), 1,
      anon_sym_STAR,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      sym_identifier,
    ACTIONS(596), 1,
      anon_sym_await,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(830), 1,
      sym_expression,
    STATE(1002), 1,
      sym_parenthesized_list_splat,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(586), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    STATE(1006), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [5479] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(743), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(668), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [5569] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(508), 1,
      anon_sym_yield,
    ACTIONS(564), 1,
      anon_sym_LPAREN,
    ACTIONS(568), 1,
      anon_sym_STAR,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(760), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(875), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [5663] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(244), 1,
      anon_sym_COMMA,
    ACTIONS(253), 1,
      anon_sym_EQ,
    ACTIONS(670), 1,
      anon_sym_for,
    ACTIONS(672), 1,
      anon_sym_with,
    ACTIONS(674), 1,
      anon_sym_def,
    ACTIONS(251), 14,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(242), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(240), 16,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [5733] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(743), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(676), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [5823] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(244), 1,
      anon_sym_COMMA,
    ACTIONS(253), 1,
      anon_sym_EQ,
    ACTIONS(678), 1,
      anon_sym_for,
    ACTIONS(680), 1,
      anon_sym_with,
    ACTIONS(682), 1,
      anon_sym_def,
    ACTIONS(251), 14,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(242), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(240), 16,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [5893] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      anon_sym_else,
    ACTIONS(690), 1,
      anon_sym_except,
    ACTIONS(692), 1,
      anon_sym_finally,
    STATE(344), 1,
      sym_else_clause,
    STATE(424), 1,
      sym_finally_clause,
    STATE(232), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
    ACTIONS(686), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(684), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [5962] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    ACTIONS(694), 1,
      anon_sym_from,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(761), 1,
      sym_expression,
    STATE(978), 1,
      sym_expression_list,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(666), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [6055] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(696), 1,
      anon_sym_else,
    ACTIONS(698), 1,
      anon_sym_except,
    ACTIONS(700), 1,
      anon_sym_finally,
    STATE(348), 1,
      sym_else_clause,
    STATE(428), 1,
      sym_finally_clause,
    STATE(212), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
    ACTIONS(686), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(684), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [6124] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(696), 1,
      anon_sym_else,
    ACTIONS(698), 1,
      anon_sym_except,
    ACTIONS(700), 1,
      anon_sym_finally,
    STATE(352), 1,
      sym_else_clause,
    STATE(411), 1,
      sym_finally_clause,
    STATE(212), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
    ACTIONS(702), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(704), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [6193] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(706), 1,
      anon_sym_RBRACE,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(853), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(1004), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [6286] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(708), 1,
      anon_sym_RBRACE,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(853), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(1004), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [6379] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(244), 1,
      anon_sym_COMMA,
    ACTIONS(253), 1,
      anon_sym_EQ,
    ACTIONS(710), 1,
      sym__string_start,
    STATE(965), 1,
      sym_string,
    ACTIONS(251), 14,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(242), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(240), 16,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [6446] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    ACTIONS(714), 1,
      anon_sym_from,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(742), 1,
      sym_expression,
    STATE(966), 1,
      sym_expression_list,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(712), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [6539] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(716), 1,
      anon_sym_RBRACE,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(853), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(1004), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [6632] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      anon_sym_else,
    ACTIONS(690), 1,
      anon_sym_except,
    ACTIONS(692), 1,
      anon_sym_finally,
    STATE(341), 1,
      sym_else_clause,
    STATE(370), 1,
      sym_finally_clause,
    STATE(232), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
    ACTIONS(702), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(704), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [6701] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(718), 1,
      anon_sym_RBRACE,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(853), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(1004), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [6794] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(720), 1,
      anon_sym_RBRACE,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(853), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(1004), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [6887] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    ACTIONS(722), 1,
      anon_sym_RBRACE,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(853), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(1004), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [6980] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(578), 16,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(576), 32,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7036] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(724), 1,
      anon_sym_COLON,
    ACTIONS(726), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(791), 1,
      sym_expression,
    STATE(1001), 1,
      sym_slice,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [7128] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(574), 16,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(572), 32,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7184] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(608), 16,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(606), 32,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7240] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(724), 1,
      anon_sym_COLON,
    ACTIONS(728), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(791), 1,
      sym_expression,
    STATE(1001), 1,
      sym_slice,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [7332] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(724), 1,
      anon_sym_COLON,
    ACTIONS(730), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(791), 1,
      sym_expression,
    STATE(1001), 1,
      sym_slice,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [7424] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(562), 16,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(560), 32,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7480] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(734), 1,
      anon_sym_COLON,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(793), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(732), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [7570] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(724), 1,
      anon_sym_COLON,
    ACTIONS(736), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(791), 1,
      sym_expression,
    STATE(1001), 1,
      sym_slice,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [7662] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(724), 1,
      anon_sym_COLON,
    ACTIONS(738), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(791), 1,
      sym_expression,
    STATE(1001), 1,
      sym_slice,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [7754] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(742), 1,
      anon_sym_COLON,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(797), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [7844] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(578), 16,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(576), 32,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7900] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(724), 1,
      anon_sym_COLON,
    ACTIONS(744), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(791), 1,
      sym_expression,
    STATE(1001), 1,
      sym_slice,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [7992] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(604), 16,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(602), 32,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8048] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(724), 1,
      anon_sym_COLON,
    ACTIONS(746), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(791), 1,
      sym_expression,
    STATE(1001), 1,
      sym_slice,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [8140] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(724), 1,
      anon_sym_COLON,
    ACTIONS(748), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(791), 1,
      sym_expression,
    STATE(1001), 1,
      sym_slice,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [8232] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(724), 1,
      anon_sym_COLON,
    ACTIONS(750), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(791), 1,
      sym_expression,
    STATE(1001), 1,
      sym_slice,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [8324] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    ACTIONS(752), 1,
      anon_sym_from,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(752), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(668), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [8414] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    ACTIONS(754), 1,
      anon_sym_from,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(752), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(676), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [8504] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(755), 1,
      sym_expression,
    STATE(1003), 1,
      sym_expression_list,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(756), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [8594] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(574), 16,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(572), 32,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8650] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(760), 1,
      anon_sym_COMMA,
    ACTIONS(765), 1,
      anon_sym_COLON_EQ,
    ACTIONS(767), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(769), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(763), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 16,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [8714] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(544), 1,
      anon_sym_STAR_STAR,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(853), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(1004), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [8804] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(724), 1,
      anon_sym_COLON,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(746), 1,
      sym_expression,
    STATE(939), 1,
      sym_slice,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [8893] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(696), 1,
      anon_sym_else,
    ACTIONS(775), 1,
      anon_sym_elif,
    STATE(253), 1,
      aux_sym_if_statement_repeat1,
    STATE(349), 1,
      sym_elif_clause,
    STATE(376), 1,
      sym_else_clause,
    ACTIONS(771), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(773), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [8958] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(827), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(732), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [9045] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      anon_sym_else,
    ACTIONS(781), 1,
      anon_sym_elif,
    STATE(207), 1,
      aux_sym_if_statement_repeat1,
    STATE(353), 1,
      sym_elif_clause,
    STATE(406), 1,
      sym_else_clause,
    ACTIONS(779), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(777), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [9110] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(805), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(783), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [9197] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(752), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(785), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [9284] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(805), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(787), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [9371] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(622), 1,
      anon_sym_lambda,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(720), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(735), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [9458] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(696), 1,
      anon_sym_else,
    ACTIONS(775), 1,
      anon_sym_elif,
    STATE(221), 1,
      aux_sym_if_statement_repeat1,
    STATE(349), 1,
      sym_elif_clause,
    STATE(426), 1,
      sym_else_clause,
    ACTIONS(779), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(777), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [9523] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      anon_sym_else,
    ACTIONS(781), 1,
      anon_sym_elif,
    STATE(240), 1,
      aux_sym_if_statement_repeat1,
    STATE(353), 1,
      sym_elif_clause,
    STATE(397), 1,
      sym_else_clause,
    ACTIONS(791), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(789), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [9588] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      anon_sym_else,
    ACTIONS(781), 1,
      anon_sym_elif,
    STATE(229), 1,
      aux_sym_if_statement_repeat1,
    STATE(353), 1,
      sym_elif_clause,
    STATE(384), 1,
      sym_else_clause,
    ACTIONS(795), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(793), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [9653] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(622), 1,
      anon_sym_lambda,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(721), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(767), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [9740] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(760), 1,
      anon_sym_COMMA,
    ACTIONS(767), 1,
      anon_sym_EQ,
    ACTIONS(769), 14,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(763), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 16,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [9801] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(805), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(797), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [9888] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(803), 1,
      anon_sym_except,
    STATE(212), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
    ACTIONS(799), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(801), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [9947] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(805), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [10034] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(810), 1,
      anon_sym_COMMA,
    ACTIONS(817), 1,
      anon_sym_EQ,
    ACTIONS(815), 14,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(813), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(808), 16,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [10095] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(821), 1,
      anon_sym_COMMA,
    ACTIONS(828), 1,
      anon_sym_EQ,
    ACTIONS(826), 14,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(824), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(819), 16,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [10156] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(752), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(830), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [10243] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      sym_identifier,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(477), 1,
      anon_sym_not,
    ACTIONS(481), 1,
      anon_sym_lambda,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(489), 1,
      anon_sym_await,
    ACTIONS(491), 1,
      sym__string_start,
    ACTIONS(832), 1,
      anon_sym_LPAREN,
    STATE(504), 1,
      sym_primary_expression,
    STATE(506), 1,
      sym_string,
    STATE(749), 1,
      sym_expression,
    STATE(887), 1,
      sym_with_item,
    STATE(1104), 1,
      sym_with_clause,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(487), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(763), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [10332] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(812), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(834), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [10419] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(696), 1,
      anon_sym_else,
    ACTIONS(775), 1,
      anon_sym_elif,
    STATE(199), 1,
      aux_sym_if_statement_repeat1,
    STATE(349), 1,
      sym_elif_clause,
    STATE(387), 1,
      sym_else_clause,
    ACTIONS(795), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(793), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [10484] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      sym_identifier,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(477), 1,
      anon_sym_not,
    ACTIONS(481), 1,
      anon_sym_lambda,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(489), 1,
      anon_sym_await,
    ACTIONS(491), 1,
      sym__string_start,
    ACTIONS(832), 1,
      anon_sym_LPAREN,
    STATE(504), 1,
      sym_primary_expression,
    STATE(506), 1,
      sym_string,
    STATE(749), 1,
      sym_expression,
    STATE(887), 1,
      sym_with_item,
    STATE(1056), 1,
      sym_with_clause,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(487), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(763), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [10573] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(696), 1,
      anon_sym_else,
    ACTIONS(775), 1,
      anon_sym_elif,
    STATE(253), 1,
      aux_sym_if_statement_repeat1,
    STATE(349), 1,
      sym_elif_clause,
    STATE(398), 1,
      sym_else_clause,
    ACTIONS(791), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(789), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [10638] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(244), 1,
      anon_sym_COMMA,
    ACTIONS(253), 1,
      anon_sym_EQ,
    ACTIONS(251), 14,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(242), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(240), 16,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [10699] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      sym_identifier,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(477), 1,
      anon_sym_not,
    ACTIONS(481), 1,
      anon_sym_lambda,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(489), 1,
      anon_sym_await,
    ACTIONS(491), 1,
      sym__string_start,
    ACTIONS(832), 1,
      anon_sym_LPAREN,
    STATE(504), 1,
      sym_primary_expression,
    STATE(506), 1,
      sym_string,
    STATE(749), 1,
      sym_expression,
    STATE(887), 1,
      sym_with_item,
    STATE(1062), 1,
      sym_with_clause,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(487), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(763), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [10788] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(724), 1,
      anon_sym_COLON,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(777), 1,
      sym_expression,
    STATE(928), 1,
      sym_slice,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [10877] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(622), 1,
      anon_sym_lambda,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(718), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(754), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [10964] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(724), 1,
      anon_sym_COLON,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(774), 1,
      sym_expression,
    STATE(950), 1,
      sym_slice,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [11053] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      sym_identifier,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(477), 1,
      anon_sym_not,
    ACTIONS(481), 1,
      anon_sym_lambda,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(489), 1,
      anon_sym_await,
    ACTIONS(491), 1,
      sym__string_start,
    ACTIONS(832), 1,
      anon_sym_LPAREN,
    STATE(504), 1,
      sym_primary_expression,
    STATE(506), 1,
      sym_string,
    STATE(749), 1,
      sym_expression,
    STATE(887), 1,
      sym_with_item,
    STATE(1084), 1,
      sym_with_clause,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(487), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(763), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [11142] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(724), 1,
      anon_sym_COLON,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(791), 1,
      sym_expression,
    STATE(1001), 1,
      sym_slice,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [11231] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      anon_sym_else,
    ACTIONS(781), 1,
      anon_sym_elif,
    STATE(240), 1,
      aux_sym_if_statement_repeat1,
    STATE(353), 1,
      sym_elif_clause,
    STATE(378), 1,
      sym_else_clause,
    ACTIONS(771), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(773), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [11296] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(814), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(836), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [11383] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(622), 1,
      anon_sym_lambda,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(720), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(762), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [11470] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(838), 1,
      anon_sym_except,
    STATE(232), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
    ACTIONS(799), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(801), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [11529] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(467), 1,
      anon_sym_await,
    ACTIONS(622), 1,
      anon_sym_lambda,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(720), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(730), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [11616] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(841), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(843), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [11670] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(745), 1,
      sym_expression,
    STATE(1047), 1,
      sym_type,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [11756] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(845), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(847), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [11810] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(851), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(849), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [11864] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(745), 1,
      sym_expression,
    STATE(1075), 1,
      sym_type,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [11950] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(804), 1,
      sym_expression,
    STATE(1072), 1,
      sym_expression_list,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [12036] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(857), 1,
      anon_sym_elif,
    STATE(240), 1,
      aux_sym_if_statement_repeat1,
    STATE(353), 1,
      sym_elif_clause,
    ACTIONS(855), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(853), 31,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [12096] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(841), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(843), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [12150] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(745), 1,
      sym_expression,
    STATE(1077), 1,
      sym_type,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [12236] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(794), 1,
      sym_expression,
    STATE(1067), 1,
      sym_expression_list,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [12322] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(745), 1,
      sym_expression,
    STATE(856), 1,
      sym_type,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [12408] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      sym_identifier,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(477), 1,
      anon_sym_not,
    ACTIONS(481), 1,
      anon_sym_lambda,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(489), 1,
      anon_sym_await,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(504), 1,
      sym_primary_expression,
    STATE(506), 1,
      sym_string,
    STATE(749), 1,
      sym_expression,
    STATE(888), 1,
      sym_with_item,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(487), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(763), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [12494] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(783), 1,
      sym_expression,
    STATE(1107), 1,
      sym_expression_list,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [12580] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(862), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(860), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [12634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(862), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(860), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [12688] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(745), 1,
      sym_expression,
    STATE(948), 1,
      sym_type,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [12774] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(845), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(847), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [12828] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(864), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [12882] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(745), 1,
      sym_expression,
    STATE(1078), 1,
      sym_type,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [12968] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(868), 1,
      anon_sym_elif,
    STATE(253), 1,
      aux_sym_if_statement_repeat1,
    STATE(349), 1,
      sym_elif_clause,
    ACTIONS(855), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(853), 31,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [13028] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(748), 1,
      sym_expression,
    STATE(997), 1,
      sym_expression_list,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [13114] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      sym_identifier,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(477), 1,
      anon_sym_not,
    ACTIONS(481), 1,
      anon_sym_lambda,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(489), 1,
      anon_sym_await,
    ACTIONS(491), 1,
      sym__string_start,
    ACTIONS(871), 1,
      anon_sym_COLON,
    STATE(504), 1,
      sym_primary_expression,
    STATE(506), 1,
      sym_string,
    STATE(807), 1,
      sym_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(487), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(763), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [13200] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(801), 1,
      sym_expression,
    STATE(938), 1,
      sym_type,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [13286] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      sym_identifier,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(477), 1,
      anon_sym_not,
    ACTIONS(481), 1,
      anon_sym_lambda,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(489), 1,
      anon_sym_await,
    ACTIONS(491), 1,
      sym__string_start,
    ACTIONS(873), 1,
      anon_sym_COLON,
    STATE(504), 1,
      sym_primary_expression,
    STATE(506), 1,
      sym_string,
    STATE(787), 1,
      sym_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(487), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(763), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [13372] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(864), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [13426] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(789), 1,
      sym_expression,
    STATE(1043), 1,
      sym_expression_list,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [13512] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(851), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(849), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [13566] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [13649] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(872), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [13732] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(727), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [13815] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(758), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [13898] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(697), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [13981] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(865), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [14064] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(864), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [14147] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(693), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [14230] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(875), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(877), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [14283] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(862), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [14366] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(866), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [14449] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(694), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [14532] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(881), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(879), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [14585] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(726), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [14668] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(759), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [14751] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(676), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [14834] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(843), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [14917] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(734), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [15000] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(684), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [15083] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(802), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [15166] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(698), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [15249] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(842), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [15332] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(838), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [15415] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(788), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [15498] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(883), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(885), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [15551] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      sym_identifier,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(477), 1,
      anon_sym_not,
    ACTIONS(481), 1,
      anon_sym_lambda,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(489), 1,
      anon_sym_await,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(504), 1,
      sym_primary_expression,
    STATE(506), 1,
      sym_string,
    STATE(756), 1,
      sym_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(487), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(763), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [15634] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      sym_identifier,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(477), 1,
      anon_sym_not,
    ACTIONS(481), 1,
      anon_sym_lambda,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(489), 1,
      anon_sym_await,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(504), 1,
      sym_primary_expression,
    STATE(506), 1,
      sym_string,
    STATE(772), 1,
      sym_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(487), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(763), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [15717] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(849), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [15800] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      sym_identifier,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(477), 1,
      anon_sym_not,
    ACTIONS(481), 1,
      anon_sym_lambda,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(489), 1,
      anon_sym_await,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(504), 1,
      sym_primary_expression,
    STATE(506), 1,
      sym_string,
    STATE(750), 1,
      sym_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(487), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(763), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [15883] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(887), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(889), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [15936] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      sym_identifier,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(477), 1,
      anon_sym_not,
    ACTIONS(481), 1,
      anon_sym_lambda,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(489), 1,
      anon_sym_await,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(504), 1,
      sym_primary_expression,
    STATE(506), 1,
      sym_string,
    STATE(778), 1,
      sym_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(487), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(763), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [16019] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(851), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [16102] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(751), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [16185] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(753), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [16268] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(689), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [16351] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(729), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [16434] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(776), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [16517] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(891), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(893), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [16570] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(688), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [16653] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      sym_identifier,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(477), 1,
      anon_sym_not,
    ACTIONS(481), 1,
      anon_sym_lambda,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(489), 1,
      anon_sym_await,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(504), 1,
      sym_primary_expression,
    STATE(506), 1,
      sym_string,
    STATE(747), 1,
      sym_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(487), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(763), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [16736] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(676), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [16819] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      sym_identifier,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(477), 1,
      anon_sym_not,
    ACTIONS(481), 1,
      anon_sym_lambda,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(489), 1,
      anon_sym_await,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(504), 1,
      sym_primary_expression,
    STATE(506), 1,
      sym_string,
    STATE(768), 1,
      sym_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(487), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(763), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [16902] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(685), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [16985] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(690), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [17068] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(897), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [17121] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(867), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [17204] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(738), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [17287] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(891), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(893), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [17340] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(899), 1,
      sym_identifier,
    ACTIONS(903), 1,
      anon_sym_await,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(744), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(648), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(901), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [17425] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(785), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [17508] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(881), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(879), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [17561] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(737), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [17644] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(897), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [17697] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(836), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [17780] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(823), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [17863] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(887), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(889), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [17916] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(883), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(885), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [17969] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(752), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [18052] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(863), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [18135] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(743), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [18218] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(805), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [18301] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(875), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(877), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [18354] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      sym_identifier,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(477), 1,
      anon_sym_not,
    ACTIONS(481), 1,
      anon_sym_lambda,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(489), 1,
      anon_sym_await,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(504), 1,
      sym_primary_expression,
    STATE(506), 1,
      sym_string,
    STATE(779), 1,
      sym_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(487), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(763), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [18437] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(682), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [18520] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(828), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [18603] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(848), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [18686] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(728), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [18769] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(816), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [18852] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(832), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [18935] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(724), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [19018] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(744), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [19101] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_not,
    ACTIONS(63), 1,
      anon_sym_lambda,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(238), 1,
      sym_identifier,
    ACTIONS(255), 1,
      anon_sym_await,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(500), 1,
      sym_primary_expression,
    STATE(813), 1,
      sym_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(71), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(725), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [19184] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(453), 1,
      sym_identifier,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(461), 1,
      anon_sym_not,
    ACTIONS(465), 1,
      anon_sym_lambda,
    ACTIONS(467), 1,
      anon_sym_await,
    STATE(361), 1,
      sym_string,
    STATE(447), 1,
      sym_primary_expression,
    STATE(687), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(457), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [19267] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      sym_identifier,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_not,
    ACTIONS(441), 1,
      anon_sym_lambda,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      anon_sym_await,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(448), 1,
      sym_primary_expression,
    STATE(790), 1,
      sym_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(433), 3,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(675), 7,
      sym_named_expression,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
      sym_await,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [19350] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(905), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(907), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [19402] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      anon_sym_else,
    STATE(392), 1,
      sym_else_clause,
    ACTIONS(911), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(909), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [19458] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      anon_sym_else,
    STATE(425), 1,
      sym_else_clause,
    ACTIONS(915), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(913), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [19514] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(905), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(907), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [19566] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(696), 1,
      anon_sym_else,
    STATE(432), 1,
      sym_else_clause,
    ACTIONS(917), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(919), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [19622] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(921), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(923), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [19674] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(692), 1,
      anon_sym_finally,
    STATE(396), 1,
      sym_finally_clause,
    ACTIONS(927), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(925), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [19730] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      anon_sym_else,
    STATE(429), 1,
      sym_else_clause,
    ACTIONS(931), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(929), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [19786] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(696), 1,
      anon_sym_else,
    STATE(383), 1,
      sym_else_clause,
    ACTIONS(911), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(909), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [19842] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(692), 1,
      anon_sym_finally,
    STATE(374), 1,
      sym_finally_clause,
    ACTIONS(935), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(933), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [19898] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(696), 1,
      anon_sym_else,
    STATE(436), 1,
      sym_else_clause,
    ACTIONS(931), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(929), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [19954] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      anon_sym_else,
    STATE(377), 1,
      sym_else_clause,
    ACTIONS(917), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(919), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20010] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(696), 1,
      anon_sym_else,
    STATE(385), 1,
      sym_else_clause,
    ACTIONS(915), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(913), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20066] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(700), 1,
      anon_sym_finally,
    STATE(417), 1,
      sym_finally_clause,
    ACTIONS(935), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(933), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20122] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(937), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(939), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20174] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(696), 1,
      anon_sym_else,
    STATE(394), 1,
      sym_else_clause,
    ACTIONS(941), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(943), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20230] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      anon_sym_else,
    STATE(422), 1,
      sym_else_clause,
    ACTIONS(947), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(945), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20286] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(700), 1,
      anon_sym_finally,
    STATE(435), 1,
      sym_finally_clause,
    ACTIONS(927), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(925), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20342] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(937), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(939), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20394] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(696), 1,
      anon_sym_else,
    STATE(366), 1,
      sym_else_clause,
    ACTIONS(947), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(945), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20450] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      anon_sym_else,
    STATE(402), 1,
      sym_else_clause,
    ACTIONS(941), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(943), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20506] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(921), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(923), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20558] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(951), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(949), 31,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20609] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(953), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(955), 31,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20660] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(953), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(955), 31,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20711] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(363), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(959), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(957), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [20766] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(360), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(763), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [20821] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(951), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(949), 31,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20872] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(965), 1,
      sym__string_start,
    STATE(363), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(963), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(961), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [20927] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(970), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(968), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [20977] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(974), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(972), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21027] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(976), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(978), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21077] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(686), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(684), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21127] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(982), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(980), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21177] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(986), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(984), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21227] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(927), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(925), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21277] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(988), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(990), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21327] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(992), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(994), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21377] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(996), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(998), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21427] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1002), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1000), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21477] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1004), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1006), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21527] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1010), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21577] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1014), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1012), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21627] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1010), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21677] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1018), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1016), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21727] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1020), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1022), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21777] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(996), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(998), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21827] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1026), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1024), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21877] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1028), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1030), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21927] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1032), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [21977] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1036), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1038), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22027] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(974), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(972), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22077] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1032), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22127] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1026), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1024), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22177] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1004), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1006), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22227] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1040), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1042), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22277] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(988), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(990), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22327] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1028), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1030), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22377] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(686), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(684), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22427] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1044), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1046), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22477] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1050), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1048), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22527] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1052), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22577] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1058), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1056), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22627] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1058), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1056), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22677] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1060), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1062), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22727] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1066), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1064), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22777] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1068), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1070), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22827] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1044), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1046), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22877] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(982), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(980), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22927] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1018), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1016), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [22977] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(522), 1,
      sym_identifier,
    ACTIONS(524), 1,
      anon_sym_LPAREN,
    ACTIONS(534), 1,
      anon_sym_LBRACK,
    ACTIONS(1072), 1,
      anon_sym_RPAREN,
    STATE(361), 1,
      sym_string,
    STATE(666), 1,
      sym_primary_expression,
    STATE(846), 1,
      sym_pattern,
    STATE(1034), 1,
      sym__patterns,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(565), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(528), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [23059] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1076), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1074), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23109] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1078), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1080), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23159] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(986), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(984), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23209] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1040), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1042), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23259] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1082), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1084), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23309] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(927), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(925), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23359] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1060), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1062), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23409] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1068), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1070), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23459] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1078), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1080), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23509] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1082), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1084), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23559] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1088), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1086), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23609] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1002), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1000), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23659] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(702), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(704), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23709] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(970), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(968), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23759] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(702), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(704), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23809] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(522), 1,
      sym_identifier,
    ACTIONS(524), 1,
      anon_sym_LPAREN,
    ACTIONS(534), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(657), 1,
      sym_pattern,
    STATE(666), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1090), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    STATE(565), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(528), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [23889] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(976), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(978), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23939] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1020), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1022), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [23989] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(933), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [24039] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1036), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1038), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [24089] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1076), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1074), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [24139] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(522), 1,
      sym_identifier,
    ACTIONS(524), 1,
      anon_sym_LPAREN,
    ACTIONS(534), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(657), 1,
      sym_pattern,
    STATE(666), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1092), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    STATE(565), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(528), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [24219] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(933), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [24269] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1096), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1094), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [24319] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1066), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1064), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [24369] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1088), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1086), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [24419] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1014), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1012), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [24469] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1050), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1048), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [24519] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(992), 12,
      sym__dedent,
      sym__string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(994), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [24569] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1052), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [24619] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1096), 12,
      sym__string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      sym_ellipsis,
      anon_sym_LBRACE,
      sym_float,
    ACTIONS(1094), 30,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [24669] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(522), 1,
      sym_identifier,
    ACTIONS(524), 1,
      anon_sym_LPAREN,
    ACTIONS(534), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(666), 1,
      sym_primary_expression,
    STATE(891), 1,
      sym_pattern,
    STATE(1106), 1,
      sym_pattern_list,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(565), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(528), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [24748] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1100), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1098), 35,
      sym__string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [24797] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(522), 1,
      sym_identifier,
    ACTIONS(524), 1,
      anon_sym_LPAREN,
    ACTIONS(534), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(666), 1,
      sym_primary_expression,
    STATE(893), 1,
      sym_pattern,
    STATE(1102), 1,
      sym_pattern_list,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(565), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(528), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [24876] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(522), 1,
      sym_identifier,
    ACTIONS(524), 1,
      anon_sym_LPAREN,
    ACTIONS(534), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(666), 1,
      sym_primary_expression,
    STATE(969), 1,
      sym_pattern,
    STATE(1076), 1,
      sym_pattern_list,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(565), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(528), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [24955] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(522), 1,
      sym_identifier,
    ACTIONS(524), 1,
      anon_sym_LPAREN,
    ACTIONS(534), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(666), 1,
      sym_primary_expression,
    STATE(961), 1,
      sym_pattern,
    STATE(1091), 1,
      sym_pattern_list,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(565), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(528), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [25034] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1104), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1102), 35,
      sym__string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [25083] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(522), 1,
      sym_identifier,
    ACTIONS(524), 1,
      anon_sym_LPAREN,
    ACTIONS(534), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(666), 1,
      sym_primary_expression,
    STATE(923), 1,
      sym_pattern,
    STATE(1036), 1,
      sym_pattern_list,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(565), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(528), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [25162] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(522), 1,
      sym_identifier,
    ACTIONS(524), 1,
      anon_sym_LPAREN,
    ACTIONS(534), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(666), 1,
      sym_primary_expression,
    STATE(892), 1,
      sym_pattern,
    STATE(1105), 1,
      sym_pattern_list,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(565), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(528), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [25241] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1108), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1106), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [25289] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1112), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1110), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [25337] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1120), 1,
      anon_sym_as,
    ACTIONS(1128), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1134), 1,
      anon_sym_not,
    ACTIONS(1138), 1,
      anon_sym_PIPE,
    ACTIONS(1140), 1,
      anon_sym_AMP,
    ACTIONS(1142), 1,
      anon_sym_CARET,
    ACTIONS(1146), 1,
      anon_sym_is,
    STATE(649), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(1122), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1124), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1136), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1144), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1130), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1126), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(1118), 10,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
      anon_sym_RBRACE,
  [25419] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1120), 1,
      anon_sym_EQ,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1154), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1158), 1,
      anon_sym_not,
    ACTIONS(1162), 1,
      anon_sym_PIPE,
    ACTIONS(1164), 1,
      anon_sym_AMP,
    ACTIONS(1166), 1,
      anon_sym_CARET,
    ACTIONS(1170), 1,
      anon_sym_is,
    STATE(651), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(1148), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1150), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1160), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1168), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1156), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1152), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(1118), 10,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
      anon_sym_RBRACE,
      sym_type_conversion,
  [25501] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1174), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1172), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [25549] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1178), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1176), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [25597] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1182), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1180), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [25645] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1186), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1184), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [25693] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1190), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1188), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [25741] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(763), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [25789] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1194), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1192), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [25837] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1198), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1196), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [25885] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1202), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1200), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [25933] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1206), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1204), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [25981] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1210), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1208), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [26029] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1214), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1212), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [26077] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1218), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1216), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [26125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1222), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1220), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [26173] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(522), 1,
      sym_identifier,
    ACTIONS(524), 1,
      anon_sym_LPAREN,
    ACTIONS(534), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(666), 1,
      sym_primary_expression,
    STATE(962), 1,
      sym_pattern,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(565), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(528), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [26249] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(522), 1,
      sym_identifier,
    ACTIONS(524), 1,
      anon_sym_LPAREN,
    ACTIONS(534), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(657), 1,
      sym_pattern,
    STATE(666), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(565), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(662), 3,
      sym_tuple_pattern,
      sym_list_pattern,
      sym_list_splat_pattern,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(528), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [26325] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1226), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1224), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [26373] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1230), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1228), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [26421] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1234), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1232), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [26469] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1238), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1236), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [26517] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1242), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1240), 34,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [26565] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1246), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 28,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
  [26622] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1142), 1,
      anon_sym_CARET,
    ACTIONS(1122), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1124), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1136), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1130), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1246), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 20,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
  [26689] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1140), 1,
      anon_sym_AMP,
    ACTIONS(1142), 1,
      anon_sym_CARET,
    ACTIONS(1122), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1124), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1136), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1130), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1246), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 19,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
  [26758] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1122), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1136), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1130), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1246), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 23,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
  [26821] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1122), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1124), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1136), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1130), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1246), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 21,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
  [26886] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1154), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1148), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1150), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1160), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1156), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1246), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 21,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [26951] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1154), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1162), 1,
      anon_sym_PIPE,
    ACTIONS(1164), 1,
      anon_sym_AMP,
    ACTIONS(1166), 1,
      anon_sym_CARET,
    ACTIONS(1148), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1150), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1160), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1156), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1250), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1248), 18,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [27022] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1154), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1166), 1,
      anon_sym_CARET,
    ACTIONS(1148), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1150), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1160), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1156), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1246), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 20,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [27089] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1154), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1164), 1,
      anon_sym_AMP,
    ACTIONS(1166), 1,
      anon_sym_CARET,
    ACTIONS(1148), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1150), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1160), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1156), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1246), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 19,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [27158] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1154), 1,
      anon_sym_STAR_STAR,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1254), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1252), 28,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [27215] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1154), 1,
      anon_sym_STAR_STAR,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1246), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 28,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [27272] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1122), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1130), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1246), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 25,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
  [27333] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1138), 1,
      anon_sym_PIPE,
    ACTIONS(1140), 1,
      anon_sym_AMP,
    ACTIONS(1142), 1,
      anon_sym_CARET,
    ACTIONS(1122), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1124), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1136), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1130), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1250), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1248), 18,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
  [27404] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1154), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1148), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1156), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1246), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 25,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [27465] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1154), 1,
      anon_sym_STAR_STAR,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1246), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 28,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [27522] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1154), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1148), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1160), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1156), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1246), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 23,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [27585] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1138), 1,
      anon_sym_PIPE,
    ACTIONS(1140), 1,
      anon_sym_AMP,
    ACTIONS(1142), 1,
      anon_sym_CARET,
    ACTIONS(1122), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1124), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1136), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1130), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1258), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1256), 18,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
  [27656] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1246), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 28,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
  [27713] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1154), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1162), 1,
      anon_sym_PIPE,
    ACTIONS(1164), 1,
      anon_sym_AMP,
    ACTIONS(1166), 1,
      anon_sym_CARET,
    ACTIONS(1148), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1150), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1160), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1156), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1258), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1256), 18,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [27784] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1254), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1252), 28,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
  [27841] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1260), 1,
      anon_sym_COLON_EQ,
    ACTIONS(763), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 31,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
  [27889] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(824), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(819), 33,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [27935] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(813), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(808), 33,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [27981] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(1262), 1,
      sym_identifier,
    STATE(361), 1,
      sym_string,
    STATE(666), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(573), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(1264), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1266), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [28051] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(242), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(240), 33,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [28097] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1268), 1,
      anon_sym_COLON_EQ,
    ACTIONS(763), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 31,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
      sym_type_conversion,
  [28145] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(242), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(240), 32,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
  [28190] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(824), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(819), 32,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
  [28235] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(75), 1,
      sym__string_start,
    STATE(502), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(763), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [28284] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(813), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(808), 32,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_RBRACE,
  [28329] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1120), 1,
      anon_sym_EQ,
    ACTIONS(1270), 1,
      anon_sym_DOT,
    ACTIONS(1272), 1,
      anon_sym_LPAREN,
    ACTIONS(1280), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACK,
    ACTIONS(1286), 1,
      anon_sym_not,
    ACTIONS(1290), 1,
      anon_sym_PIPE,
    ACTIONS(1292), 1,
      anon_sym_AMP,
    ACTIONS(1294), 1,
      anon_sym_CARET,
    ACTIONS(1298), 1,
      anon_sym_is,
    STATE(659), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(1274), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1276), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1288), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1296), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(595), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1282), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1278), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(1118), 7,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_and,
      anon_sym_or,
  [28408] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1300), 1,
      sym__string_start,
    STATE(501), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(963), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(961), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [28457] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(75), 1,
      sym__string_start,
    STATE(501), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(959), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(957), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [28506] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 1,
      anon_sym_DOT,
    ACTIONS(1272), 1,
      anon_sym_LPAREN,
    ACTIONS(1280), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACK,
    ACTIONS(1290), 1,
      anon_sym_PIPE,
    ACTIONS(1292), 1,
      anon_sym_AMP,
    ACTIONS(1294), 1,
      anon_sym_CARET,
    ACTIONS(1274), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1276), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1288), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(595), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1258), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1282), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1256), 15,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [28574] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1303), 1,
      anon_sym_DOT,
    ACTIONS(1305), 1,
      anon_sym_LPAREN,
    ACTIONS(1313), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1317), 1,
      anon_sym_LBRACK,
    ACTIONS(1319), 1,
      anon_sym_not,
    ACTIONS(1323), 1,
      anon_sym_PIPE,
    ACTIONS(1325), 1,
      anon_sym_AMP,
    ACTIONS(1327), 1,
      anon_sym_CARET,
    ACTIONS(1331), 1,
      anon_sym_is,
    STATE(663), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(1307), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1309), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1321), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1329), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(627), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1315), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1311), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(1118), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
  [28650] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 1,
      anon_sym_DOT,
    ACTIONS(1272), 1,
      anon_sym_LPAREN,
    ACTIONS(1280), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACK,
    STATE(595), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1246), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 25,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [28704] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(517), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(763), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [28752] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(1333), 1,
      anon_sym_not,
    STATE(361), 1,
      sym_string,
    STATE(488), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [28816] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 1,
      anon_sym_DOT,
    ACTIONS(1272), 1,
      anon_sym_LPAREN,
    ACTIONS(1280), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACK,
    ACTIONS(1290), 1,
      anon_sym_PIPE,
    ACTIONS(1292), 1,
      anon_sym_AMP,
    ACTIONS(1294), 1,
      anon_sym_CARET,
    ACTIONS(1274), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1276), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1288), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(595), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1250), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1282), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1248), 15,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [28884] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 1,
      anon_sym_DOT,
    ACTIONS(1272), 1,
      anon_sym_LPAREN,
    ACTIONS(1280), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACK,
    STATE(595), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1254), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1252), 25,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [28938] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 1,
      anon_sym_DOT,
    ACTIONS(1272), 1,
      anon_sym_LPAREN,
    ACTIONS(1280), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACK,
    ACTIONS(1274), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1288), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(595), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1246), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1282), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1244), 20,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [28998] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 1,
      anon_sym_DOT,
    ACTIONS(1272), 1,
      anon_sym_LPAREN,
    ACTIONS(1280), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACK,
    STATE(595), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1246), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 25,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [29052] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    ACTIONS(1335), 1,
      anon_sym_not,
    STATE(361), 1,
      sym_string,
    STATE(486), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(457), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [29116] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 1,
      anon_sym_DOT,
    ACTIONS(1272), 1,
      anon_sym_LPAREN,
    ACTIONS(1280), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACK,
    ACTIONS(1274), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1276), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1288), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(595), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1246), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1282), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1244), 18,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [29178] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 1,
      anon_sym_DOT,
    ACTIONS(1272), 1,
      anon_sym_LPAREN,
    ACTIONS(1280), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACK,
    ACTIONS(1294), 1,
      anon_sym_CARET,
    ACTIONS(1274), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1276), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1288), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(595), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1246), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1282), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1244), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [29242] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 1,
      anon_sym_DOT,
    ACTIONS(1272), 1,
      anon_sym_LPAREN,
    ACTIONS(1280), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACK,
    ACTIONS(1292), 1,
      anon_sym_AMP,
    ACTIONS(1294), 1,
      anon_sym_CARET,
    ACTIONS(1274), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1276), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1288), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(595), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1246), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1282), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1244), 16,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [29308] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 1,
      anon_sym_DOT,
    ACTIONS(1272), 1,
      anon_sym_LPAREN,
    ACTIONS(1280), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACK,
    ACTIONS(1274), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    STATE(595), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1246), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1282), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1244), 22,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [29366] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(518), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(959), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(957), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [29414] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1337), 1,
      sym__string_start,
    STATE(518), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(963), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(961), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [29462] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    ACTIONS(1340), 1,
      anon_sym_not,
    STATE(498), 1,
      sym_string,
    STATE(503), 1,
      sym_primary_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(71), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [29526] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(491), 1,
      sym__string_start,
    ACTIONS(1342), 1,
      anon_sym_not,
    STATE(506), 1,
      sym_string,
    STATE(556), 1,
      sym_primary_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(487), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [29590] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(506), 1,
      sym_string,
    STATE(563), 1,
      sym_primary_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(487), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [29651] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(765), 1,
      anon_sym_COLON_EQ,
    ACTIONS(763), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [29696] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(813), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(815), 19,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [29741] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(819), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(824), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(826), 19,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [29786] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1303), 1,
      anon_sym_DOT,
    ACTIONS(1305), 1,
      anon_sym_LPAREN,
    ACTIONS(1313), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1317), 1,
      anon_sym_LBRACK,
    STATE(627), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1254), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1252), 25,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [29839] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(508), 1,
      sym_primary_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(71), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [29900] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(484), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [29961] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(485), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30022] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(661), 1,
      sym_primary_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(71), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30083] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(474), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(457), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30144] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(488), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30205] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(480), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30266] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(483), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30327] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1260), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1344), 1,
      anon_sym_EQ,
    ACTIONS(763), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [30374] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(471), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(457), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30435] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(478), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30496] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(472), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(457), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30557] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(477), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30618] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(475), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30679] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(481), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(457), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30740] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(511), 1,
      sym_primary_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(71), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30801] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(476), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30862] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(487), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(457), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30923] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(486), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(457), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [30984] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(473), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(457), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [31045] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(506), 1,
      sym_string,
    STATE(554), 1,
      sym_primary_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(487), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [31106] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(506), 1,
      sym_string,
    STATE(555), 1,
      sym_primary_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(487), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [31167] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(506), 1,
      sym_string,
    STATE(556), 1,
      sym_primary_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(487), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [31228] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(506), 1,
      sym_string,
    STATE(557), 1,
      sym_primary_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(487), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [31289] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(506), 1,
      sym_string,
    STATE(559), 1,
      sym_primary_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(487), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [31350] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(506), 1,
      sym_string,
    STATE(561), 1,
      sym_primary_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(487), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [31411] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(506), 1,
      sym_string,
    STATE(562), 1,
      sym_primary_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(487), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [31472] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(470), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(457), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [31533] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1303), 1,
      anon_sym_DOT,
    ACTIONS(1305), 1,
      anon_sym_LPAREN,
    ACTIONS(1313), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1317), 1,
      anon_sym_LBRACK,
    STATE(627), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1246), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 25,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [31586] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1303), 1,
      anon_sym_DOT,
    ACTIONS(1305), 1,
      anon_sym_LPAREN,
    ACTIONS(1313), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1317), 1,
      anon_sym_LBRACK,
    ACTIONS(1246), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1307), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1321), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(627), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1315), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1244), 20,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [31645] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1303), 1,
      anon_sym_DOT,
    ACTIONS(1305), 1,
      anon_sym_LPAREN,
    ACTIONS(1313), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1317), 1,
      anon_sym_LBRACK,
    ACTIONS(1323), 1,
      anon_sym_PIPE,
    ACTIONS(1325), 1,
      anon_sym_AMP,
    ACTIONS(1327), 1,
      anon_sym_CARET,
    ACTIONS(1258), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1307), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1309), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1321), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(627), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1315), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1256), 15,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [31712] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1303), 1,
      anon_sym_DOT,
    ACTIONS(1305), 1,
      anon_sym_LPAREN,
    ACTIONS(1313), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1317), 1,
      anon_sym_LBRACK,
    STATE(627), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1246), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1244), 25,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [31765] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(506), 1,
      sym_string,
    STATE(567), 1,
      sym_primary_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(487), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [31826] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1303), 1,
      anon_sym_DOT,
    ACTIONS(1305), 1,
      anon_sym_LPAREN,
    ACTIONS(1313), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1317), 1,
      anon_sym_LBRACK,
    ACTIONS(1246), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1307), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    STATE(627), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1315), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1244), 22,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [31883] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(509), 1,
      sym_primary_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(71), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [31944] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1303), 1,
      anon_sym_DOT,
    ACTIONS(1305), 1,
      anon_sym_LPAREN,
    ACTIONS(1313), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1317), 1,
      anon_sym_LBRACK,
    ACTIONS(1325), 1,
      anon_sym_AMP,
    ACTIONS(1327), 1,
      anon_sym_CARET,
    ACTIONS(1246), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1307), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1309), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1321), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(627), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1315), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1244), 16,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [32009] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1303), 1,
      anon_sym_DOT,
    ACTIONS(1305), 1,
      anon_sym_LPAREN,
    ACTIONS(1313), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1317), 1,
      anon_sym_LBRACK,
    ACTIONS(1327), 1,
      anon_sym_CARET,
    ACTIONS(1246), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1307), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1309), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1321), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(627), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1315), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1244), 17,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [32072] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1303), 1,
      anon_sym_DOT,
    ACTIONS(1305), 1,
      anon_sym_LPAREN,
    ACTIONS(1313), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1317), 1,
      anon_sym_LBRACK,
    ACTIONS(1246), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1307), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1309), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1321), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(627), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1315), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1244), 18,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [32133] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1104), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1102), 30,
      sym__newline,
      sym__string_start,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [32176] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(758), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(763), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(769), 19,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [32221] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 1,
      anon_sym_LPAREN,
    ACTIONS(475), 1,
      anon_sym_LBRACK,
    ACTIONS(485), 1,
      anon_sym_LBRACE,
    ACTIONS(491), 1,
      sym__string_start,
    STATE(506), 1,
      sym_string,
    STATE(525), 1,
      sym_primary_expression,
    ACTIONS(483), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(479), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(487), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(639), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [32282] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1303), 1,
      anon_sym_DOT,
    ACTIONS(1305), 1,
      anon_sym_LPAREN,
    ACTIONS(1313), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1317), 1,
      anon_sym_LBRACK,
    ACTIONS(1323), 1,
      anon_sym_PIPE,
    ACTIONS(1325), 1,
      anon_sym_AMP,
    ACTIONS(1327), 1,
      anon_sym_CARET,
    ACTIONS(1250), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1307), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1309), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1321), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(627), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1315), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(1248), 15,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [32349] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(240), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(242), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1346), 19,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [32394] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(489), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(457), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [32455] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1100), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1098), 30,
      sym__newline,
      sym__string_start,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [32498] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(455), 1,
      anon_sym_LPAREN,
    ACTIONS(459), 1,
      anon_sym_LBRACK,
    STATE(361), 1,
      sym_string,
    STATE(482), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(463), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(457), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [32559] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(240), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(242), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(251), 19,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [32604] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(758), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(763), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1348), 19,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [32649] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    STATE(361), 1,
      sym_string,
    STATE(479), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(433), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(447), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(454), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [32710] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(513), 1,
      sym_primary_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(71), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [32771] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(514), 1,
      sym_primary_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(71), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [32832] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(515), 1,
      sym_primary_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(71), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [32893] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(516), 1,
      sym_primary_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(71), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [32954] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(505), 1,
      sym_primary_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(71), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [33015] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(503), 1,
      sym_primary_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(71), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [33076] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      sym__string_start,
    ACTIONS(257), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_LBRACK,
    STATE(498), 1,
      sym_string,
    STATE(510), 1,
      sym_primary_expression,
    ACTIONS(67), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(61), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(247), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    ACTIONS(71), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(605), 15,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [33137] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(1262), 1,
      sym_identifier,
    STATE(361), 1,
      sym_string,
    STATE(666), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(573), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1266), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [33202] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(435), 1,
      anon_sym_LBRACK,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(451), 1,
      sym__string_start,
    ACTIONS(1350), 1,
      sym_identifier,
    STATE(361), 1,
      sym_string,
    STATE(666), 1,
      sym_primary_expression,
    ACTIONS(443), 2,
      sym_ellipsis,
      sym_float,
    STATE(655), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(439), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1352), 4,
      anon_sym_print,
      anon_sym_async,
      anon_sym_exec,
      anon_sym_await,
    STATE(454), 13,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
  [33267] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1260), 1,
      anon_sym_COLON_EQ,
    ACTIONS(760), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(763), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1214), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1212), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33356] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1104), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1102), 30,
      sym__string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33398] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1238), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1236), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33440] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(760), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(763), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33484] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1354), 1,
      anon_sym_COLON_EQ,
    ACTIONS(763), 5,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33528] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1198), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1196), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33570] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(244), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(242), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(240), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33614] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(242), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(240), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33656] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(813), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(808), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33698] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(810), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(813), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(808), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33742] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1202), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1200), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33784] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1234), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1232), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1230), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1228), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33868] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1190), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1188), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33910] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1206), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1204), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33952] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1242), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1240), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [33994] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(821), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(824), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(819), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34038] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1182), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1180), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34080] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1222), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1220), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34122] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1174), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1172), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34164] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(763), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34206] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(824), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(819), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34248] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1108), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1106), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34290] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1194), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1192), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34332] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1218), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1216), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34374] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1112), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1110), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34416] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1100), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1098), 30,
      sym__string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34458] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1226), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1224), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34500] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(469), 1,
      anon_sym_EQ,
    ACTIONS(242), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(240), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34544] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1186), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1184), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34586] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1178), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1176), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34628] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1210), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1208), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34670] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1234), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1232), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34711] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1108), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1106), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34752] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1198), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1196), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34793] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(578), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(576), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34834] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1222), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1220), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34875] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1214), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1212), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34916] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1190), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1188), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [34957] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1268), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1356), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(763), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 25,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35002] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(562), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(560), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35043] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1268), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1344), 1,
      anon_sym_EQ,
    ACTIONS(763), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35088] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1202), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1200), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35129] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1206), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1204), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35170] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1226), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1224), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35211] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(608), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(606), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35252] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(578), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(576), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35293] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1242), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1240), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35334] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1210), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1208), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35375] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(574), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(572), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35416] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1186), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1184), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35457] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1174), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1172), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35498] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(574), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(572), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35539] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1178), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1176), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35580] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(763), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35621] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1238), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1236), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35662] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1194), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1192), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35703] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1230), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1228), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35744] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1182), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1180), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35785] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1112), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1110), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(604), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(602), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35867] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1218), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1216), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35908] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(493), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(242), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(240), 25,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35950] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1356), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(763), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 25,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [35992] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1134), 1,
      anon_sym_not,
    ACTIONS(1146), 1,
      anon_sym_is,
    ACTIONS(1361), 1,
      anon_sym_as,
    STATE(652), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(1144), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1126), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(1359), 10,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
      anon_sym_RBRACE,
  [36032] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1368), 1,
      anon_sym_EQ,
    ACTIONS(1370), 1,
      anon_sym_not,
    ACTIONS(1376), 1,
      anon_sym_is,
    STATE(650), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(1373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1365), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(1363), 10,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
      anon_sym_RBRACE,
      sym_type_conversion,
  [36072] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1158), 1,
      anon_sym_not,
    ACTIONS(1170), 1,
      anon_sym_is,
    ACTIONS(1361), 1,
      anon_sym_EQ,
    STATE(650), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(1168), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1152), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(1359), 10,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
      anon_sym_RBRACE,
      sym_type_conversion,
  [36112] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1368), 1,
      anon_sym_as,
    ACTIONS(1382), 1,
      anon_sym_not,
    ACTIONS(1388), 1,
      anon_sym_is,
    STATE(652), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(1385), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1379), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(1363), 10,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
      anon_sym_RBRACE,
  [36152] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 1,
      anon_sym_COMMA,
    STATE(653), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(1391), 18,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [36182] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1368), 1,
      anon_sym_EQ,
    ACTIONS(1399), 1,
      anon_sym_not,
    ACTIONS(1405), 1,
      anon_sym_is,
    STATE(654), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(1402), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1396), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(1363), 7,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_and,
      anon_sym_or,
  [36219] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(763), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1408), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(758), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [36248] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1410), 19,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [36273] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1391), 19,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [36298] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(242), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1412), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(240), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [36327] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 1,
      anon_sym_not,
    ACTIONS(1298), 1,
      anon_sym_is,
    ACTIONS(1361), 1,
      anon_sym_EQ,
    STATE(654), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(1296), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1278), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(1359), 7,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_and,
      anon_sym_or,
  [36364] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1414), 19,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [36389] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 1,
      anon_sym_DOT,
    ACTIONS(1272), 1,
      anon_sym_LPAREN,
    ACTIONS(1280), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACK,
    ACTIONS(1290), 1,
      anon_sym_PIPE,
    ACTIONS(1292), 1,
      anon_sym_AMP,
    ACTIONS(1294), 1,
      anon_sym_CARET,
    ACTIONS(1416), 1,
      sym__newline,
    ACTIONS(1274), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1276), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1288), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(595), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1282), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
  [36438] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(769), 19,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [36463] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1319), 1,
      anon_sym_not,
    ACTIONS(1331), 1,
      anon_sym_is,
    STATE(664), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(1329), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1311), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(1359), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
  [36497] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1421), 1,
      anon_sym_not,
    ACTIONS(1427), 1,
      anon_sym_is,
    STATE(664), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(1424), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1418), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(1363), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
  [36531] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1430), 1,
      anon_sym_COMMA,
    STATE(653), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(530), 16,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [36559] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_DOT,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_LBRACK,
    ACTIONS(1154), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1162), 1,
      anon_sym_PIPE,
    ACTIONS(1164), 1,
      anon_sym_AMP,
    ACTIONS(1166), 1,
      anon_sym_CARET,
    ACTIONS(1148), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1150), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1160), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(457), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(1156), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
  [36605] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1432), 1,
      anon_sym_COMMA,
    ACTIONS(1434), 1,
      anon_sym_COLON,
    ACTIONS(1436), 1,
      anon_sym_EQ,
    STATE(665), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(1438), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [36636] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1434), 1,
      anon_sym_COLON,
    ACTIONS(1436), 1,
      anon_sym_EQ,
    ACTIONS(1438), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [36661] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1440), 1,
      sym_identifier,
    ACTIONS(1442), 1,
      anon_sym_LPAREN,
    ACTIONS(1444), 1,
      anon_sym_STAR,
    ACTIONS(1446), 1,
      anon_sym_COLON,
    ACTIONS(1448), 1,
      anon_sym_STAR_STAR,
    STATE(968), 1,
      sym_parameter,
    STATE(1048), 1,
      sym_lambda_parameters,
    STATE(1101), 1,
      sym__parameters,
    STATE(979), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(967), 4,
      sym_tuple_pattern,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
  [36699] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1440), 1,
      sym_identifier,
    ACTIONS(1442), 1,
      anon_sym_LPAREN,
    ACTIONS(1444), 1,
      anon_sym_STAR,
    ACTIONS(1448), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1450), 1,
      anon_sym_COLON,
    STATE(968), 1,
      sym_parameter,
    STATE(1098), 1,
      sym_lambda_parameters,
    STATE(1101), 1,
      sym__parameters,
    STATE(979), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(967), 4,
      sym_tuple_pattern,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
  [36737] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1440), 1,
      sym_identifier,
    ACTIONS(1442), 1,
      anon_sym_LPAREN,
    ACTIONS(1444), 1,
      anon_sym_STAR,
    ACTIONS(1448), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1452), 1,
      anon_sym_COLON,
    STATE(968), 1,
      sym_parameter,
    STATE(1054), 1,
      sym_lambda_parameters,
    STATE(1101), 1,
      sym__parameters,
    STATE(979), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(967), 4,
      sym_tuple_pattern,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
  [36775] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1440), 1,
      sym_identifier,
    ACTIONS(1442), 1,
      anon_sym_LPAREN,
    ACTIONS(1444), 1,
      anon_sym_STAR,
    ACTIONS(1448), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1454), 1,
      anon_sym_COLON,
    STATE(968), 1,
      sym_parameter,
    STATE(1081), 1,
      sym_lambda_parameters,
    STATE(1101), 1,
      sym__parameters,
    STATE(979), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(967), 4,
      sym_tuple_pattern,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
  [36813] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1458), 1,
      anon_sym_as,
    ACTIONS(1456), 13,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_RBRACE,
      sym_type_conversion,
  [36835] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1440), 1,
      sym_identifier,
    ACTIONS(1442), 1,
      anon_sym_LPAREN,
    ACTIONS(1444), 1,
      anon_sym_STAR,
    ACTIONS(1448), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1460), 1,
      anon_sym_COLON,
    STATE(968), 1,
      sym_parameter,
    STATE(1080), 1,
      sym_lambda_parameters,
    STATE(1101), 1,
      sym__parameters,
    STATE(979), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(967), 4,
      sym_tuple_pattern,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
  [36873] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1120), 1,
      anon_sym_as,
    ACTIONS(1118), 13,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_RBRACE,
      sym_type_conversion,
  [36895] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1464), 1,
      anon_sym_as,
    ACTIONS(1462), 13,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_RBRACE,
      sym_type_conversion,
  [36917] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1442), 1,
      anon_sym_LPAREN,
    ACTIONS(1444), 1,
      anon_sym_STAR,
    ACTIONS(1448), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1466), 1,
      sym_identifier,
    ACTIONS(1468), 1,
      anon_sym_RPAREN,
    STATE(904), 1,
      sym_parameter,
    STATE(1068), 1,
      sym__parameters,
    STATE(889), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(967), 4,
      sym_tuple_pattern,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
  [36952] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1440), 1,
      sym_identifier,
    ACTIONS(1442), 1,
      anon_sym_LPAREN,
    ACTIONS(1444), 1,
      anon_sym_STAR,
    ACTIONS(1448), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1470), 1,
      anon_sym_COLON,
    STATE(963), 1,
      sym_parameter,
    STATE(979), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(967), 4,
      sym_tuple_pattern,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
  [36984] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1440), 1,
      sym_identifier,
    ACTIONS(1442), 1,
      anon_sym_LPAREN,
    ACTIONS(1444), 1,
      anon_sym_STAR,
    ACTIONS(1448), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1472), 1,
      anon_sym_COLON,
    STATE(963), 1,
      sym_parameter,
    STATE(979), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(967), 4,
      sym_tuple_pattern,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
  [37016] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1442), 1,
      anon_sym_LPAREN,
    ACTIONS(1444), 1,
      anon_sym_STAR,
    ACTIONS(1448), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1466), 1,
      sym_identifier,
    ACTIONS(1470), 1,
      anon_sym_RPAREN,
    STATE(963), 1,
      sym_parameter,
    STATE(889), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(967), 4,
      sym_tuple_pattern,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
  [37048] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1442), 1,
      anon_sym_LPAREN,
    ACTIONS(1444), 1,
      anon_sym_STAR,
    ACTIONS(1448), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1466), 1,
      sym_identifier,
    ACTIONS(1472), 1,
      anon_sym_RPAREN,
    STATE(963), 1,
      sym_parameter,
    STATE(889), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(967), 4,
      sym_tuple_pattern,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
  [37080] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1474), 9,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [37101] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1484), 1,
      anon_sym_COLON,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1494), 1,
      anon_sym_RBRACE,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
    STATE(1030), 1,
      sym__comprehension_clauses,
  [37138] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1498), 1,
      anon_sym_as,
    ACTIONS(1496), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37161] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1496), 9,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [37182] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1442), 1,
      anon_sym_LPAREN,
    ACTIONS(1444), 1,
      anon_sym_STAR,
    ACTIONS(1448), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1466), 1,
      sym_identifier,
    STATE(963), 1,
      sym_parameter,
    STATE(889), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(967), 4,
      sym_tuple_pattern,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
  [37211] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1502), 1,
      anon_sym_as,
    ACTIONS(1500), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37236] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1462), 10,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_RBRACE,
      sym_type_conversion,
  [37255] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1506), 1,
      anon_sym_as,
    ACTIONS(1504), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37280] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1504), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [37303] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1510), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [37326] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1484), 1,
      anon_sym_COLON,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1494), 1,
      anon_sym_RBRACE,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
    STATE(1027), 1,
      sym__comprehension_clauses,
  [37363] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1500), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [37386] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1464), 1,
      anon_sym_as,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1462), 9,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_or,
      anon_sym_RBRACE,
  [37407] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1484), 1,
      anon_sym_COLON,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1494), 1,
      anon_sym_RBRACE,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
    STATE(1020), 1,
      sym__comprehension_clauses,
  [37444] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1512), 1,
      anon_sym_RPAREN,
    ACTIONS(1514), 1,
      anon_sym_COMMA,
    ACTIONS(1517), 1,
      anon_sym_as,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
    STATE(1017), 1,
      sym__comprehension_clauses,
  [37481] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1519), 1,
      anon_sym_as,
    ACTIONS(1474), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37504] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1521), 1,
      anon_sym_as,
    ACTIONS(1510), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37529] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1440), 1,
      sym_identifier,
    ACTIONS(1442), 1,
      anon_sym_LPAREN,
    ACTIONS(1444), 1,
      anon_sym_STAR,
    ACTIONS(1448), 1,
      anon_sym_STAR_STAR,
    STATE(963), 1,
      sym_parameter,
    STATE(979), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(967), 4,
      sym_tuple_pattern,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
  [37558] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1494), 1,
      anon_sym_RBRACK,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
    STATE(1018), 1,
      sym__comprehension_clauses,
  [37592] = 6,
    ACTIONS(1523), 1,
      anon_sym_LBRACE,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1531), 1,
      sym__string_content,
    ACTIONS(1534), 1,
      sym__string_end,
    STATE(701), 3,
      sym_interpolation,
      sym__escape_interpolation,
      aux_sym_string_repeat1,
    ACTIONS(1526), 4,
      anon_sym_LBRACE_LBRACE,
      anon_sym_RBRACE_RBRACE,
      sym_escape_sequence,
      sym__not_escape_sequence,
  [37616] = 6,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1536), 1,
      anon_sym_LBRACE,
    ACTIONS(1540), 1,
      sym__string_content,
    ACTIONS(1542), 1,
      sym__string_end,
    STATE(710), 3,
      sym_interpolation,
      sym__escape_interpolation,
      aux_sym_string_repeat1,
    ACTIONS(1538), 4,
      anon_sym_LBRACE_LBRACE,
      anon_sym_RBRACE_RBRACE,
      sym_escape_sequence,
      sym__not_escape_sequence,
  [37640] = 6,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1536), 1,
      anon_sym_LBRACE,
    ACTIONS(1546), 1,
      sym__string_content,
    ACTIONS(1548), 1,
      sym__string_end,
    STATE(705), 3,
      sym_interpolation,
      sym__escape_interpolation,
      aux_sym_string_repeat1,
    ACTIONS(1544), 4,
      anon_sym_LBRACE_LBRACE,
      anon_sym_RBRACE_RBRACE,
      sym_escape_sequence,
      sym__not_escape_sequence,
  [37664] = 6,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1536), 1,
      anon_sym_LBRACE,
    ACTIONS(1552), 1,
      sym__string_content,
    ACTIONS(1554), 1,
      sym__string_end,
    STATE(717), 3,
      sym_interpolation,
      sym__escape_interpolation,
      aux_sym_string_repeat1,
    ACTIONS(1550), 4,
      anon_sym_LBRACE_LBRACE,
      anon_sym_RBRACE_RBRACE,
      sym_escape_sequence,
      sym__not_escape_sequence,
  [37688] = 6,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1536), 1,
      anon_sym_LBRACE,
    ACTIONS(1558), 1,
      sym__string_content,
    ACTIONS(1560), 1,
      sym__string_end,
    STATE(701), 3,
      sym_interpolation,
      sym__escape_interpolation,
      aux_sym_string_repeat1,
    ACTIONS(1556), 4,
      anon_sym_LBRACE_LBRACE,
      anon_sym_RBRACE_RBRACE,
      sym_escape_sequence,
      sym__not_escape_sequence,
  [37712] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1494), 1,
      anon_sym_RBRACK,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
    STATE(1033), 1,
      sym__comprehension_clauses,
  [37746] = 6,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1536), 1,
      anon_sym_LBRACE,
    ACTIONS(1558), 1,
      sym__string_content,
    ACTIONS(1562), 1,
      sym__string_end,
    STATE(701), 3,
      sym_interpolation,
      sym__escape_interpolation,
      aux_sym_string_repeat1,
    ACTIONS(1556), 4,
      anon_sym_LBRACE_LBRACE,
      anon_sym_RBRACE_RBRACE,
      sym_escape_sequence,
      sym__not_escape_sequence,
  [37770] = 6,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1536), 1,
      anon_sym_LBRACE,
    ACTIONS(1566), 1,
      sym__string_content,
    ACTIONS(1568), 1,
      sym__string_end,
    STATE(707), 3,
      sym_interpolation,
      sym__escape_interpolation,
      aux_sym_string_repeat1,
    ACTIONS(1564), 4,
      anon_sym_LBRACE_LBRACE,
      anon_sym_RBRACE_RBRACE,
      sym_escape_sequence,
      sym__not_escape_sequence,
  [37794] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1570), 1,
      anon_sym_RPAREN,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
    STATE(1038), 1,
      sym__comprehension_clauses,
  [37828] = 6,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1536), 1,
      anon_sym_LBRACE,
    ACTIONS(1558), 1,
      sym__string_content,
    ACTIONS(1572), 1,
      sym__string_end,
    STATE(701), 3,
      sym_interpolation,
      sym__escape_interpolation,
      aux_sym_string_repeat1,
    ACTIONS(1556), 4,
      anon_sym_LBRACE_LBRACE,
      anon_sym_RBRACE_RBRACE,
      sym_escape_sequence,
      sym__not_escape_sequence,
  [37852] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1512), 1,
      anon_sym_RPAREN,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
    STATE(1017), 1,
      sym__comprehension_clauses,
  [37886] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1574), 1,
      anon_sym_RPAREN,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
    STATE(1060), 1,
      sym__comprehension_clauses,
  [37920] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1576), 1,
      anon_sym_RPAREN,
    ACTIONS(1578), 1,
      anon_sym_COMMA,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(942), 1,
      aux_sym_argument_list_repeat1,
    STATE(1060), 1,
      sym__comprehension_clauses,
  [37954] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1580), 1,
      anon_sym_RPAREN,
    ACTIONS(1582), 1,
      anon_sym_COMMA,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(919), 1,
      aux_sym_argument_list_repeat1,
    STATE(1017), 1,
      sym__comprehension_clauses,
  [37988] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1494), 1,
      anon_sym_RBRACK,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
    STATE(1037), 1,
      sym__comprehension_clauses,
  [38022] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1584), 1,
      anon_sym_RPAREN,
    ACTIONS(1586), 1,
      anon_sym_COMMA,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(953), 1,
      aux_sym_argument_list_repeat1,
    STATE(1038), 1,
      sym__comprehension_clauses,
  [38056] = 6,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1536), 1,
      anon_sym_LBRACE,
    ACTIONS(1558), 1,
      sym__string_content,
    ACTIONS(1588), 1,
      sym__string_end,
    STATE(701), 3,
      sym_interpolation,
      sym__escape_interpolation,
      aux_sym_string_repeat1,
    ACTIONS(1556), 4,
      anon_sym_LBRACE_LBRACE,
      anon_sym_RBRACE_RBRACE,
      sym_escape_sequence,
      sym__not_escape_sequence,
  [38080] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1590), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38099] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1594), 1,
      anon_sym_if,
    ACTIONS(1592), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(723), 3,
      sym_for_in_clause,
      sym_if_clause,
      aux_sym__comprehension_clauses_repeat1,
  [38122] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1590), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38141] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1590), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38160] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1598), 1,
      anon_sym_if,
    ACTIONS(1601), 1,
      anon_sym_async,
    ACTIONS(1604), 1,
      anon_sym_for,
    ACTIONS(1596), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(722), 3,
      sym_for_in_clause,
      sym_if_clause,
      aux_sym__comprehension_clauses_repeat1,
  [38183] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1594), 1,
      anon_sym_if,
    ACTIONS(1607), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(722), 3,
      sym_for_in_clause,
      sym_if_clause,
      aux_sym__comprehension_clauses_repeat1,
  [38206] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1609), 6,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38224] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1118), 8,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_EQ,
      anon_sym_and,
      anon_sym_or,
  [38238] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1474), 6,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_EQ,
  [38256] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1496), 6,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_EQ,
  [38274] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1504), 5,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_EQ,
  [38294] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1462), 7,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_EQ,
      anon_sym_or,
  [38310] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1619), 1,
      anon_sym_COMMA,
    STATE(736), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(1617), 6,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38328] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_AT,
    ACTIONS(1621), 1,
      anon_sym_async,
    ACTIONS(1623), 1,
      anon_sym_def,
    ACTIONS(1625), 1,
      anon_sym_class,
    STATE(434), 2,
      sym_function_definition,
      sym_class_definition,
    STATE(792), 2,
      sym_decorator,
      aux_sym_decorated_definition_repeat1,
  [38352] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1456), 8,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_EQ,
      anon_sym_and,
      anon_sym_or,
  [38366] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_AT,
    ACTIONS(1627), 1,
      anon_sym_async,
    ACTIONS(1629), 1,
      anon_sym_def,
    ACTIONS(1631), 1,
      anon_sym_class,
    STATE(372), 2,
      sym_function_definition,
      sym_class_definition,
    STATE(792), 2,
      sym_decorator,
      aux_sym_decorated_definition_repeat1,
  [38390] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1500), 5,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_EQ,
  [38410] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1635), 1,
      anon_sym_COMMA,
    STATE(739), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(1633), 6,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38428] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1639), 1,
      anon_sym_COMMA,
    STATE(741), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(1637), 6,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38446] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1462), 8,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_EQ,
      anon_sym_and,
      anon_sym_or,
  [38460] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1510), 5,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_EQ,
  [38480] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1643), 1,
      anon_sym_COMMA,
    STATE(741), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(1641), 6,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38498] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1647), 1,
      anon_sym_COMMA,
    STATE(800), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(1645), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38522] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1651), 1,
      anon_sym_COMMA,
    STATE(741), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(1649), 6,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38540] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1656), 1,
      anon_sym_from,
    ACTIONS(1658), 1,
      anon_sym_COMMA,
    STATE(831), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(1654), 2,
      sym__newline,
      anon_sym_SEMI,
  [38566] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1660), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38586] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1662), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38605] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1664), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
  [38624] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1666), 1,
      anon_sym_COMMA,
    ACTIONS(1668), 1,
      anon_sym_COLON,
    ACTIONS(1670), 1,
      anon_sym_RBRACK,
    STATE(957), 1,
      aux_sym_subscript_repeat1,
  [38649] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1672), 1,
      anon_sym_if,
    ACTIONS(1674), 1,
      anon_sym_and,
    ACTIONS(1676), 1,
      anon_sym_or,
    ACTIONS(1510), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_COLON,
  [38668] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1658), 1,
      anon_sym_COMMA,
    STATE(831), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(1678), 2,
      sym__newline,
      anon_sym_SEMI,
  [38691] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1672), 1,
      anon_sym_if,
    ACTIONS(1674), 1,
      anon_sym_and,
    ACTIONS(1676), 1,
      anon_sym_or,
    ACTIONS(1682), 1,
      anon_sym_as,
    ACTIONS(1680), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
  [38712] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1462), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
  [38725] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1686), 1,
      anon_sym_COMMA,
    STATE(840), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(1684), 2,
      sym__newline,
      anon_sym_SEMI,
  [38748] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1660), 4,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
  [38767] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1688), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38786] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1690), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38799] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1658), 1,
      anon_sym_COMMA,
    STATE(831), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(1692), 2,
      sym__newline,
      anon_sym_SEMI,
  [38822] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1672), 1,
      anon_sym_if,
    ACTIONS(1674), 1,
      anon_sym_and,
    ACTIONS(1676), 1,
      anon_sym_or,
    ACTIONS(1504), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_COLON,
  [38841] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1658), 1,
      anon_sym_COMMA,
    STATE(831), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(1694), 2,
      sym__newline,
      anon_sym_SEMI,
  [38864] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1686), 1,
      anon_sym_COMMA,
    STATE(879), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(1696), 2,
      sym__newline,
      anon_sym_SEMI,
  [38887] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1482), 1,
      anon_sym_if,
    ACTIONS(1490), 1,
      anon_sym_and,
    ACTIONS(1492), 1,
      anon_sym_or,
    ACTIONS(1698), 4,
      anon_sym_COMMA,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [38906] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1700), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38925] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1658), 1,
      anon_sym_COMMA,
    STATE(831), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(1645), 2,
      sym__newline,
      anon_sym_SEMI,
  [38948] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1649), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38961] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1118), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
  [38974] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1702), 1,
      anon_sym_COMMA,
    ACTIONS(1704), 1,
      anon_sym_RBRACE,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(933), 1,
      aux_sym_dictionary_repeat1,
    STATE(1021), 1,
      sym__comprehension_clauses,
  [38999] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1706), 1,
      anon_sym_COMMA,
    ACTIONS(1708), 1,
      anon_sym_RBRACE,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(930), 1,
      aux_sym_dictionary_repeat1,
    STATE(1025), 1,
      sym__comprehension_clauses,
  [39024] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(880), 1,
      aux_sym_print_statement_repeat1,
    ACTIONS(1710), 2,
      sym__newline,
      anon_sym_SEMI,
  [39047] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1714), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [39060] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1674), 1,
      anon_sym_and,
    ACTIONS(1676), 1,
      anon_sym_or,
    ACTIONS(1474), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
  [39077] = 3,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1718), 2,
      sym__string_content,
      sym__string_end,
    ACTIONS(1716), 5,
      anon_sym_LBRACE,
      anon_sym_LBRACE_LBRACE,
      anon_sym_RBRACE_RBRACE,
      sym_escape_sequence,
      sym__not_escape_sequence,
  [39092] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1456), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
  [39105] = 3,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1722), 2,
      sym__string_content,
      sym__string_end,
    ACTIONS(1720), 5,
      anon_sym_LBRACE,
      anon_sym_LBRACE_LBRACE,
      anon_sym_RBRACE_RBRACE,
      sym_escape_sequence,
      sym__not_escape_sequence,
  [39120] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1674), 1,
      anon_sym_and,
    ACTIONS(1676), 1,
      anon_sym_or,
    ACTIONS(1496), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
  [39137] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1486), 1,
      anon_sym_async,
    ACTIONS(1488), 1,
      anon_sym_for,
    ACTIONS(1724), 1,
      anon_sym_COMMA,
    ACTIONS(1726), 1,
      anon_sym_RBRACE,
    STATE(719), 1,
      sym_for_in_clause,
    STATE(926), 1,
      aux_sym_dictionary_repeat1,
    STATE(1029), 1,
      sym__comprehension_clauses,
  [39162] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1668), 1,
      anon_sym_COLON,
    ACTIONS(1728), 1,
      anon_sym_COMMA,
    ACTIONS(1730), 1,
      anon_sym_RBRACK,
    STATE(940), 1,
      aux_sym_subscript_repeat1,
  [39187] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1734), 1,
      anon_sym_LPAREN,
    ACTIONS(1736), 1,
      anon_sym_STAR,
    STATE(835), 1,
      sym_dotted_name,
    STATE(839), 1,
      sym_aliased_import,
    STATE(977), 1,
      sym__import_list,
    STATE(982), 1,
      sym_wildcard_import,
  [39212] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1738), 1,
      anon_sym_COLON,
    ACTIONS(1740), 1,
      anon_sym_RBRACE,
    ACTIONS(1742), 1,
      sym_type_conversion,
    STATE(1063), 1,
      sym_format_specifier,
  [39237] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1668), 1,
      anon_sym_COLON,
    ACTIONS(1744), 1,
      anon_sym_COMMA,
    ACTIONS(1746), 1,
      anon_sym_RBRACK,
    STATE(917), 1,
      aux_sym_subscript_repeat1,
  [39262] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1674), 1,
      anon_sym_and,
    ACTIONS(1462), 6,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_or,
  [39277] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1672), 1,
      anon_sym_if,
    ACTIONS(1674), 1,
      anon_sym_and,
    ACTIONS(1676), 1,
      anon_sym_or,
    ACTIONS(1500), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_COLON,
  [39296] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1750), 1,
      anon_sym_COMMA,
    STATE(841), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(1748), 2,
      sym__newline,
      anon_sym_SEMI,
  [39319] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1752), 1,
      sym_identifier,
    ACTIONS(1754), 1,
      anon_sym_DOT,
    ACTIONS(1756), 1,
      anon_sym___future__,
    STATE(845), 1,
      aux_sym_import_prefix_repeat1,
    STATE(915), 1,
      sym_import_prefix,
    STATE(1013), 2,
      sym_relative_import,
      sym_dotted_name,
  [39342] = 3,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1760), 2,
      sym__string_content,
      sym__string_end,
    ACTIONS(1758), 5,
      anon_sym_LBRACE,
      anon_sym_LBRACE_LBRACE,
      anon_sym_RBRACE_RBRACE,
      sym_escape_sequence,
      sym__not_escape_sequence,
  [39357] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1647), 1,
      anon_sym_COMMA,
    ACTIONS(1762), 1,
      anon_sym_COLON,
    STATE(800), 1,
      aux_sym_assert_statement_repeat1,
  [39379] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1766), 1,
      anon_sym_DOT,
    STATE(784), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(1764), 4,
      anon_sym_import,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
  [39395] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1769), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [39413] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1773), 1,
      anon_sym_DOT,
    STATE(795), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(1771), 4,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_as,
  [39429] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1672), 1,
      anon_sym_if,
    ACTIONS(1674), 1,
      anon_sym_and,
    ACTIONS(1676), 1,
      anon_sym_or,
    ACTIONS(1777), 1,
      anon_sym_COLON,
    ACTIONS(1775), 2,
      anon_sym_COMMA,
      anon_sym_as,
  [39449] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1779), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
  [39467] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1647), 1,
      anon_sym_COMMA,
    ACTIONS(1781), 1,
      anon_sym_COLON,
    STATE(800), 1,
      aux_sym_assert_statement_repeat1,
  [39489] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1783), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [39507] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1668), 1,
      anon_sym_COLON,
    ACTIONS(1785), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [39527] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1789), 1,
      anon_sym_AT,
    STATE(792), 2,
      sym_decorator,
      aux_sym_decorated_definition_repeat1,
    ACTIONS(1787), 3,
      anon_sym_async,
      anon_sym_def,
      anon_sym_class,
  [39543] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1792), 1,
      anon_sym_COLON,
    ACTIONS(834), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [39563] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1647), 1,
      anon_sym_COMMA,
    ACTIONS(1794), 1,
      anon_sym_COLON,
    STATE(800), 1,
      aux_sym_assert_statement_repeat1,
  [39585] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1773), 1,
      anon_sym_DOT,
    STATE(799), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(1796), 4,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_as,
  [39601] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1798), 1,
      anon_sym_DOT,
    STATE(784), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(1796), 4,
      anon_sym_import,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
  [39617] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(734), 1,
      anon_sym_COLON,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(732), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [39637] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1798), 1,
      anon_sym_DOT,
    STATE(796), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(1771), 4,
      anon_sym_import,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
  [39653] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1800), 1,
      anon_sym_DOT,
    STATE(799), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(1764), 4,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_as,
  [39669] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1803), 1,
      anon_sym_COMMA,
    STATE(806), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(668), 4,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [39685] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1664), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_EQ,
  [39703] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1805), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
  [39721] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1584), 1,
      anon_sym_RPAREN,
    ACTIONS(1586), 1,
      anon_sym_COMMA,
    STATE(953), 1,
      aux_sym_argument_list_repeat1,
  [39743] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1647), 1,
      anon_sym_COMMA,
    ACTIONS(1807), 1,
      anon_sym_COLON,
    STATE(800), 1,
      aux_sym_assert_statement_repeat1,
  [39765] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1809), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [39783] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1811), 1,
      anon_sym_COMMA,
    STATE(806), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(1660), 4,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [39799] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1672), 1,
      anon_sym_if,
    ACTIONS(1674), 1,
      anon_sym_and,
    ACTIONS(1676), 1,
      anon_sym_or,
    ACTIONS(1816), 1,
      anon_sym_COLON,
    ACTIONS(1814), 2,
      anon_sym_COMMA,
      anon_sym_as,
  [39819] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1818), 1,
      anon_sym_except,
    ACTIONS(1820), 1,
      anon_sym_finally,
    STATE(418), 1,
      sym_finally_clause,
    STATE(165), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
  [39836] = 5,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1822), 1,
      anon_sym_LBRACE,
    ACTIONS(1825), 1,
      anon_sym_RBRACE,
    ACTIONS(1827), 1,
      aux_sym_format_specifier_token1,
    STATE(809), 2,
      sym_format_expression,
      aux_sym_format_specifier_repeat1,
  [39853] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1764), 5,
      anon_sym_import,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
  [39864] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1830), 1,
      anon_sym_COMMA,
    STATE(811), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(1700), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [39879] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(836), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [39896] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1833), 2,
      sym__newline,
      anon_sym_SEMI,
  [39913] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1835), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [39930] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1837), 1,
      anon_sym_except,
    ACTIONS(1839), 1,
      anon_sym_finally,
    STATE(367), 1,
      sym_finally_clause,
    STATE(162), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
  [39947] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1698), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [39964] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1841), 1,
      anon_sym_LPAREN,
    STATE(835), 1,
      sym_dotted_name,
    STATE(839), 1,
      sym_aliased_import,
    STATE(1011), 1,
      sym__import_list,
  [39983] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1818), 1,
      anon_sym_except,
    ACTIONS(1820), 1,
      anon_sym_finally,
    STATE(393), 1,
      sym_finally_clause,
    STATE(164), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
  [40000] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1764), 5,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
  [40011] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1843), 1,
      anon_sym_COMMA,
    STATE(811), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(610), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [40026] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1845), 1,
      anon_sym_COMMA,
    STATE(821), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(1660), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
  [40041] = 5,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1848), 1,
      anon_sym_LBRACE,
    ACTIONS(1850), 1,
      anon_sym_RBRACE,
    ACTIONS(1852), 1,
      aux_sym_format_specifier_token1,
    STATE(809), 2,
      sym_format_expression,
      aux_sym_format_specifier_repeat1,
  [40058] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1854), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [40075] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      sym_identifier,
    STATE(877), 1,
      sym_dotted_name,
    STATE(956), 1,
      sym_aliased_import,
    ACTIONS(1856), 2,
      sym__newline,
      anon_sym_SEMI,
  [40092] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      sym_identifier,
    STATE(877), 1,
      sym_dotted_name,
    STATE(956), 1,
      sym_aliased_import,
    ACTIONS(1858), 2,
      sym__newline,
      anon_sym_SEMI,
  [40109] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1837), 1,
      anon_sym_except,
    ACTIONS(1839), 1,
      anon_sym_finally,
    STATE(420), 1,
      sym_finally_clause,
    STATE(171), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
  [40126] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(834), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [40143] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1860), 2,
      sym__newline,
      anon_sym_SEMI,
  [40160] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(1494), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [40175] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1862), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [40192] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1864), 1,
      anon_sym_COMMA,
    STATE(821), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(668), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
  [40207] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      anon_sym_and,
    ACTIONS(1613), 1,
      anon_sym_or,
    ACTIONS(1615), 1,
      anon_sym_if,
    ACTIONS(1688), 2,
      sym__newline,
      anon_sym_SEMI,
  [40224] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      sym_identifier,
    STATE(877), 1,
      sym_dotted_name,
    STATE(956), 1,
      sym_aliased_import,
    ACTIONS(1858), 2,
      sym__newline,
      anon_sym_SEMI,
  [40241] = 5,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(1848), 1,
      anon_sym_LBRACE,
    ACTIONS(1866), 1,
      anon_sym_RBRACE,
    ACTIONS(1868), 1,
      aux_sym_format_specifier_token1,
    STATE(822), 2,
      sym_format_expression,
      aux_sym_format_specifier_repeat1,
  [40258] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1872), 1,
      anon_sym_COMMA,
    ACTIONS(1874), 1,
      anon_sym_as,
    STATE(844), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(1870), 2,
      sym__newline,
      anon_sym_SEMI,
  [40275] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1876), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [40292] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      sym_identifier,
    STATE(835), 1,
      sym_dotted_name,
    STATE(839), 1,
      sym_aliased_import,
    STATE(1008), 1,
      sym__import_list,
  [40308] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1878), 1,
      anon_sym_else,
  [40324] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1872), 1,
      anon_sym_COMMA,
    STATE(847), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(1870), 2,
      sym__newline,
      anon_sym_SEMI,
  [40338] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1686), 1,
      anon_sym_COMMA,
    STATE(821), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(1880), 2,
      sym__newline,
      anon_sym_SEMI,
  [40352] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1882), 1,
      anon_sym_COMMA,
    STATE(821), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(785), 2,
      sym__newline,
      anon_sym_SEMI,
  [40366] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1884), 1,
      anon_sym_COLON,
  [40382] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1886), 1,
      anon_sym_COLON,
  [40398] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1890), 1,
      anon_sym_COMMA,
    STATE(878), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(1888), 2,
      sym__newline,
      anon_sym_SEMI,
  [40412] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1894), 1,
      anon_sym_DOT,
    STATE(855), 1,
      aux_sym_import_prefix_repeat1,
    ACTIONS(1892), 2,
      anon_sym_import,
      sym_identifier,
  [40426] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1898), 1,
      anon_sym_COMMA,
    STATE(876), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(1896), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [40440] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1900), 1,
      anon_sym_COMMA,
    STATE(878), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(1888), 2,
      sym__newline,
      anon_sym_SEMI,
  [40454] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1902), 1,
      anon_sym_RBRACE,
  [40470] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1904), 1,
      anon_sym_else,
  [40486] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1858), 1,
      anon_sym_RPAREN,
    ACTIONS(1906), 1,
      sym_identifier,
    STATE(906), 1,
      sym_dotted_name,
    STATE(992), 1,
      sym_aliased_import,
  [40502] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1908), 1,
      anon_sym_else,
  [40518] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1912), 1,
      anon_sym_COMMA,
    STATE(881), 1,
      aux_sym_print_statement_repeat1,
    ACTIONS(1910), 2,
      sym__newline,
      anon_sym_SEMI,
  [40532] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1914), 1,
      anon_sym_COLON,
  [40548] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1858), 1,
      anon_sym_RPAREN,
    ACTIONS(1906), 1,
      sym_identifier,
    STATE(906), 1,
      sym_dotted_name,
    STATE(992), 1,
      sym_aliased_import,
  [40564] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1918), 1,
      anon_sym_DOT,
    STATE(855), 1,
      aux_sym_import_prefix_repeat1,
    ACTIONS(1916), 2,
      anon_sym_import,
      sym_identifier,
  [40578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1923), 1,
      anon_sym_EQ,
    ACTIONS(1921), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
  [40590] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1925), 4,
      anon_sym_async,
      anon_sym_def,
      anon_sym_class,
      anon_sym_AT,
  [40600] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1929), 1,
      anon_sym_COMMA,
    STATE(858), 1,
      aux_sym_global_statement_repeat1,
    ACTIONS(1927), 2,
      sym__newline,
      anon_sym_SEMI,
  [40614] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1934), 1,
      anon_sym_COMMA,
    STATE(858), 1,
      aux_sym_global_statement_repeat1,
    ACTIONS(1932), 2,
      sym__newline,
      anon_sym_SEMI,
  [40628] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1934), 1,
      anon_sym_COMMA,
    STATE(858), 1,
      aux_sym_global_statement_repeat1,
    ACTIONS(1936), 2,
      sym__newline,
      anon_sym_SEMI,
  [40642] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1940), 1,
      anon_sym_COMMA,
    STATE(861), 1,
      aux_sym_with_clause_repeat1,
    ACTIONS(1938), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [40656] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1943), 1,
      anon_sym_COLON,
  [40672] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1945), 1,
      anon_sym_COLON,
  [40688] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1947), 1,
      anon_sym_COLON,
  [40704] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1949), 1,
      anon_sym_COLON,
  [40720] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1951), 1,
      anon_sym_COLON,
  [40736] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1953), 1,
      anon_sym_COLON,
  [40752] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1906), 1,
      sym_identifier,
    STATE(882), 1,
      sym_dotted_name,
    STATE(890), 1,
      sym_aliased_import,
    STATE(1031), 1,
      sym__import_list,
  [40768] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COMMA,
    STATE(869), 1,
      aux_sym_print_statement_repeat1,
    ACTIONS(1955), 2,
      sym__newline,
      anon_sym_SEMI,
  [40782] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1934), 1,
      anon_sym_COMMA,
    STATE(859), 1,
      aux_sym_global_statement_repeat1,
    ACTIONS(1960), 2,
      sym__newline,
      anon_sym_SEMI,
  [40796] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1962), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [40806] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_and,
    ACTIONS(1478), 1,
      anon_sym_or,
    ACTIONS(1508), 1,
      anon_sym_if,
    ACTIONS(1964), 1,
      anon_sym_else,
  [40822] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1966), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [40832] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1856), 1,
      anon_sym_RPAREN,
    ACTIONS(1906), 1,
      sym_identifier,
    STATE(906), 1,
      sym_dotted_name,
    STATE(992), 1,
      sym_aliased_import,
  [40848] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1700), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [40858] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1968), 1,
      anon_sym_COMMA,
    STATE(653), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(1092), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [40872] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1874), 1,
      anon_sym_as,
    ACTIONS(1970), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [40884] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1974), 1,
      anon_sym_COMMA,
    STATE(878), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(1972), 2,
      sym__newline,
      anon_sym_SEMI,
  [40898] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1686), 1,
      anon_sym_COMMA,
    STATE(821), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(1977), 2,
      sym__newline,
      anon_sym_SEMI,
  [40912] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1981), 1,
      anon_sym_COMMA,
    STATE(869), 1,
      aux_sym_print_statement_repeat1,
    ACTIONS(1979), 2,
      sym__newline,
      anon_sym_SEMI,
  [40926] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1985), 1,
      anon_sym_COMMA,
    STATE(869), 1,
      aux_sym_print_statement_repeat1,
    ACTIONS(1983), 2,
      sym__newline,
      anon_sym_SEMI,
  [40940] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1870), 1,
      anon_sym_RPAREN,
    ACTIONS(1987), 1,
      anon_sym_COMMA,
    ACTIONS(1989), 1,
      anon_sym_as,
    STATE(901), 1,
      aux_sym__import_list_repeat1,
  [40956] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1934), 1,
      anon_sym_COMMA,
    STATE(860), 1,
      aux_sym_global_statement_repeat1,
    ACTIONS(1991), 2,
      sym__newline,
      anon_sym_SEMI,
  [40970] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1906), 1,
      sym_identifier,
    STATE(882), 1,
      sym_dotted_name,
    STATE(890), 1,
      sym_aliased_import,
    STATE(1028), 1,
      sym__import_list,
  [40986] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1645), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [40996] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1995), 1,
      anon_sym_COLON,
    ACTIONS(1997), 1,
      anon_sym_EQ,
    ACTIONS(1993), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [41010] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1999), 1,
      anon_sym_COMMA,
    ACTIONS(2001), 1,
      anon_sym_COLON,
    STATE(900), 1,
      aux_sym_with_clause_repeat1,
  [41023] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1938), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
  [41032] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2003), 1,
      anon_sym_COLON,
    ACTIONS(1993), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [41043] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1870), 1,
      anon_sym_RPAREN,
    ACTIONS(1987), 1,
      anon_sym_COMMA,
    STATE(895), 1,
      aux_sym__import_list_repeat1,
  [41056] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1432), 1,
      anon_sym_COMMA,
    ACTIONS(2005), 1,
      anon_sym_in,
    STATE(665), 1,
      aux_sym__patterns_repeat1,
  [41069] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1432), 1,
      anon_sym_COMMA,
    ACTIONS(2007), 1,
      anon_sym_in,
    STATE(665), 1,
      aux_sym__patterns_repeat1,
  [41082] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1432), 1,
      anon_sym_COMMA,
    ACTIONS(2009), 1,
      anon_sym_in,
    STATE(665), 1,
      aux_sym__patterns_repeat1,
  [41095] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2011), 1,
      anon_sym_SEMI,
    ACTIONS(2013), 1,
      sym__newline,
    STATE(911), 1,
      aux_sym__simple_statements_repeat1,
  [41108] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1888), 1,
      anon_sym_RPAREN,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    STATE(908), 1,
      aux_sym__import_list_repeat1,
  [41121] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1098), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_in,
  [41130] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1999), 1,
      anon_sym_COMMA,
    ACTIONS(2017), 1,
      anon_sym_RPAREN,
    STATE(972), 1,
      aux_sym_with_clause_repeat1,
  [41143] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    ACTIONS(1570), 1,
      anon_sym_RPAREN,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
  [41156] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2019), 1,
      anon_sym_SEMI,
    ACTIONS(2021), 1,
      sym__newline,
    STATE(954), 1,
      aux_sym__simple_statements_repeat1,
  [41169] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1999), 1,
      anon_sym_COMMA,
    ACTIONS(2023), 1,
      anon_sym_COLON,
    STATE(861), 1,
      aux_sym_with_clause_repeat1,
  [41182] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1888), 1,
      anon_sym_RPAREN,
    ACTIONS(2025), 1,
      anon_sym_COMMA,
    STATE(908), 1,
      aux_sym__import_list_repeat1,
  [41195] = 3,
    ACTIONS(1529), 1,
      sym_comment,
    ACTIONS(2029), 1,
      aux_sym_format_specifier_token1,
    ACTIONS(2027), 2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [41206] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(616), 1,
      anon_sym_RPAREN,
    ACTIONS(2031), 1,
      anon_sym_COMMA,
    STATE(912), 1,
      aux_sym_argument_list_repeat1,
  [41219] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2033), 1,
      anon_sym_RPAREN,
    ACTIONS(2035), 1,
      anon_sym_COMMA,
    STATE(924), 1,
      aux_sym__parameters_repeat1,
  [41232] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    ACTIONS(2037), 1,
      anon_sym_RPAREN,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
  [41245] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1989), 1,
      anon_sym_as,
    ACTIONS(1970), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [41256] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1724), 1,
      anon_sym_COMMA,
    ACTIONS(1726), 1,
      anon_sym_RBRACE,
    STATE(926), 1,
      aux_sym_dictionary_repeat1,
  [41269] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1972), 1,
      anon_sym_RPAREN,
    ACTIONS(2039), 1,
      anon_sym_COMMA,
    STATE(908), 1,
      aux_sym__import_list_repeat1,
  [41282] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2042), 1,
      anon_sym_COMMA,
    ACTIONS(2045), 1,
      anon_sym_RBRACK,
    STATE(909), 1,
      aux_sym_subscript_repeat1,
  [41295] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    ACTIONS(2047), 1,
      anon_sym_RPAREN,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
  [41308] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(419), 1,
      sym__newline,
    ACTIONS(2049), 1,
      anon_sym_SEMI,
    STATE(937), 1,
      aux_sym__simple_statements_repeat1,
  [41321] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1862), 1,
      anon_sym_RPAREN,
    ACTIONS(2051), 1,
      anon_sym_COMMA,
    STATE(912), 1,
      aux_sym_argument_list_repeat1,
  [41334] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2054), 1,
      anon_sym_LPAREN,
    ACTIONS(2056), 1,
      anon_sym_COLON,
    STATE(1065), 1,
      sym_argument_list,
  [41347] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1906), 1,
      sym_identifier,
    STATE(906), 1,
      sym_dotted_name,
    STATE(992), 1,
      sym_aliased_import,
  [41360] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1752), 1,
      sym_identifier,
    ACTIONS(2058), 1,
      anon_sym_import,
    STATE(1035), 1,
      sym_dotted_name,
  [41373] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2060), 1,
      anon_sym_COMMA,
    ACTIONS(2062), 1,
      anon_sym_RBRACK,
    STATE(909), 1,
      aux_sym_subscript_repeat1,
  [41386] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2064), 1,
      anon_sym_COMMA,
    ACTIONS(2066), 1,
      anon_sym_RBRACK,
    STATE(909), 1,
      aux_sym_subscript_repeat1,
  [41399] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(650), 1,
      anon_sym_RPAREN,
    ACTIONS(2068), 1,
      anon_sym_COMMA,
    STATE(912), 1,
      aux_sym_argument_list_repeat1,
  [41412] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(612), 1,
      anon_sym_RPAREN,
    ACTIONS(2070), 1,
      anon_sym_COMMA,
    STATE(912), 1,
      aux_sym_argument_list_repeat1,
  [41425] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(815), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
  [41434] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1706), 1,
      anon_sym_COMMA,
    ACTIONS(1708), 1,
      anon_sym_RBRACE,
    STATE(930), 1,
      aux_sym_dictionary_repeat1,
  [41447] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1102), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_in,
  [41456] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1432), 1,
      anon_sym_COMMA,
    ACTIONS(2072), 1,
      anon_sym_in,
    STATE(665), 1,
      aux_sym__patterns_repeat1,
  [41469] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1472), 1,
      anon_sym_RPAREN,
    ACTIONS(2074), 1,
      anon_sym_COMMA,
    STATE(949), 1,
      aux_sym__parameters_repeat1,
  [41482] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    ACTIONS(1574), 1,
      anon_sym_RPAREN,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
  [41495] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(718), 1,
      anon_sym_RBRACE,
    ACTIONS(2076), 1,
      anon_sym_COMMA,
    STATE(943), 1,
      aux_sym_dictionary_repeat1,
  [41508] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1472), 1,
      anon_sym_COLON,
    ACTIONS(2078), 1,
      anon_sym_COMMA,
    STATE(952), 1,
      aux_sym__parameters_repeat1,
  [41521] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1744), 1,
      anon_sym_COMMA,
    ACTIONS(1746), 1,
      anon_sym_RBRACK,
    STATE(916), 1,
      aux_sym_subscript_repeat1,
  [41534] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      sym_identifier,
    STATE(877), 1,
      sym_dotted_name,
    STATE(956), 1,
      sym_aliased_import,
  [41547] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(708), 1,
      anon_sym_RBRACE,
    ACTIONS(2080), 1,
      anon_sym_COMMA,
    STATE(943), 1,
      aux_sym_dictionary_repeat1,
  [41560] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2082), 1,
      anon_sym_RPAREN,
    ACTIONS(2084), 1,
      anon_sym_COMMA,
    STATE(918), 1,
      aux_sym_argument_list_repeat1,
  [41573] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1580), 1,
      anon_sym_RPAREN,
    ACTIONS(1582), 1,
      anon_sym_COMMA,
    STATE(919), 1,
      aux_sym_argument_list_repeat1,
  [41586] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(720), 1,
      anon_sym_RBRACE,
    ACTIONS(2086), 1,
      anon_sym_COMMA,
    STATE(943), 1,
      aux_sym_dictionary_repeat1,
  [41599] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2088), 1,
      anon_sym_COMMA,
    ACTIONS(2090), 1,
      anon_sym_RBRACK,
    STATE(909), 1,
      aux_sym_subscript_repeat1,
  [41612] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1584), 1,
      anon_sym_RPAREN,
    ACTIONS(1586), 1,
      anon_sym_COMMA,
    STATE(953), 1,
      aux_sym_argument_list_repeat1,
  [41625] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2092), 1,
      anon_sym_RPAREN,
    ACTIONS(2094), 1,
      anon_sym_COMMA,
    STATE(955), 1,
      aux_sym_argument_list_repeat1,
  [41638] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2096), 1,
      anon_sym_SEMI,
    ACTIONS(2099), 1,
      sym__newline,
    STATE(937), 1,
      aux_sym__simple_statements_repeat1,
  [41651] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2103), 1,
      anon_sym_EQ,
    ACTIONS(2101), 2,
      sym__newline,
      anon_sym_SEMI,
  [41662] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1666), 1,
      anon_sym_COMMA,
    ACTIONS(1670), 1,
      anon_sym_RBRACK,
    STATE(958), 1,
      aux_sym_subscript_repeat1,
  [41675] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2105), 1,
      anon_sym_COMMA,
    ACTIONS(2107), 1,
      anon_sym_RBRACK,
    STATE(909), 1,
      aux_sym_subscript_repeat1,
  [41688] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(423), 1,
      sym__newline,
    ACTIONS(2109), 1,
      anon_sym_SEMI,
    STATE(937), 1,
      aux_sym__simple_statements_repeat1,
  [41701] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(624), 1,
      anon_sym_RPAREN,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    STATE(912), 1,
      aux_sym_argument_list_repeat1,
  [41714] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2113), 1,
      anon_sym_COMMA,
    ACTIONS(2116), 1,
      anon_sym_RBRACE,
    STATE(943), 1,
      aux_sym_dictionary_repeat1,
  [41727] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1576), 1,
      anon_sym_RPAREN,
    ACTIONS(1578), 1,
      anon_sym_COMMA,
    STATE(942), 1,
      aux_sym_argument_list_repeat1,
  [41740] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1702), 1,
      anon_sym_COMMA,
    ACTIONS(1704), 1,
      anon_sym_RBRACE,
    STATE(933), 1,
      aux_sym_dictionary_repeat1,
  [41753] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2118), 1,
      anon_sym_RPAREN,
    ACTIONS(2120), 1,
      anon_sym_COMMA,
    STATE(903), 1,
      aux_sym_argument_list_repeat1,
  [41766] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_COMMA,
    ACTIONS(1512), 1,
      anon_sym_RPAREN,
    STATE(820), 1,
      aux_sym__collection_elements_repeat1,
  [41779] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1921), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
  [41788] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2122), 1,
      anon_sym_RPAREN,
    ACTIONS(2124), 1,
      anon_sym_COMMA,
    STATE(949), 1,
      aux_sym__parameters_repeat1,
  [41801] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1728), 1,
      anon_sym_COMMA,
    ACTIONS(1730), 1,
      anon_sym_RBRACK,
    STATE(934), 1,
      aux_sym_subscript_repeat1,
  [41814] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1738), 1,
      anon_sym_COLON,
    ACTIONS(2127), 1,
      anon_sym_RBRACE,
    STATE(1023), 1,
      sym_format_specifier,
  [41827] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2122), 1,
      anon_sym_COLON,
    ACTIONS(2129), 1,
      anon_sym_COMMA,
    STATE(952), 1,
      aux_sym__parameters_repeat1,
  [41840] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(632), 1,
      anon_sym_RPAREN,
    ACTIONS(2132), 1,
      anon_sym_COMMA,
    STATE(912), 1,
      aux_sym_argument_list_repeat1,
  [41853] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(421), 1,
      sym__newline,
    ACTIONS(2134), 1,
      anon_sym_SEMI,
    STATE(937), 1,
      aux_sym__simple_statements_repeat1,
  [41866] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(626), 1,
      anon_sym_RPAREN,
    ACTIONS(2136), 1,
      anon_sym_COMMA,
    STATE(912), 1,
      aux_sym_argument_list_repeat1,
  [41879] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1970), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [41888] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2138), 1,
      anon_sym_COMMA,
    ACTIONS(2140), 1,
      anon_sym_RBRACK,
    STATE(909), 1,
      aux_sym_subscript_repeat1,
  [41901] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2142), 1,
      anon_sym_COMMA,
    ACTIONS(2144), 1,
      anon_sym_RBRACK,
    STATE(909), 1,
      aux_sym_subscript_repeat1,
  [41914] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2146), 1,
      anon_sym_SEMI,
    ACTIONS(2148), 1,
      sym__newline,
    STATE(941), 1,
      aux_sym__simple_statements_repeat1,
  [41927] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2150), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [41936] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1432), 1,
      anon_sym_COMMA,
    ACTIONS(2152), 1,
      anon_sym_in,
    STATE(665), 1,
      aux_sym__patterns_repeat1,
  [41949] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2154), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
  [41958] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2122), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
  [41967] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2054), 1,
      anon_sym_LPAREN,
    ACTIONS(2156), 1,
      anon_sym_COLON,
    STATE(1058), 1,
      sym_argument_list,
  [41980] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2160), 1,
      anon_sym_in,
    ACTIONS(2158), 2,
      sym__newline,
      anon_sym_SEMI,
  [41991] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1656), 1,
      anon_sym_from,
    ACTIONS(1654), 2,
      sym__newline,
      anon_sym_SEMI,
  [42002] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1993), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
  [42011] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2033), 1,
      anon_sym_COLON,
    ACTIONS(2162), 1,
      anon_sym_COMMA,
    STATE(927), 1,
      aux_sym__parameters_repeat1,
  [42024] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1432), 1,
      anon_sym_COMMA,
    ACTIONS(2164), 1,
      anon_sym_in,
    STATE(665), 1,
      aux_sym__patterns_repeat1,
  [42037] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1927), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [42046] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1997), 1,
      anon_sym_EQ,
    ACTIONS(1993), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
  [42057] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1999), 1,
      anon_sym_COMMA,
    ACTIONS(2166), 1,
      anon_sym_RPAREN,
    STATE(861), 1,
      aux_sym_with_clause_repeat1,
  [42070] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2168), 2,
      sym__newline,
      anon_sym_SEMI,
  [42078] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2099), 2,
      sym__newline,
      anon_sym_SEMI,
  [42086] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2170), 2,
      sym__newline,
      anon_sym_SEMI,
  [42094] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2172), 1,
      anon_sym_LPAREN,
    STATE(986), 1,
      sym_parameters,
  [42104] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2174), 2,
      sym__newline,
      anon_sym_SEMI,
  [42112] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1645), 2,
      sym__newline,
      anon_sym_SEMI,
  [42120] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1993), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
  [42128] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2176), 2,
      sym__newline,
      anon_sym_SEMI,
  [42136] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2178), 2,
      sym__newline,
      anon_sym_SEMI,
  [42144] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2180), 2,
      sym__newline,
      anon_sym_SEMI,
  [42152] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2182), 2,
      sym__newline,
      anon_sym_SEMI,
  [42160] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2172), 1,
      anon_sym_LPAREN,
    STATE(996), 1,
      sym_parameters,
  [42170] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2172), 1,
      anon_sym_LPAREN,
    STATE(998), 1,
      sym_parameters,
  [42180] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2184), 1,
      anon_sym_COLON,
    ACTIONS(2186), 1,
      anon_sym_DASH_GT,
  [42190] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2188), 1,
      anon_sym_COLON,
    ACTIONS(2190), 1,
      anon_sym_DASH_GT,
  [42200] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2172), 1,
      anon_sym_LPAREN,
    STATE(987), 1,
      sym_parameters,
  [42210] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(851), 2,
      anon_sym_except,
      anon_sym_finally,
  [42218] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(845), 2,
      anon_sym_except,
      anon_sym_finally,
  [42226] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 2,
      anon_sym_except,
      anon_sym_finally,
  [42234] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1970), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [42242] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2150), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [42250] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2192), 2,
      sym__newline,
      anon_sym_SEMI,
  [42258] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2194), 2,
      anon_sym_COLON,
      anon_sym_DASH_GT,
  [42266] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2196), 1,
      anon_sym_COLON,
    ACTIONS(2198), 1,
      anon_sym_DASH_GT,
  [42276] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1678), 2,
      sym__newline,
      anon_sym_SEMI,
  [42284] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2200), 1,
      anon_sym_COLON,
    ACTIONS(2202), 1,
      anon_sym_DASH_GT,
  [42294] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1748), 2,
      sym__newline,
      anon_sym_SEMI,
  [42302] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2204), 2,
      sym__newline,
      anon_sym_SEMI,
  [42310] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1785), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [42318] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2206), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [42326] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1692), 2,
      sym__newline,
      anon_sym_SEMI,
  [42334] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2116), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [42342] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(862), 2,
      anon_sym_except,
      anon_sym_finally,
  [42350] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1862), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [42358] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2208), 2,
      sym__newline,
      anon_sym_SEMI,
  [42366] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2210), 2,
      sym__newline,
      anon_sym_SEMI,
  [42374] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 2,
      anon_sym_COLON,
      anon_sym_DASH_GT,
  [42382] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(841), 2,
      anon_sym_except,
      anon_sym_finally,
  [42390] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2214), 2,
      sym__newline,
      anon_sym_SEMI,
  [42398] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2216), 2,
      sym__newline,
      anon_sym_SEMI,
  [42406] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2218), 1,
      anon_sym_import,
  [42413] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2220), 1,
      sym_identifier,
  [42420] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2222), 1,
      sym_identifier,
  [42427] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2224), 1,
      anon_sym_in,
  [42434] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2226), 1,
      anon_sym_RPAREN,
  [42441] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2228), 1,
      anon_sym_RBRACK,
  [42448] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2230), 1,
      sym_identifier,
  [42455] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2232), 1,
      anon_sym_RBRACE,
  [42462] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2234), 1,
      anon_sym_RBRACE,
  [42469] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2236), 1,
      anon_sym_RPAREN,
  [42476] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2238), 1,
      anon_sym_RBRACE,
  [42483] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1580), 1,
      anon_sym_RPAREN,
  [42490] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2240), 1,
      anon_sym_RBRACE,
  [42497] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1584), 1,
      anon_sym_RPAREN,
  [42504] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2242), 1,
      anon_sym_RBRACE,
  [42511] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2244), 1,
      anon_sym_RPAREN,
  [42518] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2246), 1,
      anon_sym_RBRACE,
  [42525] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2248), 1,
      anon_sym_RBRACE,
  [42532] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2250), 1,
      anon_sym_RPAREN,
  [42539] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2252), 1,
      sym_identifier,
  [42546] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2254), 1,
      anon_sym_RBRACK,
  [42553] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2256), 1,
      anon_sym_RPAREN,
  [42560] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2258), 1,
      anon_sym_import,
  [42567] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2072), 1,
      anon_sym_in,
  [42574] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2260), 1,
      anon_sym_RBRACK,
  [42581] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2262), 1,
      anon_sym_RPAREN,
  [42588] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2264), 1,
      anon_sym_COLON,
  [42595] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1708), 1,
      anon_sym_RBRACE,
  [42602] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2266), 1,
      sym_identifier,
  [42609] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2268), 1,
      anon_sym_import,
  [42616] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1781), 1,
      anon_sym_COLON,
  [42623] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1576), 1,
      anon_sym_RPAREN,
  [42630] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2270), 1,
      anon_sym_COLON,
  [42637] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2272), 1,
      anon_sym_RBRACE,
  [42644] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2274), 1,
      anon_sym_COLON,
  [42651] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2276), 1,
      anon_sym_COLON,
  [42658] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2278), 1,
      anon_sym_in,
  [42665] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2280), 1,
      sym_identifier,
  [42672] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(682), 1,
      anon_sym_def,
  [42679] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2282), 1,
      anon_sym_in,
  [42686] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1704), 1,
      anon_sym_RBRACE,
  [42693] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2284), 1,
      anon_sym_COLON,
  [42700] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2286), 1,
      anon_sym_RBRACK,
  [42707] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2288), 1,
      anon_sym_COLON,
  [42714] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2290), 1,
      anon_sym_in,
  [42721] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2292), 1,
      anon_sym_COLON,
  [42728] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2294), 1,
      anon_sym_RPAREN,
  [42735] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2296), 1,
      anon_sym_RPAREN,
  [42742] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2298), 1,
      sym_identifier,
  [42749] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2300), 1,
      anon_sym_COLON,
  [42756] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2127), 1,
      anon_sym_RBRACE,
  [42763] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2302), 1,
      anon_sym_RBRACE,
  [42770] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2304), 1,
      anon_sym_COLON,
  [42777] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2306), 1,
      anon_sym_for,
  [42784] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1794), 1,
      anon_sym_COLON,
  [42791] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2308), 1,
      anon_sym_RPAREN,
  [42798] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2310), 1,
      sym_identifier,
  [42805] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2312), 1,
      anon_sym_COLON,
  [42812] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2314), 1,
      anon_sym_COLON,
  [42819] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1807), 1,
      anon_sym_COLON,
  [42826] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2316), 1,
      anon_sym_RBRACE,
  [42833] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2318), 1,
      sym_identifier,
  [42840] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2320), 1,
      anon_sym_COLON,
  [42847] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2164), 1,
      anon_sym_in,
  [42854] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2322), 1,
      anon_sym_COLON,
  [42861] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2324), 1,
      anon_sym_COLON,
  [42868] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1726), 1,
      anon_sym_RBRACE,
  [42875] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2326), 1,
      anon_sym_COLON,
  [42882] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2328), 1,
      anon_sym_COLON,
  [42889] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2330), 1,
      anon_sym_COLON,
  [42896] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2332), 1,
      anon_sym_RBRACK,
  [42903] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2334), 1,
      anon_sym_COLON,
  [42910] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2336), 1,
      ts_builtin_sym_end,
  [42917] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2338), 1,
      anon_sym_COLON,
  [42924] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2340), 1,
      anon_sym_RPAREN,
  [42931] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2342), 1,
      sym_identifier,
  [42938] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2344), 1,
      sym_identifier,
  [42945] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2346), 1,
      anon_sym_COLON,
  [42952] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2152), 1,
      anon_sym_in,
  [42959] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2348), 1,
      sym_identifier,
  [42966] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2350), 1,
      sym_identifier,
  [42973] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2352), 1,
      sym_identifier,
  [42980] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2354), 1,
      anon_sym_COLON,
  [42987] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2356), 1,
      anon_sym_RBRACK,
  [42994] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2358), 1,
      anon_sym_RBRACK,
  [43001] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2360), 1,
      anon_sym_COLON,
  [43008] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2362), 1,
      sym_identifier,
  [43015] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2364), 1,
      sym_identifier,
  [43022] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2366), 1,
      anon_sym_COLON,
  [43029] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2009), 1,
      anon_sym_in,
  [43036] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(674), 1,
      anon_sym_def,
  [43043] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2368), 1,
      anon_sym_COLON,
  [43050] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2007), 1,
      anon_sym_in,
  [43057] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2005), 1,
      anon_sym_in,
  [43064] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1762), 1,
      anon_sym_COLON,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(101)] = 0,
  [SMALL_STATE(102)] = 113,
  [SMALL_STATE(103)] = 226,
  [SMALL_STATE(104)] = 341,
  [SMALL_STATE(105)] = 450,
  [SMALL_STATE(106)] = 559,
  [SMALL_STATE(107)] = 672,
  [SMALL_STATE(108)] = 781,
  [SMALL_STATE(109)] = 896,
  [SMALL_STATE(110)] = 1013,
  [SMALL_STATE(111)] = 1111,
  [SMALL_STATE(112)] = 1223,
  [SMALL_STATE(113)] = 1335,
  [SMALL_STATE(114)] = 1447,
  [SMALL_STATE(115)] = 1545,
  [SMALL_STATE(116)] = 1606,
  [SMALL_STATE(117)] = 1705,
  [SMALL_STATE(118)] = 1810,
  [SMALL_STATE(119)] = 1871,
  [SMALL_STATE(120)] = 1932,
  [SMALL_STATE(121)] = 1993,
  [SMALL_STATE(122)] = 2096,
  [SMALL_STATE(123)] = 2199,
  [SMALL_STATE(124)] = 2302,
  [SMALL_STATE(125)] = 2405,
  [SMALL_STATE(126)] = 2466,
  [SMALL_STATE(127)] = 2527,
  [SMALL_STATE(128)] = 2626,
  [SMALL_STATE(129)] = 2687,
  [SMALL_STATE(130)] = 2787,
  [SMALL_STATE(131)] = 2889,
  [SMALL_STATE(132)] = 2993,
  [SMALL_STATE(133)] = 3093,
  [SMALL_STATE(134)] = 3195,
  [SMALL_STATE(135)] = 3291,
  [SMALL_STATE(136)] = 3391,
  [SMALL_STATE(137)] = 3491,
  [SMALL_STATE(138)] = 3591,
  [SMALL_STATE(139)] = 3691,
  [SMALL_STATE(140)] = 3791,
  [SMALL_STATE(141)] = 3891,
  [SMALL_STATE(142)] = 3991,
  [SMALL_STATE(143)] = 4091,
  [SMALL_STATE(144)] = 4191,
  [SMALL_STATE(145)] = 4293,
  [SMALL_STATE(146)] = 4395,
  [SMALL_STATE(147)] = 4495,
  [SMALL_STATE(148)] = 4599,
  [SMALL_STATE(149)] = 4699,
  [SMALL_STATE(150)] = 4799,
  [SMALL_STATE(151)] = 4899,
  [SMALL_STATE(152)] = 4999,
  [SMALL_STATE(153)] = 5095,
  [SMALL_STATE(154)] = 5191,
  [SMALL_STATE(155)] = 5287,
  [SMALL_STATE(156)] = 5382,
  [SMALL_STATE(157)] = 5479,
  [SMALL_STATE(158)] = 5569,
  [SMALL_STATE(159)] = 5663,
  [SMALL_STATE(160)] = 5733,
  [SMALL_STATE(161)] = 5823,
  [SMALL_STATE(162)] = 5893,
  [SMALL_STATE(163)] = 5962,
  [SMALL_STATE(164)] = 6055,
  [SMALL_STATE(165)] = 6124,
  [SMALL_STATE(166)] = 6193,
  [SMALL_STATE(167)] = 6286,
  [SMALL_STATE(168)] = 6379,
  [SMALL_STATE(169)] = 6446,
  [SMALL_STATE(170)] = 6539,
  [SMALL_STATE(171)] = 6632,
  [SMALL_STATE(172)] = 6701,
  [SMALL_STATE(173)] = 6794,
  [SMALL_STATE(174)] = 6887,
  [SMALL_STATE(175)] = 6980,
  [SMALL_STATE(176)] = 7036,
  [SMALL_STATE(177)] = 7128,
  [SMALL_STATE(178)] = 7184,
  [SMALL_STATE(179)] = 7240,
  [SMALL_STATE(180)] = 7332,
  [SMALL_STATE(181)] = 7424,
  [SMALL_STATE(182)] = 7480,
  [SMALL_STATE(183)] = 7570,
  [SMALL_STATE(184)] = 7662,
  [SMALL_STATE(185)] = 7754,
  [SMALL_STATE(186)] = 7844,
  [SMALL_STATE(187)] = 7900,
  [SMALL_STATE(188)] = 7992,
  [SMALL_STATE(189)] = 8048,
  [SMALL_STATE(190)] = 8140,
  [SMALL_STATE(191)] = 8232,
  [SMALL_STATE(192)] = 8324,
  [SMALL_STATE(193)] = 8414,
  [SMALL_STATE(194)] = 8504,
  [SMALL_STATE(195)] = 8594,
  [SMALL_STATE(196)] = 8650,
  [SMALL_STATE(197)] = 8714,
  [SMALL_STATE(198)] = 8804,
  [SMALL_STATE(199)] = 8893,
  [SMALL_STATE(200)] = 8958,
  [SMALL_STATE(201)] = 9045,
  [SMALL_STATE(202)] = 9110,
  [SMALL_STATE(203)] = 9197,
  [SMALL_STATE(204)] = 9284,
  [SMALL_STATE(205)] = 9371,
  [SMALL_STATE(206)] = 9458,
  [SMALL_STATE(207)] = 9523,
  [SMALL_STATE(208)] = 9588,
  [SMALL_STATE(209)] = 9653,
  [SMALL_STATE(210)] = 9740,
  [SMALL_STATE(211)] = 9801,
  [SMALL_STATE(212)] = 9888,
  [SMALL_STATE(213)] = 9947,
  [SMALL_STATE(214)] = 10034,
  [SMALL_STATE(215)] = 10095,
  [SMALL_STATE(216)] = 10156,
  [SMALL_STATE(217)] = 10243,
  [SMALL_STATE(218)] = 10332,
  [SMALL_STATE(219)] = 10419,
  [SMALL_STATE(220)] = 10484,
  [SMALL_STATE(221)] = 10573,
  [SMALL_STATE(222)] = 10638,
  [SMALL_STATE(223)] = 10699,
  [SMALL_STATE(224)] = 10788,
  [SMALL_STATE(225)] = 10877,
  [SMALL_STATE(226)] = 10964,
  [SMALL_STATE(227)] = 11053,
  [SMALL_STATE(228)] = 11142,
  [SMALL_STATE(229)] = 11231,
  [SMALL_STATE(230)] = 11296,
  [SMALL_STATE(231)] = 11383,
  [SMALL_STATE(232)] = 11470,
  [SMALL_STATE(233)] = 11529,
  [SMALL_STATE(234)] = 11616,
  [SMALL_STATE(235)] = 11670,
  [SMALL_STATE(236)] = 11756,
  [SMALL_STATE(237)] = 11810,
  [SMALL_STATE(238)] = 11864,
  [SMALL_STATE(239)] = 11950,
  [SMALL_STATE(240)] = 12036,
  [SMALL_STATE(241)] = 12096,
  [SMALL_STATE(242)] = 12150,
  [SMALL_STATE(243)] = 12236,
  [SMALL_STATE(244)] = 12322,
  [SMALL_STATE(245)] = 12408,
  [SMALL_STATE(246)] = 12494,
  [SMALL_STATE(247)] = 12580,
  [SMALL_STATE(248)] = 12634,
  [SMALL_STATE(249)] = 12688,
  [SMALL_STATE(250)] = 12774,
  [SMALL_STATE(251)] = 12828,
  [SMALL_STATE(252)] = 12882,
  [SMALL_STATE(253)] = 12968,
  [SMALL_STATE(254)] = 13028,
  [SMALL_STATE(255)] = 13114,
  [SMALL_STATE(256)] = 13200,
  [SMALL_STATE(257)] = 13286,
  [SMALL_STATE(258)] = 13372,
  [SMALL_STATE(259)] = 13426,
  [SMALL_STATE(260)] = 13512,
  [SMALL_STATE(261)] = 13566,
  [SMALL_STATE(262)] = 13649,
  [SMALL_STATE(263)] = 13732,
  [SMALL_STATE(264)] = 13815,
  [SMALL_STATE(265)] = 13898,
  [SMALL_STATE(266)] = 13981,
  [SMALL_STATE(267)] = 14064,
  [SMALL_STATE(268)] = 14147,
  [SMALL_STATE(269)] = 14230,
  [SMALL_STATE(270)] = 14283,
  [SMALL_STATE(271)] = 14366,
  [SMALL_STATE(272)] = 14449,
  [SMALL_STATE(273)] = 14532,
  [SMALL_STATE(274)] = 14585,
  [SMALL_STATE(275)] = 14668,
  [SMALL_STATE(276)] = 14751,
  [SMALL_STATE(277)] = 14834,
  [SMALL_STATE(278)] = 14917,
  [SMALL_STATE(279)] = 15000,
  [SMALL_STATE(280)] = 15083,
  [SMALL_STATE(281)] = 15166,
  [SMALL_STATE(282)] = 15249,
  [SMALL_STATE(283)] = 15332,
  [SMALL_STATE(284)] = 15415,
  [SMALL_STATE(285)] = 15498,
  [SMALL_STATE(286)] = 15551,
  [SMALL_STATE(287)] = 15634,
  [SMALL_STATE(288)] = 15717,
  [SMALL_STATE(289)] = 15800,
  [SMALL_STATE(290)] = 15883,
  [SMALL_STATE(291)] = 15936,
  [SMALL_STATE(292)] = 16019,
  [SMALL_STATE(293)] = 16102,
  [SMALL_STATE(294)] = 16185,
  [SMALL_STATE(295)] = 16268,
  [SMALL_STATE(296)] = 16351,
  [SMALL_STATE(297)] = 16434,
  [SMALL_STATE(298)] = 16517,
  [SMALL_STATE(299)] = 16570,
  [SMALL_STATE(300)] = 16653,
  [SMALL_STATE(301)] = 16736,
  [SMALL_STATE(302)] = 16819,
  [SMALL_STATE(303)] = 16902,
  [SMALL_STATE(304)] = 16985,
  [SMALL_STATE(305)] = 17068,
  [SMALL_STATE(306)] = 17121,
  [SMALL_STATE(307)] = 17204,
  [SMALL_STATE(308)] = 17287,
  [SMALL_STATE(309)] = 17340,
  [SMALL_STATE(310)] = 17425,
  [SMALL_STATE(311)] = 17508,
  [SMALL_STATE(312)] = 17561,
  [SMALL_STATE(313)] = 17644,
  [SMALL_STATE(314)] = 17697,
  [SMALL_STATE(315)] = 17780,
  [SMALL_STATE(316)] = 17863,
  [SMALL_STATE(317)] = 17916,
  [SMALL_STATE(318)] = 17969,
  [SMALL_STATE(319)] = 18052,
  [SMALL_STATE(320)] = 18135,
  [SMALL_STATE(321)] = 18218,
  [SMALL_STATE(322)] = 18301,
  [SMALL_STATE(323)] = 18354,
  [SMALL_STATE(324)] = 18437,
  [SMALL_STATE(325)] = 18520,
  [SMALL_STATE(326)] = 18603,
  [SMALL_STATE(327)] = 18686,
  [SMALL_STATE(328)] = 18769,
  [SMALL_STATE(329)] = 18852,
  [SMALL_STATE(330)] = 18935,
  [SMALL_STATE(331)] = 19018,
  [SMALL_STATE(332)] = 19101,
  [SMALL_STATE(333)] = 19184,
  [SMALL_STATE(334)] = 19267,
  [SMALL_STATE(335)] = 19350,
  [SMALL_STATE(336)] = 19402,
  [SMALL_STATE(337)] = 19458,
  [SMALL_STATE(338)] = 19514,
  [SMALL_STATE(339)] = 19566,
  [SMALL_STATE(340)] = 19622,
  [SMALL_STATE(341)] = 19674,
  [SMALL_STATE(342)] = 19730,
  [SMALL_STATE(343)] = 19786,
  [SMALL_STATE(344)] = 19842,
  [SMALL_STATE(345)] = 19898,
  [SMALL_STATE(346)] = 19954,
  [SMALL_STATE(347)] = 20010,
  [SMALL_STATE(348)] = 20066,
  [SMALL_STATE(349)] = 20122,
  [SMALL_STATE(350)] = 20174,
  [SMALL_STATE(351)] = 20230,
  [SMALL_STATE(352)] = 20286,
  [SMALL_STATE(353)] = 20342,
  [SMALL_STATE(354)] = 20394,
  [SMALL_STATE(355)] = 20450,
  [SMALL_STATE(356)] = 20506,
  [SMALL_STATE(357)] = 20558,
  [SMALL_STATE(358)] = 20609,
  [SMALL_STATE(359)] = 20660,
  [SMALL_STATE(360)] = 20711,
  [SMALL_STATE(361)] = 20766,
  [SMALL_STATE(362)] = 20821,
  [SMALL_STATE(363)] = 20872,
  [SMALL_STATE(364)] = 20927,
  [SMALL_STATE(365)] = 20977,
  [SMALL_STATE(366)] = 21027,
  [SMALL_STATE(367)] = 21077,
  [SMALL_STATE(368)] = 21127,
  [SMALL_STATE(369)] = 21177,
  [SMALL_STATE(370)] = 21227,
  [SMALL_STATE(371)] = 21277,
  [SMALL_STATE(372)] = 21327,
  [SMALL_STATE(373)] = 21377,
  [SMALL_STATE(374)] = 21427,
  [SMALL_STATE(375)] = 21477,
  [SMALL_STATE(376)] = 21527,
  [SMALL_STATE(377)] = 21577,
  [SMALL_STATE(378)] = 21627,
  [SMALL_STATE(379)] = 21677,
  [SMALL_STATE(380)] = 21727,
  [SMALL_STATE(381)] = 21777,
  [SMALL_STATE(382)] = 21827,
  [SMALL_STATE(383)] = 21877,
  [SMALL_STATE(384)] = 21927,
  [SMALL_STATE(385)] = 21977,
  [SMALL_STATE(386)] = 22027,
  [SMALL_STATE(387)] = 22077,
  [SMALL_STATE(388)] = 22127,
  [SMALL_STATE(389)] = 22177,
  [SMALL_STATE(390)] = 22227,
  [SMALL_STATE(391)] = 22277,
  [SMALL_STATE(392)] = 22327,
  [SMALL_STATE(393)] = 22377,
  [SMALL_STATE(394)] = 22427,
  [SMALL_STATE(395)] = 22477,
  [SMALL_STATE(396)] = 22527,
  [SMALL_STATE(397)] = 22577,
  [SMALL_STATE(398)] = 22627,
  [SMALL_STATE(399)] = 22677,
  [SMALL_STATE(400)] = 22727,
  [SMALL_STATE(401)] = 22777,
  [SMALL_STATE(402)] = 22827,
  [SMALL_STATE(403)] = 22877,
  [SMALL_STATE(404)] = 22927,
  [SMALL_STATE(405)] = 22977,
  [SMALL_STATE(406)] = 23059,
  [SMALL_STATE(407)] = 23109,
  [SMALL_STATE(408)] = 23159,
  [SMALL_STATE(409)] = 23209,
  [SMALL_STATE(410)] = 23259,
  [SMALL_STATE(411)] = 23309,
  [SMALL_STATE(412)] = 23359,
  [SMALL_STATE(413)] = 23409,
  [SMALL_STATE(414)] = 23459,
  [SMALL_STATE(415)] = 23509,
  [SMALL_STATE(416)] = 23559,
  [SMALL_STATE(417)] = 23609,
  [SMALL_STATE(418)] = 23659,
  [SMALL_STATE(419)] = 23709,
  [SMALL_STATE(420)] = 23759,
  [SMALL_STATE(421)] = 23809,
  [SMALL_STATE(422)] = 23889,
  [SMALL_STATE(423)] = 23939,
  [SMALL_STATE(424)] = 23989,
  [SMALL_STATE(425)] = 24039,
  [SMALL_STATE(426)] = 24089,
  [SMALL_STATE(427)] = 24139,
  [SMALL_STATE(428)] = 24219,
  [SMALL_STATE(429)] = 24269,
  [SMALL_STATE(430)] = 24319,
  [SMALL_STATE(431)] = 24369,
  [SMALL_STATE(432)] = 24419,
  [SMALL_STATE(433)] = 24469,
  [SMALL_STATE(434)] = 24519,
  [SMALL_STATE(435)] = 24569,
  [SMALL_STATE(436)] = 24619,
  [SMALL_STATE(437)] = 24669,
  [SMALL_STATE(438)] = 24748,
  [SMALL_STATE(439)] = 24797,
  [SMALL_STATE(440)] = 24876,
  [SMALL_STATE(441)] = 24955,
  [SMALL_STATE(442)] = 25034,
  [SMALL_STATE(443)] = 25083,
  [SMALL_STATE(444)] = 25162,
  [SMALL_STATE(445)] = 25241,
  [SMALL_STATE(446)] = 25289,
  [SMALL_STATE(447)] = 25337,
  [SMALL_STATE(448)] = 25419,
  [SMALL_STATE(449)] = 25501,
  [SMALL_STATE(450)] = 25549,
  [SMALL_STATE(451)] = 25597,
  [SMALL_STATE(452)] = 25645,
  [SMALL_STATE(453)] = 25693,
  [SMALL_STATE(454)] = 25741,
  [SMALL_STATE(455)] = 25789,
  [SMALL_STATE(456)] = 25837,
  [SMALL_STATE(457)] = 25885,
  [SMALL_STATE(458)] = 25933,
  [SMALL_STATE(459)] = 25981,
  [SMALL_STATE(460)] = 26029,
  [SMALL_STATE(461)] = 26077,
  [SMALL_STATE(462)] = 26125,
  [SMALL_STATE(463)] = 26173,
  [SMALL_STATE(464)] = 26249,
  [SMALL_STATE(465)] = 26325,
  [SMALL_STATE(466)] = 26373,
  [SMALL_STATE(467)] = 26421,
  [SMALL_STATE(468)] = 26469,
  [SMALL_STATE(469)] = 26517,
  [SMALL_STATE(470)] = 26565,
  [SMALL_STATE(471)] = 26622,
  [SMALL_STATE(472)] = 26689,
  [SMALL_STATE(473)] = 26758,
  [SMALL_STATE(474)] = 26821,
  [SMALL_STATE(475)] = 26886,
  [SMALL_STATE(476)] = 26951,
  [SMALL_STATE(477)] = 27022,
  [SMALL_STATE(478)] = 27089,
  [SMALL_STATE(479)] = 27158,
  [SMALL_STATE(480)] = 27215,
  [SMALL_STATE(481)] = 27272,
  [SMALL_STATE(482)] = 27333,
  [SMALL_STATE(483)] = 27404,
  [SMALL_STATE(484)] = 27465,
  [SMALL_STATE(485)] = 27522,
  [SMALL_STATE(486)] = 27585,
  [SMALL_STATE(487)] = 27656,
  [SMALL_STATE(488)] = 27713,
  [SMALL_STATE(489)] = 27784,
  [SMALL_STATE(490)] = 27841,
  [SMALL_STATE(491)] = 27889,
  [SMALL_STATE(492)] = 27935,
  [SMALL_STATE(493)] = 27981,
  [SMALL_STATE(494)] = 28051,
  [SMALL_STATE(495)] = 28097,
  [SMALL_STATE(496)] = 28145,
  [SMALL_STATE(497)] = 28190,
  [SMALL_STATE(498)] = 28235,
  [SMALL_STATE(499)] = 28284,
  [SMALL_STATE(500)] = 28329,
  [SMALL_STATE(501)] = 28408,
  [SMALL_STATE(502)] = 28457,
  [SMALL_STATE(503)] = 28506,
  [SMALL_STATE(504)] = 28574,
  [SMALL_STATE(505)] = 28650,
  [SMALL_STATE(506)] = 28704,
  [SMALL_STATE(507)] = 28752,
  [SMALL_STATE(508)] = 28816,
  [SMALL_STATE(509)] = 28884,
  [SMALL_STATE(510)] = 28938,
  [SMALL_STATE(511)] = 28998,
  [SMALL_STATE(512)] = 29052,
  [SMALL_STATE(513)] = 29116,
  [SMALL_STATE(514)] = 29178,
  [SMALL_STATE(515)] = 29242,
  [SMALL_STATE(516)] = 29308,
  [SMALL_STATE(517)] = 29366,
  [SMALL_STATE(518)] = 29414,
  [SMALL_STATE(519)] = 29462,
  [SMALL_STATE(520)] = 29526,
  [SMALL_STATE(521)] = 29590,
  [SMALL_STATE(522)] = 29651,
  [SMALL_STATE(523)] = 29696,
  [SMALL_STATE(524)] = 29741,
  [SMALL_STATE(525)] = 29786,
  [SMALL_STATE(526)] = 29839,
  [SMALL_STATE(527)] = 29900,
  [SMALL_STATE(528)] = 29961,
  [SMALL_STATE(529)] = 30022,
  [SMALL_STATE(530)] = 30083,
  [SMALL_STATE(531)] = 30144,
  [SMALL_STATE(532)] = 30205,
  [SMALL_STATE(533)] = 30266,
  [SMALL_STATE(534)] = 30327,
  [SMALL_STATE(535)] = 30374,
  [SMALL_STATE(536)] = 30435,
  [SMALL_STATE(537)] = 30496,
  [SMALL_STATE(538)] = 30557,
  [SMALL_STATE(539)] = 30618,
  [SMALL_STATE(540)] = 30679,
  [SMALL_STATE(541)] = 30740,
  [SMALL_STATE(542)] = 30801,
  [SMALL_STATE(543)] = 30862,
  [SMALL_STATE(544)] = 30923,
  [SMALL_STATE(545)] = 30984,
  [SMALL_STATE(546)] = 31045,
  [SMALL_STATE(547)] = 31106,
  [SMALL_STATE(548)] = 31167,
  [SMALL_STATE(549)] = 31228,
  [SMALL_STATE(550)] = 31289,
  [SMALL_STATE(551)] = 31350,
  [SMALL_STATE(552)] = 31411,
  [SMALL_STATE(553)] = 31472,
  [SMALL_STATE(554)] = 31533,
  [SMALL_STATE(555)] = 31586,
  [SMALL_STATE(556)] = 31645,
  [SMALL_STATE(557)] = 31712,
  [SMALL_STATE(558)] = 31765,
  [SMALL_STATE(559)] = 31826,
  [SMALL_STATE(560)] = 31883,
  [SMALL_STATE(561)] = 31944,
  [SMALL_STATE(562)] = 32009,
  [SMALL_STATE(563)] = 32072,
  [SMALL_STATE(564)] = 32133,
  [SMALL_STATE(565)] = 32176,
  [SMALL_STATE(566)] = 32221,
  [SMALL_STATE(567)] = 32282,
  [SMALL_STATE(568)] = 32349,
  [SMALL_STATE(569)] = 32394,
  [SMALL_STATE(570)] = 32455,
  [SMALL_STATE(571)] = 32498,
  [SMALL_STATE(572)] = 32559,
  [SMALL_STATE(573)] = 32604,
  [SMALL_STATE(574)] = 32649,
  [SMALL_STATE(575)] = 32710,
  [SMALL_STATE(576)] = 32771,
  [SMALL_STATE(577)] = 32832,
  [SMALL_STATE(578)] = 32893,
  [SMALL_STATE(579)] = 32954,
  [SMALL_STATE(580)] = 33015,
  [SMALL_STATE(581)] = 33076,
  [SMALL_STATE(582)] = 33137,
  [SMALL_STATE(583)] = 33202,
  [SMALL_STATE(584)] = 33267,
  [SMALL_STATE(585)] = 33314,
  [SMALL_STATE(586)] = 33356,
  [SMALL_STATE(587)] = 33398,
  [SMALL_STATE(588)] = 33440,
  [SMALL_STATE(589)] = 33484,
  [SMALL_STATE(590)] = 33528,
  [SMALL_STATE(591)] = 33570,
  [SMALL_STATE(592)] = 33614,
  [SMALL_STATE(593)] = 33656,
  [SMALL_STATE(594)] = 33698,
  [SMALL_STATE(595)] = 33742,
  [SMALL_STATE(596)] = 33784,
  [SMALL_STATE(597)] = 33826,
  [SMALL_STATE(598)] = 33868,
  [SMALL_STATE(599)] = 33910,
  [SMALL_STATE(600)] = 33952,
  [SMALL_STATE(601)] = 33994,
  [SMALL_STATE(602)] = 34038,
  [SMALL_STATE(603)] = 34080,
  [SMALL_STATE(604)] = 34122,
  [SMALL_STATE(605)] = 34164,
  [SMALL_STATE(606)] = 34206,
  [SMALL_STATE(607)] = 34248,
  [SMALL_STATE(608)] = 34290,
  [SMALL_STATE(609)] = 34332,
  [SMALL_STATE(610)] = 34374,
  [SMALL_STATE(611)] = 34416,
  [SMALL_STATE(612)] = 34458,
  [SMALL_STATE(613)] = 34500,
  [SMALL_STATE(614)] = 34544,
  [SMALL_STATE(615)] = 34586,
  [SMALL_STATE(616)] = 34628,
  [SMALL_STATE(617)] = 34670,
  [SMALL_STATE(618)] = 34711,
  [SMALL_STATE(619)] = 34752,
  [SMALL_STATE(620)] = 34793,
  [SMALL_STATE(621)] = 34834,
  [SMALL_STATE(622)] = 34875,
  [SMALL_STATE(623)] = 34916,
  [SMALL_STATE(624)] = 34957,
  [SMALL_STATE(625)] = 35002,
  [SMALL_STATE(626)] = 35043,
  [SMALL_STATE(627)] = 35088,
  [SMALL_STATE(628)] = 35129,
  [SMALL_STATE(629)] = 35170,
  [SMALL_STATE(630)] = 35211,
  [SMALL_STATE(631)] = 35252,
  [SMALL_STATE(632)] = 35293,
  [SMALL_STATE(633)] = 35334,
  [SMALL_STATE(634)] = 35375,
  [SMALL_STATE(635)] = 35416,
  [SMALL_STATE(636)] = 35457,
  [SMALL_STATE(637)] = 35498,
  [SMALL_STATE(638)] = 35539,
  [SMALL_STATE(639)] = 35580,
  [SMALL_STATE(640)] = 35621,
  [SMALL_STATE(641)] = 35662,
  [SMALL_STATE(642)] = 35703,
  [SMALL_STATE(643)] = 35744,
  [SMALL_STATE(644)] = 35785,
  [SMALL_STATE(645)] = 35826,
  [SMALL_STATE(646)] = 35867,
  [SMALL_STATE(647)] = 35908,
  [SMALL_STATE(648)] = 35950,
  [SMALL_STATE(649)] = 35992,
  [SMALL_STATE(650)] = 36032,
  [SMALL_STATE(651)] = 36072,
  [SMALL_STATE(652)] = 36112,
  [SMALL_STATE(653)] = 36152,
  [SMALL_STATE(654)] = 36182,
  [SMALL_STATE(655)] = 36219,
  [SMALL_STATE(656)] = 36248,
  [SMALL_STATE(657)] = 36273,
  [SMALL_STATE(658)] = 36298,
  [SMALL_STATE(659)] = 36327,
  [SMALL_STATE(660)] = 36364,
  [SMALL_STATE(661)] = 36389,
  [SMALL_STATE(662)] = 36438,
  [SMALL_STATE(663)] = 36463,
  [SMALL_STATE(664)] = 36497,
  [SMALL_STATE(665)] = 36531,
  [SMALL_STATE(666)] = 36559,
  [SMALL_STATE(667)] = 36605,
  [SMALL_STATE(668)] = 36636,
  [SMALL_STATE(669)] = 36661,
  [SMALL_STATE(670)] = 36699,
  [SMALL_STATE(671)] = 36737,
  [SMALL_STATE(672)] = 36775,
  [SMALL_STATE(673)] = 36813,
  [SMALL_STATE(674)] = 36835,
  [SMALL_STATE(675)] = 36873,
  [SMALL_STATE(676)] = 36895,
  [SMALL_STATE(677)] = 36917,
  [SMALL_STATE(678)] = 36952,
  [SMALL_STATE(679)] = 36984,
  [SMALL_STATE(680)] = 37016,
  [SMALL_STATE(681)] = 37048,
  [SMALL_STATE(682)] = 37080,
  [SMALL_STATE(683)] = 37101,
  [SMALL_STATE(684)] = 37138,
  [SMALL_STATE(685)] = 37161,
  [SMALL_STATE(686)] = 37182,
  [SMALL_STATE(687)] = 37211,
  [SMALL_STATE(688)] = 37236,
  [SMALL_STATE(689)] = 37255,
  [SMALL_STATE(690)] = 37280,
  [SMALL_STATE(691)] = 37303,
  [SMALL_STATE(692)] = 37326,
  [SMALL_STATE(693)] = 37363,
  [SMALL_STATE(694)] = 37386,
  [SMALL_STATE(695)] = 37407,
  [SMALL_STATE(696)] = 37444,
  [SMALL_STATE(697)] = 37481,
  [SMALL_STATE(698)] = 37504,
  [SMALL_STATE(699)] = 37529,
  [SMALL_STATE(700)] = 37558,
  [SMALL_STATE(701)] = 37592,
  [SMALL_STATE(702)] = 37616,
  [SMALL_STATE(703)] = 37640,
  [SMALL_STATE(704)] = 37664,
  [SMALL_STATE(705)] = 37688,
  [SMALL_STATE(706)] = 37712,
  [SMALL_STATE(707)] = 37746,
  [SMALL_STATE(708)] = 37770,
  [SMALL_STATE(709)] = 37794,
  [SMALL_STATE(710)] = 37828,
  [SMALL_STATE(711)] = 37852,
  [SMALL_STATE(712)] = 37886,
  [SMALL_STATE(713)] = 37920,
  [SMALL_STATE(714)] = 37954,
  [SMALL_STATE(715)] = 37988,
  [SMALL_STATE(716)] = 38022,
  [SMALL_STATE(717)] = 38056,
  [SMALL_STATE(718)] = 38080,
  [SMALL_STATE(719)] = 38099,
  [SMALL_STATE(720)] = 38122,
  [SMALL_STATE(721)] = 38141,
  [SMALL_STATE(722)] = 38160,
  [SMALL_STATE(723)] = 38183,
  [SMALL_STATE(724)] = 38206,
  [SMALL_STATE(725)] = 38224,
  [SMALL_STATE(726)] = 38238,
  [SMALL_STATE(727)] = 38256,
  [SMALL_STATE(728)] = 38274,
  [SMALL_STATE(729)] = 38294,
  [SMALL_STATE(730)] = 38310,
  [SMALL_STATE(731)] = 38328,
  [SMALL_STATE(732)] = 38352,
  [SMALL_STATE(733)] = 38366,
  [SMALL_STATE(734)] = 38390,
  [SMALL_STATE(735)] = 38410,
  [SMALL_STATE(736)] = 38428,
  [SMALL_STATE(737)] = 38446,
  [SMALL_STATE(738)] = 38460,
  [SMALL_STATE(739)] = 38480,
  [SMALL_STATE(740)] = 38498,
  [SMALL_STATE(741)] = 38522,
  [SMALL_STATE(742)] = 38540,
  [SMALL_STATE(743)] = 38566,
  [SMALL_STATE(744)] = 38586,
  [SMALL_STATE(745)] = 38605,
  [SMALL_STATE(746)] = 38624,
  [SMALL_STATE(747)] = 38649,
  [SMALL_STATE(748)] = 38668,
  [SMALL_STATE(749)] = 38691,
  [SMALL_STATE(750)] = 38712,
  [SMALL_STATE(751)] = 38725,
  [SMALL_STATE(752)] = 38748,
  [SMALL_STATE(753)] = 38767,
  [SMALL_STATE(754)] = 38786,
  [SMALL_STATE(755)] = 38799,
  [SMALL_STATE(756)] = 38822,
  [SMALL_STATE(757)] = 38841,
  [SMALL_STATE(758)] = 38864,
  [SMALL_STATE(759)] = 38887,
  [SMALL_STATE(760)] = 38906,
  [SMALL_STATE(761)] = 38925,
  [SMALL_STATE(762)] = 38948,
  [SMALL_STATE(763)] = 38961,
  [SMALL_STATE(764)] = 38974,
  [SMALL_STATE(765)] = 38999,
  [SMALL_STATE(766)] = 39024,
  [SMALL_STATE(767)] = 39047,
  [SMALL_STATE(768)] = 39060,
  [SMALL_STATE(769)] = 39077,
  [SMALL_STATE(770)] = 39092,
  [SMALL_STATE(771)] = 39105,
  [SMALL_STATE(772)] = 39120,
  [SMALL_STATE(773)] = 39137,
  [SMALL_STATE(774)] = 39162,
  [SMALL_STATE(775)] = 39187,
  [SMALL_STATE(776)] = 39212,
  [SMALL_STATE(777)] = 39237,
  [SMALL_STATE(778)] = 39262,
  [SMALL_STATE(779)] = 39277,
  [SMALL_STATE(780)] = 39296,
  [SMALL_STATE(781)] = 39319,
  [SMALL_STATE(782)] = 39342,
  [SMALL_STATE(783)] = 39357,
  [SMALL_STATE(784)] = 39379,
  [SMALL_STATE(785)] = 39395,
  [SMALL_STATE(786)] = 39413,
  [SMALL_STATE(787)] = 39429,
  [SMALL_STATE(788)] = 39449,
  [SMALL_STATE(789)] = 39467,
  [SMALL_STATE(790)] = 39489,
  [SMALL_STATE(791)] = 39507,
  [SMALL_STATE(792)] = 39527,
  [SMALL_STATE(793)] = 39543,
  [SMALL_STATE(794)] = 39563,
  [SMALL_STATE(795)] = 39585,
  [SMALL_STATE(796)] = 39601,
  [SMALL_STATE(797)] = 39617,
  [SMALL_STATE(798)] = 39637,
  [SMALL_STATE(799)] = 39653,
  [SMALL_STATE(800)] = 39669,
  [SMALL_STATE(801)] = 39685,
  [SMALL_STATE(802)] = 39703,
  [SMALL_STATE(803)] = 39721,
  [SMALL_STATE(804)] = 39743,
  [SMALL_STATE(805)] = 39765,
  [SMALL_STATE(806)] = 39783,
  [SMALL_STATE(807)] = 39799,
  [SMALL_STATE(808)] = 39819,
  [SMALL_STATE(809)] = 39836,
  [SMALL_STATE(810)] = 39853,
  [SMALL_STATE(811)] = 39864,
  [SMALL_STATE(812)] = 39879,
  [SMALL_STATE(813)] = 39896,
  [SMALL_STATE(814)] = 39913,
  [SMALL_STATE(815)] = 39930,
  [SMALL_STATE(816)] = 39947,
  [SMALL_STATE(817)] = 39964,
  [SMALL_STATE(818)] = 39983,
  [SMALL_STATE(819)] = 40000,
  [SMALL_STATE(820)] = 40011,
  [SMALL_STATE(821)] = 40026,
  [SMALL_STATE(822)] = 40041,
  [SMALL_STATE(823)] = 40058,
  [SMALL_STATE(824)] = 40075,
  [SMALL_STATE(825)] = 40092,
  [SMALL_STATE(826)] = 40109,
  [SMALL_STATE(827)] = 40126,
  [SMALL_STATE(828)] = 40143,
  [SMALL_STATE(829)] = 40160,
  [SMALL_STATE(830)] = 40175,
  [SMALL_STATE(831)] = 40192,
  [SMALL_STATE(832)] = 40207,
  [SMALL_STATE(833)] = 40224,
  [SMALL_STATE(834)] = 40241,
  [SMALL_STATE(835)] = 40258,
  [SMALL_STATE(836)] = 40275,
  [SMALL_STATE(837)] = 40292,
  [SMALL_STATE(838)] = 40308,
  [SMALL_STATE(839)] = 40324,
  [SMALL_STATE(840)] = 40338,
  [SMALL_STATE(841)] = 40352,
  [SMALL_STATE(842)] = 40366,
  [SMALL_STATE(843)] = 40382,
  [SMALL_STATE(844)] = 40398,
  [SMALL_STATE(845)] = 40412,
  [SMALL_STATE(846)] = 40426,
  [SMALL_STATE(847)] = 40440,
  [SMALL_STATE(848)] = 40454,
  [SMALL_STATE(849)] = 40470,
  [SMALL_STATE(850)] = 40486,
  [SMALL_STATE(851)] = 40502,
  [SMALL_STATE(852)] = 40518,
  [SMALL_STATE(853)] = 40532,
  [SMALL_STATE(854)] = 40548,
  [SMALL_STATE(855)] = 40564,
  [SMALL_STATE(856)] = 40578,
  [SMALL_STATE(857)] = 40590,
  [SMALL_STATE(858)] = 40600,
  [SMALL_STATE(859)] = 40614,
  [SMALL_STATE(860)] = 40628,
  [SMALL_STATE(861)] = 40642,
  [SMALL_STATE(862)] = 40656,
  [SMALL_STATE(863)] = 40672,
  [SMALL_STATE(864)] = 40688,
  [SMALL_STATE(865)] = 40704,
  [SMALL_STATE(866)] = 40720,
  [SMALL_STATE(867)] = 40736,
  [SMALL_STATE(868)] = 40752,
  [SMALL_STATE(869)] = 40768,
  [SMALL_STATE(870)] = 40782,
  [SMALL_STATE(871)] = 40796,
  [SMALL_STATE(872)] = 40806,
  [SMALL_STATE(873)] = 40822,
  [SMALL_STATE(874)] = 40832,
  [SMALL_STATE(875)] = 40848,
  [SMALL_STATE(876)] = 40858,
  [SMALL_STATE(877)] = 40872,
  [SMALL_STATE(878)] = 40884,
  [SMALL_STATE(879)] = 40898,
  [SMALL_STATE(880)] = 40912,
  [SMALL_STATE(881)] = 40926,
  [SMALL_STATE(882)] = 40940,
  [SMALL_STATE(883)] = 40956,
  [SMALL_STATE(884)] = 40970,
  [SMALL_STATE(885)] = 40986,
  [SMALL_STATE(886)] = 40996,
  [SMALL_STATE(887)] = 41010,
  [SMALL_STATE(888)] = 41023,
  [SMALL_STATE(889)] = 41032,
  [SMALL_STATE(890)] = 41043,
  [SMALL_STATE(891)] = 41056,
  [SMALL_STATE(892)] = 41069,
  [SMALL_STATE(893)] = 41082,
  [SMALL_STATE(894)] = 41095,
  [SMALL_STATE(895)] = 41108,
  [SMALL_STATE(896)] = 41121,
  [SMALL_STATE(897)] = 41130,
  [SMALL_STATE(898)] = 41143,
  [SMALL_STATE(899)] = 41156,
  [SMALL_STATE(900)] = 41169,
  [SMALL_STATE(901)] = 41182,
  [SMALL_STATE(902)] = 41195,
  [SMALL_STATE(903)] = 41206,
  [SMALL_STATE(904)] = 41219,
  [SMALL_STATE(905)] = 41232,
  [SMALL_STATE(906)] = 41245,
  [SMALL_STATE(907)] = 41256,
  [SMALL_STATE(908)] = 41269,
  [SMALL_STATE(909)] = 41282,
  [SMALL_STATE(910)] = 41295,
  [SMALL_STATE(911)] = 41308,
  [SMALL_STATE(912)] = 41321,
  [SMALL_STATE(913)] = 41334,
  [SMALL_STATE(914)] = 41347,
  [SMALL_STATE(915)] = 41360,
  [SMALL_STATE(916)] = 41373,
  [SMALL_STATE(917)] = 41386,
  [SMALL_STATE(918)] = 41399,
  [SMALL_STATE(919)] = 41412,
  [SMALL_STATE(920)] = 41425,
  [SMALL_STATE(921)] = 41434,
  [SMALL_STATE(922)] = 41447,
  [SMALL_STATE(923)] = 41456,
  [SMALL_STATE(924)] = 41469,
  [SMALL_STATE(925)] = 41482,
  [SMALL_STATE(926)] = 41495,
  [SMALL_STATE(927)] = 41508,
  [SMALL_STATE(928)] = 41521,
  [SMALL_STATE(929)] = 41534,
  [SMALL_STATE(930)] = 41547,
  [SMALL_STATE(931)] = 41560,
  [SMALL_STATE(932)] = 41573,
  [SMALL_STATE(933)] = 41586,
  [SMALL_STATE(934)] = 41599,
  [SMALL_STATE(935)] = 41612,
  [SMALL_STATE(936)] = 41625,
  [SMALL_STATE(937)] = 41638,
  [SMALL_STATE(938)] = 41651,
  [SMALL_STATE(939)] = 41662,
  [SMALL_STATE(940)] = 41675,
  [SMALL_STATE(941)] = 41688,
  [SMALL_STATE(942)] = 41701,
  [SMALL_STATE(943)] = 41714,
  [SMALL_STATE(944)] = 41727,
  [SMALL_STATE(945)] = 41740,
  [SMALL_STATE(946)] = 41753,
  [SMALL_STATE(947)] = 41766,
  [SMALL_STATE(948)] = 41779,
  [SMALL_STATE(949)] = 41788,
  [SMALL_STATE(950)] = 41801,
  [SMALL_STATE(951)] = 41814,
  [SMALL_STATE(952)] = 41827,
  [SMALL_STATE(953)] = 41840,
  [SMALL_STATE(954)] = 41853,
  [SMALL_STATE(955)] = 41866,
  [SMALL_STATE(956)] = 41879,
  [SMALL_STATE(957)] = 41888,
  [SMALL_STATE(958)] = 41901,
  [SMALL_STATE(959)] = 41914,
  [SMALL_STATE(960)] = 41927,
  [SMALL_STATE(961)] = 41936,
  [SMALL_STATE(962)] = 41949,
  [SMALL_STATE(963)] = 41958,
  [SMALL_STATE(964)] = 41967,
  [SMALL_STATE(965)] = 41980,
  [SMALL_STATE(966)] = 41991,
  [SMALL_STATE(967)] = 42002,
  [SMALL_STATE(968)] = 42011,
  [SMALL_STATE(969)] = 42024,
  [SMALL_STATE(970)] = 42037,
  [SMALL_STATE(971)] = 42046,
  [SMALL_STATE(972)] = 42057,
  [SMALL_STATE(973)] = 42070,
  [SMALL_STATE(974)] = 42078,
  [SMALL_STATE(975)] = 42086,
  [SMALL_STATE(976)] = 42094,
  [SMALL_STATE(977)] = 42104,
  [SMALL_STATE(978)] = 42112,
  [SMALL_STATE(979)] = 42120,
  [SMALL_STATE(980)] = 42128,
  [SMALL_STATE(981)] = 42136,
  [SMALL_STATE(982)] = 42144,
  [SMALL_STATE(983)] = 42152,
  [SMALL_STATE(984)] = 42160,
  [SMALL_STATE(985)] = 42170,
  [SMALL_STATE(986)] = 42180,
  [SMALL_STATE(987)] = 42190,
  [SMALL_STATE(988)] = 42200,
  [SMALL_STATE(989)] = 42210,
  [SMALL_STATE(990)] = 42218,
  [SMALL_STATE(991)] = 42226,
  [SMALL_STATE(992)] = 42234,
  [SMALL_STATE(993)] = 42242,
  [SMALL_STATE(994)] = 42250,
  [SMALL_STATE(995)] = 42258,
  [SMALL_STATE(996)] = 42266,
  [SMALL_STATE(997)] = 42276,
  [SMALL_STATE(998)] = 42284,
  [SMALL_STATE(999)] = 42294,
  [SMALL_STATE(1000)] = 42302,
  [SMALL_STATE(1001)] = 42310,
  [SMALL_STATE(1002)] = 42318,
  [SMALL_STATE(1003)] = 42326,
  [SMALL_STATE(1004)] = 42334,
  [SMALL_STATE(1005)] = 42342,
  [SMALL_STATE(1006)] = 42350,
  [SMALL_STATE(1007)] = 42358,
  [SMALL_STATE(1008)] = 42366,
  [SMALL_STATE(1009)] = 42374,
  [SMALL_STATE(1010)] = 42382,
  [SMALL_STATE(1011)] = 42390,
  [SMALL_STATE(1012)] = 42398,
  [SMALL_STATE(1013)] = 42406,
  [SMALL_STATE(1014)] = 42413,
  [SMALL_STATE(1015)] = 42420,
  [SMALL_STATE(1016)] = 42427,
  [SMALL_STATE(1017)] = 42434,
  [SMALL_STATE(1018)] = 42441,
  [SMALL_STATE(1019)] = 42448,
  [SMALL_STATE(1020)] = 42455,
  [SMALL_STATE(1021)] = 42462,
  [SMALL_STATE(1022)] = 42469,
  [SMALL_STATE(1023)] = 42476,
  [SMALL_STATE(1024)] = 42483,
  [SMALL_STATE(1025)] = 42490,
  [SMALL_STATE(1026)] = 42497,
  [SMALL_STATE(1027)] = 42504,
  [SMALL_STATE(1028)] = 42511,
  [SMALL_STATE(1029)] = 42518,
  [SMALL_STATE(1030)] = 42525,
  [SMALL_STATE(1031)] = 42532,
  [SMALL_STATE(1032)] = 42539,
  [SMALL_STATE(1033)] = 42546,
  [SMALL_STATE(1034)] = 42553,
  [SMALL_STATE(1035)] = 42560,
  [SMALL_STATE(1036)] = 42567,
  [SMALL_STATE(1037)] = 42574,
  [SMALL_STATE(1038)] = 42581,
  [SMALL_STATE(1039)] = 42588,
  [SMALL_STATE(1040)] = 42595,
  [SMALL_STATE(1041)] = 42602,
  [SMALL_STATE(1042)] = 42609,
  [SMALL_STATE(1043)] = 42616,
  [SMALL_STATE(1044)] = 42623,
  [SMALL_STATE(1045)] = 42630,
  [SMALL_STATE(1046)] = 42637,
  [SMALL_STATE(1047)] = 42644,
  [SMALL_STATE(1048)] = 42651,
  [SMALL_STATE(1049)] = 42658,
  [SMALL_STATE(1050)] = 42665,
  [SMALL_STATE(1051)] = 42672,
  [SMALL_STATE(1052)] = 42679,
  [SMALL_STATE(1053)] = 42686,
  [SMALL_STATE(1054)] = 42693,
  [SMALL_STATE(1055)] = 42700,
  [SMALL_STATE(1056)] = 42707,
  [SMALL_STATE(1057)] = 42714,
  [SMALL_STATE(1058)] = 42721,
  [SMALL_STATE(1059)] = 42728,
  [SMALL_STATE(1060)] = 42735,
  [SMALL_STATE(1061)] = 42742,
  [SMALL_STATE(1062)] = 42749,
  [SMALL_STATE(1063)] = 42756,
  [SMALL_STATE(1064)] = 42763,
  [SMALL_STATE(1065)] = 42770,
  [SMALL_STATE(1066)] = 42777,
  [SMALL_STATE(1067)] = 42784,
  [SMALL_STATE(1068)] = 42791,
  [SMALL_STATE(1069)] = 42798,
  [SMALL_STATE(1070)] = 42805,
  [SMALL_STATE(1071)] = 42812,
  [SMALL_STATE(1072)] = 42819,
  [SMALL_STATE(1073)] = 42826,
  [SMALL_STATE(1074)] = 42833,
  [SMALL_STATE(1075)] = 42840,
  [SMALL_STATE(1076)] = 42847,
  [SMALL_STATE(1077)] = 42854,
  [SMALL_STATE(1078)] = 42861,
  [SMALL_STATE(1079)] = 42868,
  [SMALL_STATE(1080)] = 42875,
  [SMALL_STATE(1081)] = 42882,
  [SMALL_STATE(1082)] = 42889,
  [SMALL_STATE(1083)] = 42896,
  [SMALL_STATE(1084)] = 42903,
  [SMALL_STATE(1085)] = 42910,
  [SMALL_STATE(1086)] = 42917,
  [SMALL_STATE(1087)] = 42924,
  [SMALL_STATE(1088)] = 42931,
  [SMALL_STATE(1089)] = 42938,
  [SMALL_STATE(1090)] = 42945,
  [SMALL_STATE(1091)] = 42952,
  [SMALL_STATE(1092)] = 42959,
  [SMALL_STATE(1093)] = 42966,
  [SMALL_STATE(1094)] = 42973,
  [SMALL_STATE(1095)] = 42980,
  [SMALL_STATE(1096)] = 42987,
  [SMALL_STATE(1097)] = 42994,
  [SMALL_STATE(1098)] = 43001,
  [SMALL_STATE(1099)] = 43008,
  [SMALL_STATE(1100)] = 43015,
  [SMALL_STATE(1101)] = 43022,
  [SMALL_STATE(1102)] = 43029,
  [SMALL_STATE(1103)] = 43036,
  [SMALL_STATE(1104)] = 43043,
  [SMALL_STATE(1105)] = 43050,
  [SMALL_STATE(1106)] = 43057,
  [SMALL_STATE(1107)] = 43064,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(196),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(837),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(46),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(264),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(194),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(254),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(169),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(980),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(981),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(983),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(270),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(161),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(440),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(271),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1095),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(227),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1094),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1093),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1092),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1089),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(274),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(670),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(605),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(47),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(282),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(159),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(439),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(277),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1086),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(220),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1099),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1088),
  [93] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [95] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [97] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [99] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module, 1),
  [105] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(196),
  [108] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(837),
  [111] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(781),
  [114] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(103),
  [117] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(582),
  [120] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(46),
  [123] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(264),
  [126] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(194),
  [129] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(254),
  [132] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(169),
  [135] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(980),
  [138] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(981),
  [141] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(983),
  [144] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(282),
  [147] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(159),
  [150] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(439),
  [153] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(277),
  [156] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(1086),
  [159] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(220),
  [162] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(1099),
  [165] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(1093),
  [168] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(1092),
  [171] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(168),
  [174] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(1088),
  [177] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(529),
  [180] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(102),
  [183] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(274),
  [186] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(560),
  [189] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(670),
  [192] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(163),
  [195] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(605),
  [198] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(111),
  [201] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(605),
  [204] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(47),
  [207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2),
  [209] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(703),
  [212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [214] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(270),
  [217] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(161),
  [220] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(440),
  [223] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(271),
  [226] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(1095),
  [229] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(227),
  [232] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(1094),
  [235] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(1089),
  [238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(522),
  [240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_expression, 1, .production_id = 1),
  [242] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primary_expression, 1, .production_id = 1),
  [244] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_pattern, 1, .production_id = 1), REDUCE(sym_primary_expression, 1, .production_id = 1),
  [247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(592),
  [249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(310),
  [251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern, 1, .production_id = 1),
  [253] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern, 1, .production_id = 1),
  [255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(95),
  [257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(560),
  [263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(222),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(495),
  [431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(494),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(324),
  [439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(671),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(454),
  [449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(93),
  [451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(490),
  [455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(496),
  [459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(265),
  [463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(674),
  [467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(94),
  [469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(314),
  [471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(589),
  [473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(302),
  [479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(669),
  [483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(639),
  [489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(97),
  [491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [493] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, .production_id = 1), REDUCE(sym_list_splat_pattern, 2, .production_id = 4),
  [496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(584),
  [498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(591),
  [504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(155),
  [510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(98),
  [512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(565),
  [524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(582),
  [528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(572),
  [530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_list, 2),
  [532] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_list, 2),
  [534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(574),
  [538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(331),
  [544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_list, 3),
  [558] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_list, 3),
  [560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 4, .production_id = 44),
  [562] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 4, .production_id = 44),
  [564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [566] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__collection_elements, 3),
  [568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 5, .production_id = 61),
  [574] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 5, .production_id = 61),
  [576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 6, .production_id = 61),
  [578] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 6, .production_id = 61),
  [580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(534),
  [582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(613),
  [588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(96),
  [590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(626),
  [596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(99),
  [598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 5, .production_id = 44),
  [604] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 5, .production_id = 44),
  [606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 3, .production_id = 22),
  [608] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute, 3, .production_id = 22),
  [610] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__collection_elements, 2),
  [612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [618] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 6, .production_id = 79),
  [620] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_in_clause, 6, .production_id = 79),
  [622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(672),
  [624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(628),
  [646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 5, .production_id = 65),
  [654] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_in_clause, 5, .production_id = 65),
  [656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 6, .production_id = 78),
  [658] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_in_clause, 6, .production_id = 78),
  [660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 7, .production_id = 87),
  [662] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_in_clause, 7, .production_id = 87),
  [664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yield, 1),
  [668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_list, 2),
  [670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_list, 3),
  [678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 4, .production_id = 37),
  [686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 4, .production_id = 37),
  [688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1071),
  [690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(255),
  [692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1070),
  [694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(329),
  [696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1039),
  [698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(257),
  [700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1090),
  [702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 5, .production_id = 53),
  [704] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 5, .production_id = 53),
  [706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [712] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raise_statement, 1),
  [714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(325),
  [716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice, 2),
  [734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice, 1),
  [742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [752] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_list, 2),
  [754] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_list, 3),
  [756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 1),
  [758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_expression, 1),
  [760] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_pattern, 1), REDUCE(sym_primary_expression, 1),
  [763] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primary_expression, 1),
  [765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [767] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern, 1),
  [769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern, 1),
  [771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, .production_id = 69),
  [773] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, .production_id = 69),
  [775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(319),
  [777] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, .production_id = 35),
  [779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, .production_id = 35),
  [781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(267),
  [783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 3),
  [785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 2),
  [787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 3, .production_id = 5),
  [789] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, .production_id = 48),
  [791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, .production_id = 48),
  [793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, .production_id = 49),
  [795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, .production_id = 49),
  [797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 4, .production_id = 15),
  [799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_try_statement_repeat1, 2),
  [801] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 2),
  [803] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 2), SHIFT_REPEAT(257),
  [806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 4, .production_id = 14),
  [808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple, 2),
  [810] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_tuple_pattern, 2), REDUCE(sym_tuple, 2),
  [813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple, 2),
  [815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 2),
  [817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_pattern, 2),
  [819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 2),
  [821] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_list_pattern, 2), REDUCE(sym_list, 2),
  [824] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 2),
  [826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 2),
  [828] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_pattern, 2),
  [830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 3),
  [832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice, 3),
  [836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice, 4),
  [838] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 2), SHIFT_REPEAT(255),
  [841] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2),
  [843] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2),
  [845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 1),
  [847] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 1),
  [849] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_statements, 2),
  [851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_statements, 2),
  [853] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 2, .production_id = 67),
  [855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, .production_id = 67),
  [857] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 2, .production_id = 67), SHIFT_REPEAT(267),
  [860] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_statements, 4),
  [862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_statements, 4),
  [864] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_statements, 3),
  [866] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_statements, 3),
  [868] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 2, .production_id = 67), SHIFT_REPEAT(319),
  [871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_clause, 5),
  [877] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_clause, 5),
  [879] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_clause, 3, .production_id = 74),
  [881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_clause, 3, .production_id = 74),
  [883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_clause, 6, .production_id = 95),
  [885] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_clause, 6, .production_id = 95),
  [887] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_clause, 7),
  [889] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_clause, 7),
  [891] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_clause, 4),
  [893] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_clause, 4),
  [895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_clause, 4, .production_id = 85),
  [897] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_clause, 4, .production_id = 85),
  [899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(624),
  [901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(647),
  [903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(100),
  [905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elif_clause, 5, .production_id = 49),
  [907] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elif_clause, 5, .production_id = 49),
  [909] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6, .production_id = 72),
  [911] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, .production_id = 72),
  [913] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 89),
  [915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 89),
  [917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 5, .production_id = 52),
  [919] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, .production_id = 52),
  [921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elif_clause, 4, .production_id = 35),
  [923] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elif_clause, 4, .production_id = 35),
  [925] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 6, .production_id = 53),
  [927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 6, .production_id = 53),
  [929] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 4, .production_id = 36),
  [931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 4, .production_id = 36),
  [933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 5, .production_id = 37),
  [935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 5, .production_id = 37),
  [937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 1, .production_id = 46),
  [939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 1, .production_id = 46),
  [941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 81),
  [943] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 81),
  [945] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 84),
  [947] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 84),
  [949] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 4, .production_id = 53),
  [951] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 4, .production_id = 53),
  [953] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 3, .production_id = 37),
  [955] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 3, .production_id = 37),
  [957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_concatenated_string, 2),
  [959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_concatenated_string, 2),
  [961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2),
  [963] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2),
  [965] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2), SHIFT_REPEAT(708),
  [968] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_finally_clause, 3, .production_id = 74),
  [970] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_finally_clause, 3, .production_id = 74),
  [972] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, .production_id = 94),
  [974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, .production_id = 94),
  [976] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 91),
  [978] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 91),
  [980] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, .production_id = 76),
  [982] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 6, .production_id = 76),
  [984] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, .production_id = 75),
  [986] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, .production_id = 75),
  [988] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 4, .production_id = 40),
  [990] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 4, .production_id = 40),
  [992] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorated_definition, 2, .production_id = 12),
  [994] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decorated_definition, 2, .production_id = 12),
  [996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_statement, 6, .production_id = 70),
  [998] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_statement, 6, .production_id = 70),
  [1000] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 6, .production_id = 37),
  [1002] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 6, .production_id = 37),
  [1004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, .production_id = 82),
  [1006] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, .production_id = 82),
  [1008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, .production_id = 80),
  [1010] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, .production_id = 80),
  [1012] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 6, .production_id = 73),
  [1014] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 6, .production_id = 73),
  [1016] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, .production_id = 71),
  [1018] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, .production_id = 71),
  [1020] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, .production_id = 92),
  [1022] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, .production_id = 92),
  [1024] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_statement, 4, .production_id = 38),
  [1026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_statement, 4, .production_id = 38),
  [1028] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 83),
  [1030] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 83),
  [1032] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, .production_id = 68),
  [1034] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, .production_id = 68),
  [1036] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, .production_id = 93),
  [1038] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, .production_id = 93),
  [1040] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, .production_id = 90),
  [1042] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, .production_id = 90),
  [1044] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 88),
  [1046] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 88),
  [1048] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_finally_clause, 4),
  [1050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_finally_clause, 4),
  [1052] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 7, .production_id = 53),
  [1054] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 7, .production_id = 53),
  [1056] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, .production_id = 66),
  [1058] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, .production_id = 66),
  [1060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 5, .production_id = 57),
  [1062] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, .production_id = 57),
  [1064] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, .production_id = 86),
  [1066] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, .production_id = 86),
  [1068] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 5, .production_id = 56),
  [1070] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, .production_id = 56),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [1074] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, .production_id = 47),
  [1076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, .production_id = 47),
  [1078] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, .production_id = 55),
  [1080] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, .production_id = 55),
  [1082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_statement, 5, .production_id = 54),
  [1084] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_statement, 5, .production_id = 54),
  [1086] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_statement, 5, .production_id = 50),
  [1088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_statement, 5, .production_id = 50),
  [1090] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__patterns, 3),
  [1092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__patterns, 2),
  [1094] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, .production_id = 51),
  [1096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 5, .production_id = 51),
  [1098] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3),
  [1100] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3),
  [1102] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2),
  [1104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2),
  [1106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3),
  [1108] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3),
  [1110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set, 3),
  [1112] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_set, 3),
  [1114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [1116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [1118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1),
  [1120] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1),
  [1122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(553),
  [1124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [1126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [1128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [1130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [1132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [1134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [1136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [1138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [1140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [1142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [1144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(544),
  [1146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [1148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(527),
  [1150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [1152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [1154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [1156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [1158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [1160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [1162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [1164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [1166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [1168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(531),
  [1170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [1172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary, 5),
  [1174] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionary, 5),
  [1176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4),
  [1178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4),
  [1180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4, .production_id = 31),
  [1182] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4, .production_id = 31),
  [1184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary, 2),
  [1186] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionary, 2),
  [1188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3),
  [1190] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3),
  [1192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 3),
  [1194] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 3),
  [1196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generator_expression, 4, .production_id = 32),
  [1198] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generator_expression, 4, .production_id = 32),
  [1200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call, 2, .production_id = 10),
  [1202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call, 2, .production_id = 10),
  [1204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 5, .production_id = 31),
  [1206] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 5, .production_id = 31),
  [1208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 5),
  [1210] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 5),
  [1212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple, 3),
  [1214] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple, 3),
  [1216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary, 3),
  [1218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionary, 3),
  [1220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3, .production_id = 31),
  [1222] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3, .production_id = 31),
  [1224] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 2),
  [1226] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 2),
  [1228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary_comprehension, 4, .production_id = 32),
  [1230] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionary_comprehension, 4, .production_id = 32),
  [1232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_comprehension, 4, .production_id = 32),
  [1234] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_set_comprehension, 4, .production_id = 32),
  [1236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary, 4),
  [1238] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionary, 4),
  [1240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_comprehension, 4, .production_id = 32),
  [1242] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_comprehension, 4, .production_id = 32),
  [1244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operator, 3, .production_id = 21),
  [1246] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operator, 3, .production_id = 21),
  [1248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 3, .production_id = 45),
  [1250] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 3, .production_id = 45),
  [1252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_operator, 2, .production_id = 8),
  [1254] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_operator, 2, .production_id = 8),
  [1256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 23),
  [1258] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 23),
  [1260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [1262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(573),
  [1264] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 1, .production_id = 9),
  [1266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(568),
  [1268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [1270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [1272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [1274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(541),
  [1276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [1278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [1280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [1282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [1284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [1286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [1288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [1290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [1292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [1294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [1296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(580),
  [1298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [1300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2), SHIFT_REPEAT(703),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [1305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [1307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(546),
  [1309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [1315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [1317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [1319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [1329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(548),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [1333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(542),
  [1335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(571),
  [1337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2), SHIFT_REPEAT(702),
  [1340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(526),
  [1342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(558),
  [1344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(315),
  [1346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_splat_pattern, 2, .production_id = 4),
  [1348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_splat_pattern, 2),
  [1350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(655),
  [1352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(658),
  [1354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [1356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1), REDUCE(sym_list_splat_pattern, 2),
  [1359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comparison_operator, 2, .production_id = 11),
  [1361] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comparison_operator, 2, .production_id = 11),
  [1363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24),
  [1365] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(531),
  [1368] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24),
  [1370] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(1016),
  [1373] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(531),
  [1376] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(507),
  [1379] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(544),
  [1382] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(1057),
  [1385] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(544),
  [1388] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(512),
  [1391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__patterns_repeat1, 2),
  [1393] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__patterns_repeat1, 2), SHIFT_REPEAT(464),
  [1396] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(580),
  [1399] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(1052),
  [1402] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(580),
  [1405] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(519),
  [1408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary_splat_pattern, 2),
  [1410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 3),
  [1412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary_splat_pattern, 2, .production_id = 4),
  [1414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 3),
  [1416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(857),
  [1418] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(548),
  [1421] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(1049),
  [1424] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(548),
  [1427] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24), SHIFT_REPEAT(520),
  [1430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [1432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [1434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [1438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [1440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [1442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [1444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(493),
  [1446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [1448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [1450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [1452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [1454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [1456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_await, 2),
  [1458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_await, 2),
  [1460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [1462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_operator, 3, .production_id = 21),
  [1464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_operator, 3, .production_id = 21),
  [1466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [1468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [1470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameters, 3),
  [1472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameters, 2),
  [1474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_not_operator, 2, .production_id = 5),
  [1476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [1478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [1480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [1482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [1484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [1486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [1488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [1490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [1492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [1494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__collection_elements, 1),
  [1496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_named_expression, 3, .production_id = 18),
  [1498] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_named_expression, 3, .production_id = 18),
  [1500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 4, .production_id = 42),
  [1502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 4, .production_id = 42),
  [1504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 3, .production_id = 17),
  [1506] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 3, .production_id = 17),
  [1508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [1510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_expression, 5),
  [1512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [1514] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_with_item, 1, .dynamic_precedence = -1, .production_id = 6), SHIFT(127),
  [1517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(463),
  [1519] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_not_operator, 2, .production_id = 5),
  [1521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional_expression, 5),
  [1523] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(297),
  [1526] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(701),
  [1529] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [1531] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(701),
  [1534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2),
  [1536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(297),
  [1538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(710),
  [1540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [1542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [1544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(705),
  [1546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [1548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [1550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(717),
  [1552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [1554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [1556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(701),
  [1558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [1560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [1562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [1564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(707),
  [1566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [1568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [1570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [1572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [1574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [1576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [1578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [1580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [1582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [1584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [1586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [1588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [1590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression_within_for_in_clause, 1),
  [1592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__comprehension_clauses, 1),
  [1594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [1596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__comprehension_clauses_repeat1, 2),
  [1598] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__comprehension_clauses_repeat1, 2), SHIFT_REPEAT(330),
  [1601] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__comprehension_clauses_repeat1, 2), SHIFT_REPEAT(1066),
  [1604] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__comprehension_clauses_repeat1, 2), SHIFT_REPEAT(441),
  [1607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__comprehension_clauses, 2),
  [1609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_clause, 2),
  [1611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [1613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [1615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [1617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 4, .production_id = 65),
  [1619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [1621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [1623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [1625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [1627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [1629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [1631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [1633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 5, .production_id = 78),
  [1635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [1637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 5, .production_id = 79),
  [1639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [1641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 6, .production_id = 87),
  [1643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [1645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yield, 2),
  [1647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [1649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_for_in_clause_repeat1, 2),
  [1651] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_in_clause_repeat1, 2), SHIFT_REPEAT(231),
  [1654] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raise_statement, 2),
  [1656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [1658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [1660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_assert_statement_repeat1, 2),
  [1662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_splat, 2),
  [1664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1),
  [1666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [1668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [1670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [1672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [1674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [1676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [1678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 2),
  [1680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_item, 1, .dynamic_precedence = -1, .production_id = 6),
  [1682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [1684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exec_statement, 4, .production_id = 7),
  [1686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [1688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yield, 3),
  [1690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_within_for_in_clause, 3, .production_id = 17),
  [1692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2),
  [1694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__right_hand_side, 1),
  [1696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assert_statement, 2),
  [1698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pair, 3, .production_id = 43),
  [1700] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__collection_elements_repeat1, 2),
  [1702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [1704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(646),
  [1706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [1708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [1710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 2, .production_id = 5),
  [1712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [1714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_within_for_in_clause, 4, .production_id = 42),
  [1716] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolation, 4),
  [1718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 4),
  [1720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolation, 3),
  [1722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 3),
  [1724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [1726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [1728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [1730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [1732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [1734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [1736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [1738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [1740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [1742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [1744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [1746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [1748] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 1),
  [1750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [1752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(798),
  [1754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [1756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1042),
  [1758] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolation, 5),
  [1760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 5),
  [1762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [1764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dotted_name_repeat1, 2),
  [1766] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dotted_name_repeat1, 2), SHIFT_REPEAT(1050),
  [1769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chevron, 2),
  [1771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dotted_name, 1),
  [1773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [1775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [1777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [1779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_default_parameter, 5, .production_id = 77),
  [1781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [1783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary_splat, 2),
  [1785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subscript_repeat1, 2, .production_id = 60),
  [1787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_decorated_definition_repeat1, 2),
  [1789] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_decorated_definition_repeat1, 2), SHIFT_REPEAT(529),
  [1792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [1794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [1796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dotted_name, 2),
  [1798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [1800] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dotted_name_repeat1, 2), SHIFT_REPEAT(1019),
  [1803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [1805] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_parameter, 3, .production_id = 18),
  [1807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [1809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_print_statement_repeat1, 2, .production_id = 5),
  [1811] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assert_statement_repeat1, 2), SHIFT_REPEAT(320),
  [1814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [1816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [1818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [1820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [1822] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_format_specifier_repeat1, 2), SHIFT_REPEAT(326),
  [1825] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_format_specifier_repeat1, 2),
  [1827] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_format_specifier_repeat1, 2), SHIFT_REPEAT(809),
  [1830] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__collection_elements_repeat1, 2), SHIFT_REPEAT(158),
  [1833] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raise_statement, 4, .production_id = 34),
  [1835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice, 5),
  [1837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [1839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [1841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [1843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [1845] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assert_statement_repeat1, 2), SHIFT_REPEAT(318),
  [1848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(326),
  [1850] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_specifier, 2),
  [1852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [1854] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_keyword_argument, 3, .production_id = 18),
  [1856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__import_list, 2, .production_id = 3),
  [1858] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__import_list, 3, .production_id = 13),
  [1860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raise_statement, 3, .production_id = 16),
  [1862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2),
  [1864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [1866] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_specifier, 1),
  [1868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [1870] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__import_list, 1, .production_id = 3),
  [1872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [1874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [1876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_keyword_argument, 3, .production_id = 59),
  [1878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [1880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exec_statement, 5, .production_id = 7),
  [1882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [1884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [1886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [1888] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__import_list, 2, .production_id = 13),
  [1890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [1892] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_prefix, 1),
  [1894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [1896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__patterns, 1),
  [1898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [1900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [1902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [1904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [1906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [1908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [1910] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 2),
  [1912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [1914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [1916] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_import_prefix_repeat1, 2),
  [1918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_import_prefix_repeat1, 2), SHIFT_REPEAT(855),
  [1921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_parameter, 3, .production_id = 41),
  [1923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [1925] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorator, 3),
  [1927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_global_statement_repeat1, 2),
  [1929] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_global_statement_repeat1, 2), SHIFT_REPEAT(1074),
  [1932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_nonlocal_statement, 3),
  [1934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [1936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_statement, 3),
  [1938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_with_clause_repeat1, 2),
  [1940] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_with_clause_repeat1, 2), SHIFT_REPEAT(245),
  [1943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [1945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [1947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [1949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [1953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [1955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_print_statement_repeat1, 2, .production_id = 33),
  [1957] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_print_statement_repeat1, 2, .production_id = 33), SHIFT_REPEAT(321),
  [1960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_nonlocal_statement, 2),
  [1962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_list_splat, 3),
  [1964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [1966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_list_splat, 3, .production_id = 31),
  [1968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [1970] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__import_list_repeat1, 2, .production_id = 25),
  [1972] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__import_list_repeat1, 2, .production_id = 26),
  [1974] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__import_list_repeat1, 2, .production_id = 26), SHIFT_REPEAT(929),
  [1977] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assert_statement, 3),
  [1979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 3, .production_id = 15),
  [1981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [1983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 3, .production_id = 14),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [1987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [1989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [1991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_statement, 2),
  [1993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 1),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [2001] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 1),
  [2003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [2005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [2007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [2009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [2011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [2013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [2017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [2023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 2),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [2027] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_expression, 3),
  [2029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_expression, 3),
  [2031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [2033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameters, 1),
  [2035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [2037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [2039] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__import_list_repeat1, 2, .production_id = 26), SHIFT_REPEAT(914),
  [2042] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subscript_repeat1, 2, .production_id = 62), SHIFT_REPEAT(228),
  [2045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subscript_repeat1, 2, .production_id = 62),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [2049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [2051] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2), SHIFT_REPEAT(156),
  [2054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [2056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [2058] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_relative_import, 1),
  [2060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [2062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [2064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [2066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [2068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [2070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [2072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [2074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [2076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [2078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(678),
  [2080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [2082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [2084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [2086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [2088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [2090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [2092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [2094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [2096] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__simple_statements_repeat1, 2), SHIFT_REPEAT(92),
  [2099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__simple_statements_repeat1, 2),
  [2101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment, 3, .production_id = 19),
  [2103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [2107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [2109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [2111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [2113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dictionary_repeat1, 2), SHIFT_REPEAT(197),
  [2116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dictionary_repeat1, 2),
  [2118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [2120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [2122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__parameters_repeat1, 2),
  [2124] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__parameters_repeat1, 2), SHIFT_REPEAT(686),
  [2127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [2129] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__parameters_repeat1, 2), SHIFT_REPEAT(699),
  [2132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [2134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [2136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [2138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [2140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [2142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [2144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [2146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [2148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [2150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_aliased_import, 3, .production_id = 27),
  [2152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [2154] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_item, 3, .dynamic_precedence = -1, .production_id = 39),
  [2156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [2158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exec_statement, 2, .production_id = 7),
  [2160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [2162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [2164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [2166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [2168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_augmented_assignment, 3, .production_id = 21),
  [2170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_wildcard_import, 1),
  [2172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [2174] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_from_statement, 4, .production_id = 29),
  [2176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pass_statement, 1),
  [2178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 1),
  [2180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_from_statement, 4, .production_id = 30),
  [2182] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 1),
  [2184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [2186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [2188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [2190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [2192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_from_statement, 6, .production_id = 64),
  [2194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 2),
  [2196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [2198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [2200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [2202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [2204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_future_import_statement, 6, .production_id = 63),
  [2206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, .production_id = 31),
  [2208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment, 5, .production_id = 58),
  [2210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 2, .production_id = 2),
  [2212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 3),
  [2214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_future_import_statement, 4, .production_id = 28),
  [2216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment, 3, .production_id = 20),
  [2218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [2220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [2222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [2224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [2226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [2228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [2230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [2232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [2234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [2236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [2238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [2240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [2242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [2244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [2246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [2248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [2250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [2252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [2254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [2256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [2258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relative_import, 2),
  [2260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [2262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [2264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [2266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [2268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [2270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 4),
  [2272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [2274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [2276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [2278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [2280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [2282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [2284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [2286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [2288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [2290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [2292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [2294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [2296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [2298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [2300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [2302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [2304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [2306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [2308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [2310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [2312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [2314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [2316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [2318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [2320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [2322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [2324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [2326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [2328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [2330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 3),
  [2332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [2334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [2336] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [2340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [2342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [2344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [2346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [2348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [2350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [2352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [2354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [2356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [2358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [2360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [2362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [2364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [2366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_parameters, 1),
  [2368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_python_external_scanner_create(void);
void tree_sitter_python_external_scanner_destroy(void *);
bool tree_sitter_python_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_python_external_scanner_serialize(void *, char *);
void tree_sitter_python_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef _WIN32
#define extern __declspec(dllexport)
#endif

extern const TSLanguage *tree_sitter_python(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_python_external_scanner_create,
      tree_sitter_python_external_scanner_destroy,
      tree_sitter_python_external_scanner_scan,
      tree_sitter_python_external_scanner_serialize,
      tree_sitter_python_external_scanner_deserialize,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
